'use client';

import React, { useImperativeHandle, useRef, useEffect } from 'react';
import { defineCustomElement } from './components/abc-flyout.js';
import { omitEventCallbacks, toNativeProps, useEventListeners } from './lib/utils.js';

const customEvents = ['flyoutChange'];
const AbcFlyout = React.forwardRef(({ children = [], ...props }, ref) => {
  const nativeProps = toNativeProps(omitEventCallbacks(customEvents, props));
  if (typeof window !== 'undefined') {
    const innerRef = useRef();
    useImperativeHandle(ref, () => innerRef.current);
    useEventListeners(innerRef, customEvents, props);
    useEffect(() => {
      if (typeof customElements !== 'undefined' && !customElements.get('abc-flyout')) {
        defineCustomElement();
      }
    }, []);

    return React.createElement('abc-flyout', { ...nativeProps, ref: innerRef }, children);
  }

  return React.createElement('abc-flyout', { ...nativeProps, ref }, children);
});

export { AbcFlyout };
