import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';

const accordionGroupCss = ":host{box-sizing:border-box;display:flex;flex-direction:column;gap:20px;padding:0}";

const isHTMLAbcAccordionItemElement = (element) => {
    if (typeof element === 'object' && typeof element.item === 'string') {
        return true;
    }
    return false;
};
const AccordionContainer = /*@__PURE__*/ proxyCustomElement(class AccordionContainer extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.accordionChange = createEvent(this, "accordionChange", 7);
        this.selectedAccordion = undefined;
    }
    onAccordionChange() {
        this.accordionChange.emit(this.selectedAccordion);
        if (typeof this.selectedAccordion === 'string') {
            const activeAccordion = this.getItems(this.selectedAccordion);
            this.accordions.forEach((accordion) => {
                if ((activeAccordion === null || activeAccordion === void 0 ? void 0 : activeAccordion.item) !== accordion.item) {
                    accordion.open = false;
                }
            });
        }
    }
    get accordions() {
        return Array.from(this.host.querySelectorAll('abc-accordion'));
    }
    getItems(accordion) {
        return isHTMLAbcAccordionItemElement(accordion) ? accordion : this.accordions.find((t) => t.item === accordion);
    }
    select(item) {
        if (this.selectedAccordion === item) {
            return false;
        }
        this.selectedAccordion = item;
        return true;
    }
    render() {
        return (h(Host, { onAccordionClick: ({ detail: { item, open } }) => {
                if (open) {
                    this.select(item);
                }
            } }, h("slot", { name: "accordions" })));
    }
    get host() { return this; }
    static get watchers() { return {
        "selectedAccordion": ["onAccordionChange"]
    }; }
    static get style() { return accordionGroupCss; }
}, [1, "abc-accordion-group", {
        "selectedAccordion": [513, "selected-accordion"]
    }, undefined, {
        "selectedAccordion": ["onAccordionChange"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["abc-accordion-group"];
    components.forEach(tagName => { switch (tagName) {
        case "abc-accordion-group":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, AccordionContainer);
            }
            break;
    } });
}

const AbcAccordionGroup = AccordionContainer;
const defineCustomElement = defineCustomElement$1;

export { AbcAccordionGroup, defineCustomElement };

//# sourceMappingURL=abc-accordion-group.js.map