import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { d as defineCustomElement$3 } from './dropdown-button.js';
import { d as defineCustomElement$2 } from './chevron-down.js';

const dropdownCss = ":host .dropdown__flyout{position:absolute;width:100%;max-height:0;overflow:hidden;transition:0.3s ease-in-out}:host .dropdown__information-wrapper{display:flex;flex-direction:row;justify-content:space-between;font:14px Arial, sans-serif;position:relative}:host .dropdown__hint{color:#777}:host .dropdown.focused{border-radius:4px;color:#007bff;outline-color:#007bff;outline-style:solid;outline-width:2px;outline-offset:2px}:host .dropdown:focus-within :host .dropdown__information-wrapper :host .dropdown__hint,:host .dropdown:focus-within :host .dropdown__information-wrapper :host .dropdown__error-message{color:#007bff}:host([open]) .dropdown__flyout{max-height:100vh;box-shadow:0 2px 4px rgba(0, 0, 0, 0.1);transition:0.3s ease-in-out}";

const isHTMLAbcFlyoutItemElement = (element) => {
    if (typeof element === 'object' && typeof element.item === 'string') {
        return true;
    }
    return false;
};
const Dropdown = /*@__PURE__*/ proxyCustomElement(class Dropdown extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.dropdownChange = createEvent(this, "dropdownChange", 7);
        this.selectedItem = undefined;
        this.disabled = false;
        this.required = false;
        this.label = undefined;
        this.text = undefined;
        this.hint = undefined;
        this.error = undefined;
        this.open = false;
        this.focused = false;
        this.keyboardEvent = false;
    }
    handleClick() {
        this.keyboardEvent = false;
    }
    handleKeyDown() {
        this.keyboardEvent = true;
    }
    onButtonBlur() {
        this.focused = false;
    }
    onButtonFocus() {
        this.keyboardEvent && (this.focused = true);
    }
    onButtonClick() {
        this.open = !this.open;
    }
    onDropdownChange() {
        this.dropdownChange.emit(this.selectedItem);
    }
    select(item) {
        if (this.selectedItem === item) {
            return false;
        }
        this.selectedItem = item;
        return true;
    }
    get items() {
        return Array.from(this.host.querySelectorAll('abc-flyout-item'));
    }
    getItems(item) {
        return isHTMLAbcFlyoutItemElement(item) ? item : this.items.find((t) => t.item === item);
    }
    componentWillUpdate() {
        const selectedItem = this.getItems(this.selectedItem);
        if (selectedItem) {
            selectedItem.selected = true;
        }
    }
    render() {
        var _a;
        const itemLabel = (_a = this.getItems(this.selectedItem)) === null || _a === void 0 ? void 0 : _a.label;
        return (h(Host, { onItemClick: ({ detail: { item } }) => {
                this.select(item);
            } }, h("abc-dropdown-button", { disabled: this.disabled, required: this.required, label: this.label, placeholder: typeof itemLabel === 'string', open: this.open, text: itemLabel || this.text }, h("div", { class: "dropdown__information-wrapper" }, h("div", null, this.hint && (typeof this.error === 'undefined' || this.error === '') && (h("span", { class: "dropdown__hint" }, this.hint)), this.error && h("abc-error-hint", { text: this.error })), h("div", { class: "dropdown__flyout", "aria-haspopup": "true", "aria-expanded": this.open ? 'true' : 'false' }, h("slot", null))))));
    }
    get host() { return this; }
    static get watchers() { return {
        "selectedItem": ["onDropdownChange"]
    }; }
    static get style() { return dropdownCss; }
}, [1, "abc-dropdown", {
        "selectedItem": [513, "selected-item"],
        "disabled": [4],
        "required": [4],
        "label": [1],
        "text": [1],
        "hint": [1],
        "error": [1],
        "open": [516],
        "focused": [32],
        "keyboardEvent": [32]
    }, [[10, "click", "handleClick"], [10, "keydown", "handleKeyDown"], [2, "dropdownButtonBlur", "onButtonBlur"], [2, "dropdownButtonFocus", "onButtonFocus"], [2, "dropdownButtonClick", "onButtonClick"]], {
        "selectedItem": ["onDropdownChange"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["abc-dropdown", "abc-dropdown-button", "abc-icon-chevron-down"];
    components.forEach(tagName => { switch (tagName) {
        case "abc-dropdown":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, Dropdown);
            }
            break;
        case "abc-dropdown-button":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "abc-icon-chevron-down":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}

const AbcDropdown = Dropdown;
const defineCustomElement = defineCustomElement$1;

export { AbcDropdown, defineCustomElement };

//# sourceMappingURL=abc-dropdown.js.map