"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*!
 Stencil Mock Doc v4.8.1-dev.1701854869.b1cf522 | MIT Licensed | https://stenciljs.com
 */
const CONTENT_REF_ID = "r";
const ORG_LOCATION_ID = "o";
const SLOT_NODE_ID = "s";
const TEXT_NODE_ID = "t";
const XLINK_NS = "http://www.w3.org/1999/xlink";
const attrHandler = {
  get(obj, prop) {
    if (prop in obj) {
      return obj[prop];
    }
    if (typeof prop !== "symbol" && !isNaN(prop)) {
      return obj.__items[prop];
    }
    return void 0;
  }
};
const createAttributeProxy = (caseInsensitive) => new Proxy(new MockAttributeMap(caseInsensitive), attrHandler);
class MockAttributeMap {
  constructor(caseInsensitive = false) {
    this.caseInsensitive = caseInsensitive;
    this.__items = [];
  }
  get length() {
    return this.__items.length;
  }
  item(index) {
    return this.__items[index] || null;
  }
  setNamedItem(attr) {
    attr.namespaceURI = null;
    this.setNamedItemNS(attr);
  }
  setNamedItemNS(attr) {
    if (attr != null && attr.value != null) {
      attr.value = String(attr.value);
    }
    const existingAttr = this.__items.find((a) => a.name === attr.name && a.namespaceURI === attr.namespaceURI);
    if (existingAttr != null) {
      existingAttr.value = attr.value;
    } else {
      this.__items.push(attr);
    }
  }
  getNamedItem(attrName) {
    if (this.caseInsensitive) {
      attrName = attrName.toLowerCase();
    }
    return this.getNamedItemNS(null, attrName);
  }
  getNamedItemNS(namespaceURI, attrName) {
    namespaceURI = getNamespaceURI(namespaceURI);
    return this.__items.find((attr) => attr.name === attrName && getNamespaceURI(attr.namespaceURI) === namespaceURI) || null;
  }
  removeNamedItem(attr) {
    this.removeNamedItemNS(attr);
  }
  removeNamedItemNS(attr) {
    for (let i = 0, ii = this.__items.length; i < ii; i++) {
      if (this.__items[i].name === attr.name && this.__items[i].namespaceURI === attr.namespaceURI) {
        this.__items.splice(i, 1);
        break;
      }
    }
  }
  [Symbol.iterator]() {
    let i = 0;
    return {
      next: () => ({
        done: i === this.length,
        value: this.item(i++)
      })
    };
  }
  get [Symbol.toStringTag]() {
    return "MockAttributeMap";
  }
}
function getNamespaceURI(namespaceURI) {
  return namespaceURI === XLINK_NS ? null : namespaceURI;
}
function cloneAttributes(srcAttrs, sortByName = false) {
  const dstAttrs = new MockAttributeMap(srcAttrs.caseInsensitive);
  if (srcAttrs != null) {
    const attrLen = srcAttrs.length;
    if (sortByName && attrLen > 1) {
      const sortedAttrs = [];
      for (let i = 0; i < attrLen; i++) {
        const srcAttr = srcAttrs.item(i);
        const dstAttr = new MockAttr(srcAttr.name, srcAttr.value, srcAttr.namespaceURI);
        sortedAttrs.push(dstAttr);
      }
      sortedAttrs.sort(sortAttributes).forEach((attr) => {
        dstAttrs.setNamedItemNS(attr);
      });
    } else {
      for (let i = 0; i < attrLen; i++) {
        const srcAttr = srcAttrs.item(i);
        const dstAttr = new MockAttr(srcAttr.name, srcAttr.value, srcAttr.namespaceURI);
        dstAttrs.setNamedItemNS(dstAttr);
      }
    }
  }
  return dstAttrs;
}
function sortAttributes(a, b) {
  if (a.name < b.name)
    return -1;
  if (a.name > b.name)
    return 1;
  return 0;
}
class MockAttr {
  constructor(attrName, attrValue, namespaceURI = null) {
    this._name = attrName;
    this._value = String(attrValue);
    this._namespaceURI = namespaceURI;
  }
  get name() {
    return this._name;
  }
  set name(value) {
    this._name = value;
  }
  get value() {
    return this._value;
  }
  set value(value) {
    this._value = String(value);
  }
  get nodeName() {
    return this._name;
  }
  set nodeName(value) {
    this._name = value;
  }
  get nodeValue() {
    return this._value;
  }
  set nodeValue(value) {
    this._value = String(value);
  }
  get namespaceURI() {
    return this._namespaceURI;
  }
  set namespaceURI(namespaceURI) {
    this._namespaceURI = namespaceURI;
  }
}
class MockClassList {
  constructor(elm) {
    this.elm = elm;
  }
  add(...classNames) {
    const clsNames = getItems(this.elm);
    let updated = false;
    classNames.forEach((className) => {
      className = String(className);
      validateClass(className);
      if (clsNames.includes(className) === false) {
        clsNames.push(className);
        updated = true;
      }
    });
    if (updated) {
      this.elm.setAttributeNS(null, "class", clsNames.join(" "));
    }
  }
  remove(...classNames) {
    const clsNames = getItems(this.elm);
    let updated = false;
    classNames.forEach((className) => {
      className = String(className);
      validateClass(className);
      const index = clsNames.indexOf(className);
      if (index > -1) {
        clsNames.splice(index, 1);
        updated = true;
      }
    });
    if (updated) {
      this.elm.setAttributeNS(null, "class", clsNames.filter((c) => c.length > 0).join(" "));
    }
  }
  contains(className) {
    className = String(className);
    return getItems(this.elm).includes(className);
  }
  toggle(className) {
    className = String(className);
    if (this.contains(className) === true) {
      this.remove(className);
    } else {
      this.add(className);
    }
  }
  get length() {
    return getItems(this.elm).length;
  }
  item(index) {
    return getItems(this.elm)[index];
  }
  toString() {
    return getItems(this.elm).join(" ");
  }
}
function validateClass(className) {
  if (className === "") {
    throw new Error("The token provided must not be empty.");
  }
  if (/\s/.test(className)) {
    throw new Error(`The token provided ('${className}') contains HTML space characters, which are not valid in tokens.`);
  }
}
function getItems(elm) {
  const className = elm.getAttribute("class");
  if (typeof className === "string" && className.length > 0) {
    return className.trim().split(" ").filter((c) => c.length > 0);
  }
  return [];
}
class MockCSSStyleDeclaration {
  constructor() {
    this._styles = /* @__PURE__ */ new Map();
  }
  setProperty(prop, value) {
    prop = jsCaseToCssCase(prop);
    if (value == null || value === "") {
      this._styles.delete(prop);
    } else {
      this._styles.set(prop, String(value));
    }
  }
  getPropertyValue(prop) {
    prop = jsCaseToCssCase(prop);
    return String(this._styles.get(prop) || "");
  }
  removeProperty(prop) {
    prop = jsCaseToCssCase(prop);
    this._styles.delete(prop);
  }
  get length() {
    return this._styles.size;
  }
  get cssText() {
    const cssText = [];
    this._styles.forEach((value, prop) => {
      cssText.push(`${prop}: ${value};`);
    });
    return cssText.join(" ").trim();
  }
  set cssText(cssText) {
    if (cssText == null || cssText === "") {
      this._styles.clear();
      return;
    }
    cssText.split(";").forEach((rule) => {
      rule = rule.trim();
      if (rule.length > 0) {
        const splt = rule.split(":");
        if (splt.length > 1) {
          const prop = splt[0].trim();
          const value = splt.slice(1).join(":").trim();
          if (prop !== "" && value !== "") {
            this._styles.set(jsCaseToCssCase(prop), value);
          }
        }
      }
    });
  }
}
function createCSSStyleDeclaration() {
  return new Proxy(new MockCSSStyleDeclaration(), cssProxyHandler);
}
const cssProxyHandler = {
  get(cssStyle, prop) {
    if (prop in cssStyle) {
      return cssStyle[prop];
    }
    prop = cssCaseToJsCase(prop);
    return cssStyle.getPropertyValue(prop);
  },
  set(cssStyle, prop, value) {
    if (prop in cssStyle) {
      cssStyle[prop] = value;
    } else {
      cssStyle.setProperty(prop, value);
    }
    return true;
  }
};
function cssCaseToJsCase(str) {
  if (str.length > 1 && str.includes("-") === true) {
    str = str.toLowerCase().split("-").map((segment) => segment.charAt(0).toUpperCase() + segment.slice(1)).join("");
    str = str.slice(0, 1).toLowerCase() + str.slice(1);
  }
  return str;
}
function jsCaseToCssCase(str) {
  if (str.length > 1 && str.includes("-") === false && /[A-Z]/.test(str) === true) {
    str = str.replace(/([A-Z])/g, (g) => " " + g[0]).trim().replace(/ /g, "-").toLowerCase();
  }
  return str;
}
class MockCustomElementRegistry {
  constructor(win) {
    this.win = win;
  }
  define(tagName, cstr, options) {
    if (tagName.toLowerCase() !== tagName) {
      throw new Error(`Failed to execute 'define' on 'CustomElementRegistry': "${tagName}" is not a valid custom element name`);
    }
    if (this.__registry == null) {
      this.__registry = /* @__PURE__ */ new Map();
    }
    this.__registry.set(tagName, { cstr, options });
    if (this.__whenDefined != null) {
      const whenDefinedResolveFns = this.__whenDefined.get(tagName);
      if (whenDefinedResolveFns != null) {
        whenDefinedResolveFns.forEach((whenDefinedResolveFn) => {
          whenDefinedResolveFn();
        });
        whenDefinedResolveFns.length = 0;
        this.__whenDefined.delete(tagName);
      }
    }
    const doc = this.win.document;
    if (doc != null) {
      const hosts = doc.querySelectorAll(tagName);
      hosts.forEach((host) => {
        if (upgradedElements.has(host) === false) {
          tempDisableCallbacks.add(doc);
          const upgradedCmp = createCustomElement(this, doc, tagName);
          for (let i = 0; i < host.childNodes.length; i++) {
            const childNode = host.childNodes[i];
            childNode.remove();
            upgradedCmp.appendChild(childNode);
          }
          tempDisableCallbacks.delete(doc);
          if (proxyElements.has(host)) {
            proxyElements.set(host, upgradedCmp);
          }
        }
        fireConnectedCallback(host);
      });
    }
  }
  get(tagName) {
    if (this.__registry != null) {
      const def = this.__registry.get(tagName.toLowerCase());
      if (def != null) {
        return def.cstr;
      }
    }
    return void 0;
  }
  upgrade(_rootNode) {
  }
  clear() {
    if (this.__registry != null) {
      this.__registry.clear();
    }
    if (this.__whenDefined != null) {
      this.__whenDefined.clear();
    }
  }
  whenDefined(tagName) {
    tagName = tagName.toLowerCase();
    if (this.__registry != null && this.__registry.has(tagName) === true) {
      return Promise.resolve(this.__registry.get(tagName).cstr);
    }
    return new Promise((resolve) => {
      if (this.__whenDefined == null) {
        this.__whenDefined = /* @__PURE__ */ new Map();
      }
      let whenDefinedResolveFns = this.__whenDefined.get(tagName);
      if (whenDefinedResolveFns == null) {
        whenDefinedResolveFns = [];
        this.__whenDefined.set(tagName, whenDefinedResolveFns);
      }
      whenDefinedResolveFns.push(resolve);
    });
  }
}
function createCustomElement(customElements, ownerDocument, tagName) {
  const Cstr = customElements.get(tagName);
  if (Cstr != null) {
    const cmp = new Cstr(ownerDocument);
    cmp.nodeName = tagName.toUpperCase();
    upgradedElements.add(cmp);
    return cmp;
  }
  const host = new Proxy({}, {
    get(obj, prop) {
      const elm2 = proxyElements.get(host);
      if (elm2 != null) {
        return elm2[prop];
      }
      return obj[prop];
    },
    set(obj, prop, val) {
      const elm2 = proxyElements.get(host);
      if (elm2 != null) {
        elm2[prop] = val;
      } else {
        obj[prop] = val;
      }
      return true;
    },
    has(obj, prop) {
      const elm2 = proxyElements.get(host);
      if (prop in elm2) {
        return true;
      }
      if (prop in obj) {
        return true;
      }
      return false;
    }
  });
  const elm = new MockHTMLElement(ownerDocument, tagName);
  proxyElements.set(host, elm);
  return host;
}
const proxyElements = /* @__PURE__ */ new WeakMap();
const upgradedElements = /* @__PURE__ */ new WeakSet();
function connectNode(ownerDocument, node) {
  node.ownerDocument = ownerDocument;
  if (node.nodeType === 1) {
    if (ownerDocument != null && node.nodeName.includes("-")) {
      const win = ownerDocument.defaultView;
      if (win != null && typeof node.connectedCallback === "function" && node.isConnected) {
        fireConnectedCallback(node);
      }
      const shadowRoot = node.shadowRoot;
      if (shadowRoot != null) {
        shadowRoot.childNodes.forEach((childNode) => {
          connectNode(ownerDocument, childNode);
        });
      }
    }
    node.childNodes.forEach((childNode) => {
      connectNode(ownerDocument, childNode);
    });
  } else {
    node.childNodes.forEach((childNode) => {
      childNode.ownerDocument = ownerDocument;
    });
  }
}
function fireConnectedCallback(node) {
  if (typeof node.connectedCallback === "function") {
    if (tempDisableCallbacks.has(node.ownerDocument) === false) {
      try {
        node.connectedCallback();
      } catch (e2) {
        console.error(e2);
      }
    }
  }
}
function disconnectNode(node) {
  if (node.nodeType === 1) {
    if (node.nodeName.includes("-") === true && typeof node.disconnectedCallback === "function") {
      if (tempDisableCallbacks.has(node.ownerDocument) === false) {
        try {
          node.disconnectedCallback();
        } catch (e2) {
          console.error(e2);
        }
      }
    }
    node.childNodes.forEach(disconnectNode);
  }
}
function attributeChanged(node, attrName, oldValue, newValue) {
  attrName = attrName.toLowerCase();
  const observedAttributes = node.constructor.observedAttributes;
  if (Array.isArray(observedAttributes) === true && observedAttributes.some((obs) => obs.toLowerCase() === attrName) === true) {
    try {
      node.attributeChangedCallback(attrName, oldValue, newValue);
    } catch (e2) {
      console.error(e2);
    }
  }
}
function checkAttributeChanged(node) {
  return node.nodeName.includes("-") === true && typeof node.attributeChangedCallback === "function";
}
const tempDisableCallbacks = /* @__PURE__ */ new Set();
function dataset(elm) {
  const ds = {};
  const attributes = elm.attributes;
  const attrLen = attributes.length;
  for (let i = 0; i < attrLen; i++) {
    const attr = attributes.item(i);
    const nodeName = attr.nodeName;
    if (nodeName.startsWith("data-")) {
      ds[dashToPascalCase(nodeName)] = attr.nodeValue;
    }
  }
  return new Proxy(ds, {
    get(_obj, camelCaseProp) {
      return ds[camelCaseProp];
    },
    set(_obj, camelCaseProp, value) {
      const dataAttr = toDataAttribute(camelCaseProp);
      elm.setAttribute(dataAttr, value);
      return true;
    }
  });
}
function toDataAttribute(str) {
  return "data-" + String(str).replace(/([A-Z0-9])/g, (g) => " " + g[0]).trim().replace(/ /g, "-").toLowerCase();
}
function dashToPascalCase(str) {
  str = String(str).slice(5);
  return str.split("-").map((segment, index) => {
    if (index === 0) {
      return segment.charAt(0).toLowerCase() + segment.slice(1);
    }
    return segment.charAt(0).toUpperCase() + segment.slice(1);
  }).join("");
}
class MockEvent {
  constructor(type, eventInitDict) {
    this.bubbles = false;
    this.cancelBubble = false;
    this.cancelable = false;
    this.composed = false;
    this.currentTarget = null;
    this.defaultPrevented = false;
    this.srcElement = null;
    this.target = null;
    if (typeof type !== "string") {
      throw new Error(`Event type required`);
    }
    this.type = type;
    this.timeStamp = Date.now();
    if (eventInitDict != null) {
      Object.assign(this, eventInitDict);
    }
  }
  preventDefault() {
    this.defaultPrevented = true;
  }
  stopPropagation() {
    this.cancelBubble = true;
  }
  stopImmediatePropagation() {
    this.cancelBubble = true;
  }
  composedPath() {
    const composedPath = [];
    let currentElement = this.target;
    while (currentElement) {
      composedPath.push(currentElement);
      if (!currentElement.parentElement && currentElement.nodeName === "#document") {
        composedPath.push(currentElement.defaultView);
        break;
      }
      currentElement = currentElement.parentElement;
    }
    return composedPath;
  }
}
class MockCustomEvent extends MockEvent {
  constructor(type, customEventInitDic) {
    super(type);
    this.detail = null;
    if (customEventInitDic != null) {
      Object.assign(this, customEventInitDic);
    }
  }
}
class MockKeyboardEvent extends MockEvent {
  constructor(type, keyboardEventInitDic) {
    super(type);
    this.code = "";
    this.key = "";
    this.altKey = false;
    this.ctrlKey = false;
    this.metaKey = false;
    this.shiftKey = false;
    this.location = 0;
    this.repeat = false;
    if (keyboardEventInitDic != null) {
      Object.assign(this, keyboardEventInitDic);
    }
  }
}
class MockMouseEvent extends MockEvent {
  constructor(type, mouseEventInitDic) {
    super(type);
    this.screenX = 0;
    this.screenY = 0;
    this.clientX = 0;
    this.clientY = 0;
    this.ctrlKey = false;
    this.shiftKey = false;
    this.altKey = false;
    this.metaKey = false;
    this.button = 0;
    this.buttons = 0;
    this.relatedTarget = null;
    if (mouseEventInitDic != null) {
      Object.assign(this, mouseEventInitDic);
    }
  }
}
class MockUIEvent extends MockEvent {
  constructor(type, uiEventInitDic) {
    super(type);
    this.detail = null;
    this.view = null;
    if (uiEventInitDic != null) {
      Object.assign(this, uiEventInitDic);
    }
  }
}
class MockFocusEvent extends MockUIEvent {
  constructor(type, focusEventInitDic) {
    super(type);
    this.relatedTarget = null;
    if (focusEventInitDic != null) {
      Object.assign(this, focusEventInitDic);
    }
  }
}
class MockEventListener {
  constructor(type, handler) {
    this.type = type;
    this.handler = handler;
  }
}
function addEventListener(elm, type, handler) {
  const target = elm;
  if (target.__listeners == null) {
    target.__listeners = [];
  }
  target.__listeners.push(new MockEventListener(type, handler));
}
function removeEventListener(elm, type, handler) {
  const target = elm;
  if (target != null && Array.isArray(target.__listeners) === true) {
    const elmListener = target.__listeners.find((e2) => e2.type === type && e2.handler === handler);
    if (elmListener != null) {
      const index = target.__listeners.indexOf(elmListener);
      target.__listeners.splice(index, 1);
    }
  }
}
function resetEventListeners(target) {
  if (target != null && target.__listeners != null) {
    target.__listeners = null;
  }
}
function triggerEventListener(elm, ev) {
  if (elm == null || ev.cancelBubble === true) {
    return;
  }
  const target = elm;
  ev.currentTarget = elm;
  if (Array.isArray(target.__listeners) === true) {
    const listeners = target.__listeners.filter((e2) => e2.type === ev.type);
    listeners.forEach((listener) => {
      try {
        listener.handler.call(target, ev);
      } catch (err) {
        console.error(err);
      }
    });
  }
  if (ev.bubbles === false) {
    return;
  }
  if (elm.nodeName === "#document") {
    triggerEventListener(elm.defaultView, ev);
  } else {
    triggerEventListener(elm.parentElement, ev);
  }
}
function dispatchEvent(currentTarget, ev) {
  ev.target = currentTarget;
  triggerEventListener(currentTarget, ev);
  return true;
}
const e = function(e2) {
  const t = /* @__PURE__ */ new Set([65534, 65535, 131070, 131071, 196606, 196607, 262142, 262143, 327678, 327679, 393214, 393215, 458750, 458751, 524286, 524287, 589822, 589823, 655358, 655359, 720894, 720895, 786430, 786431, 851966, 851967, 917502, 917503, 983038, 983039, 1048574, 1048575, 1114110, 1114111]), s = "\uFFFD";
  var a;
  !function(e3) {
    e3[e3.EOF = -1] = "EOF", e3[e3.NULL = 0] = "NULL", e3[e3.TABULATION = 9] = "TABULATION", e3[e3.CARRIAGE_RETURN = 13] = "CARRIAGE_RETURN", e3[e3.LINE_FEED = 10] = "LINE_FEED", e3[e3.FORM_FEED = 12] = "FORM_FEED", e3[e3.SPACE = 32] = "SPACE", e3[e3.EXCLAMATION_MARK = 33] = "EXCLAMATION_MARK", e3[e3.QUOTATION_MARK = 34] = "QUOTATION_MARK", e3[e3.NUMBER_SIGN = 35] = "NUMBER_SIGN", e3[e3.AMPERSAND = 38] = "AMPERSAND", e3[e3.APOSTROPHE = 39] = "APOSTROPHE", e3[e3.HYPHEN_MINUS = 45] = "HYPHEN_MINUS", e3[e3.SOLIDUS = 47] = "SOLIDUS", e3[e3.DIGIT_0 = 48] = "DIGIT_0", e3[e3.DIGIT_9 = 57] = "DIGIT_9", e3[e3.SEMICOLON = 59] = "SEMICOLON", e3[e3.LESS_THAN_SIGN = 60] = "LESS_THAN_SIGN", e3[e3.EQUALS_SIGN = 61] = "EQUALS_SIGN", e3[e3.GREATER_THAN_SIGN = 62] = "GREATER_THAN_SIGN", e3[e3.QUESTION_MARK = 63] = "QUESTION_MARK", e3[e3.LATIN_CAPITAL_A = 65] = "LATIN_CAPITAL_A", e3[e3.LATIN_CAPITAL_F = 70] = "LATIN_CAPITAL_F", e3[e3.LATIN_CAPITAL_X = 88] = "LATIN_CAPITAL_X", e3[e3.LATIN_CAPITAL_Z = 90] = "LATIN_CAPITAL_Z", e3[e3.RIGHT_SQUARE_BRACKET = 93] = "RIGHT_SQUARE_BRACKET", e3[e3.GRAVE_ACCENT = 96] = "GRAVE_ACCENT", e3[e3.LATIN_SMALL_A = 97] = "LATIN_SMALL_A", e3[e3.LATIN_SMALL_F = 102] = "LATIN_SMALL_F", e3[e3.LATIN_SMALL_X = 120] = "LATIN_SMALL_X", e3[e3.LATIN_SMALL_Z = 122] = "LATIN_SMALL_Z", e3[e3.REPLACEMENT_CHARACTER = 65533] = "REPLACEMENT_CHARACTER";
  }(a = a || (a = {}));
  const r = "[CDATA[", n = "doctype", i = "script";
  function o(e3) {
    return e3 >= 55296 && e3 <= 57343;
  }
  function c(e3) {
    return 32 !== e3 && 10 !== e3 && 13 !== e3 && 9 !== e3 && 12 !== e3 && e3 >= 1 && e3 <= 31 || e3 >= 127 && e3 <= 159;
  }
  function E(e3) {
    return e3 >= 64976 && e3 <= 65007 || t.has(e3);
  }
  var T, h;
  !function(e3) {
    e3.controlCharacterInInputStream = "control-character-in-input-stream", e3.noncharacterInInputStream = "noncharacter-in-input-stream", e3.surrogateInInputStream = "surrogate-in-input-stream", e3.nonVoidHtmlElementStartTagWithTrailingSolidus = "non-void-html-element-start-tag-with-trailing-solidus", e3.endTagWithAttributes = "end-tag-with-attributes", e3.endTagWithTrailingSolidus = "end-tag-with-trailing-solidus", e3.unexpectedSolidusInTag = "unexpected-solidus-in-tag", e3.unexpectedNullCharacter = "unexpected-null-character", e3.unexpectedQuestionMarkInsteadOfTagName = "unexpected-question-mark-instead-of-tag-name", e3.invalidFirstCharacterOfTagName = "invalid-first-character-of-tag-name", e3.unexpectedEqualsSignBeforeAttributeName = "unexpected-equals-sign-before-attribute-name", e3.missingEndTagName = "missing-end-tag-name", e3.unexpectedCharacterInAttributeName = "unexpected-character-in-attribute-name", e3.unknownNamedCharacterReference = "unknown-named-character-reference", e3.missingSemicolonAfterCharacterReference = "missing-semicolon-after-character-reference", e3.unexpectedCharacterAfterDoctypeSystemIdentifier = "unexpected-character-after-doctype-system-identifier", e3.unexpectedCharacterInUnquotedAttributeValue = "unexpected-character-in-unquoted-attribute-value", e3.eofBeforeTagName = "eof-before-tag-name", e3.eofInTag = "eof-in-tag", e3.missingAttributeValue = "missing-attribute-value", e3.missingWhitespaceBetweenAttributes = "missing-whitespace-between-attributes", e3.missingWhitespaceAfterDoctypePublicKeyword = "missing-whitespace-after-doctype-public-keyword", e3.missingWhitespaceBetweenDoctypePublicAndSystemIdentifiers = "missing-whitespace-between-doctype-public-and-system-identifiers", e3.missingWhitespaceAfterDoctypeSystemKeyword = "missing-whitespace-after-doctype-system-keyword", e3.missingQuoteBeforeDoctypePublicIdentifier = "missing-quote-before-doctype-public-identifier", e3.missingQuoteBeforeDoctypeSystemIdentifier = "missing-quote-before-doctype-system-identifier", e3.missingDoctypePublicIdentifier = "missing-doctype-public-identifier", e3.missingDoctypeSystemIdentifier = "missing-doctype-system-identifier", e3.abruptDoctypePublicIdentifier = "abrupt-doctype-public-identifier", e3.abruptDoctypeSystemIdentifier = "abrupt-doctype-system-identifier", e3.cdataInHtmlContent = "cdata-in-html-content", e3.incorrectlyOpenedComment = "incorrectly-opened-comment", e3.eofInScriptHtmlCommentLikeText = "eof-in-script-html-comment-like-text", e3.eofInDoctype = "eof-in-doctype", e3.nestedComment = "nested-comment", e3.abruptClosingOfEmptyComment = "abrupt-closing-of-empty-comment", e3.eofInComment = "eof-in-comment", e3.incorrectlyClosedComment = "incorrectly-closed-comment", e3.eofInCdata = "eof-in-cdata", e3.absenceOfDigitsInNumericCharacterReference = "absence-of-digits-in-numeric-character-reference", e3.nullCharacterReference = "null-character-reference", e3.surrogateCharacterReference = "surrogate-character-reference", e3.characterReferenceOutsideUnicodeRange = "character-reference-outside-unicode-range", e3.controlCharacterReference = "control-character-reference", e3.noncharacterCharacterReference = "noncharacter-character-reference", e3.missingWhitespaceBeforeDoctypeName = "missing-whitespace-before-doctype-name", e3.missingDoctypeName = "missing-doctype-name", e3.invalidCharacterSequenceAfterDoctypeName = "invalid-character-sequence-after-doctype-name", e3.duplicateAttribute = "duplicate-attribute", e3.nonConformingDoctype = "non-conforming-doctype", e3.missingDoctype = "missing-doctype", e3.misplacedDoctype = "misplaced-doctype", e3.endTagWithoutMatchingOpenElement = "end-tag-without-matching-open-element", e3.closingOfElementWithOpenChildElements = "closing-of-element-with-open-child-elements", e3.disallowedContentInNoscriptInHead = "disallowed-content-in-noscript-in-head", e3.openElementsLeftAfterEof = "open-elements-left-after-eof", e3.abandonedHeadElementChild = "abandoned-head-element-child", e3.misplacedStartTagForHeadElement = "misplaced-start-tag-for-head-element", e3.nestedNoscriptInHead = "nested-noscript-in-head", e3.eofInElementThatCanContainOnlyText = "eof-in-element-that-can-contain-only-text";
  }(T = T || (T = {}));
  class _ {
    constructor(e3) {
      this.handler = e3, this.html = "", this.pos = -1, this.lastGapPos = -2, this.gapStack = [], this.skipNextNewLine = false, this.lastChunkWritten = false, this.endOfChunkHit = false, this.bufferWaterline = 65536, this.isEol = false, this.lineStartPos = 0, this.droppedBufferSize = 0, this.line = 1, this.lastErrOffset = -1;
    }
    get col() {
      return this.pos - this.lineStartPos + Number(this.lastGapPos !== this.pos);
    }
    get offset() {
      return this.droppedBufferSize + this.pos;
    }
    getError(e3) {
      const { line: t2, col: s2, offset: a2 } = this;
      return { code: e3, startLine: t2, endLine: t2, startCol: s2, endCol: s2, startOffset: a2, endOffset: a2 };
    }
    _err(e3) {
      this.handler.onParseError && this.lastErrOffset !== this.offset && (this.lastErrOffset = this.offset, this.handler.onParseError(this.getError(e3)));
    }
    _addGap() {
      this.gapStack.push(this.lastGapPos), this.lastGapPos = this.pos;
    }
    _processSurrogate(e3) {
      if (this.pos !== this.html.length - 1) {
        const t2 = this.html.charCodeAt(this.pos + 1);
        if (function(e4) {
          return e4 >= 56320 && e4 <= 57343;
        }(t2))
          return this.pos++, this._addGap(), 1024 * (e3 - 55296) + 9216 + t2;
      } else if (!this.lastChunkWritten)
        return this.endOfChunkHit = true, a.EOF;
      return this._err(T.surrogateInInputStream), e3;
    }
    willDropParsedChunk() {
      return this.pos > this.bufferWaterline;
    }
    dropParsedChunk() {
      this.willDropParsedChunk() && (this.html = this.html.substring(this.pos), this.lineStartPos -= this.pos, this.droppedBufferSize += this.pos, this.pos = 0, this.lastGapPos = -2, this.gapStack.length = 0);
    }
    write(e3, t2) {
      this.html.length > 0 ? this.html += e3 : this.html = e3, this.endOfChunkHit = false, this.lastChunkWritten = t2;
    }
    insertHtmlAtCurrentPos(e3) {
      this.html = this.html.substring(0, this.pos + 1) + e3 + this.html.substring(this.pos + 1), this.endOfChunkHit = false;
    }
    startsWith(e3, t2) {
      if (this.pos + e3.length > this.html.length)
        return this.endOfChunkHit = !this.lastChunkWritten, false;
      if (t2)
        return this.html.startsWith(e3, this.pos);
      for (let t3 = 0; t3 < e3.length; t3++)
        if ((32 | this.html.charCodeAt(this.pos + t3)) !== e3.charCodeAt(t3))
          return false;
      return true;
    }
    peek(e3) {
      const t2 = this.pos + e3;
      if (t2 >= this.html.length)
        return this.endOfChunkHit = !this.lastChunkWritten, a.EOF;
      const s2 = this.html.charCodeAt(t2);
      return s2 === a.CARRIAGE_RETURN ? a.LINE_FEED : s2;
    }
    advance() {
      if (this.pos++, this.isEol && (this.isEol = false, this.line++, this.lineStartPos = this.pos), this.pos >= this.html.length)
        return this.endOfChunkHit = !this.lastChunkWritten, a.EOF;
      let e3 = this.html.charCodeAt(this.pos);
      return e3 === a.CARRIAGE_RETURN ? (this.isEol = true, this.skipNextNewLine = true, a.LINE_FEED) : e3 === a.LINE_FEED && (this.isEol = true, this.skipNextNewLine) ? (this.line--, this.skipNextNewLine = false, this._addGap(), this.advance()) : (this.skipNextNewLine = false, o(e3) && (e3 = this._processSurrogate(e3)), null === this.handler.onParseError || e3 > 31 && e3 < 127 || e3 === a.LINE_FEED || e3 === a.CARRIAGE_RETURN || e3 > 159 && e3 < 64976 || this._checkForProblematicCharacters(e3), e3);
    }
    _checkForProblematicCharacters(e3) {
      c(e3) ? this._err(T.controlCharacterInInputStream) : E(e3) && this._err(T.noncharacterInInputStream);
    }
    retreat(e3) {
      for (this.pos -= e3; this.pos < this.lastGapPos; )
        this.lastGapPos = this.gapStack.pop(), this.pos--;
      this.isEol = false;
    }
  }
  function A(e3, t2) {
    for (let s2 = e3.attrs.length - 1; s2 >= 0; s2--)
      if (e3.attrs[s2].name === t2)
        return e3.attrs[s2].value;
    return null;
  }
  !function(e3) {
    e3[e3.CHARACTER = 0] = "CHARACTER", e3[e3.NULL_CHARACTER = 1] = "NULL_CHARACTER", e3[e3.WHITESPACE_CHARACTER = 2] = "WHITESPACE_CHARACTER", e3[e3.START_TAG = 3] = "START_TAG", e3[e3.END_TAG = 4] = "END_TAG", e3[e3.COMMENT = 5] = "COMMENT", e3[e3.DOCTYPE = 6] = "DOCTYPE", e3[e3.EOF = 7] = "EOF", e3[e3.HIBERNATION = 8] = "HIBERNATION";
  }(h = h || (h = {}));
  var l = "undefined" != typeof globalThis ? globalThis : "undefined" != typeof window ? window : "undefined" != typeof global ? global : "undefined" != typeof self ? self : {};
  function m(e3, t2, s2) {
    return e3(s2 = { path: t2, exports: {}, require: function(e4, t3) {
      return function() {
        throw new Error("Dynamic requires are not currently supported by @rollup/plugin-commonjs");
      }(null == t3 && s2.path);
    } }, s2.exports), s2.exports;
  }
  var p, d, I, N, u, C = m(function(e3, t2) {
    Object.defineProperty(t2, "__esModule", { value: true }), t2.default = new Uint16Array('\u1D41<\xD5\u0131\u028A\u049D\u057B\u05D0\u0675\u06DE\u07A2\u07D6\u080F\u0A4A\u0A91\u0DA1\u0E6D\u0F09\u0F26\u10CA\u1228\u12E1\u1415\u149D\u14C3\u14DF\u1525\0\0\0\0\0\0\u156B\u16CD\u198D\u1C12\u1DDD\u1F7E\u2060\u21B0\u228D\u23C0\u23FB\u2442\u2824\u2912\u2D08\u2E48\u2FCE\u3016\u32BA\u3639\u37AC\u38FE\u3A28\u3A71\u3AE0\u3B2E\u0800EMabcfglmnoprstu\\bfms\x7F\x84\x8B\x90\x95\x98\xA6\xB3\xB9\xC8\xCFlig\u803B\xC6\u40C6P\u803B&\u4026cute\u803B\xC1\u40C1reve;\u4102\u0100iyx}rc\u803B\xC2\u40C2;\u4410r;\uC000\u{1D504}rave\u803B\xC0\u40C0pha;\u4391acr;\u4100d;\u6A53\u0100gp\x9D\xA1on;\u4104f;\uC000\u{1D538}plyFunction;\u6061ing\u803B\xC5\u40C5\u0100cs\xBE\xC3r;\uC000\u{1D49C}ign;\u6254ilde\u803B\xC3\u40C3ml\u803B\xC4\u40C4\u0400aceforsu\xE5\xFB\xFE\u0117\u011C\u0122\u0127\u012A\u0100cr\xEA\xF2kslash;\u6216\u0176\xF6\xF8;\u6AE7ed;\u6306y;\u4411\u0180crt\u0105\u010B\u0114ause;\u6235noullis;\u612Ca;\u4392r;\uC000\u{1D505}pf;\uC000\u{1D539}eve;\u42D8c\xF2\u0113mpeq;\u624E\u0700HOacdefhilorsu\u014D\u0151\u0156\u0180\u019E\u01A2\u01B5\u01B7\u01BA\u01DC\u0215\u0273\u0278\u027Ecy;\u4427PY\u803B\xA9\u40A9\u0180cpy\u015D\u0162\u017Aute;\u4106\u0100;i\u0167\u0168\u62D2talDifferentialD;\u6145leys;\u612D\u0200aeio\u0189\u018E\u0194\u0198ron;\u410Cdil\u803B\xC7\u40C7rc;\u4108nint;\u6230ot;\u410A\u0100dn\u01A7\u01ADilla;\u40B8terDot;\u40B7\xF2\u017Fi;\u43A7rcle\u0200DMPT\u01C7\u01CB\u01D1\u01D6ot;\u6299inus;\u6296lus;\u6295imes;\u6297o\u0100cs\u01E2\u01F8kwiseContourIntegral;\u6232eCurly\u0100DQ\u0203\u020FoubleQuote;\u601Duote;\u6019\u0200lnpu\u021E\u0228\u0247\u0255on\u0100;e\u0225\u0226\u6237;\u6A74\u0180git\u022F\u0236\u023Aruent;\u6261nt;\u622FourIntegral;\u622E\u0100fr\u024C\u024E;\u6102oduct;\u6210nterClockwiseContourIntegral;\u6233oss;\u6A2Fcr;\uC000\u{1D49E}p\u0100;C\u0284\u0285\u62D3ap;\u624D\u0580DJSZacefios\u02A0\u02AC\u02B0\u02B4\u02B8\u02CB\u02D7\u02E1\u02E6\u0333\u048D\u0100;o\u0179\u02A5trahd;\u6911cy;\u4402cy;\u4405cy;\u440F\u0180grs\u02BF\u02C4\u02C7ger;\u6021r;\u61A1hv;\u6AE4\u0100ay\u02D0\u02D5ron;\u410E;\u4414l\u0100;t\u02DD\u02DE\u6207a;\u4394r;\uC000\u{1D507}\u0100af\u02EB\u0327\u0100cm\u02F0\u0322ritical\u0200ADGT\u0300\u0306\u0316\u031Ccute;\u40B4o\u0174\u030B\u030D;\u42D9bleAcute;\u42DDrave;\u4060ilde;\u42DCond;\u62C4ferentialD;\u6146\u0470\u033D\0\0\0\u0342\u0354\0\u0405f;\uC000\u{1D53B}\u0180;DE\u0348\u0349\u034D\u40A8ot;\u60DCqual;\u6250ble\u0300CDLRUV\u0363\u0372\u0382\u03CF\u03E2\u03F8ontourIntegra\xEC\u0239o\u0274\u0379\0\0\u037B\xBB\u0349nArrow;\u61D3\u0100eo\u0387\u03A4ft\u0180ART\u0390\u0396\u03A1rrow;\u61D0ightArrow;\u61D4e\xE5\u02CAng\u0100LR\u03AB\u03C4eft\u0100AR\u03B3\u03B9rrow;\u67F8ightArrow;\u67FAightArrow;\u67F9ight\u0100AT\u03D8\u03DErrow;\u61D2ee;\u62A8p\u0241\u03E9\0\0\u03EFrrow;\u61D1ownArrow;\u61D5erticalBar;\u6225n\u0300ABLRTa\u0412\u042A\u0430\u045E\u047F\u037Crrow\u0180;BU\u041D\u041E\u0422\u6193ar;\u6913pArrow;\u61F5reve;\u4311eft\u02D2\u043A\0\u0446\0\u0450ightVector;\u6950eeVector;\u695Eector\u0100;B\u0459\u045A\u61BDar;\u6956ight\u01D4\u0467\0\u0471eeVector;\u695Fector\u0100;B\u047A\u047B\u61C1ar;\u6957ee\u0100;A\u0486\u0487\u62A4rrow;\u61A7\u0100ct\u0492\u0497r;\uC000\u{1D49F}rok;\u4110\u0800NTacdfglmopqstux\u04BD\u04C0\u04C4\u04CB\u04DE\u04E2\u04E7\u04EE\u04F5\u0521\u052F\u0536\u0552\u055D\u0560\u0565G;\u414AH\u803B\xD0\u40D0cute\u803B\xC9\u40C9\u0180aiy\u04D2\u04D7\u04DCron;\u411Arc\u803B\xCA\u40CA;\u442Dot;\u4116r;\uC000\u{1D508}rave\u803B\xC8\u40C8ement;\u6208\u0100ap\u04FA\u04FEcr;\u4112ty\u0253\u0506\0\0\u0512mallSquare;\u65FBerySmallSquare;\u65AB\u0100gp\u0526\u052Aon;\u4118f;\uC000\u{1D53C}silon;\u4395u\u0100ai\u053C\u0549l\u0100;T\u0542\u0543\u6A75ilde;\u6242librium;\u61CC\u0100ci\u0557\u055Ar;\u6130m;\u6A73a;\u4397ml\u803B\xCB\u40CB\u0100ip\u056A\u056Fsts;\u6203onentialE;\u6147\u0280cfios\u0585\u0588\u058D\u05B2\u05CCy;\u4424r;\uC000\u{1D509}lled\u0253\u0597\0\0\u05A3mallSquare;\u65FCerySmallSquare;\u65AA\u0370\u05BA\0\u05BF\0\0\u05C4f;\uC000\u{1D53D}All;\u6200riertrf;\u6131c\xF2\u05CB\u0600JTabcdfgorst\u05E8\u05EC\u05EF\u05FA\u0600\u0612\u0616\u061B\u061D\u0623\u066C\u0672cy;\u4403\u803B>\u403Emma\u0100;d\u05F7\u05F8\u4393;\u43DCreve;\u411E\u0180eiy\u0607\u060C\u0610dil;\u4122rc;\u411C;\u4413ot;\u4120r;\uC000\u{1D50A};\u62D9pf;\uC000\u{1D53E}eater\u0300EFGLST\u0635\u0644\u064E\u0656\u065B\u0666qual\u0100;L\u063E\u063F\u6265ess;\u62DBullEqual;\u6267reater;\u6AA2ess;\u6277lantEqual;\u6A7Eilde;\u6273cr;\uC000\u{1D4A2};\u626B\u0400Aacfiosu\u0685\u068B\u0696\u069B\u069E\u06AA\u06BE\u06CARDcy;\u442A\u0100ct\u0690\u0694ek;\u42C7;\u405Eirc;\u4124r;\u610ClbertSpace;\u610B\u01F0\u06AF\0\u06B2f;\u610DizontalLine;\u6500\u0100ct\u06C3\u06C5\xF2\u06A9rok;\u4126mp\u0144\u06D0\u06D8ownHum\xF0\u012Fqual;\u624F\u0700EJOacdfgmnostu\u06FA\u06FE\u0703\u0707\u070E\u071A\u071E\u0721\u0728\u0744\u0778\u078B\u078F\u0795cy;\u4415lig;\u4132cy;\u4401cute\u803B\xCD\u40CD\u0100iy\u0713\u0718rc\u803B\xCE\u40CE;\u4418ot;\u4130r;\u6111rave\u803B\xCC\u40CC\u0180;ap\u0720\u072F\u073F\u0100cg\u0734\u0737r;\u412AinaryI;\u6148lie\xF3\u03DD\u01F4\u0749\0\u0762\u0100;e\u074D\u074E\u622C\u0100gr\u0753\u0758ral;\u622Bsection;\u62C2isible\u0100CT\u076C\u0772omma;\u6063imes;\u6062\u0180gpt\u077F\u0783\u0788on;\u412Ef;\uC000\u{1D540}a;\u4399cr;\u6110ilde;\u4128\u01EB\u079A\0\u079Ecy;\u4406l\u803B\xCF\u40CF\u0280cfosu\u07AC\u07B7\u07BC\u07C2\u07D0\u0100iy\u07B1\u07B5rc;\u4134;\u4419r;\uC000\u{1D50D}pf;\uC000\u{1D541}\u01E3\u07C7\0\u07CCr;\uC000\u{1D4A5}rcy;\u4408kcy;\u4404\u0380HJacfos\u07E4\u07E8\u07EC\u07F1\u07FD\u0802\u0808cy;\u4425cy;\u440Cppa;\u439A\u0100ey\u07F6\u07FBdil;\u4136;\u441Ar;\uC000\u{1D50E}pf;\uC000\u{1D542}cr;\uC000\u{1D4A6}\u0580JTaceflmost\u0825\u0829\u082C\u0850\u0863\u09B3\u09B8\u09C7\u09CD\u0A37\u0A47cy;\u4409\u803B<\u403C\u0280cmnpr\u0837\u083C\u0841\u0844\u084Dute;\u4139bda;\u439Bg;\u67EAlacetrf;\u6112r;\u619E\u0180aey\u0857\u085C\u0861ron;\u413Ddil;\u413B;\u441B\u0100fs\u0868\u0970t\u0500ACDFRTUVar\u087E\u08A9\u08B1\u08E0\u08E6\u08FC\u092F\u095B\u0390\u096A\u0100nr\u0883\u088FgleBracket;\u67E8row\u0180;BR\u0899\u089A\u089E\u6190ar;\u61E4ightArrow;\u61C6eiling;\u6308o\u01F5\u08B7\0\u08C3bleBracket;\u67E6n\u01D4\u08C8\0\u08D2eeVector;\u6961ector\u0100;B\u08DB\u08DC\u61C3ar;\u6959loor;\u630Aight\u0100AV\u08EF\u08F5rrow;\u6194ector;\u694E\u0100er\u0901\u0917e\u0180;AV\u0909\u090A\u0910\u62A3rrow;\u61A4ector;\u695Aiangle\u0180;BE\u0924\u0925\u0929\u62B2ar;\u69CFqual;\u62B4p\u0180DTV\u0937\u0942\u094CownVector;\u6951eeVector;\u6960ector\u0100;B\u0956\u0957\u61BFar;\u6958ector\u0100;B\u0965\u0966\u61BCar;\u6952ight\xE1\u039Cs\u0300EFGLST\u097E\u098B\u0995\u099D\u09A2\u09ADqualGreater;\u62DAullEqual;\u6266reater;\u6276ess;\u6AA1lantEqual;\u6A7Dilde;\u6272r;\uC000\u{1D50F}\u0100;e\u09BD\u09BE\u62D8ftarrow;\u61DAidot;\u413F\u0180npw\u09D4\u0A16\u0A1Bg\u0200LRlr\u09DE\u09F7\u0A02\u0A10eft\u0100AR\u09E6\u09ECrrow;\u67F5ightArrow;\u67F7ightArrow;\u67F6eft\u0100ar\u03B3\u0A0Aight\xE1\u03BFight\xE1\u03CAf;\uC000\u{1D543}er\u0100LR\u0A22\u0A2CeftArrow;\u6199ightArrow;\u6198\u0180cht\u0A3E\u0A40\u0A42\xF2\u084C;\u61B0rok;\u4141;\u626A\u0400acefiosu\u0A5A\u0A5D\u0A60\u0A77\u0A7C\u0A85\u0A8B\u0A8Ep;\u6905y;\u441C\u0100dl\u0A65\u0A6FiumSpace;\u605Flintrf;\u6133r;\uC000\u{1D510}nusPlus;\u6213pf;\uC000\u{1D544}c\xF2\u0A76;\u439C\u0480Jacefostu\u0AA3\u0AA7\u0AAD\u0AC0\u0B14\u0B19\u0D91\u0D97\u0D9Ecy;\u440Acute;\u4143\u0180aey\u0AB4\u0AB9\u0ABEron;\u4147dil;\u4145;\u441D\u0180gsw\u0AC7\u0AF0\u0B0Eative\u0180MTV\u0AD3\u0ADF\u0AE8ediumSpace;\u600Bhi\u0100cn\u0AE6\u0AD8\xEB\u0AD9eryThi\xEE\u0AD9ted\u0100GL\u0AF8\u0B06reaterGreate\xF2\u0673essLes\xF3\u0A48Line;\u400Ar;\uC000\u{1D511}\u0200Bnpt\u0B22\u0B28\u0B37\u0B3Areak;\u6060BreakingSpace;\u40A0f;\u6115\u0680;CDEGHLNPRSTV\u0B55\u0B56\u0B6A\u0B7C\u0BA1\u0BEB\u0C04\u0C5E\u0C84\u0CA6\u0CD8\u0D61\u0D85\u6AEC\u0100ou\u0B5B\u0B64ngruent;\u6262pCap;\u626DoubleVerticalBar;\u6226\u0180lqx\u0B83\u0B8A\u0B9Bement;\u6209ual\u0100;T\u0B92\u0B93\u6260ilde;\uC000\u2242\u0338ists;\u6204reater\u0380;EFGLST\u0BB6\u0BB7\u0BBD\u0BC9\u0BD3\u0BD8\u0BE5\u626Fqual;\u6271ullEqual;\uC000\u2267\u0338reater;\uC000\u226B\u0338ess;\u6279lantEqual;\uC000\u2A7E\u0338ilde;\u6275ump\u0144\u0BF2\u0BFDownHump;\uC000\u224E\u0338qual;\uC000\u224F\u0338e\u0100fs\u0C0A\u0C27tTriangle\u0180;BE\u0C1A\u0C1B\u0C21\u62EAar;\uC000\u29CF\u0338qual;\u62ECs\u0300;EGLST\u0C35\u0C36\u0C3C\u0C44\u0C4B\u0C58\u626Equal;\u6270reater;\u6278ess;\uC000\u226A\u0338lantEqual;\uC000\u2A7D\u0338ilde;\u6274ested\u0100GL\u0C68\u0C79reaterGreater;\uC000\u2AA2\u0338essLess;\uC000\u2AA1\u0338recedes\u0180;ES\u0C92\u0C93\u0C9B\u6280qual;\uC000\u2AAF\u0338lantEqual;\u62E0\u0100ei\u0CAB\u0CB9verseElement;\u620CghtTriangle\u0180;BE\u0CCB\u0CCC\u0CD2\u62EBar;\uC000\u29D0\u0338qual;\u62ED\u0100qu\u0CDD\u0D0CuareSu\u0100bp\u0CE8\u0CF9set\u0100;E\u0CF0\u0CF3\uC000\u228F\u0338qual;\u62E2erset\u0100;E\u0D03\u0D06\uC000\u2290\u0338qual;\u62E3\u0180bcp\u0D13\u0D24\u0D4Eset\u0100;E\u0D1B\u0D1E\uC000\u2282\u20D2qual;\u6288ceeds\u0200;EST\u0D32\u0D33\u0D3B\u0D46\u6281qual;\uC000\u2AB0\u0338lantEqual;\u62E1ilde;\uC000\u227F\u0338erset\u0100;E\u0D58\u0D5B\uC000\u2283\u20D2qual;\u6289ilde\u0200;EFT\u0D6E\u0D6F\u0D75\u0D7F\u6241qual;\u6244ullEqual;\u6247ilde;\u6249erticalBar;\u6224cr;\uC000\u{1D4A9}ilde\u803B\xD1\u40D1;\u439D\u0700Eacdfgmoprstuv\u0DBD\u0DC2\u0DC9\u0DD5\u0DDB\u0DE0\u0DE7\u0DFC\u0E02\u0E20\u0E22\u0E32\u0E3F\u0E44lig;\u4152cute\u803B\xD3\u40D3\u0100iy\u0DCE\u0DD3rc\u803B\xD4\u40D4;\u441Eblac;\u4150r;\uC000\u{1D512}rave\u803B\xD2\u40D2\u0180aei\u0DEE\u0DF2\u0DF6cr;\u414Cga;\u43A9cron;\u439Fpf;\uC000\u{1D546}enCurly\u0100DQ\u0E0E\u0E1AoubleQuote;\u601Cuote;\u6018;\u6A54\u0100cl\u0E27\u0E2Cr;\uC000\u{1D4AA}ash\u803B\xD8\u40D8i\u016C\u0E37\u0E3Cde\u803B\xD5\u40D5es;\u6A37ml\u803B\xD6\u40D6er\u0100BP\u0E4B\u0E60\u0100ar\u0E50\u0E53r;\u603Eac\u0100ek\u0E5A\u0E5C;\u63DEet;\u63B4arenthesis;\u63DC\u0480acfhilors\u0E7F\u0E87\u0E8A\u0E8F\u0E92\u0E94\u0E9D\u0EB0\u0EFCrtialD;\u6202y;\u441Fr;\uC000\u{1D513}i;\u43A6;\u43A0usMinus;\u40B1\u0100ip\u0EA2\u0EADncareplan\xE5\u069Df;\u6119\u0200;eio\u0EB9\u0EBA\u0EE0\u0EE4\u6ABBcedes\u0200;EST\u0EC8\u0EC9\u0ECF\u0EDA\u627Aqual;\u6AAFlantEqual;\u627Cilde;\u627Eme;\u6033\u0100dp\u0EE9\u0EEEuct;\u620Fortion\u0100;a\u0225\u0EF9l;\u621D\u0100ci\u0F01\u0F06r;\uC000\u{1D4AB};\u43A8\u0200Ufos\u0F11\u0F16\u0F1B\u0F1FOT\u803B"\u4022r;\uC000\u{1D514}pf;\u611Acr;\uC000\u{1D4AC}\u0600BEacefhiorsu\u0F3E\u0F43\u0F47\u0F60\u0F73\u0FA7\u0FAA\u0FAD\u1096\u10A9\u10B4\u10BEarr;\u6910G\u803B\xAE\u40AE\u0180cnr\u0F4E\u0F53\u0F56ute;\u4154g;\u67EBr\u0100;t\u0F5C\u0F5D\u61A0l;\u6916\u0180aey\u0F67\u0F6C\u0F71ron;\u4158dil;\u4156;\u4420\u0100;v\u0F78\u0F79\u611Cerse\u0100EU\u0F82\u0F99\u0100lq\u0F87\u0F8Eement;\u620Builibrium;\u61CBpEquilibrium;\u696Fr\xBB\u0F79o;\u43A1ght\u0400ACDFTUVa\u0FC1\u0FEB\u0FF3\u1022\u1028\u105B\u1087\u03D8\u0100nr\u0FC6\u0FD2gleBracket;\u67E9row\u0180;BL\u0FDC\u0FDD\u0FE1\u6192ar;\u61E5eftArrow;\u61C4eiling;\u6309o\u01F5\u0FF9\0\u1005bleBracket;\u67E7n\u01D4\u100A\0\u1014eeVector;\u695Dector\u0100;B\u101D\u101E\u61C2ar;\u6955loor;\u630B\u0100er\u102D\u1043e\u0180;AV\u1035\u1036\u103C\u62A2rrow;\u61A6ector;\u695Biangle\u0180;BE\u1050\u1051\u1055\u62B3ar;\u69D0qual;\u62B5p\u0180DTV\u1063\u106E\u1078ownVector;\u694FeeVector;\u695Cector\u0100;B\u1082\u1083\u61BEar;\u6954ector\u0100;B\u1091\u1092\u61C0ar;\u6953\u0100pu\u109B\u109Ef;\u611DndImplies;\u6970ightarrow;\u61DB\u0100ch\u10B9\u10BCr;\u611B;\u61B1leDelayed;\u69F4\u0680HOacfhimoqstu\u10E4\u10F1\u10F7\u10FD\u1119\u111E\u1151\u1156\u1161\u1167\u11B5\u11BB\u11BF\u0100Cc\u10E9\u10EEHcy;\u4429y;\u4428FTcy;\u442Ccute;\u415A\u0280;aeiy\u1108\u1109\u110E\u1113\u1117\u6ABCron;\u4160dil;\u415Erc;\u415C;\u4421r;\uC000\u{1D516}ort\u0200DLRU\u112A\u1134\u113E\u1149ownArrow\xBB\u041EeftArrow\xBB\u089AightArrow\xBB\u0FDDpArrow;\u6191gma;\u43A3allCircle;\u6218pf;\uC000\u{1D54A}\u0272\u116D\0\0\u1170t;\u621Aare\u0200;ISU\u117B\u117C\u1189\u11AF\u65A1ntersection;\u6293u\u0100bp\u118F\u119Eset\u0100;E\u1197\u1198\u628Fqual;\u6291erset\u0100;E\u11A8\u11A9\u6290qual;\u6292nion;\u6294cr;\uC000\u{1D4AE}ar;\u62C6\u0200bcmp\u11C8\u11DB\u1209\u120B\u0100;s\u11CD\u11CE\u62D0et\u0100;E\u11CD\u11D5qual;\u6286\u0100ch\u11E0\u1205eeds\u0200;EST\u11ED\u11EE\u11F4\u11FF\u627Bqual;\u6AB0lantEqual;\u627Dilde;\u627FTh\xE1\u0F8C;\u6211\u0180;es\u1212\u1213\u1223\u62D1rset\u0100;E\u121C\u121D\u6283qual;\u6287et\xBB\u1213\u0580HRSacfhiors\u123E\u1244\u1249\u1255\u125E\u1271\u1276\u129F\u12C2\u12C8\u12D1ORN\u803B\xDE\u40DEADE;\u6122\u0100Hc\u124E\u1252cy;\u440By;\u4426\u0100bu\u125A\u125C;\u4009;\u43A4\u0180aey\u1265\u126A\u126Fron;\u4164dil;\u4162;\u4422r;\uC000\u{1D517}\u0100ei\u127B\u1289\u01F2\u1280\0\u1287efore;\u6234a;\u4398\u0100cn\u128E\u1298kSpace;\uC000\u205F\u200ASpace;\u6009lde\u0200;EFT\u12AB\u12AC\u12B2\u12BC\u623Cqual;\u6243ullEqual;\u6245ilde;\u6248pf;\uC000\u{1D54B}ipleDot;\u60DB\u0100ct\u12D6\u12DBr;\uC000\u{1D4AF}rok;\u4166\u0AE1\u12F7\u130E\u131A\u1326\0\u132C\u1331\0\0\0\0\0\u1338\u133D\u1377\u1385\0\u13FF\u1404\u140A\u1410\u0100cr\u12FB\u1301ute\u803B\xDA\u40DAr\u0100;o\u1307\u1308\u619Fcir;\u6949r\u01E3\u1313\0\u1316y;\u440Eve;\u416C\u0100iy\u131E\u1323rc\u803B\xDB\u40DB;\u4423blac;\u4170r;\uC000\u{1D518}rave\u803B\xD9\u40D9acr;\u416A\u0100di\u1341\u1369er\u0100BP\u1348\u135D\u0100ar\u134D\u1350r;\u405Fac\u0100ek\u1357\u1359;\u63DFet;\u63B5arenthesis;\u63DDon\u0100;P\u1370\u1371\u62C3lus;\u628E\u0100gp\u137B\u137Fon;\u4172f;\uC000\u{1D54C}\u0400ADETadps\u1395\u13AE\u13B8\u13C4\u03E8\u13D2\u13D7\u13F3rrow\u0180;BD\u1150\u13A0\u13A4ar;\u6912ownArrow;\u61C5ownArrow;\u6195quilibrium;\u696Eee\u0100;A\u13CB\u13CC\u62A5rrow;\u61A5own\xE1\u03F3er\u0100LR\u13DE\u13E8eftArrow;\u6196ightArrow;\u6197i\u0100;l\u13F9\u13FA\u43D2on;\u43A5ing;\u416Ecr;\uC000\u{1D4B0}ilde;\u4168ml\u803B\xDC\u40DC\u0480Dbcdefosv\u1427\u142C\u1430\u1433\u143E\u1485\u148A\u1490\u1496ash;\u62ABar;\u6AEBy;\u4412ash\u0100;l\u143B\u143C\u62A9;\u6AE6\u0100er\u1443\u1445;\u62C1\u0180bty\u144C\u1450\u147Aar;\u6016\u0100;i\u144F\u1455cal\u0200BLST\u1461\u1465\u146A\u1474ar;\u6223ine;\u407Ceparator;\u6758ilde;\u6240ThinSpace;\u600Ar;\uC000\u{1D519}pf;\uC000\u{1D54D}cr;\uC000\u{1D4B1}dash;\u62AA\u0280cefos\u14A7\u14AC\u14B1\u14B6\u14BCirc;\u4174dge;\u62C0r;\uC000\u{1D51A}pf;\uC000\u{1D54E}cr;\uC000\u{1D4B2}\u0200fios\u14CB\u14D0\u14D2\u14D8r;\uC000\u{1D51B};\u439Epf;\uC000\u{1D54F}cr;\uC000\u{1D4B3}\u0480AIUacfosu\u14F1\u14F5\u14F9\u14FD\u1504\u150F\u1514\u151A\u1520cy;\u442Fcy;\u4407cy;\u442Ecute\u803B\xDD\u40DD\u0100iy\u1509\u150Drc;\u4176;\u442Br;\uC000\u{1D51C}pf;\uC000\u{1D550}cr;\uC000\u{1D4B4}ml;\u4178\u0400Hacdefos\u1535\u1539\u153F\u154B\u154F\u155D\u1560\u1564cy;\u4416cute;\u4179\u0100ay\u1544\u1549ron;\u417D;\u4417ot;\u417B\u01F2\u1554\0\u155BoWidt\xE8\u0AD9a;\u4396r;\u6128pf;\u6124cr;\uC000\u{1D4B5}\u0BE1\u1583\u158A\u1590\0\u15B0\u15B6\u15BF\0\0\0\0\u15C6\u15DB\u15EB\u165F\u166D\0\u1695\u169B\u16B2\u16B9\0\u16BEcute\u803B\xE1\u40E1reve;\u4103\u0300;Ediuy\u159C\u159D\u15A1\u15A3\u15A8\u15AD\u623E;\uC000\u223E\u0333;\u623Frc\u803B\xE2\u40E2te\u80BB\xB4\u0306;\u4430lig\u803B\xE6\u40E6\u0100;r\xB2\u15BA;\uC000\u{1D51E}rave\u803B\xE0\u40E0\u0100ep\u15CA\u15D6\u0100fp\u15CF\u15D4sym;\u6135\xE8\u15D3ha;\u43B1\u0100ap\u15DFc\u0100cl\u15E4\u15E7r;\u4101g;\u6A3F\u0264\u15F0\0\0\u160A\u0280;adsv\u15FA\u15FB\u15FF\u1601\u1607\u6227nd;\u6A55;\u6A5Clope;\u6A58;\u6A5A\u0380;elmrsz\u1618\u1619\u161B\u161E\u163F\u164F\u1659\u6220;\u69A4e\xBB\u1619sd\u0100;a\u1625\u1626\u6221\u0461\u1630\u1632\u1634\u1636\u1638\u163A\u163C\u163E;\u69A8;\u69A9;\u69AA;\u69AB;\u69AC;\u69AD;\u69AE;\u69AFt\u0100;v\u1645\u1646\u621Fb\u0100;d\u164C\u164D\u62BE;\u699D\u0100pt\u1654\u1657h;\u6222\xBB\xB9arr;\u637C\u0100gp\u1663\u1667on;\u4105f;\uC000\u{1D552}\u0380;Eaeiop\u12C1\u167B\u167D\u1682\u1684\u1687\u168A;\u6A70cir;\u6A6F;\u624Ad;\u624Bs;\u4027rox\u0100;e\u12C1\u1692\xF1\u1683ing\u803B\xE5\u40E5\u0180cty\u16A1\u16A6\u16A8r;\uC000\u{1D4B6};\u402Amp\u0100;e\u12C1\u16AF\xF1\u0288ilde\u803B\xE3\u40E3ml\u803B\xE4\u40E4\u0100ci\u16C2\u16C8onin\xF4\u0272nt;\u6A11\u0800Nabcdefiklnoprsu\u16ED\u16F1\u1730\u173C\u1743\u1748\u1778\u177D\u17E0\u17E6\u1839\u1850\u170D\u193D\u1948\u1970ot;\u6AED\u0100cr\u16F6\u171Ek\u0200ceps\u1700\u1705\u170D\u1713ong;\u624Cpsilon;\u43F6rime;\u6035im\u0100;e\u171A\u171B\u623Dq;\u62CD\u0176\u1722\u1726ee;\u62BDed\u0100;g\u172C\u172D\u6305e\xBB\u172Drk\u0100;t\u135C\u1737brk;\u63B6\u0100oy\u1701\u1741;\u4431quo;\u601E\u0280cmprt\u1753\u175B\u1761\u1764\u1768aus\u0100;e\u010A\u0109ptyv;\u69B0s\xE9\u170Cno\xF5\u0113\u0180ahw\u176F\u1771\u1773;\u43B2;\u6136een;\u626Cr;\uC000\u{1D51F}g\u0380costuvw\u178D\u179D\u17B3\u17C1\u17D5\u17DB\u17DE\u0180aiu\u1794\u1796\u179A\xF0\u0760rc;\u65EFp\xBB\u1371\u0180dpt\u17A4\u17A8\u17ADot;\u6A00lus;\u6A01imes;\u6A02\u0271\u17B9\0\0\u17BEcup;\u6A06ar;\u6605riangle\u0100du\u17CD\u17D2own;\u65BDp;\u65B3plus;\u6A04e\xE5\u1444\xE5\u14ADarow;\u690D\u0180ako\u17ED\u1826\u1835\u0100cn\u17F2\u1823k\u0180lst\u17FA\u05AB\u1802ozenge;\u69EBriangle\u0200;dlr\u1812\u1813\u1818\u181D\u65B4own;\u65BEeft;\u65C2ight;\u65B8k;\u6423\u01B1\u182B\0\u1833\u01B2\u182F\0\u1831;\u6592;\u65914;\u6593ck;\u6588\u0100eo\u183E\u184D\u0100;q\u1843\u1846\uC000=\u20E5uiv;\uC000\u2261\u20E5t;\u6310\u0200ptwx\u1859\u185E\u1867\u186Cf;\uC000\u{1D553}\u0100;t\u13CB\u1863om\xBB\u13CCtie;\u62C8\u0600DHUVbdhmptuv\u1885\u1896\u18AA\u18BB\u18D7\u18DB\u18EC\u18FF\u1905\u190A\u1910\u1921\u0200LRlr\u188E\u1890\u1892\u1894;\u6557;\u6554;\u6556;\u6553\u0280;DUdu\u18A1\u18A2\u18A4\u18A6\u18A8\u6550;\u6566;\u6569;\u6564;\u6567\u0200LRlr\u18B3\u18B5\u18B7\u18B9;\u655D;\u655A;\u655C;\u6559\u0380;HLRhlr\u18CA\u18CB\u18CD\u18CF\u18D1\u18D3\u18D5\u6551;\u656C;\u6563;\u6560;\u656B;\u6562;\u655Fox;\u69C9\u0200LRlr\u18E4\u18E6\u18E8\u18EA;\u6555;\u6552;\u6510;\u650C\u0280;DUdu\u06BD\u18F7\u18F9\u18FB\u18FD;\u6565;\u6568;\u652C;\u6534inus;\u629Flus;\u629Eimes;\u62A0\u0200LRlr\u1919\u191B\u191D\u191F;\u655B;\u6558;\u6518;\u6514\u0380;HLRhlr\u1930\u1931\u1933\u1935\u1937\u1939\u193B\u6502;\u656A;\u6561;\u655E;\u653C;\u6524;\u651C\u0100ev\u0123\u1942bar\u803B\xA6\u40A6\u0200ceio\u1951\u1956\u195A\u1960r;\uC000\u{1D4B7}mi;\u604Fm\u0100;e\u171A\u171Cl\u0180;bh\u1968\u1969\u196B\u405C;\u69C5sub;\u67C8\u016C\u1974\u197El\u0100;e\u1979\u197A\u6022t\xBB\u197Ap\u0180;Ee\u012F\u1985\u1987;\u6AAE\u0100;q\u06DC\u06DB\u0CE1\u19A7\0\u19E8\u1A11\u1A15\u1A32\0\u1A37\u1A50\0\0\u1AB4\0\0\u1AC1\0\0\u1B21\u1B2E\u1B4D\u1B52\0\u1BFD\0\u1C0C\u0180cpr\u19AD\u19B2\u19DDute;\u4107\u0300;abcds\u19BF\u19C0\u19C4\u19CA\u19D5\u19D9\u6229nd;\u6A44rcup;\u6A49\u0100au\u19CF\u19D2p;\u6A4Bp;\u6A47ot;\u6A40;\uC000\u2229\uFE00\u0100eo\u19E2\u19E5t;\u6041\xEE\u0693\u0200aeiu\u19F0\u19FB\u1A01\u1A05\u01F0\u19F5\0\u19F8s;\u6A4Don;\u410Ddil\u803B\xE7\u40E7rc;\u4109ps\u0100;s\u1A0C\u1A0D\u6A4Cm;\u6A50ot;\u410B\u0180dmn\u1A1B\u1A20\u1A26il\u80BB\xB8\u01ADptyv;\u69B2t\u8100\xA2;e\u1A2D\u1A2E\u40A2r\xE4\u01B2r;\uC000\u{1D520}\u0180cei\u1A3D\u1A40\u1A4Dy;\u4447ck\u0100;m\u1A47\u1A48\u6713ark\xBB\u1A48;\u43C7r\u0380;Ecefms\u1A5F\u1A60\u1A62\u1A6B\u1AA4\u1AAA\u1AAE\u65CB;\u69C3\u0180;el\u1A69\u1A6A\u1A6D\u42C6q;\u6257e\u0261\u1A74\0\0\u1A88rrow\u0100lr\u1A7C\u1A81eft;\u61BAight;\u61BB\u0280RSacd\u1A92\u1A94\u1A96\u1A9A\u1A9F\xBB\u0F47;\u64C8st;\u629Birc;\u629Aash;\u629Dnint;\u6A10id;\u6AEFcir;\u69C2ubs\u0100;u\u1ABB\u1ABC\u6663it\xBB\u1ABC\u02EC\u1AC7\u1AD4\u1AFA\0\u1B0Aon\u0100;e\u1ACD\u1ACE\u403A\u0100;q\xC7\xC6\u026D\u1AD9\0\0\u1AE2a\u0100;t\u1ADE\u1ADF\u402C;\u4040\u0180;fl\u1AE8\u1AE9\u1AEB\u6201\xEE\u1160e\u0100mx\u1AF1\u1AF6ent\xBB\u1AE9e\xF3\u024D\u01E7\u1AFE\0\u1B07\u0100;d\u12BB\u1B02ot;\u6A6Dn\xF4\u0246\u0180fry\u1B10\u1B14\u1B17;\uC000\u{1D554}o\xE4\u0254\u8100\xA9;s\u0155\u1B1Dr;\u6117\u0100ao\u1B25\u1B29rr;\u61B5ss;\u6717\u0100cu\u1B32\u1B37r;\uC000\u{1D4B8}\u0100bp\u1B3C\u1B44\u0100;e\u1B41\u1B42\u6ACF;\u6AD1\u0100;e\u1B49\u1B4A\u6AD0;\u6AD2dot;\u62EF\u0380delprvw\u1B60\u1B6C\u1B77\u1B82\u1BAC\u1BD4\u1BF9arr\u0100lr\u1B68\u1B6A;\u6938;\u6935\u0270\u1B72\0\0\u1B75r;\u62DEc;\u62DFarr\u0100;p\u1B7F\u1B80\u61B6;\u693D\u0300;bcdos\u1B8F\u1B90\u1B96\u1BA1\u1BA5\u1BA8\u622Arcap;\u6A48\u0100au\u1B9B\u1B9Ep;\u6A46p;\u6A4Aot;\u628Dr;\u6A45;\uC000\u222A\uFE00\u0200alrv\u1BB5\u1BBF\u1BDE\u1BE3rr\u0100;m\u1BBC\u1BBD\u61B7;\u693Cy\u0180evw\u1BC7\u1BD4\u1BD8q\u0270\u1BCE\0\0\u1BD2re\xE3\u1B73u\xE3\u1B75ee;\u62CEedge;\u62CFen\u803B\xA4\u40A4earrow\u0100lr\u1BEE\u1BF3eft\xBB\u1B80ight\xBB\u1BBDe\xE4\u1BDD\u0100ci\u1C01\u1C07onin\xF4\u01F7nt;\u6231lcty;\u632D\u0980AHabcdefhijlorstuwz\u1C38\u1C3B\u1C3F\u1C5D\u1C69\u1C75\u1C8A\u1C9E\u1CAC\u1CB7\u1CFB\u1CFF\u1D0D\u1D7B\u1D91\u1DAB\u1DBB\u1DC6\u1DCDr\xF2\u0381ar;\u6965\u0200glrs\u1C48\u1C4D\u1C52\u1C54ger;\u6020eth;\u6138\xF2\u1133h\u0100;v\u1C5A\u1C5B\u6010\xBB\u090A\u016B\u1C61\u1C67arow;\u690Fa\xE3\u0315\u0100ay\u1C6E\u1C73ron;\u410F;\u4434\u0180;ao\u0332\u1C7C\u1C84\u0100gr\u02BF\u1C81r;\u61CAtseq;\u6A77\u0180glm\u1C91\u1C94\u1C98\u803B\xB0\u40B0ta;\u43B4ptyv;\u69B1\u0100ir\u1CA3\u1CA8sht;\u697F;\uC000\u{1D521}ar\u0100lr\u1CB3\u1CB5\xBB\u08DC\xBB\u101E\u0280aegsv\u1CC2\u0378\u1CD6\u1CDC\u1CE0m\u0180;os\u0326\u1CCA\u1CD4nd\u0100;s\u0326\u1CD1uit;\u6666amma;\u43DDin;\u62F2\u0180;io\u1CE7\u1CE8\u1CF8\u40F7de\u8100\xF7;o\u1CE7\u1CF0ntimes;\u62C7n\xF8\u1CF7cy;\u4452c\u026F\u1D06\0\0\u1D0Arn;\u631Eop;\u630D\u0280lptuw\u1D18\u1D1D\u1D22\u1D49\u1D55lar;\u4024f;\uC000\u{1D555}\u0280;emps\u030B\u1D2D\u1D37\u1D3D\u1D42q\u0100;d\u0352\u1D33ot;\u6251inus;\u6238lus;\u6214quare;\u62A1blebarwedg\xE5\xFAn\u0180adh\u112E\u1D5D\u1D67ownarrow\xF3\u1C83arpoon\u0100lr\u1D72\u1D76ef\xF4\u1CB4igh\xF4\u1CB6\u0162\u1D7F\u1D85karo\xF7\u0F42\u026F\u1D8A\0\0\u1D8Ern;\u631Fop;\u630C\u0180cot\u1D98\u1DA3\u1DA6\u0100ry\u1D9D\u1DA1;\uC000\u{1D4B9};\u4455l;\u69F6rok;\u4111\u0100dr\u1DB0\u1DB4ot;\u62F1i\u0100;f\u1DBA\u1816\u65BF\u0100ah\u1DC0\u1DC3r\xF2\u0429a\xF2\u0FA6angle;\u69A6\u0100ci\u1DD2\u1DD5y;\u445Fgrarr;\u67FF\u0900Dacdefglmnopqrstux\u1E01\u1E09\u1E19\u1E38\u0578\u1E3C\u1E49\u1E61\u1E7E\u1EA5\u1EAF\u1EBD\u1EE1\u1F2A\u1F37\u1F44\u1F4E\u1F5A\u0100Do\u1E06\u1D34o\xF4\u1C89\u0100cs\u1E0E\u1E14ute\u803B\xE9\u40E9ter;\u6A6E\u0200aioy\u1E22\u1E27\u1E31\u1E36ron;\u411Br\u0100;c\u1E2D\u1E2E\u6256\u803B\xEA\u40EAlon;\u6255;\u444Dot;\u4117\u0100Dr\u1E41\u1E45ot;\u6252;\uC000\u{1D522}\u0180;rs\u1E50\u1E51\u1E57\u6A9Aave\u803B\xE8\u40E8\u0100;d\u1E5C\u1E5D\u6A96ot;\u6A98\u0200;ils\u1E6A\u1E6B\u1E72\u1E74\u6A99nters;\u63E7;\u6113\u0100;d\u1E79\u1E7A\u6A95ot;\u6A97\u0180aps\u1E85\u1E89\u1E97cr;\u4113ty\u0180;sv\u1E92\u1E93\u1E95\u6205et\xBB\u1E93p\u01001;\u1E9D\u1EA4\u0133\u1EA1\u1EA3;\u6004;\u6005\u6003\u0100gs\u1EAA\u1EAC;\u414Bp;\u6002\u0100gp\u1EB4\u1EB8on;\u4119f;\uC000\u{1D556}\u0180als\u1EC4\u1ECE\u1ED2r\u0100;s\u1ECA\u1ECB\u62D5l;\u69E3us;\u6A71i\u0180;lv\u1EDA\u1EDB\u1EDF\u43B5on\xBB\u1EDB;\u43F5\u0200csuv\u1EEA\u1EF3\u1F0B\u1F23\u0100io\u1EEF\u1E31rc\xBB\u1E2E\u0269\u1EF9\0\0\u1EFB\xED\u0548ant\u0100gl\u1F02\u1F06tr\xBB\u1E5Dess\xBB\u1E7A\u0180aei\u1F12\u1F16\u1F1Als;\u403Dst;\u625Fv\u0100;D\u0235\u1F20D;\u6A78parsl;\u69E5\u0100Da\u1F2F\u1F33ot;\u6253rr;\u6971\u0180cdi\u1F3E\u1F41\u1EF8r;\u612Fo\xF4\u0352\u0100ah\u1F49\u1F4B;\u43B7\u803B\xF0\u40F0\u0100mr\u1F53\u1F57l\u803B\xEB\u40EBo;\u60AC\u0180cip\u1F61\u1F64\u1F67l;\u4021s\xF4\u056E\u0100eo\u1F6C\u1F74ctatio\xEE\u0559nential\xE5\u0579\u09E1\u1F92\0\u1F9E\0\u1FA1\u1FA7\0\0\u1FC6\u1FCC\0\u1FD3\0\u1FE6\u1FEA\u2000\0\u2008\u205Allingdotse\xF1\u1E44y;\u4444male;\u6640\u0180ilr\u1FAD\u1FB3\u1FC1lig;\u8000\uFB03\u0269\u1FB9\0\0\u1FBDg;\u8000\uFB00ig;\u8000\uFB04;\uC000\u{1D523}lig;\u8000\uFB01lig;\uC000fj\u0180alt\u1FD9\u1FDC\u1FE1t;\u666Dig;\u8000\uFB02ns;\u65B1of;\u4192\u01F0\u1FEE\0\u1FF3f;\uC000\u{1D557}\u0100ak\u05BF\u1FF7\u0100;v\u1FFC\u1FFD\u62D4;\u6AD9artint;\u6A0D\u0100ao\u200C\u2055\u0100cs\u2011\u2052\u03B1\u201A\u2030\u2038\u2045\u2048\0\u2050\u03B2\u2022\u2025\u2027\u202A\u202C\0\u202E\u803B\xBD\u40BD;\u6153\u803B\xBC\u40BC;\u6155;\u6159;\u615B\u01B3\u2034\0\u2036;\u6154;\u6156\u02B4\u203E\u2041\0\0\u2043\u803B\xBE\u40BE;\u6157;\u615C5;\u6158\u01B6\u204C\0\u204E;\u615A;\u615D8;\u615El;\u6044wn;\u6322cr;\uC000\u{1D4BB}\u0880Eabcdefgijlnorstv\u2082\u2089\u209F\u20A5\u20B0\u20B4\u20F0\u20F5\u20FA\u20FF\u2103\u2112\u2138\u0317\u213E\u2152\u219E\u0100;l\u064D\u2087;\u6A8C\u0180cmp\u2090\u2095\u209Dute;\u41F5ma\u0100;d\u209C\u1CDA\u43B3;\u6A86reve;\u411F\u0100iy\u20AA\u20AErc;\u411D;\u4433ot;\u4121\u0200;lqs\u063E\u0642\u20BD\u20C9\u0180;qs\u063E\u064C\u20C4lan\xF4\u0665\u0200;cdl\u0665\u20D2\u20D5\u20E5c;\u6AA9ot\u0100;o\u20DC\u20DD\u6A80\u0100;l\u20E2\u20E3\u6A82;\u6A84\u0100;e\u20EA\u20ED\uC000\u22DB\uFE00s;\u6A94r;\uC000\u{1D524}\u0100;g\u0673\u061Bmel;\u6137cy;\u4453\u0200;Eaj\u065A\u210C\u210E\u2110;\u6A92;\u6AA5;\u6AA4\u0200Eaes\u211B\u211D\u2129\u2134;\u6269p\u0100;p\u2123\u2124\u6A8Arox\xBB\u2124\u0100;q\u212E\u212F\u6A88\u0100;q\u212E\u211Bim;\u62E7pf;\uC000\u{1D558}\u0100ci\u2143\u2146r;\u610Am\u0180;el\u066B\u214E\u2150;\u6A8E;\u6A90\u8300>;cdlqr\u05EE\u2160\u216A\u216E\u2173\u2179\u0100ci\u2165\u2167;\u6AA7r;\u6A7Aot;\u62D7Par;\u6995uest;\u6A7C\u0280adels\u2184\u216A\u2190\u0656\u219B\u01F0\u2189\0\u218Epro\xF8\u209Er;\u6978q\u0100lq\u063F\u2196les\xF3\u2088i\xED\u066B\u0100en\u21A3\u21ADrtneqq;\uC000\u2269\uFE00\xC5\u21AA\u0500Aabcefkosy\u21C4\u21C7\u21F1\u21F5\u21FA\u2218\u221D\u222F\u2268\u227Dr\xF2\u03A0\u0200ilmr\u21D0\u21D4\u21D7\u21DBrs\xF0\u1484f\xBB\u2024il\xF4\u06A9\u0100dr\u21E0\u21E4cy;\u444A\u0180;cw\u08F4\u21EB\u21EFir;\u6948;\u61ADar;\u610Firc;\u4125\u0180alr\u2201\u220E\u2213rts\u0100;u\u2209\u220A\u6665it\xBB\u220Alip;\u6026con;\u62B9r;\uC000\u{1D525}s\u0100ew\u2223\u2229arow;\u6925arow;\u6926\u0280amopr\u223A\u223E\u2243\u225E\u2263rr;\u61FFtht;\u623Bk\u0100lr\u2249\u2253eftarrow;\u61A9ightarrow;\u61AAf;\uC000\u{1D559}bar;\u6015\u0180clt\u226F\u2274\u2278r;\uC000\u{1D4BD}as\xE8\u21F4rok;\u4127\u0100bp\u2282\u2287ull;\u6043hen\xBB\u1C5B\u0AE1\u22A3\0\u22AA\0\u22B8\u22C5\u22CE\0\u22D5\u22F3\0\0\u22F8\u2322\u2367\u2362\u237F\0\u2386\u23AA\u23B4cute\u803B\xED\u40ED\u0180;iy\u0771\u22B0\u22B5rc\u803B\xEE\u40EE;\u4438\u0100cx\u22BC\u22BFy;\u4435cl\u803B\xA1\u40A1\u0100fr\u039F\u22C9;\uC000\u{1D526}rave\u803B\xEC\u40EC\u0200;ino\u073E\u22DD\u22E9\u22EE\u0100in\u22E2\u22E6nt;\u6A0Ct;\u622Dfin;\u69DCta;\u6129lig;\u4133\u0180aop\u22FE\u231A\u231D\u0180cgt\u2305\u2308\u2317r;\u412B\u0180elp\u071F\u230F\u2313in\xE5\u078Ear\xF4\u0720h;\u4131f;\u62B7ed;\u41B5\u0280;cfot\u04F4\u232C\u2331\u233D\u2341are;\u6105in\u0100;t\u2338\u2339\u621Eie;\u69DDdo\xF4\u2319\u0280;celp\u0757\u234C\u2350\u235B\u2361al;\u62BA\u0100gr\u2355\u2359er\xF3\u1563\xE3\u234Darhk;\u6A17rod;\u6A3C\u0200cgpt\u236F\u2372\u2376\u237By;\u4451on;\u412Ff;\uC000\u{1D55A}a;\u43B9uest\u803B\xBF\u40BF\u0100ci\u238A\u238Fr;\uC000\u{1D4BE}n\u0280;Edsv\u04F4\u239B\u239D\u23A1\u04F3;\u62F9ot;\u62F5\u0100;v\u23A6\u23A7\u62F4;\u62F3\u0100;i\u0777\u23AElde;\u4129\u01EB\u23B8\0\u23BCcy;\u4456l\u803B\xEF\u40EF\u0300cfmosu\u23CC\u23D7\u23DC\u23E1\u23E7\u23F5\u0100iy\u23D1\u23D5rc;\u4135;\u4439r;\uC000\u{1D527}ath;\u4237pf;\uC000\u{1D55B}\u01E3\u23EC\0\u23F1r;\uC000\u{1D4BF}rcy;\u4458kcy;\u4454\u0400acfghjos\u240B\u2416\u2422\u2427\u242D\u2431\u2435\u243Bppa\u0100;v\u2413\u2414\u43BA;\u43F0\u0100ey\u241B\u2420dil;\u4137;\u443Ar;\uC000\u{1D528}reen;\u4138cy;\u4445cy;\u445Cpf;\uC000\u{1D55C}cr;\uC000\u{1D4C0}\u0B80ABEHabcdefghjlmnoprstuv\u2470\u2481\u2486\u248D\u2491\u250E\u253D\u255A\u2580\u264E\u265E\u2665\u2679\u267D\u269A\u26B2\u26D8\u275D\u2768\u278B\u27C0\u2801\u2812\u0180art\u2477\u247A\u247Cr\xF2\u09C6\xF2\u0395ail;\u691Barr;\u690E\u0100;g\u0994\u248B;\u6A8Bar;\u6962\u0963\u24A5\0\u24AA\0\u24B1\0\0\0\0\0\u24B5\u24BA\0\u24C6\u24C8\u24CD\0\u24F9ute;\u413Amptyv;\u69B4ra\xEE\u084Cbda;\u43BBg\u0180;dl\u088E\u24C1\u24C3;\u6991\xE5\u088E;\u6A85uo\u803B\xAB\u40ABr\u0400;bfhlpst\u0899\u24DE\u24E6\u24E9\u24EB\u24EE\u24F1\u24F5\u0100;f\u089D\u24E3s;\u691Fs;\u691D\xEB\u2252p;\u61ABl;\u6939im;\u6973l;\u61A2\u0180;ae\u24FF\u2500\u2504\u6AABil;\u6919\u0100;s\u2509\u250A\u6AAD;\uC000\u2AAD\uFE00\u0180abr\u2515\u2519\u251Drr;\u690Crk;\u6772\u0100ak\u2522\u252Cc\u0100ek\u2528\u252A;\u407B;\u405B\u0100es\u2531\u2533;\u698Bl\u0100du\u2539\u253B;\u698F;\u698D\u0200aeuy\u2546\u254B\u2556\u2558ron;\u413E\u0100di\u2550\u2554il;\u413C\xEC\u08B0\xE2\u2529;\u443B\u0200cqrs\u2563\u2566\u256D\u257Da;\u6936uo\u0100;r\u0E19\u1746\u0100du\u2572\u2577har;\u6967shar;\u694Bh;\u61B2\u0280;fgqs\u258B\u258C\u0989\u25F3\u25FF\u6264t\u0280ahlrt\u2598\u25A4\u25B7\u25C2\u25E8rrow\u0100;t\u0899\u25A1a\xE9\u24F6arpoon\u0100du\u25AF\u25B4own\xBB\u045Ap\xBB\u0966eftarrows;\u61C7ight\u0180ahs\u25CD\u25D6\u25DErrow\u0100;s\u08F4\u08A7arpoon\xF3\u0F98quigarro\xF7\u21F0hreetimes;\u62CB\u0180;qs\u258B\u0993\u25FAlan\xF4\u09AC\u0280;cdgs\u09AC\u260A\u260D\u261D\u2628c;\u6AA8ot\u0100;o\u2614\u2615\u6A7F\u0100;r\u261A\u261B\u6A81;\u6A83\u0100;e\u2622\u2625\uC000\u22DA\uFE00s;\u6A93\u0280adegs\u2633\u2639\u263D\u2649\u264Bppro\xF8\u24C6ot;\u62D6q\u0100gq\u2643\u2645\xF4\u0989gt\xF2\u248C\xF4\u099Bi\xED\u09B2\u0180ilr\u2655\u08E1\u265Asht;\u697C;\uC000\u{1D529}\u0100;E\u099C\u2663;\u6A91\u0161\u2669\u2676r\u0100du\u25B2\u266E\u0100;l\u0965\u2673;\u696Alk;\u6584cy;\u4459\u0280;acht\u0A48\u2688\u268B\u2691\u2696r\xF2\u25C1orne\xF2\u1D08ard;\u696Bri;\u65FA\u0100io\u269F\u26A4dot;\u4140ust\u0100;a\u26AC\u26AD\u63B0che\xBB\u26AD\u0200Eaes\u26BB\u26BD\u26C9\u26D4;\u6268p\u0100;p\u26C3\u26C4\u6A89rox\xBB\u26C4\u0100;q\u26CE\u26CF\u6A87\u0100;q\u26CE\u26BBim;\u62E6\u0400abnoptwz\u26E9\u26F4\u26F7\u271A\u272F\u2741\u2747\u2750\u0100nr\u26EE\u26F1g;\u67ECr;\u61FDr\xEB\u08C1g\u0180lmr\u26FF\u270D\u2714eft\u0100ar\u09E6\u2707ight\xE1\u09F2apsto;\u67FCight\xE1\u09FDparrow\u0100lr\u2725\u2729ef\xF4\u24EDight;\u61AC\u0180afl\u2736\u2739\u273Dr;\u6985;\uC000\u{1D55D}us;\u6A2Dimes;\u6A34\u0161\u274B\u274Fst;\u6217\xE1\u134E\u0180;ef\u2757\u2758\u1800\u65CAnge\xBB\u2758ar\u0100;l\u2764\u2765\u4028t;\u6993\u0280achmt\u2773\u2776\u277C\u2785\u2787r\xF2\u08A8orne\xF2\u1D8Car\u0100;d\u0F98\u2783;\u696D;\u600Eri;\u62BF\u0300achiqt\u2798\u279D\u0A40\u27A2\u27AE\u27BBquo;\u6039r;\uC000\u{1D4C1}m\u0180;eg\u09B2\u27AA\u27AC;\u6A8D;\u6A8F\u0100bu\u252A\u27B3o\u0100;r\u0E1F\u27B9;\u601Arok;\u4142\u8400<;cdhilqr\u082B\u27D2\u2639\u27DC\u27E0\u27E5\u27EA\u27F0\u0100ci\u27D7\u27D9;\u6AA6r;\u6A79re\xE5\u25F2mes;\u62C9arr;\u6976uest;\u6A7B\u0100Pi\u27F5\u27F9ar;\u6996\u0180;ef\u2800\u092D\u181B\u65C3r\u0100du\u2807\u280Dshar;\u694Ahar;\u6966\u0100en\u2817\u2821rtneqq;\uC000\u2268\uFE00\xC5\u281E\u0700Dacdefhilnopsu\u2840\u2845\u2882\u288E\u2893\u28A0\u28A5\u28A8\u28DA\u28E2\u28E4\u0A83\u28F3\u2902Dot;\u623A\u0200clpr\u284E\u2852\u2863\u287Dr\u803B\xAF\u40AF\u0100et\u2857\u2859;\u6642\u0100;e\u285E\u285F\u6720se\xBB\u285F\u0100;s\u103B\u2868to\u0200;dlu\u103B\u2873\u2877\u287Bow\xEE\u048Cef\xF4\u090F\xF0\u13D1ker;\u65AE\u0100oy\u2887\u288Cmma;\u6A29;\u443Cash;\u6014asuredangle\xBB\u1626r;\uC000\u{1D52A}o;\u6127\u0180cdn\u28AF\u28B4\u28C9ro\u803B\xB5\u40B5\u0200;acd\u1464\u28BD\u28C0\u28C4s\xF4\u16A7ir;\u6AF0ot\u80BB\xB7\u01B5us\u0180;bd\u28D2\u1903\u28D3\u6212\u0100;u\u1D3C\u28D8;\u6A2A\u0163\u28DE\u28E1p;\u6ADB\xF2\u2212\xF0\u0A81\u0100dp\u28E9\u28EEels;\u62A7f;\uC000\u{1D55E}\u0100ct\u28F8\u28FDr;\uC000\u{1D4C2}pos\xBB\u159D\u0180;lm\u2909\u290A\u290D\u43BCtimap;\u62B8\u0C00GLRVabcdefghijlmoprstuvw\u2942\u2953\u297E\u2989\u2998\u29DA\u29E9\u2A15\u2A1A\u2A58\u2A5D\u2A83\u2A95\u2AA4\u2AA8\u2B04\u2B07\u2B44\u2B7F\u2BAE\u2C34\u2C67\u2C7C\u2CE9\u0100gt\u2947\u294B;\uC000\u22D9\u0338\u0100;v\u2950\u0BCF\uC000\u226B\u20D2\u0180elt\u295A\u2972\u2976ft\u0100ar\u2961\u2967rrow;\u61CDightarrow;\u61CE;\uC000\u22D8\u0338\u0100;v\u297B\u0C47\uC000\u226A\u20D2ightarrow;\u61CF\u0100Dd\u298E\u2993ash;\u62AFash;\u62AE\u0280bcnpt\u29A3\u29A7\u29AC\u29B1\u29CCla\xBB\u02DEute;\u4144g;\uC000\u2220\u20D2\u0280;Eiop\u0D84\u29BC\u29C0\u29C5\u29C8;\uC000\u2A70\u0338d;\uC000\u224B\u0338s;\u4149ro\xF8\u0D84ur\u0100;a\u29D3\u29D4\u666El\u0100;s\u29D3\u0B38\u01F3\u29DF\0\u29E3p\u80BB\xA0\u0B37mp\u0100;e\u0BF9\u0C00\u0280aeouy\u29F4\u29FE\u2A03\u2A10\u2A13\u01F0\u29F9\0\u29FB;\u6A43on;\u4148dil;\u4146ng\u0100;d\u0D7E\u2A0Aot;\uC000\u2A6D\u0338p;\u6A42;\u443Dash;\u6013\u0380;Aadqsx\u0B92\u2A29\u2A2D\u2A3B\u2A41\u2A45\u2A50rr;\u61D7r\u0100hr\u2A33\u2A36k;\u6924\u0100;o\u13F2\u13F0ot;\uC000\u2250\u0338ui\xF6\u0B63\u0100ei\u2A4A\u2A4Ear;\u6928\xED\u0B98ist\u0100;s\u0BA0\u0B9Fr;\uC000\u{1D52B}\u0200Eest\u0BC5\u2A66\u2A79\u2A7C\u0180;qs\u0BBC\u2A6D\u0BE1\u0180;qs\u0BBC\u0BC5\u2A74lan\xF4\u0BE2i\xED\u0BEA\u0100;r\u0BB6\u2A81\xBB\u0BB7\u0180Aap\u2A8A\u2A8D\u2A91r\xF2\u2971rr;\u61AEar;\u6AF2\u0180;sv\u0F8D\u2A9C\u0F8C\u0100;d\u2AA1\u2AA2\u62FC;\u62FAcy;\u445A\u0380AEadest\u2AB7\u2ABA\u2ABE\u2AC2\u2AC5\u2AF6\u2AF9r\xF2\u2966;\uC000\u2266\u0338rr;\u619Ar;\u6025\u0200;fqs\u0C3B\u2ACE\u2AE3\u2AEFt\u0100ar\u2AD4\u2AD9rro\xF7\u2AC1ightarro\xF7\u2A90\u0180;qs\u0C3B\u2ABA\u2AEAlan\xF4\u0C55\u0100;s\u0C55\u2AF4\xBB\u0C36i\xED\u0C5D\u0100;r\u0C35\u2AFEi\u0100;e\u0C1A\u0C25i\xE4\u0D90\u0100pt\u2B0C\u2B11f;\uC000\u{1D55F}\u8180\xAC;in\u2B19\u2B1A\u2B36\u40ACn\u0200;Edv\u0B89\u2B24\u2B28\u2B2E;\uC000\u22F9\u0338ot;\uC000\u22F5\u0338\u01E1\u0B89\u2B33\u2B35;\u62F7;\u62F6i\u0100;v\u0CB8\u2B3C\u01E1\u0CB8\u2B41\u2B43;\u62FE;\u62FD\u0180aor\u2B4B\u2B63\u2B69r\u0200;ast\u0B7B\u2B55\u2B5A\u2B5Flle\xEC\u0B7Bl;\uC000\u2AFD\u20E5;\uC000\u2202\u0338lint;\u6A14\u0180;ce\u0C92\u2B70\u2B73u\xE5\u0CA5\u0100;c\u0C98\u2B78\u0100;e\u0C92\u2B7D\xF1\u0C98\u0200Aait\u2B88\u2B8B\u2B9D\u2BA7r\xF2\u2988rr\u0180;cw\u2B94\u2B95\u2B99\u619B;\uC000\u2933\u0338;\uC000\u219D\u0338ghtarrow\xBB\u2B95ri\u0100;e\u0CCB\u0CD6\u0380chimpqu\u2BBD\u2BCD\u2BD9\u2B04\u0B78\u2BE4\u2BEF\u0200;cer\u0D32\u2BC6\u0D37\u2BC9u\xE5\u0D45;\uC000\u{1D4C3}ort\u026D\u2B05\0\0\u2BD6ar\xE1\u2B56m\u0100;e\u0D6E\u2BDF\u0100;q\u0D74\u0D73su\u0100bp\u2BEB\u2BED\xE5\u0CF8\xE5\u0D0B\u0180bcp\u2BF6\u2C11\u2C19\u0200;Ees\u2BFF\u2C00\u0D22\u2C04\u6284;\uC000\u2AC5\u0338et\u0100;e\u0D1B\u2C0Bq\u0100;q\u0D23\u2C00c\u0100;e\u0D32\u2C17\xF1\u0D38\u0200;Ees\u2C22\u2C23\u0D5F\u2C27\u6285;\uC000\u2AC6\u0338et\u0100;e\u0D58\u2C2Eq\u0100;q\u0D60\u2C23\u0200gilr\u2C3D\u2C3F\u2C45\u2C47\xEC\u0BD7lde\u803B\xF1\u40F1\xE7\u0C43iangle\u0100lr\u2C52\u2C5Ceft\u0100;e\u0C1A\u2C5A\xF1\u0C26ight\u0100;e\u0CCB\u2C65\xF1\u0CD7\u0100;m\u2C6C\u2C6D\u43BD\u0180;es\u2C74\u2C75\u2C79\u4023ro;\u6116p;\u6007\u0480DHadgilrs\u2C8F\u2C94\u2C99\u2C9E\u2CA3\u2CB0\u2CB6\u2CD3\u2CE3ash;\u62ADarr;\u6904p;\uC000\u224D\u20D2ash;\u62AC\u0100et\u2CA8\u2CAC;\uC000\u2265\u20D2;\uC000>\u20D2nfin;\u69DE\u0180Aet\u2CBD\u2CC1\u2CC5rr;\u6902;\uC000\u2264\u20D2\u0100;r\u2CCA\u2CCD\uC000<\u20D2ie;\uC000\u22B4\u20D2\u0100At\u2CD8\u2CDCrr;\u6903rie;\uC000\u22B5\u20D2im;\uC000\u223C\u20D2\u0180Aan\u2CF0\u2CF4\u2D02rr;\u61D6r\u0100hr\u2CFA\u2CFDk;\u6923\u0100;o\u13E7\u13E5ear;\u6927\u1253\u1A95\0\0\0\0\0\0\0\0\0\0\0\0\0\u2D2D\0\u2D38\u2D48\u2D60\u2D65\u2D72\u2D84\u1B07\0\0\u2D8D\u2DAB\0\u2DC8\u2DCE\0\u2DDC\u2E19\u2E2B\u2E3E\u2E43\u0100cs\u2D31\u1A97ute\u803B\xF3\u40F3\u0100iy\u2D3C\u2D45r\u0100;c\u1A9E\u2D42\u803B\xF4\u40F4;\u443E\u0280abios\u1AA0\u2D52\u2D57\u01C8\u2D5Alac;\u4151v;\u6A38old;\u69BClig;\u4153\u0100cr\u2D69\u2D6Dir;\u69BF;\uC000\u{1D52C}\u036F\u2D79\0\0\u2D7C\0\u2D82n;\u42DBave\u803B\xF2\u40F2;\u69C1\u0100bm\u2D88\u0DF4ar;\u69B5\u0200acit\u2D95\u2D98\u2DA5\u2DA8r\xF2\u1A80\u0100ir\u2D9D\u2DA0r;\u69BEoss;\u69BBn\xE5\u0E52;\u69C0\u0180aei\u2DB1\u2DB5\u2DB9cr;\u414Dga;\u43C9\u0180cdn\u2DC0\u2DC5\u01CDron;\u43BF;\u69B6pf;\uC000\u{1D560}\u0180ael\u2DD4\u2DD7\u01D2r;\u69B7rp;\u69B9\u0380;adiosv\u2DEA\u2DEB\u2DEE\u2E08\u2E0D\u2E10\u2E16\u6228r\xF2\u1A86\u0200;efm\u2DF7\u2DF8\u2E02\u2E05\u6A5Dr\u0100;o\u2DFE\u2DFF\u6134f\xBB\u2DFF\u803B\xAA\u40AA\u803B\xBA\u40BAgof;\u62B6r;\u6A56lope;\u6A57;\u6A5B\u0180clo\u2E1F\u2E21\u2E27\xF2\u2E01ash\u803B\xF8\u40F8l;\u6298i\u016C\u2E2F\u2E34de\u803B\xF5\u40F5es\u0100;a\u01DB\u2E3As;\u6A36ml\u803B\xF6\u40F6bar;\u633D\u0AE1\u2E5E\0\u2E7D\0\u2E80\u2E9D\0\u2EA2\u2EB9\0\0\u2ECB\u0E9C\0\u2F13\0\0\u2F2B\u2FBC\0\u2FC8r\u0200;ast\u0403\u2E67\u2E72\u0E85\u8100\xB6;l\u2E6D\u2E6E\u40B6le\xEC\u0403\u0269\u2E78\0\0\u2E7Bm;\u6AF3;\u6AFDy;\u443Fr\u0280cimpt\u2E8B\u2E8F\u2E93\u1865\u2E97nt;\u4025od;\u402Eil;\u6030enk;\u6031r;\uC000\u{1D52D}\u0180imo\u2EA8\u2EB0\u2EB4\u0100;v\u2EAD\u2EAE\u43C6;\u43D5ma\xF4\u0A76ne;\u660E\u0180;tv\u2EBF\u2EC0\u2EC8\u43C0chfork\xBB\u1FFD;\u43D6\u0100au\u2ECF\u2EDFn\u0100ck\u2ED5\u2EDDk\u0100;h\u21F4\u2EDB;\u610E\xF6\u21F4s\u0480;abcdemst\u2EF3\u2EF4\u1908\u2EF9\u2EFD\u2F04\u2F06\u2F0A\u2F0E\u402Bcir;\u6A23ir;\u6A22\u0100ou\u1D40\u2F02;\u6A25;\u6A72n\u80BB\xB1\u0E9Dim;\u6A26wo;\u6A27\u0180ipu\u2F19\u2F20\u2F25ntint;\u6A15f;\uC000\u{1D561}nd\u803B\xA3\u40A3\u0500;Eaceinosu\u0EC8\u2F3F\u2F41\u2F44\u2F47\u2F81\u2F89\u2F92\u2F7E\u2FB6;\u6AB3p;\u6AB7u\xE5\u0ED9\u0100;c\u0ECE\u2F4C\u0300;acens\u0EC8\u2F59\u2F5F\u2F66\u2F68\u2F7Eppro\xF8\u2F43urlye\xF1\u0ED9\xF1\u0ECE\u0180aes\u2F6F\u2F76\u2F7Approx;\u6AB9qq;\u6AB5im;\u62E8i\xED\u0EDFme\u0100;s\u2F88\u0EAE\u6032\u0180Eas\u2F78\u2F90\u2F7A\xF0\u2F75\u0180dfp\u0EEC\u2F99\u2FAF\u0180als\u2FA0\u2FA5\u2FAAlar;\u632Eine;\u6312urf;\u6313\u0100;t\u0EFB\u2FB4\xEF\u0EFBrel;\u62B0\u0100ci\u2FC0\u2FC5r;\uC000\u{1D4C5};\u43C8ncsp;\u6008\u0300fiopsu\u2FDA\u22E2\u2FDF\u2FE5\u2FEB\u2FF1r;\uC000\u{1D52E}pf;\uC000\u{1D562}rime;\u6057cr;\uC000\u{1D4C6}\u0180aeo\u2FF8\u3009\u3013t\u0100ei\u2FFE\u3005rnion\xF3\u06B0nt;\u6A16st\u0100;e\u3010\u3011\u403F\xF1\u1F19\xF4\u0F14\u0A80ABHabcdefhilmnoprstux\u3040\u3051\u3055\u3059\u30E0\u310E\u312B\u3147\u3162\u3172\u318E\u3206\u3215\u3224\u3229\u3258\u326E\u3272\u3290\u32B0\u32B7\u0180art\u3047\u304A\u304Cr\xF2\u10B3\xF2\u03DDail;\u691Car\xF2\u1C65ar;\u6964\u0380cdenqrt\u3068\u3075\u3078\u307F\u308F\u3094\u30CC\u0100eu\u306D\u3071;\uC000\u223D\u0331te;\u4155i\xE3\u116Emptyv;\u69B3g\u0200;del\u0FD1\u3089\u308B\u308D;\u6992;\u69A5\xE5\u0FD1uo\u803B\xBB\u40BBr\u0580;abcfhlpstw\u0FDC\u30AC\u30AF\u30B7\u30B9\u30BC\u30BE\u30C0\u30C3\u30C7\u30CAp;\u6975\u0100;f\u0FE0\u30B4s;\u6920;\u6933s;\u691E\xEB\u225D\xF0\u272El;\u6945im;\u6974l;\u61A3;\u619D\u0100ai\u30D1\u30D5il;\u691Ao\u0100;n\u30DB\u30DC\u6236al\xF3\u0F1E\u0180abr\u30E7\u30EA\u30EEr\xF2\u17E5rk;\u6773\u0100ak\u30F3\u30FDc\u0100ek\u30F9\u30FB;\u407D;\u405D\u0100es\u3102\u3104;\u698Cl\u0100du\u310A\u310C;\u698E;\u6990\u0200aeuy\u3117\u311C\u3127\u3129ron;\u4159\u0100di\u3121\u3125il;\u4157\xEC\u0FF2\xE2\u30FA;\u4440\u0200clqs\u3134\u3137\u313D\u3144a;\u6937dhar;\u6969uo\u0100;r\u020E\u020Dh;\u61B3\u0180acg\u314E\u315F\u0F44l\u0200;ips\u0F78\u3158\u315B\u109Cn\xE5\u10BBar\xF4\u0FA9t;\u65AD\u0180ilr\u3169\u1023\u316Esht;\u697D;\uC000\u{1D52F}\u0100ao\u3177\u3186r\u0100du\u317D\u317F\xBB\u047B\u0100;l\u1091\u3184;\u696C\u0100;v\u318B\u318C\u43C1;\u43F1\u0180gns\u3195\u31F9\u31FCht\u0300ahlrst\u31A4\u31B0\u31C2\u31D8\u31E4\u31EErrow\u0100;t\u0FDC\u31ADa\xE9\u30C8arpoon\u0100du\u31BB\u31BFow\xEE\u317Ep\xBB\u1092eft\u0100ah\u31CA\u31D0rrow\xF3\u0FEAarpoon\xF3\u0551ightarrows;\u61C9quigarro\xF7\u30CBhreetimes;\u62CCg;\u42DAingdotse\xF1\u1F32\u0180ahm\u320D\u3210\u3213r\xF2\u0FEAa\xF2\u0551;\u600Foust\u0100;a\u321E\u321F\u63B1che\xBB\u321Fmid;\u6AEE\u0200abpt\u3232\u323D\u3240\u3252\u0100nr\u3237\u323Ag;\u67EDr;\u61FEr\xEB\u1003\u0180afl\u3247\u324A\u324Er;\u6986;\uC000\u{1D563}us;\u6A2Eimes;\u6A35\u0100ap\u325D\u3267r\u0100;g\u3263\u3264\u4029t;\u6994olint;\u6A12ar\xF2\u31E3\u0200achq\u327B\u3280\u10BC\u3285quo;\u603Ar;\uC000\u{1D4C7}\u0100bu\u30FB\u328Ao\u0100;r\u0214\u0213\u0180hir\u3297\u329B\u32A0re\xE5\u31F8mes;\u62CAi\u0200;efl\u32AA\u1059\u1821\u32AB\u65B9tri;\u69CEluhar;\u6968;\u611E\u0D61\u32D5\u32DB\u32DF\u332C\u3338\u3371\0\u337A\u33A4\0\0\u33EC\u33F0\0\u3428\u3448\u345A\u34AD\u34B1\u34CA\u34F1\0\u3616\0\0\u3633cute;\u415Bqu\xEF\u27BA\u0500;Eaceinpsy\u11ED\u32F3\u32F5\u32FF\u3302\u330B\u330F\u331F\u3326\u3329;\u6AB4\u01F0\u32FA\0\u32FC;\u6AB8on;\u4161u\xE5\u11FE\u0100;d\u11F3\u3307il;\u415Frc;\u415D\u0180Eas\u3316\u3318\u331B;\u6AB6p;\u6ABAim;\u62E9olint;\u6A13i\xED\u1204;\u4441ot\u0180;be\u3334\u1D47\u3335\u62C5;\u6A66\u0380Aacmstx\u3346\u334A\u3357\u335B\u335E\u3363\u336Drr;\u61D8r\u0100hr\u3350\u3352\xEB\u2228\u0100;o\u0A36\u0A34t\u803B\xA7\u40A7i;\u403Bwar;\u6929m\u0100in\u3369\xF0nu\xF3\xF1t;\u6736r\u0100;o\u3376\u2055\uC000\u{1D530}\u0200acoy\u3382\u3386\u3391\u33A0rp;\u666F\u0100hy\u338B\u338Fcy;\u4449;\u4448rt\u026D\u3399\0\0\u339Ci\xE4\u1464ara\xEC\u2E6F\u803B\xAD\u40AD\u0100gm\u33A8\u33B4ma\u0180;fv\u33B1\u33B2\u33B2\u43C3;\u43C2\u0400;deglnpr\u12AB\u33C5\u33C9\u33CE\u33D6\u33DE\u33E1\u33E6ot;\u6A6A\u0100;q\u12B1\u12B0\u0100;E\u33D3\u33D4\u6A9E;\u6AA0\u0100;E\u33DB\u33DC\u6A9D;\u6A9Fe;\u6246lus;\u6A24arr;\u6972ar\xF2\u113D\u0200aeit\u33F8\u3408\u340F\u3417\u0100ls\u33FD\u3404lsetm\xE9\u336Ahp;\u6A33parsl;\u69E4\u0100dl\u1463\u3414e;\u6323\u0100;e\u341C\u341D\u6AAA\u0100;s\u3422\u3423\u6AAC;\uC000\u2AAC\uFE00\u0180flp\u342E\u3433\u3442tcy;\u444C\u0100;b\u3438\u3439\u402F\u0100;a\u343E\u343F\u69C4r;\u633Ff;\uC000\u{1D564}a\u0100dr\u344D\u0402es\u0100;u\u3454\u3455\u6660it\xBB\u3455\u0180csu\u3460\u3479\u349F\u0100au\u3465\u346Fp\u0100;s\u1188\u346B;\uC000\u2293\uFE00p\u0100;s\u11B4\u3475;\uC000\u2294\uFE00u\u0100bp\u347F\u348F\u0180;es\u1197\u119C\u3486et\u0100;e\u1197\u348D\xF1\u119D\u0180;es\u11A8\u11AD\u3496et\u0100;e\u11A8\u349D\xF1\u11AE\u0180;af\u117B\u34A6\u05B0r\u0165\u34AB\u05B1\xBB\u117Car\xF2\u1148\u0200cemt\u34B9\u34BE\u34C2\u34C5r;\uC000\u{1D4C8}tm\xEE\xF1i\xEC\u3415ar\xE6\u11BE\u0100ar\u34CE\u34D5r\u0100;f\u34D4\u17BF\u6606\u0100an\u34DA\u34EDight\u0100ep\u34E3\u34EApsilo\xEE\u1EE0h\xE9\u2EAFs\xBB\u2852\u0280bcmnp\u34FB\u355E\u1209\u358B\u358E\u0480;Edemnprs\u350E\u350F\u3511\u3515\u351E\u3523\u352C\u3531\u3536\u6282;\u6AC5ot;\u6ABD\u0100;d\u11DA\u351Aot;\u6AC3ult;\u6AC1\u0100Ee\u3528\u352A;\u6ACB;\u628Alus;\u6ABFarr;\u6979\u0180eiu\u353D\u3552\u3555t\u0180;en\u350E\u3545\u354Bq\u0100;q\u11DA\u350Feq\u0100;q\u352B\u3528m;\u6AC7\u0100bp\u355A\u355C;\u6AD5;\u6AD3c\u0300;acens\u11ED\u356C\u3572\u3579\u357B\u3326ppro\xF8\u32FAurlye\xF1\u11FE\xF1\u11F3\u0180aes\u3582\u3588\u331Bppro\xF8\u331Aq\xF1\u3317g;\u666A\u0680123;Edehlmnps\u35A9\u35AC\u35AF\u121C\u35B2\u35B4\u35C0\u35C9\u35D5\u35DA\u35DF\u35E8\u35ED\u803B\xB9\u40B9\u803B\xB2\u40B2\u803B\xB3\u40B3;\u6AC6\u0100os\u35B9\u35BCt;\u6ABEub;\u6AD8\u0100;d\u1222\u35C5ot;\u6AC4s\u0100ou\u35CF\u35D2l;\u67C9b;\u6AD7arr;\u697Bult;\u6AC2\u0100Ee\u35E4\u35E6;\u6ACC;\u628Blus;\u6AC0\u0180eiu\u35F4\u3609\u360Ct\u0180;en\u121C\u35FC\u3602q\u0100;q\u1222\u35B2eq\u0100;q\u35E7\u35E4m;\u6AC8\u0100bp\u3611\u3613;\u6AD4;\u6AD6\u0180Aan\u361C\u3620\u362Drr;\u61D9r\u0100hr\u3626\u3628\xEB\u222E\u0100;o\u0A2B\u0A29war;\u692Alig\u803B\xDF\u40DF\u0BE1\u3651\u365D\u3660\u12CE\u3673\u3679\0\u367E\u36C2\0\0\0\0\0\u36DB\u3703\0\u3709\u376C\0\0\0\u3787\u0272\u3656\0\0\u365Bget;\u6316;\u43C4r\xEB\u0E5F\u0180aey\u3666\u366B\u3670ron;\u4165dil;\u4163;\u4442lrec;\u6315r;\uC000\u{1D531}\u0200eiko\u3686\u369D\u36B5\u36BC\u01F2\u368B\0\u3691e\u01004f\u1284\u1281a\u0180;sv\u3698\u3699\u369B\u43B8ym;\u43D1\u0100cn\u36A2\u36B2k\u0100as\u36A8\u36AEppro\xF8\u12C1im\xBB\u12ACs\xF0\u129E\u0100as\u36BA\u36AE\xF0\u12C1rn\u803B\xFE\u40FE\u01EC\u031F\u36C6\u22E7es\u8180\xD7;bd\u36CF\u36D0\u36D8\u40D7\u0100;a\u190F\u36D5r;\u6A31;\u6A30\u0180eps\u36E1\u36E3\u3700\xE1\u2A4D\u0200;bcf\u0486\u36EC\u36F0\u36F4ot;\u6336ir;\u6AF1\u0100;o\u36F9\u36FC\uC000\u{1D565}rk;\u6ADA\xE1\u3362rime;\u6034\u0180aip\u370F\u3712\u3764d\xE5\u1248\u0380adempst\u3721\u374D\u3740\u3751\u3757\u375C\u375Fngle\u0280;dlqr\u3730\u3731\u3736\u3740\u3742\u65B5own\xBB\u1DBBeft\u0100;e\u2800\u373E\xF1\u092E;\u625Cight\u0100;e\u32AA\u374B\xF1\u105Aot;\u65ECinus;\u6A3Alus;\u6A39b;\u69CDime;\u6A3Bezium;\u63E2\u0180cht\u3772\u377D\u3781\u0100ry\u3777\u377B;\uC000\u{1D4C9};\u4446cy;\u445Brok;\u4167\u0100io\u378B\u378Ex\xF4\u1777head\u0100lr\u3797\u37A0eftarro\xF7\u084Fightarrow\xBB\u0F5D\u0900AHabcdfghlmoprstuw\u37D0\u37D3\u37D7\u37E4\u37F0\u37FC\u380E\u381C\u3823\u3834\u3851\u385D\u386B\u38A9\u38CC\u38D2\u38EA\u38F6r\xF2\u03EDar;\u6963\u0100cr\u37DC\u37E2ute\u803B\xFA\u40FA\xF2\u1150r\u01E3\u37EA\0\u37EDy;\u445Eve;\u416D\u0100iy\u37F5\u37FArc\u803B\xFB\u40FB;\u4443\u0180abh\u3803\u3806\u380Br\xF2\u13ADlac;\u4171a\xF2\u13C3\u0100ir\u3813\u3818sht;\u697E;\uC000\u{1D532}rave\u803B\xF9\u40F9\u0161\u3827\u3831r\u0100lr\u382C\u382E\xBB\u0957\xBB\u1083lk;\u6580\u0100ct\u3839\u384D\u026F\u383F\0\0\u384Arn\u0100;e\u3845\u3846\u631Cr\xBB\u3846op;\u630Fri;\u65F8\u0100al\u3856\u385Acr;\u416B\u80BB\xA8\u0349\u0100gp\u3862\u3866on;\u4173f;\uC000\u{1D566}\u0300adhlsu\u114B\u3878\u387D\u1372\u3891\u38A0own\xE1\u13B3arpoon\u0100lr\u3888\u388Cef\xF4\u382Digh\xF4\u382Fi\u0180;hl\u3899\u389A\u389C\u43C5\xBB\u13FAon\xBB\u389Aparrows;\u61C8\u0180cit\u38B0\u38C4\u38C8\u026F\u38B6\0\0\u38C1rn\u0100;e\u38BC\u38BD\u631Dr\xBB\u38BDop;\u630Eng;\u416Fri;\u65F9cr;\uC000\u{1D4CA}\u0180dir\u38D9\u38DD\u38E2ot;\u62F0lde;\u4169i\u0100;f\u3730\u38E8\xBB\u1813\u0100am\u38EF\u38F2r\xF2\u38A8l\u803B\xFC\u40FCangle;\u69A7\u0780ABDacdeflnoprsz\u391C\u391F\u3929\u392D\u39B5\u39B8\u39BD\u39DF\u39E4\u39E8\u39F3\u39F9\u39FD\u3A01\u3A20r\xF2\u03F7ar\u0100;v\u3926\u3927\u6AE8;\u6AE9as\xE8\u03E1\u0100nr\u3932\u3937grt;\u699C\u0380eknprst\u34E3\u3946\u394B\u3952\u395D\u3964\u3996app\xE1\u2415othin\xE7\u1E96\u0180hir\u34EB\u2EC8\u3959op\xF4\u2FB5\u0100;h\u13B7\u3962\xEF\u318D\u0100iu\u3969\u396Dgm\xE1\u33B3\u0100bp\u3972\u3984setneq\u0100;q\u397D\u3980\uC000\u228A\uFE00;\uC000\u2ACB\uFE00setneq\u0100;q\u398F\u3992\uC000\u228B\uFE00;\uC000\u2ACC\uFE00\u0100hr\u399B\u399Fet\xE1\u369Ciangle\u0100lr\u39AA\u39AFeft\xBB\u0925ight\xBB\u1051y;\u4432ash\xBB\u1036\u0180elr\u39C4\u39D2\u39D7\u0180;be\u2DEA\u39CB\u39CFar;\u62BBq;\u625Alip;\u62EE\u0100bt\u39DC\u1468a\xF2\u1469r;\uC000\u{1D533}tr\xE9\u39AEsu\u0100bp\u39EF\u39F1\xBB\u0D1C\xBB\u0D59pf;\uC000\u{1D567}ro\xF0\u0EFBtr\xE9\u39B4\u0100cu\u3A06\u3A0Br;\uC000\u{1D4CB}\u0100bp\u3A10\u3A18n\u0100Ee\u3980\u3A16\xBB\u397En\u0100Ee\u3992\u3A1E\xBB\u3990igzag;\u699A\u0380cefoprs\u3A36\u3A3B\u3A56\u3A5B\u3A54\u3A61\u3A6Airc;\u4175\u0100di\u3A40\u3A51\u0100bg\u3A45\u3A49ar;\u6A5Fe\u0100;q\u15FA\u3A4F;\u6259erp;\u6118r;\uC000\u{1D534}pf;\uC000\u{1D568}\u0100;e\u1479\u3A66at\xE8\u1479cr;\uC000\u{1D4CC}\u0AE3\u178E\u3A87\0\u3A8B\0\u3A90\u3A9B\0\0\u3A9D\u3AA8\u3AAB\u3AAF\0\0\u3AC3\u3ACE\0\u3AD8\u17DC\u17DFtr\xE9\u17D1r;\uC000\u{1D535}\u0100Aa\u3A94\u3A97r\xF2\u03C3r\xF2\u09F6;\u43BE\u0100Aa\u3AA1\u3AA4r\xF2\u03B8r\xF2\u09EBa\xF0\u2713is;\u62FB\u0180dpt\u17A4\u3AB5\u3ABE\u0100fl\u3ABA\u17A9;\uC000\u{1D569}im\xE5\u17B2\u0100Aa\u3AC7\u3ACAr\xF2\u03CEr\xF2\u0A01\u0100cq\u3AD2\u17B8r;\uC000\u{1D4CD}\u0100pt\u17D6\u3ADCr\xE9\u17D4\u0400acefiosu\u3AF0\u3AFD\u3B08\u3B0C\u3B11\u3B15\u3B1B\u3B21c\u0100uy\u3AF6\u3AFBte\u803B\xFD\u40FD;\u444F\u0100iy\u3B02\u3B06rc;\u4177;\u444Bn\u803B\xA5\u40A5r;\uC000\u{1D536}cy;\u4457pf;\uC000\u{1D56A}cr;\uC000\u{1D4CE}\u0100cm\u3B26\u3B29y;\u444El\u803B\xFF\u40FF\u0500acdefhiosw\u3B42\u3B48\u3B54\u3B58\u3B64\u3B69\u3B6D\u3B74\u3B7A\u3B80cute;\u417A\u0100ay\u3B4D\u3B52ron;\u417E;\u4437ot;\u417C\u0100et\u3B5D\u3B61tr\xE6\u155Fa;\u43B6r;\uC000\u{1D537}cy;\u4436grarr;\u61DDpf;\uC000\u{1D56B}cr;\uC000\u{1D4CF}\u0100jn\u3B85\u3B87;\u600Dj;\u600C'.split("").map(function(e4) {
      return e4.charCodeAt(0);
    }));
  }), D = m(function(e3, t2) {
    Object.defineProperty(t2, "__esModule", { value: true }), t2.default = new Uint16Array("\u0200aglq	\x1B\u026D\0\0p;\u4026os;\u4027t;\u403Et;\u403Cuot;\u4022".split("").map(function(e4) {
      return e4.charCodeAt(0);
    }));
  }), S = m(function(e3, t2) {
    var s2;
    Object.defineProperty(t2, "__esModule", { value: true }), t2.replaceCodePoint = t2.fromCodePoint = void 0;
    var a2 = /* @__PURE__ */ new Map([[0, 65533], [128, 8364], [130, 8218], [131, 402], [132, 8222], [133, 8230], [134, 8224], [135, 8225], [136, 710], [137, 8240], [138, 352], [139, 8249], [140, 338], [142, 381], [145, 8216], [146, 8217], [147, 8220], [148, 8221], [149, 8226], [150, 8211], [151, 8212], [152, 732], [153, 8482], [154, 353], [155, 8250], [156, 339], [158, 382], [159, 376]]);
    function r2(e4) {
      var t3;
      return e4 >= 55296 && e4 <= 57343 || e4 > 1114111 ? 65533 : null !== (t3 = a2.get(e4)) && void 0 !== t3 ? t3 : e4;
    }
    t2.fromCodePoint = null !== (s2 = String.fromCodePoint) && void 0 !== s2 ? s2 : function(e4) {
      var t3 = "";
      return e4 > 65535 && (e4 -= 65536, t3 += String.fromCharCode(e4 >>> 10 & 1023 | 55296), e4 = 56320 | 1023 & e4), t3 + String.fromCharCode(e4);
    }, t2.replaceCodePoint = r2, t2.default = function(e4) {
      return (0, t2.fromCodePoint)(r2(e4));
    };
  }), R = m(function(e3, t2) {
    var s2 = l && l.__importDefault || function(e4) {
      return e4 && e4.__esModule ? e4 : { default: e4 };
    };
    Object.defineProperty(t2, "__esModule", { value: true }), t2.decodeXML = t2.decodeHTMLStrict = t2.decodeHTML = t2.determineBranch = t2.BinTrieFlags = t2.fromCodePoint = t2.replaceCodePoint = t2.decodeCodePoint = t2.xmlDecodeTree = t2.htmlDecodeTree = void 0;
    var a2 = s2(C);
    t2.htmlDecodeTree = a2.default;
    var r2 = s2(D);
    t2.xmlDecodeTree = r2.default;
    var n2 = s2(S);
    t2.decodeCodePoint = n2.default;
    var i2, o2, c2 = S;
    function E2(e4) {
      return function(t3, s3) {
        for (var a3 = "", r3 = 0, c3 = 0; (c3 = t3.indexOf("&", c3)) >= 0; )
          if (a3 += t3.slice(r3, c3), r3 = c3, c3 += 1, t3.charCodeAt(c3) !== i2.NUM) {
            for (var E3 = 0, h3 = 1, _3 = 0, A2 = e4[_3]; c3 < t3.length && !((_3 = T2(e4, A2, _3 + 1, t3.charCodeAt(c3))) < 0); c3++, h3++) {
              var l2 = (A2 = e4[_3]) & o2.VALUE_LENGTH;
              if (l2) {
                var m2;
                if (s3 && t3.charCodeAt(c3) !== i2.SEMI || (E3 = _3, h3 = 0), 0 == (m2 = (l2 >> 14) - 1))
                  break;
                _3 += m2;
              }
            }
            0 !== E3 && (a3 += 1 == (m2 = (e4[E3] & o2.VALUE_LENGTH) >> 14) ? String.fromCharCode(e4[E3] & ~o2.VALUE_LENGTH) : 2 === m2 ? String.fromCharCode(e4[E3 + 1]) : String.fromCharCode(e4[E3 + 1], e4[E3 + 2]), r3 = c3 - h3 + 1);
          } else {
            var p2 = c3 + 1, d2 = 10, I2 = t3.charCodeAt(p2);
            (I2 | i2.To_LOWER_BIT) === i2.LOWER_X && (d2 = 16, c3 += 1, p2 += 1);
            do {
              I2 = t3.charCodeAt(++c3);
            } while (I2 >= i2.ZERO && I2 <= i2.NINE || 16 === d2 && (I2 | i2.To_LOWER_BIT) >= i2.LOWER_A && (I2 | i2.To_LOWER_BIT) <= i2.LOWER_F);
            if (p2 !== c3) {
              var N2 = t3.substring(p2, c3), u2 = parseInt(N2, d2);
              if (t3.charCodeAt(c3) === i2.SEMI)
                c3 += 1;
              else if (s3)
                continue;
              a3 += (0, n2.default)(u2), r3 = c3;
            }
          }
        return a3 + t3.slice(r3);
      };
    }
    function T2(e4, t3, s3, a3) {
      var r3 = (t3 & o2.BRANCH_LENGTH) >> 7, n3 = t3 & o2.JUMP_TABLE;
      if (0 === r3)
        return 0 !== n3 && a3 === n3 ? s3 : -1;
      if (n3) {
        var i3 = a3 - n3;
        return i3 < 0 || i3 >= r3 ? -1 : e4[s3 + i3] - 1;
      }
      for (var c3 = s3, E3 = c3 + r3 - 1; c3 <= E3; ) {
        var T3 = c3 + E3 >>> 1, h3 = e4[T3];
        if (h3 < a3)
          c3 = T3 + 1;
        else {
          if (!(h3 > a3))
            return e4[T3 + r3];
          E3 = T3 - 1;
        }
      }
      return -1;
    }
    Object.defineProperty(t2, "replaceCodePoint", { enumerable: true, get: function() {
      return c2.replaceCodePoint;
    } }), Object.defineProperty(t2, "fromCodePoint", { enumerable: true, get: function() {
      return c2.fromCodePoint;
    } }), function(e4) {
      e4[e4.NUM = 35] = "NUM", e4[e4.SEMI = 59] = "SEMI", e4[e4.ZERO = 48] = "ZERO", e4[e4.NINE = 57] = "NINE", e4[e4.LOWER_A = 97] = "LOWER_A", e4[e4.LOWER_F = 102] = "LOWER_F", e4[e4.LOWER_X = 120] = "LOWER_X", e4[e4.To_LOWER_BIT = 32] = "To_LOWER_BIT";
    }(i2 || (i2 = {})), function(e4) {
      e4[e4.VALUE_LENGTH = 49152] = "VALUE_LENGTH", e4[e4.BRANCH_LENGTH = 16256] = "BRANCH_LENGTH", e4[e4.JUMP_TABLE = 127] = "JUMP_TABLE";
    }(o2 = t2.BinTrieFlags || (t2.BinTrieFlags = {})), t2.determineBranch = T2;
    var h2 = E2(a2.default), _2 = E2(r2.default);
    t2.decodeHTML = function(e4) {
      return h2(e4, false);
    }, t2.decodeHTMLStrict = function(e4) {
      return h2(e4, true);
    }, t2.decodeXML = function(e4) {
      return _2(e4, true);
    };
  });
  !function(e3) {
    e3.HTML = "http://www.w3.org/1999/xhtml", e3.MATHML = "http://www.w3.org/1998/Math/MathML", e3.SVG = "http://www.w3.org/2000/svg", e3.XLINK = "http://www.w3.org/1999/xlink", e3.XML = "http://www.w3.org/XML/1998/namespace", e3.XMLNS = "http://www.w3.org/2000/xmlns/";
  }(p = p || (p = {})), function(e3) {
    e3.TYPE = "type", e3.ACTION = "action", e3.ENCODING = "encoding", e3.PROMPT = "prompt", e3.NAME = "name", e3.COLOR = "color", e3.FACE = "face", e3.SIZE = "size";
  }(d = d || (d = {})), function(e3) {
    e3.NO_QUIRKS = "no-quirks", e3.QUIRKS = "quirks", e3.LIMITED_QUIRKS = "limited-quirks";
  }(I = I || (I = {})), function(e3) {
    e3.A = "a", e3.ADDRESS = "address", e3.ANNOTATION_XML = "annotation-xml", e3.APPLET = "applet", e3.AREA = "area", e3.ARTICLE = "article", e3.ASIDE = "aside", e3.B = "b", e3.BASE = "base", e3.BASEFONT = "basefont", e3.BGSOUND = "bgsound", e3.BIG = "big", e3.BLOCKQUOTE = "blockquote", e3.BODY = "body", e3.BR = "br", e3.BUTTON = "button", e3.CAPTION = "caption", e3.CENTER = "center", e3.CODE = "code", e3.COL = "col", e3.COLGROUP = "colgroup", e3.DD = "dd", e3.DESC = "desc", e3.DETAILS = "details", e3.DIALOG = "dialog", e3.DIR = "dir", e3.DIV = "div", e3.DL = "dl", e3.DT = "dt", e3.EM = "em", e3.EMBED = "embed", e3.FIELDSET = "fieldset", e3.FIGCAPTION = "figcaption", e3.FIGURE = "figure", e3.FONT = "font", e3.FOOTER = "footer", e3.FOREIGN_OBJECT = "foreignObject", e3.FORM = "form", e3.FRAME = "frame", e3.FRAMESET = "frameset", e3.H1 = "h1", e3.H2 = "h2", e3.H3 = "h3", e3.H4 = "h4", e3.H5 = "h5", e3.H6 = "h6", e3.HEAD = "head", e3.HEADER = "header", e3.HGROUP = "hgroup", e3.HR = "hr", e3.HTML = "html", e3.I = "i", e3.IMG = "img", e3.IMAGE = "image", e3.INPUT = "input", e3.IFRAME = "iframe", e3.KEYGEN = "keygen", e3.LABEL = "label", e3.LI = "li", e3.LINK = "link", e3.LISTING = "listing", e3.MAIN = "main", e3.MALIGNMARK = "malignmark", e3.MARQUEE = "marquee", e3.MATH = "math", e3.MENU = "menu", e3.META = "meta", e3.MGLYPH = "mglyph", e3.MI = "mi", e3.MO = "mo", e3.MN = "mn", e3.MS = "ms", e3.MTEXT = "mtext", e3.NAV = "nav", e3.NOBR = "nobr", e3.NOFRAMES = "noframes", e3.NOEMBED = "noembed", e3.NOSCRIPT = "noscript", e3.OBJECT = "object", e3.OL = "ol", e3.OPTGROUP = "optgroup", e3.OPTION = "option", e3.P = "p", e3.PARAM = "param", e3.PLAINTEXT = "plaintext", e3.PRE = "pre", e3.RB = "rb", e3.RP = "rp", e3.RT = "rt", e3.RTC = "rtc", e3.RUBY = "ruby", e3.S = "s", e3.SCRIPT = "script", e3.SECTION = "section", e3.SELECT = "select", e3.SOURCE = "source", e3.SMALL = "small", e3.SPAN = "span", e3.STRIKE = "strike", e3.STRONG = "strong", e3.STYLE = "style", e3.SUB = "sub", e3.SUMMARY = "summary", e3.SUP = "sup", e3.TABLE = "table", e3.TBODY = "tbody", e3.TEMPLATE = "template", e3.TEXTAREA = "textarea", e3.TFOOT = "tfoot", e3.TD = "td", e3.TH = "th", e3.THEAD = "thead", e3.TITLE = "title", e3.TR = "tr", e3.TRACK = "track", e3.TT = "tt", e3.U = "u", e3.UL = "ul", e3.SVG = "svg", e3.VAR = "var", e3.WBR = "wbr", e3.XMP = "xmp";
  }(N = N || (N = {})), function(e3) {
    e3[e3.UNKNOWN = 0] = "UNKNOWN", e3[e3.A = 1] = "A", e3[e3.ADDRESS = 2] = "ADDRESS", e3[e3.ANNOTATION_XML = 3] = "ANNOTATION_XML", e3[e3.APPLET = 4] = "APPLET", e3[e3.AREA = 5] = "AREA", e3[e3.ARTICLE = 6] = "ARTICLE", e3[e3.ASIDE = 7] = "ASIDE", e3[e3.B = 8] = "B", e3[e3.BASE = 9] = "BASE", e3[e3.BASEFONT = 10] = "BASEFONT", e3[e3.BGSOUND = 11] = "BGSOUND", e3[e3.BIG = 12] = "BIG", e3[e3.BLOCKQUOTE = 13] = "BLOCKQUOTE", e3[e3.BODY = 14] = "BODY", e3[e3.BR = 15] = "BR", e3[e3.BUTTON = 16] = "BUTTON", e3[e3.CAPTION = 17] = "CAPTION", e3[e3.CENTER = 18] = "CENTER", e3[e3.CODE = 19] = "CODE", e3[e3.COL = 20] = "COL", e3[e3.COLGROUP = 21] = "COLGROUP", e3[e3.DD = 22] = "DD", e3[e3.DESC = 23] = "DESC", e3[e3.DETAILS = 24] = "DETAILS", e3[e3.DIALOG = 25] = "DIALOG", e3[e3.DIR = 26] = "DIR", e3[e3.DIV = 27] = "DIV", e3[e3.DL = 28] = "DL", e3[e3.DT = 29] = "DT", e3[e3.EM = 30] = "EM", e3[e3.EMBED = 31] = "EMBED", e3[e3.FIELDSET = 32] = "FIELDSET", e3[e3.FIGCAPTION = 33] = "FIGCAPTION", e3[e3.FIGURE = 34] = "FIGURE", e3[e3.FONT = 35] = "FONT", e3[e3.FOOTER = 36] = "FOOTER", e3[e3.FOREIGN_OBJECT = 37] = "FOREIGN_OBJECT", e3[e3.FORM = 38] = "FORM", e3[e3.FRAME = 39] = "FRAME", e3[e3.FRAMESET = 40] = "FRAMESET", e3[e3.H1 = 41] = "H1", e3[e3.H2 = 42] = "H2", e3[e3.H3 = 43] = "H3", e3[e3.H4 = 44] = "H4", e3[e3.H5 = 45] = "H5", e3[e3.H6 = 46] = "H6", e3[e3.HEAD = 47] = "HEAD", e3[e3.HEADER = 48] = "HEADER", e3[e3.HGROUP = 49] = "HGROUP", e3[e3.HR = 50] = "HR", e3[e3.HTML = 51] = "HTML", e3[e3.I = 52] = "I", e3[e3.IMG = 53] = "IMG", e3[e3.IMAGE = 54] = "IMAGE", e3[e3.INPUT = 55] = "INPUT", e3[e3.IFRAME = 56] = "IFRAME", e3[e3.KEYGEN = 57] = "KEYGEN", e3[e3.LABEL = 58] = "LABEL", e3[e3.LI = 59] = "LI", e3[e3.LINK = 60] = "LINK", e3[e3.LISTING = 61] = "LISTING", e3[e3.MAIN = 62] = "MAIN", e3[e3.MALIGNMARK = 63] = "MALIGNMARK", e3[e3.MARQUEE = 64] = "MARQUEE", e3[e3.MATH = 65] = "MATH", e3[e3.MENU = 66] = "MENU", e3[e3.META = 67] = "META", e3[e3.MGLYPH = 68] = "MGLYPH", e3[e3.MI = 69] = "MI", e3[e3.MO = 70] = "MO", e3[e3.MN = 71] = "MN", e3[e3.MS = 72] = "MS", e3[e3.MTEXT = 73] = "MTEXT", e3[e3.NAV = 74] = "NAV", e3[e3.NOBR = 75] = "NOBR", e3[e3.NOFRAMES = 76] = "NOFRAMES", e3[e3.NOEMBED = 77] = "NOEMBED", e3[e3.NOSCRIPT = 78] = "NOSCRIPT", e3[e3.OBJECT = 79] = "OBJECT", e3[e3.OL = 80] = "OL", e3[e3.OPTGROUP = 81] = "OPTGROUP", e3[e3.OPTION = 82] = "OPTION", e3[e3.P = 83] = "P", e3[e3.PARAM = 84] = "PARAM", e3[e3.PLAINTEXT = 85] = "PLAINTEXT", e3[e3.PRE = 86] = "PRE", e3[e3.RB = 87] = "RB", e3[e3.RP = 88] = "RP", e3[e3.RT = 89] = "RT", e3[e3.RTC = 90] = "RTC", e3[e3.RUBY = 91] = "RUBY", e3[e3.S = 92] = "S", e3[e3.SCRIPT = 93] = "SCRIPT", e3[e3.SECTION = 94] = "SECTION", e3[e3.SELECT = 95] = "SELECT", e3[e3.SOURCE = 96] = "SOURCE", e3[e3.SMALL = 97] = "SMALL", e3[e3.SPAN = 98] = "SPAN", e3[e3.STRIKE = 99] = "STRIKE", e3[e3.STRONG = 100] = "STRONG", e3[e3.STYLE = 101] = "STYLE", e3[e3.SUB = 102] = "SUB", e3[e3.SUMMARY = 103] = "SUMMARY", e3[e3.SUP = 104] = "SUP", e3[e3.TABLE = 105] = "TABLE", e3[e3.TBODY = 106] = "TBODY", e3[e3.TEMPLATE = 107] = "TEMPLATE", e3[e3.TEXTAREA = 108] = "TEXTAREA", e3[e3.TFOOT = 109] = "TFOOT", e3[e3.TD = 110] = "TD", e3[e3.TH = 111] = "TH", e3[e3.THEAD = 112] = "THEAD", e3[e3.TITLE = 113] = "TITLE", e3[e3.TR = 114] = "TR", e3[e3.TRACK = 115] = "TRACK", e3[e3.TT = 116] = "TT", e3[e3.U = 117] = "U", e3[e3.UL = 118] = "UL", e3[e3.SVG = 119] = "SVG", e3[e3.VAR = 120] = "VAR", e3[e3.WBR = 121] = "WBR", e3[e3.XMP = 122] = "XMP";
  }(u = u || (u = {}));
  const O = /* @__PURE__ */ new Map([[N.A, u.A], [N.ADDRESS, u.ADDRESS], [N.ANNOTATION_XML, u.ANNOTATION_XML], [N.APPLET, u.APPLET], [N.AREA, u.AREA], [N.ARTICLE, u.ARTICLE], [N.ASIDE, u.ASIDE], [N.B, u.B], [N.BASE, u.BASE], [N.BASEFONT, u.BASEFONT], [N.BGSOUND, u.BGSOUND], [N.BIG, u.BIG], [N.BLOCKQUOTE, u.BLOCKQUOTE], [N.BODY, u.BODY], [N.BR, u.BR], [N.BUTTON, u.BUTTON], [N.CAPTION, u.CAPTION], [N.CENTER, u.CENTER], [N.CODE, u.CODE], [N.COL, u.COL], [N.COLGROUP, u.COLGROUP], [N.DD, u.DD], [N.DESC, u.DESC], [N.DETAILS, u.DETAILS], [N.DIALOG, u.DIALOG], [N.DIR, u.DIR], [N.DIV, u.DIV], [N.DL, u.DL], [N.DT, u.DT], [N.EM, u.EM], [N.EMBED, u.EMBED], [N.FIELDSET, u.FIELDSET], [N.FIGCAPTION, u.FIGCAPTION], [N.FIGURE, u.FIGURE], [N.FONT, u.FONT], [N.FOOTER, u.FOOTER], [N.FOREIGN_OBJECT, u.FOREIGN_OBJECT], [N.FORM, u.FORM], [N.FRAME, u.FRAME], [N.FRAMESET, u.FRAMESET], [N.H1, u.H1], [N.H2, u.H2], [N.H3, u.H3], [N.H4, u.H4], [N.H5, u.H5], [N.H6, u.H6], [N.HEAD, u.HEAD], [N.HEADER, u.HEADER], [N.HGROUP, u.HGROUP], [N.HR, u.HR], [N.HTML, u.HTML], [N.I, u.I], [N.IMG, u.IMG], [N.IMAGE, u.IMAGE], [N.INPUT, u.INPUT], [N.IFRAME, u.IFRAME], [N.KEYGEN, u.KEYGEN], [N.LABEL, u.LABEL], [N.LI, u.LI], [N.LINK, u.LINK], [N.LISTING, u.LISTING], [N.MAIN, u.MAIN], [N.MALIGNMARK, u.MALIGNMARK], [N.MARQUEE, u.MARQUEE], [N.MATH, u.MATH], [N.MENU, u.MENU], [N.META, u.META], [N.MGLYPH, u.MGLYPH], [N.MI, u.MI], [N.MO, u.MO], [N.MN, u.MN], [N.MS, u.MS], [N.MTEXT, u.MTEXT], [N.NAV, u.NAV], [N.NOBR, u.NOBR], [N.NOFRAMES, u.NOFRAMES], [N.NOEMBED, u.NOEMBED], [N.NOSCRIPT, u.NOSCRIPT], [N.OBJECT, u.OBJECT], [N.OL, u.OL], [N.OPTGROUP, u.OPTGROUP], [N.OPTION, u.OPTION], [N.P, u.P], [N.PARAM, u.PARAM], [N.PLAINTEXT, u.PLAINTEXT], [N.PRE, u.PRE], [N.RB, u.RB], [N.RP, u.RP], [N.RT, u.RT], [N.RTC, u.RTC], [N.RUBY, u.RUBY], [N.S, u.S], [N.SCRIPT, u.SCRIPT], [N.SECTION, u.SECTION], [N.SELECT, u.SELECT], [N.SOURCE, u.SOURCE], [N.SMALL, u.SMALL], [N.SPAN, u.SPAN], [N.STRIKE, u.STRIKE], [N.STRONG, u.STRONG], [N.STYLE, u.STYLE], [N.SUB, u.SUB], [N.SUMMARY, u.SUMMARY], [N.SUP, u.SUP], [N.TABLE, u.TABLE], [N.TBODY, u.TBODY], [N.TEMPLATE, u.TEMPLATE], [N.TEXTAREA, u.TEXTAREA], [N.TFOOT, u.TFOOT], [N.TD, u.TD], [N.TH, u.TH], [N.THEAD, u.THEAD], [N.TITLE, u.TITLE], [N.TR, u.TR], [N.TRACK, u.TRACK], [N.TT, u.TT], [N.U, u.U], [N.UL, u.UL], [N.SVG, u.SVG], [N.VAR, u.VAR], [N.WBR, u.WBR], [N.XMP, u.XMP]]);
  function f(e3) {
    var t2;
    return null !== (t2 = O.get(e3)) && void 0 !== t2 ? t2 : u.UNKNOWN;
  }
  const L = u, M = { [p.HTML]: /* @__PURE__ */ new Set([L.ADDRESS, L.APPLET, L.AREA, L.ARTICLE, L.ASIDE, L.BASE, L.BASEFONT, L.BGSOUND, L.BLOCKQUOTE, L.BODY, L.BR, L.BUTTON, L.CAPTION, L.CENTER, L.COL, L.COLGROUP, L.DD, L.DETAILS, L.DIR, L.DIV, L.DL, L.DT, L.EMBED, L.FIELDSET, L.FIGCAPTION, L.FIGURE, L.FOOTER, L.FORM, L.FRAME, L.FRAMESET, L.H1, L.H2, L.H3, L.H4, L.H5, L.H6, L.HEAD, L.HEADER, L.HGROUP, L.HR, L.HTML, L.IFRAME, L.IMG, L.INPUT, L.LI, L.LINK, L.LISTING, L.MAIN, L.MARQUEE, L.MENU, L.META, L.NAV, L.NOEMBED, L.NOFRAMES, L.NOSCRIPT, L.OBJECT, L.OL, L.P, L.PARAM, L.PLAINTEXT, L.PRE, L.SCRIPT, L.SECTION, L.SELECT, L.SOURCE, L.STYLE, L.SUMMARY, L.TABLE, L.TBODY, L.TD, L.TEMPLATE, L.TEXTAREA, L.TFOOT, L.TH, L.THEAD, L.TITLE, L.TR, L.TRACK, L.UL, L.WBR, L.XMP]), [p.MATHML]: /* @__PURE__ */ new Set([L.MI, L.MO, L.MN, L.MS, L.MTEXT, L.ANNOTATION_XML]), [p.SVG]: /* @__PURE__ */ new Set([L.TITLE, L.FOREIGN_OBJECT, L.DESC]), [p.XLINK]: /* @__PURE__ */ new Set(), [p.XML]: /* @__PURE__ */ new Set(), [p.XMLNS]: /* @__PURE__ */ new Set() };
  function g(e3) {
    return e3 === L.H1 || e3 === L.H2 || e3 === L.H3 || e3 === L.H4 || e3 === L.H5 || e3 === L.H6;
  }
  /* @__PURE__ */ new Set([N.STYLE, N.SCRIPT, N.XMP, N.IFRAME, N.NOEMBED, N.NOFRAMES, N.PLAINTEXT]);
  const k = /* @__PURE__ */ new Map([[128, 8364], [130, 8218], [131, 402], [132, 8222], [133, 8230], [134, 8224], [135, 8225], [136, 710], [137, 8240], [138, 352], [139, 8249], [140, 338], [142, 381], [145, 8216], [146, 8217], [147, 8220], [148, 8221], [149, 8226], [150, 8211], [151, 8212], [152, 732], [153, 8482], [154, 353], [155, 8250], [156, 339], [158, 382], [159, 376]]);
  var P;
  !function(e3) {
    e3[e3.DATA = 0] = "DATA", e3[e3.RCDATA = 1] = "RCDATA", e3[e3.RAWTEXT = 2] = "RAWTEXT", e3[e3.SCRIPT_DATA = 3] = "SCRIPT_DATA", e3[e3.PLAINTEXT = 4] = "PLAINTEXT", e3[e3.TAG_OPEN = 5] = "TAG_OPEN", e3[e3.END_TAG_OPEN = 6] = "END_TAG_OPEN", e3[e3.TAG_NAME = 7] = "TAG_NAME", e3[e3.RCDATA_LESS_THAN_SIGN = 8] = "RCDATA_LESS_THAN_SIGN", e3[e3.RCDATA_END_TAG_OPEN = 9] = "RCDATA_END_TAG_OPEN", e3[e3.RCDATA_END_TAG_NAME = 10] = "RCDATA_END_TAG_NAME", e3[e3.RAWTEXT_LESS_THAN_SIGN = 11] = "RAWTEXT_LESS_THAN_SIGN", e3[e3.RAWTEXT_END_TAG_OPEN = 12] = "RAWTEXT_END_TAG_OPEN", e3[e3.RAWTEXT_END_TAG_NAME = 13] = "RAWTEXT_END_TAG_NAME", e3[e3.SCRIPT_DATA_LESS_THAN_SIGN = 14] = "SCRIPT_DATA_LESS_THAN_SIGN", e3[e3.SCRIPT_DATA_END_TAG_OPEN = 15] = "SCRIPT_DATA_END_TAG_OPEN", e3[e3.SCRIPT_DATA_END_TAG_NAME = 16] = "SCRIPT_DATA_END_TAG_NAME", e3[e3.SCRIPT_DATA_ESCAPE_START = 17] = "SCRIPT_DATA_ESCAPE_START", e3[e3.SCRIPT_DATA_ESCAPE_START_DASH = 18] = "SCRIPT_DATA_ESCAPE_START_DASH", e3[e3.SCRIPT_DATA_ESCAPED = 19] = "SCRIPT_DATA_ESCAPED", e3[e3.SCRIPT_DATA_ESCAPED_DASH = 20] = "SCRIPT_DATA_ESCAPED_DASH", e3[e3.SCRIPT_DATA_ESCAPED_DASH_DASH = 21] = "SCRIPT_DATA_ESCAPED_DASH_DASH", e3[e3.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN = 22] = "SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN", e3[e3.SCRIPT_DATA_ESCAPED_END_TAG_OPEN = 23] = "SCRIPT_DATA_ESCAPED_END_TAG_OPEN", e3[e3.SCRIPT_DATA_ESCAPED_END_TAG_NAME = 24] = "SCRIPT_DATA_ESCAPED_END_TAG_NAME", e3[e3.SCRIPT_DATA_DOUBLE_ESCAPE_START = 25] = "SCRIPT_DATA_DOUBLE_ESCAPE_START", e3[e3.SCRIPT_DATA_DOUBLE_ESCAPED = 26] = "SCRIPT_DATA_DOUBLE_ESCAPED", e3[e3.SCRIPT_DATA_DOUBLE_ESCAPED_DASH = 27] = "SCRIPT_DATA_DOUBLE_ESCAPED_DASH", e3[e3.SCRIPT_DATA_DOUBLE_ESCAPED_DASH_DASH = 28] = "SCRIPT_DATA_DOUBLE_ESCAPED_DASH_DASH", e3[e3.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN = 29] = "SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN", e3[e3.SCRIPT_DATA_DOUBLE_ESCAPE_END = 30] = "SCRIPT_DATA_DOUBLE_ESCAPE_END", e3[e3.BEFORE_ATTRIBUTE_NAME = 31] = "BEFORE_ATTRIBUTE_NAME", e3[e3.ATTRIBUTE_NAME = 32] = "ATTRIBUTE_NAME", e3[e3.AFTER_ATTRIBUTE_NAME = 33] = "AFTER_ATTRIBUTE_NAME", e3[e3.BEFORE_ATTRIBUTE_VALUE = 34] = "BEFORE_ATTRIBUTE_VALUE", e3[e3.ATTRIBUTE_VALUE_DOUBLE_QUOTED = 35] = "ATTRIBUTE_VALUE_DOUBLE_QUOTED", e3[e3.ATTRIBUTE_VALUE_SINGLE_QUOTED = 36] = "ATTRIBUTE_VALUE_SINGLE_QUOTED", e3[e3.ATTRIBUTE_VALUE_UNQUOTED = 37] = "ATTRIBUTE_VALUE_UNQUOTED", e3[e3.AFTER_ATTRIBUTE_VALUE_QUOTED = 38] = "AFTER_ATTRIBUTE_VALUE_QUOTED", e3[e3.SELF_CLOSING_START_TAG = 39] = "SELF_CLOSING_START_TAG", e3[e3.BOGUS_COMMENT = 40] = "BOGUS_COMMENT", e3[e3.MARKUP_DECLARATION_OPEN = 41] = "MARKUP_DECLARATION_OPEN", e3[e3.COMMENT_START = 42] = "COMMENT_START", e3[e3.COMMENT_START_DASH = 43] = "COMMENT_START_DASH", e3[e3.COMMENT = 44] = "COMMENT", e3[e3.COMMENT_LESS_THAN_SIGN = 45] = "COMMENT_LESS_THAN_SIGN", e3[e3.COMMENT_LESS_THAN_SIGN_BANG = 46] = "COMMENT_LESS_THAN_SIGN_BANG", e3[e3.COMMENT_LESS_THAN_SIGN_BANG_DASH = 47] = "COMMENT_LESS_THAN_SIGN_BANG_DASH", e3[e3.COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH = 48] = "COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH", e3[e3.COMMENT_END_DASH = 49] = "COMMENT_END_DASH", e3[e3.COMMENT_END = 50] = "COMMENT_END", e3[e3.COMMENT_END_BANG = 51] = "COMMENT_END_BANG", e3[e3.DOCTYPE = 52] = "DOCTYPE", e3[e3.BEFORE_DOCTYPE_NAME = 53] = "BEFORE_DOCTYPE_NAME", e3[e3.DOCTYPE_NAME = 54] = "DOCTYPE_NAME", e3[e3.AFTER_DOCTYPE_NAME = 55] = "AFTER_DOCTYPE_NAME", e3[e3.AFTER_DOCTYPE_PUBLIC_KEYWORD = 56] = "AFTER_DOCTYPE_PUBLIC_KEYWORD", e3[e3.BEFORE_DOCTYPE_PUBLIC_IDENTIFIER = 57] = "BEFORE_DOCTYPE_PUBLIC_IDENTIFIER", e3[e3.DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED = 58] = "DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED", e3[e3.DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED = 59] = "DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED", e3[e3.AFTER_DOCTYPE_PUBLIC_IDENTIFIER = 60] = "AFTER_DOCTYPE_PUBLIC_IDENTIFIER", e3[e3.BETWEEN_DOCTYPE_PUBLIC_AND_SYSTEM_IDENTIFIERS = 61] = "BETWEEN_DOCTYPE_PUBLIC_AND_SYSTEM_IDENTIFIERS", e3[e3.AFTER_DOCTYPE_SYSTEM_KEYWORD = 62] = "AFTER_DOCTYPE_SYSTEM_KEYWORD", e3[e3.BEFORE_DOCTYPE_SYSTEM_IDENTIFIER = 63] = "BEFORE_DOCTYPE_SYSTEM_IDENTIFIER", e3[e3.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED = 64] = "DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED", e3[e3.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED = 65] = "DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED", e3[e3.AFTER_DOCTYPE_SYSTEM_IDENTIFIER = 66] = "AFTER_DOCTYPE_SYSTEM_IDENTIFIER", e3[e3.BOGUS_DOCTYPE = 67] = "BOGUS_DOCTYPE", e3[e3.CDATA_SECTION = 68] = "CDATA_SECTION", e3[e3.CDATA_SECTION_BRACKET = 69] = "CDATA_SECTION_BRACKET", e3[e3.CDATA_SECTION_END = 70] = "CDATA_SECTION_END", e3[e3.CHARACTER_REFERENCE = 71] = "CHARACTER_REFERENCE", e3[e3.NAMED_CHARACTER_REFERENCE = 72] = "NAMED_CHARACTER_REFERENCE", e3[e3.AMBIGUOUS_AMPERSAND = 73] = "AMBIGUOUS_AMPERSAND", e3[e3.NUMERIC_CHARACTER_REFERENCE = 74] = "NUMERIC_CHARACTER_REFERENCE", e3[e3.HEXADEMICAL_CHARACTER_REFERENCE_START = 75] = "HEXADEMICAL_CHARACTER_REFERENCE_START", e3[e3.HEXADEMICAL_CHARACTER_REFERENCE = 76] = "HEXADEMICAL_CHARACTER_REFERENCE", e3[e3.DECIMAL_CHARACTER_REFERENCE = 77] = "DECIMAL_CHARACTER_REFERENCE", e3[e3.NUMERIC_CHARACTER_REFERENCE_END = 78] = "NUMERIC_CHARACTER_REFERENCE_END";
  }(P || (P = {}));
  const b = { DATA: P.DATA, RCDATA: P.RCDATA, RAWTEXT: P.RAWTEXT, SCRIPT_DATA: P.SCRIPT_DATA, PLAINTEXT: P.PLAINTEXT, CDATA_SECTION: P.CDATA_SECTION };
  function B(e3) {
    return e3 >= a.DIGIT_0 && e3 <= a.DIGIT_9;
  }
  function H(e3) {
    return e3 >= a.LATIN_CAPITAL_A && e3 <= a.LATIN_CAPITAL_Z;
  }
  function F(e3) {
    return function(e4) {
      return e4 >= a.LATIN_SMALL_A && e4 <= a.LATIN_SMALL_Z;
    }(e3) || H(e3);
  }
  function U(e3) {
    return F(e3) || B(e3);
  }
  function G(e3) {
    return e3 >= a.LATIN_CAPITAL_A && e3 <= a.LATIN_CAPITAL_F;
  }
  function y(e3) {
    return e3 >= a.LATIN_SMALL_A && e3 <= a.LATIN_SMALL_F;
  }
  function w(e3) {
    return e3 + 32;
  }
  function Y(e3) {
    return e3 === a.SPACE || e3 === a.LINE_FEED || e3 === a.TABULATION || e3 === a.FORM_FEED;
  }
  function x(e3) {
    return Y(e3) || e3 === a.SOLIDUS || e3 === a.GREATER_THAN_SIGN;
  }
  class v {
    constructor(e3, t2) {
      this.options = e3, this.handler = t2, this.paused = false, this.inLoop = false, this.inForeignNode = false, this.lastStartTagName = "", this.active = false, this.state = P.DATA, this.returnState = P.DATA, this.charRefCode = -1, this.consumedAfterSnapshot = -1, this.currentCharacterToken = null, this.currentToken = null, this.currentAttr = { name: "", value: "" }, this.preprocessor = new _(t2), this.currentLocation = this.getCurrentLocation(-1);
    }
    _err(e3) {
      var t2, s2;
      null === (s2 = (t2 = this.handler).onParseError) || void 0 === s2 || s2.call(t2, this.preprocessor.getError(e3));
    }
    getCurrentLocation(e3) {
      return this.options.sourceCodeLocationInfo ? { startLine: this.preprocessor.line, startCol: this.preprocessor.col - e3, startOffset: this.preprocessor.offset - e3, endLine: -1, endCol: -1, endOffset: -1 } : null;
    }
    _runParsingLoop() {
      if (!this.inLoop) {
        for (this.inLoop = true; this.active && !this.paused; ) {
          this.consumedAfterSnapshot = 0;
          const e3 = this._consume();
          this._ensureHibernation() || this._callState(e3);
        }
        this.inLoop = false;
      }
    }
    pause() {
      this.paused = true;
    }
    resume(e3) {
      if (!this.paused)
        throw new Error("Parser was already resumed");
      this.paused = false, this.inLoop || (this._runParsingLoop(), this.paused || null == e3 || e3());
    }
    write(e3, t2, s2) {
      this.active = true, this.preprocessor.write(e3, t2), this._runParsingLoop(), this.paused || null == s2 || s2();
    }
    insertHtmlAtCurrentPos(e3) {
      this.active = true, this.preprocessor.insertHtmlAtCurrentPos(e3), this._runParsingLoop();
    }
    _ensureHibernation() {
      return !!this.preprocessor.endOfChunkHit && (this._unconsume(this.consumedAfterSnapshot), this.active = false, true);
    }
    _consume() {
      return this.consumedAfterSnapshot++, this.preprocessor.advance();
    }
    _unconsume(e3) {
      this.consumedAfterSnapshot -= e3, this.preprocessor.retreat(e3);
    }
    _reconsumeInState(e3, t2) {
      this.state = e3, this._callState(t2);
    }
    _advanceBy(e3) {
      this.consumedAfterSnapshot += e3;
      for (let t2 = 0; t2 < e3; t2++)
        this.preprocessor.advance();
    }
    _consumeSequenceIfMatch(e3, t2) {
      return !!this.preprocessor.startsWith(e3, t2) && (this._advanceBy(e3.length - 1), true);
    }
    _createStartTagToken() {
      this.currentToken = { type: h.START_TAG, tagName: "", tagID: u.UNKNOWN, selfClosing: false, ackSelfClosing: false, attrs: [], location: this.getCurrentLocation(1) };
    }
    _createEndTagToken() {
      this.currentToken = { type: h.END_TAG, tagName: "", tagID: u.UNKNOWN, selfClosing: false, ackSelfClosing: false, attrs: [], location: this.getCurrentLocation(2) };
    }
    _createCommentToken(e3) {
      this.currentToken = { type: h.COMMENT, data: "", location: this.getCurrentLocation(e3) };
    }
    _createDoctypeToken(e3) {
      this.currentToken = { type: h.DOCTYPE, name: e3, forceQuirks: false, publicId: null, systemId: null, location: this.currentLocation };
    }
    _createCharacterToken(e3, t2) {
      this.currentCharacterToken = { type: e3, chars: t2, location: this.currentLocation };
    }
    _createAttr(e3) {
      this.currentAttr = { name: e3, value: "" }, this.currentLocation = this.getCurrentLocation(0);
    }
    _leaveAttrName() {
      var e3, t2;
      const s2 = this.currentToken;
      null === A(s2, this.currentAttr.name) ? (s2.attrs.push(this.currentAttr), s2.location && this.currentLocation && ((null !== (e3 = (t2 = s2.location).attrs) && void 0 !== e3 ? e3 : t2.attrs = /* @__PURE__ */ Object.create(null))[this.currentAttr.name] = this.currentLocation, this._leaveAttrValue())) : this._err(T.duplicateAttribute);
    }
    _leaveAttrValue() {
      this.currentLocation && (this.currentLocation.endLine = this.preprocessor.line, this.currentLocation.endCol = this.preprocessor.col, this.currentLocation.endOffset = this.preprocessor.offset);
    }
    prepareToken(e3) {
      this._emitCurrentCharacterToken(e3.location), this.currentToken = null, e3.location && (e3.location.endLine = this.preprocessor.line, e3.location.endCol = this.preprocessor.col + 1, e3.location.endOffset = this.preprocessor.offset + 1), this.currentLocation = this.getCurrentLocation(-1);
    }
    emitCurrentTagToken() {
      const e3 = this.currentToken;
      this.prepareToken(e3), e3.tagID = f(e3.tagName), e3.type === h.START_TAG ? (this.lastStartTagName = e3.tagName, this.handler.onStartTag(e3)) : (e3.attrs.length > 0 && this._err(T.endTagWithAttributes), e3.selfClosing && this._err(T.endTagWithTrailingSolidus), this.handler.onEndTag(e3)), this.preprocessor.dropParsedChunk();
    }
    emitCurrentComment(e3) {
      this.prepareToken(e3), this.handler.onComment(e3), this.preprocessor.dropParsedChunk();
    }
    emitCurrentDoctype(e3) {
      this.prepareToken(e3), this.handler.onDoctype(e3), this.preprocessor.dropParsedChunk();
    }
    _emitCurrentCharacterToken(e3) {
      if (this.currentCharacterToken) {
        switch (e3 && this.currentCharacterToken.location && (this.currentCharacterToken.location.endLine = e3.startLine, this.currentCharacterToken.location.endCol = e3.startCol, this.currentCharacterToken.location.endOffset = e3.startOffset), this.currentCharacterToken.type) {
          case h.CHARACTER:
            this.handler.onCharacter(this.currentCharacterToken);
            break;
          case h.NULL_CHARACTER:
            this.handler.onNullCharacter(this.currentCharacterToken);
            break;
          case h.WHITESPACE_CHARACTER:
            this.handler.onWhitespaceCharacter(this.currentCharacterToken);
        }
        this.currentCharacterToken = null;
      }
    }
    _emitEOFToken() {
      const e3 = this.getCurrentLocation(0);
      e3 && (e3.endLine = e3.startLine, e3.endCol = e3.startCol, e3.endOffset = e3.startOffset), this._emitCurrentCharacterToken(e3), this.handler.onEof({ type: h.EOF, location: e3 }), this.active = false;
    }
    _appendCharToCurrentCharacterToken(e3, t2) {
      if (this.currentCharacterToken) {
        if (this.currentCharacterToken.type === e3)
          return void (this.currentCharacterToken.chars += t2);
        this.currentLocation = this.getCurrentLocation(0), this._emitCurrentCharacterToken(this.currentLocation), this.preprocessor.dropParsedChunk();
      }
      this._createCharacterToken(e3, t2);
    }
    _emitCodePoint(e3) {
      const t2 = Y(e3) ? h.WHITESPACE_CHARACTER : e3 === a.NULL ? h.NULL_CHARACTER : h.CHARACTER;
      this._appendCharToCurrentCharacterToken(t2, String.fromCodePoint(e3));
    }
    _emitChars(e3) {
      this._appendCharToCurrentCharacterToken(h.CHARACTER, e3);
    }
    _matchNamedCharacterReference(e3) {
      let t2 = null, s2 = 0, r2 = false;
      for (let i2 = 0, o2 = R.htmlDecodeTree[0]; i2 >= 0 && (i2 = R.determineBranch(R.htmlDecodeTree, o2, i2 + 1, e3), !(i2 < 0)); e3 = this._consume()) {
        s2 += 1, o2 = R.htmlDecodeTree[i2];
        const c2 = o2 & R.BinTrieFlags.VALUE_LENGTH;
        if (c2) {
          const o3 = (c2 >> 14) - 1;
          if (e3 !== a.SEMICOLON && this._isCharacterReferenceInAttribute() && ((n2 = this.preprocessor.peek(1)) === a.EQUALS_SIGN || U(n2)) ? (t2 = [a.AMPERSAND], i2 += o3) : (t2 = 0 === o3 ? [R.htmlDecodeTree[i2] & ~R.BinTrieFlags.VALUE_LENGTH] : 1 === o3 ? [R.htmlDecodeTree[++i2]] : [R.htmlDecodeTree[++i2], R.htmlDecodeTree[++i2]], s2 = 0, r2 = e3 !== a.SEMICOLON), 0 === o3) {
            this._consume();
            break;
          }
        }
      }
      var n2;
      return this._unconsume(s2), r2 && !this.preprocessor.endOfChunkHit && this._err(T.missingSemicolonAfterCharacterReference), this._unconsume(1), t2;
    }
    _isCharacterReferenceInAttribute() {
      return this.returnState === P.ATTRIBUTE_VALUE_DOUBLE_QUOTED || this.returnState === P.ATTRIBUTE_VALUE_SINGLE_QUOTED || this.returnState === P.ATTRIBUTE_VALUE_UNQUOTED;
    }
    _flushCodePointConsumedAsCharacterReference(e3) {
      this._isCharacterReferenceInAttribute() ? this.currentAttr.value += String.fromCodePoint(e3) : this._emitCodePoint(e3);
    }
    _callState(e3) {
      switch (this.state) {
        case P.DATA:
          this._stateData(e3);
          break;
        case P.RCDATA:
          this._stateRcdata(e3);
          break;
        case P.RAWTEXT:
          this._stateRawtext(e3);
          break;
        case P.SCRIPT_DATA:
          this._stateScriptData(e3);
          break;
        case P.PLAINTEXT:
          this._statePlaintext(e3);
          break;
        case P.TAG_OPEN:
          this._stateTagOpen(e3);
          break;
        case P.END_TAG_OPEN:
          this._stateEndTagOpen(e3);
          break;
        case P.TAG_NAME:
          this._stateTagName(e3);
          break;
        case P.RCDATA_LESS_THAN_SIGN:
          this._stateRcdataLessThanSign(e3);
          break;
        case P.RCDATA_END_TAG_OPEN:
          this._stateRcdataEndTagOpen(e3);
          break;
        case P.RCDATA_END_TAG_NAME:
          this._stateRcdataEndTagName(e3);
          break;
        case P.RAWTEXT_LESS_THAN_SIGN:
          this._stateRawtextLessThanSign(e3);
          break;
        case P.RAWTEXT_END_TAG_OPEN:
          this._stateRawtextEndTagOpen(e3);
          break;
        case P.RAWTEXT_END_TAG_NAME:
          this._stateRawtextEndTagName(e3);
          break;
        case P.SCRIPT_DATA_LESS_THAN_SIGN:
          this._stateScriptDataLessThanSign(e3);
          break;
        case P.SCRIPT_DATA_END_TAG_OPEN:
          this._stateScriptDataEndTagOpen(e3);
          break;
        case P.SCRIPT_DATA_END_TAG_NAME:
          this._stateScriptDataEndTagName(e3);
          break;
        case P.SCRIPT_DATA_ESCAPE_START:
          this._stateScriptDataEscapeStart(e3);
          break;
        case P.SCRIPT_DATA_ESCAPE_START_DASH:
          this._stateScriptDataEscapeStartDash(e3);
          break;
        case P.SCRIPT_DATA_ESCAPED:
          this._stateScriptDataEscaped(e3);
          break;
        case P.SCRIPT_DATA_ESCAPED_DASH:
          this._stateScriptDataEscapedDash(e3);
          break;
        case P.SCRIPT_DATA_ESCAPED_DASH_DASH:
          this._stateScriptDataEscapedDashDash(e3);
          break;
        case P.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN:
          this._stateScriptDataEscapedLessThanSign(e3);
          break;
        case P.SCRIPT_DATA_ESCAPED_END_TAG_OPEN:
          this._stateScriptDataEscapedEndTagOpen(e3);
          break;
        case P.SCRIPT_DATA_ESCAPED_END_TAG_NAME:
          this._stateScriptDataEscapedEndTagName(e3);
          break;
        case P.SCRIPT_DATA_DOUBLE_ESCAPE_START:
          this._stateScriptDataDoubleEscapeStart(e3);
          break;
        case P.SCRIPT_DATA_DOUBLE_ESCAPED:
          this._stateScriptDataDoubleEscaped(e3);
          break;
        case P.SCRIPT_DATA_DOUBLE_ESCAPED_DASH:
          this._stateScriptDataDoubleEscapedDash(e3);
          break;
        case P.SCRIPT_DATA_DOUBLE_ESCAPED_DASH_DASH:
          this._stateScriptDataDoubleEscapedDashDash(e3);
          break;
        case P.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN:
          this._stateScriptDataDoubleEscapedLessThanSign(e3);
          break;
        case P.SCRIPT_DATA_DOUBLE_ESCAPE_END:
          this._stateScriptDataDoubleEscapeEnd(e3);
          break;
        case P.BEFORE_ATTRIBUTE_NAME:
          this._stateBeforeAttributeName(e3);
          break;
        case P.ATTRIBUTE_NAME:
          this._stateAttributeName(e3);
          break;
        case P.AFTER_ATTRIBUTE_NAME:
          this._stateAfterAttributeName(e3);
          break;
        case P.BEFORE_ATTRIBUTE_VALUE:
          this._stateBeforeAttributeValue(e3);
          break;
        case P.ATTRIBUTE_VALUE_DOUBLE_QUOTED:
          this._stateAttributeValueDoubleQuoted(e3);
          break;
        case P.ATTRIBUTE_VALUE_SINGLE_QUOTED:
          this._stateAttributeValueSingleQuoted(e3);
          break;
        case P.ATTRIBUTE_VALUE_UNQUOTED:
          this._stateAttributeValueUnquoted(e3);
          break;
        case P.AFTER_ATTRIBUTE_VALUE_QUOTED:
          this._stateAfterAttributeValueQuoted(e3);
          break;
        case P.SELF_CLOSING_START_TAG:
          this._stateSelfClosingStartTag(e3);
          break;
        case P.BOGUS_COMMENT:
          this._stateBogusComment(e3);
          break;
        case P.MARKUP_DECLARATION_OPEN:
          this._stateMarkupDeclarationOpen(e3);
          break;
        case P.COMMENT_START:
          this._stateCommentStart(e3);
          break;
        case P.COMMENT_START_DASH:
          this._stateCommentStartDash(e3);
          break;
        case P.COMMENT:
          this._stateComment(e3);
          break;
        case P.COMMENT_LESS_THAN_SIGN:
          this._stateCommentLessThanSign(e3);
          break;
        case P.COMMENT_LESS_THAN_SIGN_BANG:
          this._stateCommentLessThanSignBang(e3);
          break;
        case P.COMMENT_LESS_THAN_SIGN_BANG_DASH:
          this._stateCommentLessThanSignBangDash(e3);
          break;
        case P.COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH:
          this._stateCommentLessThanSignBangDashDash(e3);
          break;
        case P.COMMENT_END_DASH:
          this._stateCommentEndDash(e3);
          break;
        case P.COMMENT_END:
          this._stateCommentEnd(e3);
          break;
        case P.COMMENT_END_BANG:
          this._stateCommentEndBang(e3);
          break;
        case P.DOCTYPE:
          this._stateDoctype(e3);
          break;
        case P.BEFORE_DOCTYPE_NAME:
          this._stateBeforeDoctypeName(e3);
          break;
        case P.DOCTYPE_NAME:
          this._stateDoctypeName(e3);
          break;
        case P.AFTER_DOCTYPE_NAME:
          this._stateAfterDoctypeName(e3);
          break;
        case P.AFTER_DOCTYPE_PUBLIC_KEYWORD:
          this._stateAfterDoctypePublicKeyword(e3);
          break;
        case P.BEFORE_DOCTYPE_PUBLIC_IDENTIFIER:
          this._stateBeforeDoctypePublicIdentifier(e3);
          break;
        case P.DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED:
          this._stateDoctypePublicIdentifierDoubleQuoted(e3);
          break;
        case P.DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED:
          this._stateDoctypePublicIdentifierSingleQuoted(e3);
          break;
        case P.AFTER_DOCTYPE_PUBLIC_IDENTIFIER:
          this._stateAfterDoctypePublicIdentifier(e3);
          break;
        case P.BETWEEN_DOCTYPE_PUBLIC_AND_SYSTEM_IDENTIFIERS:
          this._stateBetweenDoctypePublicAndSystemIdentifiers(e3);
          break;
        case P.AFTER_DOCTYPE_SYSTEM_KEYWORD:
          this._stateAfterDoctypeSystemKeyword(e3);
          break;
        case P.BEFORE_DOCTYPE_SYSTEM_IDENTIFIER:
          this._stateBeforeDoctypeSystemIdentifier(e3);
          break;
        case P.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED:
          this._stateDoctypeSystemIdentifierDoubleQuoted(e3);
          break;
        case P.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED:
          this._stateDoctypeSystemIdentifierSingleQuoted(e3);
          break;
        case P.AFTER_DOCTYPE_SYSTEM_IDENTIFIER:
          this._stateAfterDoctypeSystemIdentifier(e3);
          break;
        case P.BOGUS_DOCTYPE:
          this._stateBogusDoctype(e3);
          break;
        case P.CDATA_SECTION:
          this._stateCdataSection(e3);
          break;
        case P.CDATA_SECTION_BRACKET:
          this._stateCdataSectionBracket(e3);
          break;
        case P.CDATA_SECTION_END:
          this._stateCdataSectionEnd(e3);
          break;
        case P.CHARACTER_REFERENCE:
          this._stateCharacterReference(e3);
          break;
        case P.NAMED_CHARACTER_REFERENCE:
          this._stateNamedCharacterReference(e3);
          break;
        case P.AMBIGUOUS_AMPERSAND:
          this._stateAmbiguousAmpersand(e3);
          break;
        case P.NUMERIC_CHARACTER_REFERENCE:
          this._stateNumericCharacterReference(e3);
          break;
        case P.HEXADEMICAL_CHARACTER_REFERENCE_START:
          this._stateHexademicalCharacterReferenceStart(e3);
          break;
        case P.HEXADEMICAL_CHARACTER_REFERENCE:
          this._stateHexademicalCharacterReference(e3);
          break;
        case P.DECIMAL_CHARACTER_REFERENCE:
          this._stateDecimalCharacterReference(e3);
          break;
        case P.NUMERIC_CHARACTER_REFERENCE_END:
          this._stateNumericCharacterReferenceEnd(e3);
          break;
        default:
          throw new Error("Unknown state");
      }
    }
    _stateData(e3) {
      switch (e3) {
        case a.LESS_THAN_SIGN:
          this.state = P.TAG_OPEN;
          break;
        case a.AMPERSAND:
          this.returnState = P.DATA, this.state = P.CHARACTER_REFERENCE;
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), this._emitCodePoint(e3);
          break;
        case a.EOF:
          this._emitEOFToken();
          break;
        default:
          this._emitCodePoint(e3);
      }
    }
    _stateRcdata(e3) {
      switch (e3) {
        case a.AMPERSAND:
          this.returnState = P.RCDATA, this.state = P.CHARACTER_REFERENCE;
          break;
        case a.LESS_THAN_SIGN:
          this.state = P.RCDATA_LESS_THAN_SIGN;
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), this._emitChars(s);
          break;
        case a.EOF:
          this._emitEOFToken();
          break;
        default:
          this._emitCodePoint(e3);
      }
    }
    _stateRawtext(e3) {
      switch (e3) {
        case a.LESS_THAN_SIGN:
          this.state = P.RAWTEXT_LESS_THAN_SIGN;
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), this._emitChars(s);
          break;
        case a.EOF:
          this._emitEOFToken();
          break;
        default:
          this._emitCodePoint(e3);
      }
    }
    _stateScriptData(e3) {
      switch (e3) {
        case a.LESS_THAN_SIGN:
          this.state = P.SCRIPT_DATA_LESS_THAN_SIGN;
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), this._emitChars(s);
          break;
        case a.EOF:
          this._emitEOFToken();
          break;
        default:
          this._emitCodePoint(e3);
      }
    }
    _statePlaintext(e3) {
      switch (e3) {
        case a.NULL:
          this._err(T.unexpectedNullCharacter), this._emitChars(s);
          break;
        case a.EOF:
          this._emitEOFToken();
          break;
        default:
          this._emitCodePoint(e3);
      }
    }
    _stateTagOpen(e3) {
      if (F(e3))
        this._createStartTagToken(), this.state = P.TAG_NAME, this._stateTagName(e3);
      else
        switch (e3) {
          case a.EXCLAMATION_MARK:
            this.state = P.MARKUP_DECLARATION_OPEN;
            break;
          case a.SOLIDUS:
            this.state = P.END_TAG_OPEN;
            break;
          case a.QUESTION_MARK:
            this._err(T.unexpectedQuestionMarkInsteadOfTagName), this._createCommentToken(1), this.state = P.BOGUS_COMMENT, this._stateBogusComment(e3);
            break;
          case a.EOF:
            this._err(T.eofBeforeTagName), this._emitChars("<"), this._emitEOFToken();
            break;
          default:
            this._err(T.invalidFirstCharacterOfTagName), this._emitChars("<"), this.state = P.DATA, this._stateData(e3);
        }
    }
    _stateEndTagOpen(e3) {
      if (F(e3))
        this._createEndTagToken(), this.state = P.TAG_NAME, this._stateTagName(e3);
      else
        switch (e3) {
          case a.GREATER_THAN_SIGN:
            this._err(T.missingEndTagName), this.state = P.DATA;
            break;
          case a.EOF:
            this._err(T.eofBeforeTagName), this._emitChars("</"), this._emitEOFToken();
            break;
          default:
            this._err(T.invalidFirstCharacterOfTagName), this._createCommentToken(2), this.state = P.BOGUS_COMMENT, this._stateBogusComment(e3);
        }
    }
    _stateTagName(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
          this.state = P.BEFORE_ATTRIBUTE_NAME;
          break;
        case a.SOLIDUS:
          this.state = P.SELF_CLOSING_START_TAG;
          break;
        case a.GREATER_THAN_SIGN:
          this.state = P.DATA, this.emitCurrentTagToken();
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), t2.tagName += s;
          break;
        case a.EOF:
          this._err(T.eofInTag), this._emitEOFToken();
          break;
        default:
          t2.tagName += String.fromCodePoint(H(e3) ? w(e3) : e3);
      }
    }
    _stateRcdataLessThanSign(e3) {
      e3 === a.SOLIDUS ? this.state = P.RCDATA_END_TAG_OPEN : (this._emitChars("<"), this.state = P.RCDATA, this._stateRcdata(e3));
    }
    _stateRcdataEndTagOpen(e3) {
      F(e3) ? (this.state = P.RCDATA_END_TAG_NAME, this._stateRcdataEndTagName(e3)) : (this._emitChars("</"), this.state = P.RCDATA, this._stateRcdata(e3));
    }
    handleSpecialEndTag(e3) {
      if (!this.preprocessor.startsWith(this.lastStartTagName, false))
        return !this._ensureHibernation();
      switch (this._createEndTagToken(), this.currentToken.tagName = this.lastStartTagName, this.preprocessor.peek(this.lastStartTagName.length)) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
          return this._advanceBy(this.lastStartTagName.length), this.state = P.BEFORE_ATTRIBUTE_NAME, false;
        case a.SOLIDUS:
          return this._advanceBy(this.lastStartTagName.length), this.state = P.SELF_CLOSING_START_TAG, false;
        case a.GREATER_THAN_SIGN:
          return this._advanceBy(this.lastStartTagName.length), this.emitCurrentTagToken(), this.state = P.DATA, false;
        default:
          return !this._ensureHibernation();
      }
    }
    _stateRcdataEndTagName(e3) {
      this.handleSpecialEndTag(e3) && (this._emitChars("</"), this.state = P.RCDATA, this._stateRcdata(e3));
    }
    _stateRawtextLessThanSign(e3) {
      e3 === a.SOLIDUS ? this.state = P.RAWTEXT_END_TAG_OPEN : (this._emitChars("<"), this.state = P.RAWTEXT, this._stateRawtext(e3));
    }
    _stateRawtextEndTagOpen(e3) {
      F(e3) ? (this.state = P.RAWTEXT_END_TAG_NAME, this._stateRawtextEndTagName(e3)) : (this._emitChars("</"), this.state = P.RAWTEXT, this._stateRawtext(e3));
    }
    _stateRawtextEndTagName(e3) {
      this.handleSpecialEndTag(e3) && (this._emitChars("</"), this.state = P.RAWTEXT, this._stateRawtext(e3));
    }
    _stateScriptDataLessThanSign(e3) {
      switch (e3) {
        case a.SOLIDUS:
          this.state = P.SCRIPT_DATA_END_TAG_OPEN;
          break;
        case a.EXCLAMATION_MARK:
          this.state = P.SCRIPT_DATA_ESCAPE_START, this._emitChars("<!");
          break;
        default:
          this._emitChars("<"), this.state = P.SCRIPT_DATA, this._stateScriptData(e3);
      }
    }
    _stateScriptDataEndTagOpen(e3) {
      F(e3) ? (this.state = P.SCRIPT_DATA_END_TAG_NAME, this._stateScriptDataEndTagName(e3)) : (this._emitChars("</"), this.state = P.SCRIPT_DATA, this._stateScriptData(e3));
    }
    _stateScriptDataEndTagName(e3) {
      this.handleSpecialEndTag(e3) && (this._emitChars("</"), this.state = P.SCRIPT_DATA, this._stateScriptData(e3));
    }
    _stateScriptDataEscapeStart(e3) {
      e3 === a.HYPHEN_MINUS ? (this.state = P.SCRIPT_DATA_ESCAPE_START_DASH, this._emitChars("-")) : (this.state = P.SCRIPT_DATA, this._stateScriptData(e3));
    }
    _stateScriptDataEscapeStartDash(e3) {
      e3 === a.HYPHEN_MINUS ? (this.state = P.SCRIPT_DATA_ESCAPED_DASH_DASH, this._emitChars("-")) : (this.state = P.SCRIPT_DATA, this._stateScriptData(e3));
    }
    _stateScriptDataEscaped(e3) {
      switch (e3) {
        case a.HYPHEN_MINUS:
          this.state = P.SCRIPT_DATA_ESCAPED_DASH, this._emitChars("-");
          break;
        case a.LESS_THAN_SIGN:
          this.state = P.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN;
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), this._emitChars(s);
          break;
        case a.EOF:
          this._err(T.eofInScriptHtmlCommentLikeText), this._emitEOFToken();
          break;
        default:
          this._emitCodePoint(e3);
      }
    }
    _stateScriptDataEscapedDash(e3) {
      switch (e3) {
        case a.HYPHEN_MINUS:
          this.state = P.SCRIPT_DATA_ESCAPED_DASH_DASH, this._emitChars("-");
          break;
        case a.LESS_THAN_SIGN:
          this.state = P.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN;
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), this.state = P.SCRIPT_DATA_ESCAPED, this._emitChars(s);
          break;
        case a.EOF:
          this._err(T.eofInScriptHtmlCommentLikeText), this._emitEOFToken();
          break;
        default:
          this.state = P.SCRIPT_DATA_ESCAPED, this._emitCodePoint(e3);
      }
    }
    _stateScriptDataEscapedDashDash(e3) {
      switch (e3) {
        case a.HYPHEN_MINUS:
          this._emitChars("-");
          break;
        case a.LESS_THAN_SIGN:
          this.state = P.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN;
          break;
        case a.GREATER_THAN_SIGN:
          this.state = P.SCRIPT_DATA, this._emitChars(">");
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), this.state = P.SCRIPT_DATA_ESCAPED, this._emitChars(s);
          break;
        case a.EOF:
          this._err(T.eofInScriptHtmlCommentLikeText), this._emitEOFToken();
          break;
        default:
          this.state = P.SCRIPT_DATA_ESCAPED, this._emitCodePoint(e3);
      }
    }
    _stateScriptDataEscapedLessThanSign(e3) {
      e3 === a.SOLIDUS ? this.state = P.SCRIPT_DATA_ESCAPED_END_TAG_OPEN : F(e3) ? (this._emitChars("<"), this.state = P.SCRIPT_DATA_DOUBLE_ESCAPE_START, this._stateScriptDataDoubleEscapeStart(e3)) : (this._emitChars("<"), this.state = P.SCRIPT_DATA_ESCAPED, this._stateScriptDataEscaped(e3));
    }
    _stateScriptDataEscapedEndTagOpen(e3) {
      F(e3) ? (this.state = P.SCRIPT_DATA_ESCAPED_END_TAG_NAME, this._stateScriptDataEscapedEndTagName(e3)) : (this._emitChars("</"), this.state = P.SCRIPT_DATA_ESCAPED, this._stateScriptDataEscaped(e3));
    }
    _stateScriptDataEscapedEndTagName(e3) {
      this.handleSpecialEndTag(e3) && (this._emitChars("</"), this.state = P.SCRIPT_DATA_ESCAPED, this._stateScriptDataEscaped(e3));
    }
    _stateScriptDataDoubleEscapeStart(e3) {
      if (this.preprocessor.startsWith(i, false) && x(this.preprocessor.peek(6))) {
        this._emitCodePoint(e3);
        for (let e4 = 0; e4 < 6; e4++)
          this._emitCodePoint(this._consume());
        this.state = P.SCRIPT_DATA_DOUBLE_ESCAPED;
      } else
        this._ensureHibernation() || (this.state = P.SCRIPT_DATA_ESCAPED, this._stateScriptDataEscaped(e3));
    }
    _stateScriptDataDoubleEscaped(e3) {
      switch (e3) {
        case a.HYPHEN_MINUS:
          this.state = P.SCRIPT_DATA_DOUBLE_ESCAPED_DASH, this._emitChars("-");
          break;
        case a.LESS_THAN_SIGN:
          this.state = P.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN, this._emitChars("<");
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), this._emitChars(s);
          break;
        case a.EOF:
          this._err(T.eofInScriptHtmlCommentLikeText), this._emitEOFToken();
          break;
        default:
          this._emitCodePoint(e3);
      }
    }
    _stateScriptDataDoubleEscapedDash(e3) {
      switch (e3) {
        case a.HYPHEN_MINUS:
          this.state = P.SCRIPT_DATA_DOUBLE_ESCAPED_DASH_DASH, this._emitChars("-");
          break;
        case a.LESS_THAN_SIGN:
          this.state = P.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN, this._emitChars("<");
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), this.state = P.SCRIPT_DATA_DOUBLE_ESCAPED, this._emitChars(s);
          break;
        case a.EOF:
          this._err(T.eofInScriptHtmlCommentLikeText), this._emitEOFToken();
          break;
        default:
          this.state = P.SCRIPT_DATA_DOUBLE_ESCAPED, this._emitCodePoint(e3);
      }
    }
    _stateScriptDataDoubleEscapedDashDash(e3) {
      switch (e3) {
        case a.HYPHEN_MINUS:
          this._emitChars("-");
          break;
        case a.LESS_THAN_SIGN:
          this.state = P.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN, this._emitChars("<");
          break;
        case a.GREATER_THAN_SIGN:
          this.state = P.SCRIPT_DATA, this._emitChars(">");
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), this.state = P.SCRIPT_DATA_DOUBLE_ESCAPED, this._emitChars(s);
          break;
        case a.EOF:
          this._err(T.eofInScriptHtmlCommentLikeText), this._emitEOFToken();
          break;
        default:
          this.state = P.SCRIPT_DATA_DOUBLE_ESCAPED, this._emitCodePoint(e3);
      }
    }
    _stateScriptDataDoubleEscapedLessThanSign(e3) {
      e3 === a.SOLIDUS ? (this.state = P.SCRIPT_DATA_DOUBLE_ESCAPE_END, this._emitChars("/")) : (this.state = P.SCRIPT_DATA_DOUBLE_ESCAPED, this._stateScriptDataDoubleEscaped(e3));
    }
    _stateScriptDataDoubleEscapeEnd(e3) {
      if (this.preprocessor.startsWith(i, false) && x(this.preprocessor.peek(6))) {
        this._emitCodePoint(e3);
        for (let e4 = 0; e4 < 6; e4++)
          this._emitCodePoint(this._consume());
        this.state = P.SCRIPT_DATA_ESCAPED;
      } else
        this._ensureHibernation() || (this.state = P.SCRIPT_DATA_DOUBLE_ESCAPED, this._stateScriptDataDoubleEscaped(e3));
    }
    _stateBeforeAttributeName(e3) {
      switch (e3) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
          break;
        case a.SOLIDUS:
        case a.GREATER_THAN_SIGN:
        case a.EOF:
          this.state = P.AFTER_ATTRIBUTE_NAME, this._stateAfterAttributeName(e3);
          break;
        case a.EQUALS_SIGN:
          this._err(T.unexpectedEqualsSignBeforeAttributeName), this._createAttr("="), this.state = P.ATTRIBUTE_NAME;
          break;
        default:
          this._createAttr(""), this.state = P.ATTRIBUTE_NAME, this._stateAttributeName(e3);
      }
    }
    _stateAttributeName(e3) {
      switch (e3) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
        case a.SOLIDUS:
        case a.GREATER_THAN_SIGN:
        case a.EOF:
          this._leaveAttrName(), this.state = P.AFTER_ATTRIBUTE_NAME, this._stateAfterAttributeName(e3);
          break;
        case a.EQUALS_SIGN:
          this._leaveAttrName(), this.state = P.BEFORE_ATTRIBUTE_VALUE;
          break;
        case a.QUOTATION_MARK:
        case a.APOSTROPHE:
        case a.LESS_THAN_SIGN:
          this._err(T.unexpectedCharacterInAttributeName), this.currentAttr.name += String.fromCodePoint(e3);
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), this.currentAttr.name += s;
          break;
        default:
          this.currentAttr.name += String.fromCodePoint(H(e3) ? w(e3) : e3);
      }
    }
    _stateAfterAttributeName(e3) {
      switch (e3) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
          break;
        case a.SOLIDUS:
          this.state = P.SELF_CLOSING_START_TAG;
          break;
        case a.EQUALS_SIGN:
          this.state = P.BEFORE_ATTRIBUTE_VALUE;
          break;
        case a.GREATER_THAN_SIGN:
          this.state = P.DATA, this.emitCurrentTagToken();
          break;
        case a.EOF:
          this._err(T.eofInTag), this._emitEOFToken();
          break;
        default:
          this._createAttr(""), this.state = P.ATTRIBUTE_NAME, this._stateAttributeName(e3);
      }
    }
    _stateBeforeAttributeValue(e3) {
      switch (e3) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
          break;
        case a.QUOTATION_MARK:
          this.state = P.ATTRIBUTE_VALUE_DOUBLE_QUOTED;
          break;
        case a.APOSTROPHE:
          this.state = P.ATTRIBUTE_VALUE_SINGLE_QUOTED;
          break;
        case a.GREATER_THAN_SIGN:
          this._err(T.missingAttributeValue), this.state = P.DATA, this.emitCurrentTagToken();
          break;
        default:
          this.state = P.ATTRIBUTE_VALUE_UNQUOTED, this._stateAttributeValueUnquoted(e3);
      }
    }
    _stateAttributeValueDoubleQuoted(e3) {
      switch (e3) {
        case a.QUOTATION_MARK:
          this.state = P.AFTER_ATTRIBUTE_VALUE_QUOTED;
          break;
        case a.AMPERSAND:
          this.returnState = P.ATTRIBUTE_VALUE_DOUBLE_QUOTED, this.state = P.CHARACTER_REFERENCE;
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), this.currentAttr.value += s;
          break;
        case a.EOF:
          this._err(T.eofInTag), this._emitEOFToken();
          break;
        default:
          this.currentAttr.value += String.fromCodePoint(e3);
      }
    }
    _stateAttributeValueSingleQuoted(e3) {
      switch (e3) {
        case a.APOSTROPHE:
          this.state = P.AFTER_ATTRIBUTE_VALUE_QUOTED;
          break;
        case a.AMPERSAND:
          this.returnState = P.ATTRIBUTE_VALUE_SINGLE_QUOTED, this.state = P.CHARACTER_REFERENCE;
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), this.currentAttr.value += s;
          break;
        case a.EOF:
          this._err(T.eofInTag), this._emitEOFToken();
          break;
        default:
          this.currentAttr.value += String.fromCodePoint(e3);
      }
    }
    _stateAttributeValueUnquoted(e3) {
      switch (e3) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
          this._leaveAttrValue(), this.state = P.BEFORE_ATTRIBUTE_NAME;
          break;
        case a.AMPERSAND:
          this.returnState = P.ATTRIBUTE_VALUE_UNQUOTED, this.state = P.CHARACTER_REFERENCE;
          break;
        case a.GREATER_THAN_SIGN:
          this._leaveAttrValue(), this.state = P.DATA, this.emitCurrentTagToken();
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), this.currentAttr.value += s;
          break;
        case a.QUOTATION_MARK:
        case a.APOSTROPHE:
        case a.LESS_THAN_SIGN:
        case a.EQUALS_SIGN:
        case a.GRAVE_ACCENT:
          this._err(T.unexpectedCharacterInUnquotedAttributeValue), this.currentAttr.value += String.fromCodePoint(e3);
          break;
        case a.EOF:
          this._err(T.eofInTag), this._emitEOFToken();
          break;
        default:
          this.currentAttr.value += String.fromCodePoint(e3);
      }
    }
    _stateAfterAttributeValueQuoted(e3) {
      switch (e3) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
          this._leaveAttrValue(), this.state = P.BEFORE_ATTRIBUTE_NAME;
          break;
        case a.SOLIDUS:
          this._leaveAttrValue(), this.state = P.SELF_CLOSING_START_TAG;
          break;
        case a.GREATER_THAN_SIGN:
          this._leaveAttrValue(), this.state = P.DATA, this.emitCurrentTagToken();
          break;
        case a.EOF:
          this._err(T.eofInTag), this._emitEOFToken();
          break;
        default:
          this._err(T.missingWhitespaceBetweenAttributes), this.state = P.BEFORE_ATTRIBUTE_NAME, this._stateBeforeAttributeName(e3);
      }
    }
    _stateSelfClosingStartTag(e3) {
      switch (e3) {
        case a.GREATER_THAN_SIGN:
          this.currentToken.selfClosing = true, this.state = P.DATA, this.emitCurrentTagToken();
          break;
        case a.EOF:
          this._err(T.eofInTag), this._emitEOFToken();
          break;
        default:
          this._err(T.unexpectedSolidusInTag), this.state = P.BEFORE_ATTRIBUTE_NAME, this._stateBeforeAttributeName(e3);
      }
    }
    _stateBogusComment(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.GREATER_THAN_SIGN:
          this.state = P.DATA, this.emitCurrentComment(t2);
          break;
        case a.EOF:
          this.emitCurrentComment(t2), this._emitEOFToken();
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), t2.data += s;
          break;
        default:
          t2.data += String.fromCodePoint(e3);
      }
    }
    _stateMarkupDeclarationOpen(e3) {
      this._consumeSequenceIfMatch("--", true) ? (this._createCommentToken(3), this.state = P.COMMENT_START) : this._consumeSequenceIfMatch(n, false) ? (this.currentLocation = this.getCurrentLocation(8), this.state = P.DOCTYPE) : this._consumeSequenceIfMatch(r, true) ? this.inForeignNode ? this.state = P.CDATA_SECTION : (this._err(T.cdataInHtmlContent), this._createCommentToken(8), this.currentToken.data = "[CDATA[", this.state = P.BOGUS_COMMENT) : this._ensureHibernation() || (this._err(T.incorrectlyOpenedComment), this._createCommentToken(2), this.state = P.BOGUS_COMMENT, this._stateBogusComment(e3));
    }
    _stateCommentStart(e3) {
      switch (e3) {
        case a.HYPHEN_MINUS:
          this.state = P.COMMENT_START_DASH;
          break;
        case a.GREATER_THAN_SIGN: {
          this._err(T.abruptClosingOfEmptyComment), this.state = P.DATA;
          const e4 = this.currentToken;
          this.emitCurrentComment(e4);
          break;
        }
        default:
          this.state = P.COMMENT, this._stateComment(e3);
      }
    }
    _stateCommentStartDash(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.HYPHEN_MINUS:
          this.state = P.COMMENT_END;
          break;
        case a.GREATER_THAN_SIGN:
          this._err(T.abruptClosingOfEmptyComment), this.state = P.DATA, this.emitCurrentComment(t2);
          break;
        case a.EOF:
          this._err(T.eofInComment), this.emitCurrentComment(t2), this._emitEOFToken();
          break;
        default:
          t2.data += "-", this.state = P.COMMENT, this._stateComment(e3);
      }
    }
    _stateComment(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.HYPHEN_MINUS:
          this.state = P.COMMENT_END_DASH;
          break;
        case a.LESS_THAN_SIGN:
          t2.data += "<", this.state = P.COMMENT_LESS_THAN_SIGN;
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), t2.data += s;
          break;
        case a.EOF:
          this._err(T.eofInComment), this.emitCurrentComment(t2), this._emitEOFToken();
          break;
        default:
          t2.data += String.fromCodePoint(e3);
      }
    }
    _stateCommentLessThanSign(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.EXCLAMATION_MARK:
          t2.data += "!", this.state = P.COMMENT_LESS_THAN_SIGN_BANG;
          break;
        case a.LESS_THAN_SIGN:
          t2.data += "<";
          break;
        default:
          this.state = P.COMMENT, this._stateComment(e3);
      }
    }
    _stateCommentLessThanSignBang(e3) {
      e3 === a.HYPHEN_MINUS ? this.state = P.COMMENT_LESS_THAN_SIGN_BANG_DASH : (this.state = P.COMMENT, this._stateComment(e3));
    }
    _stateCommentLessThanSignBangDash(e3) {
      e3 === a.HYPHEN_MINUS ? this.state = P.COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH : (this.state = P.COMMENT_END_DASH, this._stateCommentEndDash(e3));
    }
    _stateCommentLessThanSignBangDashDash(e3) {
      e3 !== a.GREATER_THAN_SIGN && e3 !== a.EOF && this._err(T.nestedComment), this.state = P.COMMENT_END, this._stateCommentEnd(e3);
    }
    _stateCommentEndDash(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.HYPHEN_MINUS:
          this.state = P.COMMENT_END;
          break;
        case a.EOF:
          this._err(T.eofInComment), this.emitCurrentComment(t2), this._emitEOFToken();
          break;
        default:
          t2.data += "-", this.state = P.COMMENT, this._stateComment(e3);
      }
    }
    _stateCommentEnd(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.GREATER_THAN_SIGN:
          this.state = P.DATA, this.emitCurrentComment(t2);
          break;
        case a.EXCLAMATION_MARK:
          this.state = P.COMMENT_END_BANG;
          break;
        case a.HYPHEN_MINUS:
          t2.data += "-";
          break;
        case a.EOF:
          this._err(T.eofInComment), this.emitCurrentComment(t2), this._emitEOFToken();
          break;
        default:
          t2.data += "--", this.state = P.COMMENT, this._stateComment(e3);
      }
    }
    _stateCommentEndBang(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.HYPHEN_MINUS:
          t2.data += "--!", this.state = P.COMMENT_END_DASH;
          break;
        case a.GREATER_THAN_SIGN:
          this._err(T.incorrectlyClosedComment), this.state = P.DATA, this.emitCurrentComment(t2);
          break;
        case a.EOF:
          this._err(T.eofInComment), this.emitCurrentComment(t2), this._emitEOFToken();
          break;
        default:
          t2.data += "--!", this.state = P.COMMENT, this._stateComment(e3);
      }
    }
    _stateDoctype(e3) {
      switch (e3) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
          this.state = P.BEFORE_DOCTYPE_NAME;
          break;
        case a.GREATER_THAN_SIGN:
          this.state = P.BEFORE_DOCTYPE_NAME, this._stateBeforeDoctypeName(e3);
          break;
        case a.EOF: {
          this._err(T.eofInDoctype), this._createDoctypeToken(null);
          const e4 = this.currentToken;
          e4.forceQuirks = true, this.emitCurrentDoctype(e4), this._emitEOFToken();
          break;
        }
        default:
          this._err(T.missingWhitespaceBeforeDoctypeName), this.state = P.BEFORE_DOCTYPE_NAME, this._stateBeforeDoctypeName(e3);
      }
    }
    _stateBeforeDoctypeName(e3) {
      if (H(e3))
        this._createDoctypeToken(String.fromCharCode(w(e3))), this.state = P.DOCTYPE_NAME;
      else
        switch (e3) {
          case a.SPACE:
          case a.LINE_FEED:
          case a.TABULATION:
          case a.FORM_FEED:
            break;
          case a.NULL:
            this._err(T.unexpectedNullCharacter), this._createDoctypeToken(s), this.state = P.DOCTYPE_NAME;
            break;
          case a.GREATER_THAN_SIGN: {
            this._err(T.missingDoctypeName), this._createDoctypeToken(null);
            const e4 = this.currentToken;
            e4.forceQuirks = true, this.emitCurrentDoctype(e4), this.state = P.DATA;
            break;
          }
          case a.EOF: {
            this._err(T.eofInDoctype), this._createDoctypeToken(null);
            const e4 = this.currentToken;
            e4.forceQuirks = true, this.emitCurrentDoctype(e4), this._emitEOFToken();
            break;
          }
          default:
            this._createDoctypeToken(String.fromCodePoint(e3)), this.state = P.DOCTYPE_NAME;
        }
    }
    _stateDoctypeName(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
          this.state = P.AFTER_DOCTYPE_NAME;
          break;
        case a.GREATER_THAN_SIGN:
          this.state = P.DATA, this.emitCurrentDoctype(t2);
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), t2.name += s;
          break;
        case a.EOF:
          this._err(T.eofInDoctype), t2.forceQuirks = true, this.emitCurrentDoctype(t2), this._emitEOFToken();
          break;
        default:
          t2.name += String.fromCodePoint(H(e3) ? w(e3) : e3);
      }
    }
    _stateAfterDoctypeName(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
          break;
        case a.GREATER_THAN_SIGN:
          this.state = P.DATA, this.emitCurrentDoctype(t2);
          break;
        case a.EOF:
          this._err(T.eofInDoctype), t2.forceQuirks = true, this.emitCurrentDoctype(t2), this._emitEOFToken();
          break;
        default:
          this._consumeSequenceIfMatch("public", false) ? this.state = P.AFTER_DOCTYPE_PUBLIC_KEYWORD : this._consumeSequenceIfMatch("system", false) ? this.state = P.AFTER_DOCTYPE_SYSTEM_KEYWORD : this._ensureHibernation() || (this._err(T.invalidCharacterSequenceAfterDoctypeName), t2.forceQuirks = true, this.state = P.BOGUS_DOCTYPE, this._stateBogusDoctype(e3));
      }
    }
    _stateAfterDoctypePublicKeyword(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
          this.state = P.BEFORE_DOCTYPE_PUBLIC_IDENTIFIER;
          break;
        case a.QUOTATION_MARK:
          this._err(T.missingWhitespaceAfterDoctypePublicKeyword), t2.publicId = "", this.state = P.DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED;
          break;
        case a.APOSTROPHE:
          this._err(T.missingWhitespaceAfterDoctypePublicKeyword), t2.publicId = "", this.state = P.DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED;
          break;
        case a.GREATER_THAN_SIGN:
          this._err(T.missingDoctypePublicIdentifier), t2.forceQuirks = true, this.state = P.DATA, this.emitCurrentDoctype(t2);
          break;
        case a.EOF:
          this._err(T.eofInDoctype), t2.forceQuirks = true, this.emitCurrentDoctype(t2), this._emitEOFToken();
          break;
        default:
          this._err(T.missingQuoteBeforeDoctypePublicIdentifier), t2.forceQuirks = true, this.state = P.BOGUS_DOCTYPE, this._stateBogusDoctype(e3);
      }
    }
    _stateBeforeDoctypePublicIdentifier(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
          break;
        case a.QUOTATION_MARK:
          t2.publicId = "", this.state = P.DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED;
          break;
        case a.APOSTROPHE:
          t2.publicId = "", this.state = P.DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED;
          break;
        case a.GREATER_THAN_SIGN:
          this._err(T.missingDoctypePublicIdentifier), t2.forceQuirks = true, this.state = P.DATA, this.emitCurrentDoctype(t2);
          break;
        case a.EOF:
          this._err(T.eofInDoctype), t2.forceQuirks = true, this.emitCurrentDoctype(t2), this._emitEOFToken();
          break;
        default:
          this._err(T.missingQuoteBeforeDoctypePublicIdentifier), t2.forceQuirks = true, this.state = P.BOGUS_DOCTYPE, this._stateBogusDoctype(e3);
      }
    }
    _stateDoctypePublicIdentifierDoubleQuoted(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.QUOTATION_MARK:
          this.state = P.AFTER_DOCTYPE_PUBLIC_IDENTIFIER;
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), t2.publicId += s;
          break;
        case a.GREATER_THAN_SIGN:
          this._err(T.abruptDoctypePublicIdentifier), t2.forceQuirks = true, this.emitCurrentDoctype(t2), this.state = P.DATA;
          break;
        case a.EOF:
          this._err(T.eofInDoctype), t2.forceQuirks = true, this.emitCurrentDoctype(t2), this._emitEOFToken();
          break;
        default:
          t2.publicId += String.fromCodePoint(e3);
      }
    }
    _stateDoctypePublicIdentifierSingleQuoted(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.APOSTROPHE:
          this.state = P.AFTER_DOCTYPE_PUBLIC_IDENTIFIER;
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), t2.publicId += s;
          break;
        case a.GREATER_THAN_SIGN:
          this._err(T.abruptDoctypePublicIdentifier), t2.forceQuirks = true, this.emitCurrentDoctype(t2), this.state = P.DATA;
          break;
        case a.EOF:
          this._err(T.eofInDoctype), t2.forceQuirks = true, this.emitCurrentDoctype(t2), this._emitEOFToken();
          break;
        default:
          t2.publicId += String.fromCodePoint(e3);
      }
    }
    _stateAfterDoctypePublicIdentifier(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
          this.state = P.BETWEEN_DOCTYPE_PUBLIC_AND_SYSTEM_IDENTIFIERS;
          break;
        case a.GREATER_THAN_SIGN:
          this.state = P.DATA, this.emitCurrentDoctype(t2);
          break;
        case a.QUOTATION_MARK:
          this._err(T.missingWhitespaceBetweenDoctypePublicAndSystemIdentifiers), t2.systemId = "", this.state = P.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED;
          break;
        case a.APOSTROPHE:
          this._err(T.missingWhitespaceBetweenDoctypePublicAndSystemIdentifiers), t2.systemId = "", this.state = P.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED;
          break;
        case a.EOF:
          this._err(T.eofInDoctype), t2.forceQuirks = true, this.emitCurrentDoctype(t2), this._emitEOFToken();
          break;
        default:
          this._err(T.missingQuoteBeforeDoctypeSystemIdentifier), t2.forceQuirks = true, this.state = P.BOGUS_DOCTYPE, this._stateBogusDoctype(e3);
      }
    }
    _stateBetweenDoctypePublicAndSystemIdentifiers(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
          break;
        case a.GREATER_THAN_SIGN:
          this.emitCurrentDoctype(t2), this.state = P.DATA;
          break;
        case a.QUOTATION_MARK:
          t2.systemId = "", this.state = P.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED;
          break;
        case a.APOSTROPHE:
          t2.systemId = "", this.state = P.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED;
          break;
        case a.EOF:
          this._err(T.eofInDoctype), t2.forceQuirks = true, this.emitCurrentDoctype(t2), this._emitEOFToken();
          break;
        default:
          this._err(T.missingQuoteBeforeDoctypeSystemIdentifier), t2.forceQuirks = true, this.state = P.BOGUS_DOCTYPE, this._stateBogusDoctype(e3);
      }
    }
    _stateAfterDoctypeSystemKeyword(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
          this.state = P.BEFORE_DOCTYPE_SYSTEM_IDENTIFIER;
          break;
        case a.QUOTATION_MARK:
          this._err(T.missingWhitespaceAfterDoctypeSystemKeyword), t2.systemId = "", this.state = P.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED;
          break;
        case a.APOSTROPHE:
          this._err(T.missingWhitespaceAfterDoctypeSystemKeyword), t2.systemId = "", this.state = P.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED;
          break;
        case a.GREATER_THAN_SIGN:
          this._err(T.missingDoctypeSystemIdentifier), t2.forceQuirks = true, this.state = P.DATA, this.emitCurrentDoctype(t2);
          break;
        case a.EOF:
          this._err(T.eofInDoctype), t2.forceQuirks = true, this.emitCurrentDoctype(t2), this._emitEOFToken();
          break;
        default:
          this._err(T.missingQuoteBeforeDoctypeSystemIdentifier), t2.forceQuirks = true, this.state = P.BOGUS_DOCTYPE, this._stateBogusDoctype(e3);
      }
    }
    _stateBeforeDoctypeSystemIdentifier(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
          break;
        case a.QUOTATION_MARK:
          t2.systemId = "", this.state = P.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED;
          break;
        case a.APOSTROPHE:
          t2.systemId = "", this.state = P.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED;
          break;
        case a.GREATER_THAN_SIGN:
          this._err(T.missingDoctypeSystemIdentifier), t2.forceQuirks = true, this.state = P.DATA, this.emitCurrentDoctype(t2);
          break;
        case a.EOF:
          this._err(T.eofInDoctype), t2.forceQuirks = true, this.emitCurrentDoctype(t2), this._emitEOFToken();
          break;
        default:
          this._err(T.missingQuoteBeforeDoctypeSystemIdentifier), t2.forceQuirks = true, this.state = P.BOGUS_DOCTYPE, this._stateBogusDoctype(e3);
      }
    }
    _stateDoctypeSystemIdentifierDoubleQuoted(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.QUOTATION_MARK:
          this.state = P.AFTER_DOCTYPE_SYSTEM_IDENTIFIER;
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), t2.systemId += s;
          break;
        case a.GREATER_THAN_SIGN:
          this._err(T.abruptDoctypeSystemIdentifier), t2.forceQuirks = true, this.emitCurrentDoctype(t2), this.state = P.DATA;
          break;
        case a.EOF:
          this._err(T.eofInDoctype), t2.forceQuirks = true, this.emitCurrentDoctype(t2), this._emitEOFToken();
          break;
        default:
          t2.systemId += String.fromCodePoint(e3);
      }
    }
    _stateDoctypeSystemIdentifierSingleQuoted(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.APOSTROPHE:
          this.state = P.AFTER_DOCTYPE_SYSTEM_IDENTIFIER;
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter), t2.systemId += s;
          break;
        case a.GREATER_THAN_SIGN:
          this._err(T.abruptDoctypeSystemIdentifier), t2.forceQuirks = true, this.emitCurrentDoctype(t2), this.state = P.DATA;
          break;
        case a.EOF:
          this._err(T.eofInDoctype), t2.forceQuirks = true, this.emitCurrentDoctype(t2), this._emitEOFToken();
          break;
        default:
          t2.systemId += String.fromCodePoint(e3);
      }
    }
    _stateAfterDoctypeSystemIdentifier(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.SPACE:
        case a.LINE_FEED:
        case a.TABULATION:
        case a.FORM_FEED:
          break;
        case a.GREATER_THAN_SIGN:
          this.emitCurrentDoctype(t2), this.state = P.DATA;
          break;
        case a.EOF:
          this._err(T.eofInDoctype), t2.forceQuirks = true, this.emitCurrentDoctype(t2), this._emitEOFToken();
          break;
        default:
          this._err(T.unexpectedCharacterAfterDoctypeSystemIdentifier), this.state = P.BOGUS_DOCTYPE, this._stateBogusDoctype(e3);
      }
    }
    _stateBogusDoctype(e3) {
      const t2 = this.currentToken;
      switch (e3) {
        case a.GREATER_THAN_SIGN:
          this.emitCurrentDoctype(t2), this.state = P.DATA;
          break;
        case a.NULL:
          this._err(T.unexpectedNullCharacter);
          break;
        case a.EOF:
          this.emitCurrentDoctype(t2), this._emitEOFToken();
      }
    }
    _stateCdataSection(e3) {
      switch (e3) {
        case a.RIGHT_SQUARE_BRACKET:
          this.state = P.CDATA_SECTION_BRACKET;
          break;
        case a.EOF:
          this._err(T.eofInCdata), this._emitEOFToken();
          break;
        default:
          this._emitCodePoint(e3);
      }
    }
    _stateCdataSectionBracket(e3) {
      e3 === a.RIGHT_SQUARE_BRACKET ? this.state = P.CDATA_SECTION_END : (this._emitChars("]"), this.state = P.CDATA_SECTION, this._stateCdataSection(e3));
    }
    _stateCdataSectionEnd(e3) {
      switch (e3) {
        case a.GREATER_THAN_SIGN:
          this.state = P.DATA;
          break;
        case a.RIGHT_SQUARE_BRACKET:
          this._emitChars("]");
          break;
        default:
          this._emitChars("]]"), this.state = P.CDATA_SECTION, this._stateCdataSection(e3);
      }
    }
    _stateCharacterReference(e3) {
      e3 === a.NUMBER_SIGN ? this.state = P.NUMERIC_CHARACTER_REFERENCE : U(e3) ? (this.state = P.NAMED_CHARACTER_REFERENCE, this._stateNamedCharacterReference(e3)) : (this._flushCodePointConsumedAsCharacterReference(a.AMPERSAND), this._reconsumeInState(this.returnState, e3));
    }
    _stateNamedCharacterReference(e3) {
      const t2 = this._matchNamedCharacterReference(e3);
      if (this._ensureHibernation())
        ;
      else if (t2) {
        for (let e4 = 0; e4 < t2.length; e4++)
          this._flushCodePointConsumedAsCharacterReference(t2[e4]);
        this.state = this.returnState;
      } else
        this._flushCodePointConsumedAsCharacterReference(a.AMPERSAND), this.state = P.AMBIGUOUS_AMPERSAND;
    }
    _stateAmbiguousAmpersand(e3) {
      U(e3) ? this._flushCodePointConsumedAsCharacterReference(e3) : (e3 === a.SEMICOLON && this._err(T.unknownNamedCharacterReference), this._reconsumeInState(this.returnState, e3));
    }
    _stateNumericCharacterReference(e3) {
      this.charRefCode = 0, e3 === a.LATIN_SMALL_X || e3 === a.LATIN_CAPITAL_X ? this.state = P.HEXADEMICAL_CHARACTER_REFERENCE_START : B(e3) ? (this.state = P.DECIMAL_CHARACTER_REFERENCE, this._stateDecimalCharacterReference(e3)) : (this._err(T.absenceOfDigitsInNumericCharacterReference), this._flushCodePointConsumedAsCharacterReference(a.AMPERSAND), this._flushCodePointConsumedAsCharacterReference(a.NUMBER_SIGN), this._reconsumeInState(this.returnState, e3));
    }
    _stateHexademicalCharacterReferenceStart(e3) {
      !function(e4) {
        return B(e4) || G(e4) || y(e4);
      }(e3) ? (this._err(T.absenceOfDigitsInNumericCharacterReference), this._flushCodePointConsumedAsCharacterReference(a.AMPERSAND), this._flushCodePointConsumedAsCharacterReference(a.NUMBER_SIGN), this._unconsume(2), this.state = this.returnState) : (this.state = P.HEXADEMICAL_CHARACTER_REFERENCE, this._stateHexademicalCharacterReference(e3));
    }
    _stateHexademicalCharacterReference(e3) {
      G(e3) ? this.charRefCode = 16 * this.charRefCode + e3 - 55 : y(e3) ? this.charRefCode = 16 * this.charRefCode + e3 - 87 : B(e3) ? this.charRefCode = 16 * this.charRefCode + e3 - 48 : e3 === a.SEMICOLON ? this.state = P.NUMERIC_CHARACTER_REFERENCE_END : (this._err(T.missingSemicolonAfterCharacterReference), this.state = P.NUMERIC_CHARACTER_REFERENCE_END, this._stateNumericCharacterReferenceEnd(e3));
    }
    _stateDecimalCharacterReference(e3) {
      B(e3) ? this.charRefCode = 10 * this.charRefCode + e3 - 48 : e3 === a.SEMICOLON ? this.state = P.NUMERIC_CHARACTER_REFERENCE_END : (this._err(T.missingSemicolonAfterCharacterReference), this.state = P.NUMERIC_CHARACTER_REFERENCE_END, this._stateNumericCharacterReferenceEnd(e3));
    }
    _stateNumericCharacterReferenceEnd(e3) {
      if (this.charRefCode === a.NULL)
        this._err(T.nullCharacterReference), this.charRefCode = a.REPLACEMENT_CHARACTER;
      else if (this.charRefCode > 1114111)
        this._err(T.characterReferenceOutsideUnicodeRange), this.charRefCode = a.REPLACEMENT_CHARACTER;
      else if (o(this.charRefCode))
        this._err(T.surrogateCharacterReference), this.charRefCode = a.REPLACEMENT_CHARACTER;
      else if (E(this.charRefCode))
        this._err(T.noncharacterCharacterReference);
      else if (c(this.charRefCode) || this.charRefCode === a.CARRIAGE_RETURN) {
        this._err(T.controlCharacterReference);
        const e4 = k.get(this.charRefCode);
        void 0 !== e4 && (this.charRefCode = e4);
      }
      this._flushCodePointConsumedAsCharacterReference(this.charRefCode), this._reconsumeInState(this.returnState, e3);
    }
  }
  const Q = /* @__PURE__ */ new Set([u.DD, u.DT, u.LI, u.OPTGROUP, u.OPTION, u.P, u.RB, u.RP, u.RT, u.RTC]), q = /* @__PURE__ */ new Set([...Q, u.CAPTION, u.COLGROUP, u.TBODY, u.TD, u.TFOOT, u.TH, u.THEAD, u.TR]), W = /* @__PURE__ */ new Map([[u.APPLET, p.HTML], [u.CAPTION, p.HTML], [u.HTML, p.HTML], [u.MARQUEE, p.HTML], [u.OBJECT, p.HTML], [u.TABLE, p.HTML], [u.TD, p.HTML], [u.TEMPLATE, p.HTML], [u.TH, p.HTML], [u.ANNOTATION_XML, p.MATHML], [u.MI, p.MATHML], [u.MN, p.MATHML], [u.MO, p.MATHML], [u.MS, p.MATHML], [u.MTEXT, p.MATHML], [u.DESC, p.SVG], [u.FOREIGN_OBJECT, p.SVG], [u.TITLE, p.SVG]]), X = [u.H1, u.H2, u.H3, u.H4, u.H5, u.H6], K = [u.TR, u.TEMPLATE, u.HTML], V = [u.TBODY, u.TFOOT, u.THEAD, u.TEMPLATE, u.HTML], z = [u.TABLE, u.TEMPLATE, u.HTML], j = [u.TD, u.TH];
  class J {
    get currentTmplContentOrNode() {
      return this._isInTemplate() ? this.treeAdapter.getTemplateContent(this.current) : this.current;
    }
    constructor(e3, t2, s2) {
      this.treeAdapter = t2, this.handler = s2, this.items = [], this.tagIDs = [], this.stackTop = -1, this.tmplCount = 0, this.currentTagId = u.UNKNOWN, this.current = e3;
    }
    _indexOf(e3) {
      return this.items.lastIndexOf(e3, this.stackTop);
    }
    _isInTemplate() {
      return this.currentTagId === u.TEMPLATE && this.treeAdapter.getNamespaceURI(this.current) === p.HTML;
    }
    _updateCurrentElement() {
      this.current = this.items[this.stackTop], this.currentTagId = this.tagIDs[this.stackTop];
    }
    push(e3, t2) {
      this.stackTop++, this.items[this.stackTop] = e3, this.current = e3, this.tagIDs[this.stackTop] = t2, this.currentTagId = t2, this._isInTemplate() && this.tmplCount++, this.handler.onItemPush(e3, t2, true);
    }
    pop() {
      const e3 = this.current;
      this.tmplCount > 0 && this._isInTemplate() && this.tmplCount--, this.stackTop--, this._updateCurrentElement(), this.handler.onItemPop(e3, true);
    }
    replace(e3, t2) {
      const s2 = this._indexOf(e3);
      this.items[s2] = t2, s2 === this.stackTop && (this.current = t2);
    }
    insertAfter(e3, t2, s2) {
      const a2 = this._indexOf(e3) + 1;
      this.items.splice(a2, 0, t2), this.tagIDs.splice(a2, 0, s2), this.stackTop++, a2 === this.stackTop && this._updateCurrentElement(), this.handler.onItemPush(this.current, this.currentTagId, a2 === this.stackTop);
    }
    popUntilTagNamePopped(e3) {
      let t2 = this.stackTop + 1;
      do {
        t2 = this.tagIDs.lastIndexOf(e3, t2 - 1);
      } while (t2 > 0 && this.treeAdapter.getNamespaceURI(this.items[t2]) !== p.HTML);
      this.shortenToLength(t2 < 0 ? 0 : t2);
    }
    shortenToLength(e3) {
      for (; this.stackTop >= e3; ) {
        const t2 = this.current;
        this.tmplCount > 0 && this._isInTemplate() && (this.tmplCount -= 1), this.stackTop--, this._updateCurrentElement(), this.handler.onItemPop(t2, this.stackTop < e3);
      }
    }
    popUntilElementPopped(e3) {
      const t2 = this._indexOf(e3);
      this.shortenToLength(t2 < 0 ? 0 : t2);
    }
    popUntilPopped(e3, t2) {
      const s2 = this._indexOfTagNames(e3, t2);
      this.shortenToLength(s2 < 0 ? 0 : s2);
    }
    popUntilNumberedHeaderPopped() {
      this.popUntilPopped(X, p.HTML);
    }
    popUntilTableCellPopped() {
      this.popUntilPopped(j, p.HTML);
    }
    popAllUpToHtmlElement() {
      this.tmplCount = 0, this.shortenToLength(1);
    }
    _indexOfTagNames(e3, t2) {
      for (let s2 = this.stackTop; s2 >= 0; s2--)
        if (e3.includes(this.tagIDs[s2]) && this.treeAdapter.getNamespaceURI(this.items[s2]) === t2)
          return s2;
      return -1;
    }
    clearBackTo(e3, t2) {
      const s2 = this._indexOfTagNames(e3, t2);
      this.shortenToLength(s2 + 1);
    }
    clearBackToTableContext() {
      this.clearBackTo(z, p.HTML);
    }
    clearBackToTableBodyContext() {
      this.clearBackTo(V, p.HTML);
    }
    clearBackToTableRowContext() {
      this.clearBackTo(K, p.HTML);
    }
    remove(e3) {
      const t2 = this._indexOf(e3);
      t2 >= 0 && (t2 === this.stackTop ? this.pop() : (this.items.splice(t2, 1), this.tagIDs.splice(t2, 1), this.stackTop--, this._updateCurrentElement(), this.handler.onItemPop(e3, false)));
    }
    tryPeekProperlyNestedBodyElement() {
      return this.stackTop >= 1 && this.tagIDs[1] === u.BODY ? this.items[1] : null;
    }
    contains(e3) {
      return this._indexOf(e3) > -1;
    }
    getCommonAncestor(e3) {
      const t2 = this._indexOf(e3) - 1;
      return t2 >= 0 ? this.items[t2] : null;
    }
    isRootHtmlElementCurrent() {
      return 0 === this.stackTop && this.tagIDs[0] === u.HTML;
    }
    hasInScope(e3) {
      for (let t2 = this.stackTop; t2 >= 0; t2--) {
        const s2 = this.tagIDs[t2], a2 = this.treeAdapter.getNamespaceURI(this.items[t2]);
        if (s2 === e3 && a2 === p.HTML)
          return true;
        if (W.get(s2) === a2)
          return false;
      }
      return true;
    }
    hasNumberedHeaderInScope() {
      for (let e3 = this.stackTop; e3 >= 0; e3--) {
        const t2 = this.tagIDs[e3], s2 = this.treeAdapter.getNamespaceURI(this.items[e3]);
        if (g(t2) && s2 === p.HTML)
          return true;
        if (W.get(t2) === s2)
          return false;
      }
      return true;
    }
    hasInListItemScope(e3) {
      for (let t2 = this.stackTop; t2 >= 0; t2--) {
        const s2 = this.tagIDs[t2], a2 = this.treeAdapter.getNamespaceURI(this.items[t2]);
        if (s2 === e3 && a2 === p.HTML)
          return true;
        if ((s2 === u.UL || s2 === u.OL) && a2 === p.HTML || W.get(s2) === a2)
          return false;
      }
      return true;
    }
    hasInButtonScope(e3) {
      for (let t2 = this.stackTop; t2 >= 0; t2--) {
        const s2 = this.tagIDs[t2], a2 = this.treeAdapter.getNamespaceURI(this.items[t2]);
        if (s2 === e3 && a2 === p.HTML)
          return true;
        if (s2 === u.BUTTON && a2 === p.HTML || W.get(s2) === a2)
          return false;
      }
      return true;
    }
    hasInTableScope(e3) {
      for (let t2 = this.stackTop; t2 >= 0; t2--) {
        const s2 = this.tagIDs[t2];
        if (this.treeAdapter.getNamespaceURI(this.items[t2]) === p.HTML) {
          if (s2 === e3)
            return true;
          if (s2 === u.TABLE || s2 === u.TEMPLATE || s2 === u.HTML)
            return false;
        }
      }
      return true;
    }
    hasTableBodyContextInTableScope() {
      for (let e3 = this.stackTop; e3 >= 0; e3--) {
        const t2 = this.tagIDs[e3];
        if (this.treeAdapter.getNamespaceURI(this.items[e3]) === p.HTML) {
          if (t2 === u.TBODY || t2 === u.THEAD || t2 === u.TFOOT)
            return true;
          if (t2 === u.TABLE || t2 === u.HTML)
            return false;
        }
      }
      return true;
    }
    hasInSelectScope(e3) {
      for (let t2 = this.stackTop; t2 >= 0; t2--) {
        const s2 = this.tagIDs[t2];
        if (this.treeAdapter.getNamespaceURI(this.items[t2]) === p.HTML) {
          if (s2 === e3)
            return true;
          if (s2 !== u.OPTION && s2 !== u.OPTGROUP)
            return false;
        }
      }
      return true;
    }
    generateImpliedEndTags() {
      for (; Q.has(this.currentTagId); )
        this.pop();
    }
    generateImpliedEndTagsThoroughly() {
      for (; q.has(this.currentTagId); )
        this.pop();
    }
    generateImpliedEndTagsWithExclusion(e3) {
      for (; this.currentTagId !== e3 && q.has(this.currentTagId); )
        this.pop();
    }
  }
  var Z;
  !function(e3) {
    e3[e3.Marker = 0] = "Marker", e3[e3.Element = 1] = "Element";
  }(Z = Z || (Z = {}));
  const $ = { type: Z.Marker };
  class ee {
    constructor(e3) {
      this.treeAdapter = e3, this.entries = [], this.bookmark = null;
    }
    _getNoahArkConditionCandidates(e3, t2) {
      const s2 = [], a2 = t2.length, r2 = this.treeAdapter.getTagName(e3), n2 = this.treeAdapter.getNamespaceURI(e3);
      for (let e4 = 0; e4 < this.entries.length; e4++) {
        const t3 = this.entries[e4];
        if (t3.type === Z.Marker)
          break;
        const { element: i2 } = t3;
        if (this.treeAdapter.getTagName(i2) === r2 && this.treeAdapter.getNamespaceURI(i2) === n2) {
          const t4 = this.treeAdapter.getAttrList(i2);
          t4.length === a2 && s2.push({ idx: e4, attrs: t4 });
        }
      }
      return s2;
    }
    _ensureNoahArkCondition(e3) {
      if (this.entries.length < 3)
        return;
      const t2 = this.treeAdapter.getAttrList(e3), s2 = this._getNoahArkConditionCandidates(e3, t2);
      if (s2.length < 3)
        return;
      const a2 = new Map(t2.map((e4) => [e4.name, e4.value]));
      let r2 = 0;
      for (let e4 = 0; e4 < s2.length; e4++) {
        const t3 = s2[e4];
        t3.attrs.every((e5) => a2.get(e5.name) === e5.value) && (r2 += 1, r2 >= 3 && this.entries.splice(t3.idx, 1));
      }
    }
    insertMarker() {
      this.entries.unshift($);
    }
    pushElement(e3, t2) {
      this._ensureNoahArkCondition(e3), this.entries.unshift({ type: Z.Element, element: e3, token: t2 });
    }
    insertElementAfterBookmark(e3, t2) {
      const s2 = this.entries.indexOf(this.bookmark);
      this.entries.splice(s2, 0, { type: Z.Element, element: e3, token: t2 });
    }
    removeEntry(e3) {
      const t2 = this.entries.indexOf(e3);
      t2 >= 0 && this.entries.splice(t2, 1);
    }
    clearToLastMarker() {
      const e3 = this.entries.indexOf($);
      e3 >= 0 ? this.entries.splice(0, e3 + 1) : this.entries.length = 0;
    }
    getElementEntryInScopeWithTagName(e3) {
      const t2 = this.entries.find((t3) => t3.type === Z.Marker || this.treeAdapter.getTagName(t3.element) === e3);
      return t2 && t2.type === Z.Element ? t2 : null;
    }
    getElementEntry(e3) {
      return this.entries.find((t2) => t2.type === Z.Element && t2.element === e3);
    }
  }
  function te(e3) {
    return { nodeName: "#text", value: e3, parentNode: null };
  }
  const se = { createDocument: () => ({ nodeName: "#document", mode: I.NO_QUIRKS, childNodes: [] }), createDocumentFragment: () => ({ nodeName: "#document-fragment", childNodes: [] }), createElement: (e3, t2, s2) => ({ nodeName: e3, tagName: e3, attrs: s2, namespaceURI: t2, childNodes: [], parentNode: null }), createCommentNode: (e3) => ({ nodeName: "#comment", data: e3, parentNode: null }), appendChild(e3, t2) {
    e3.childNodes.push(t2), t2.parentNode = e3;
  }, insertBefore(e3, t2, s2) {
    const a2 = e3.childNodes.indexOf(s2);
    e3.childNodes.splice(a2, 0, t2), t2.parentNode = e3;
  }, setTemplateContent(e3, t2) {
    e3.content = t2;
  }, getTemplateContent: (e3) => e3.content, setDocumentType(e3, t2, s2, a2) {
    const r2 = e3.childNodes.find((e4) => "#documentType" === e4.nodeName);
    if (r2)
      r2.name = t2, r2.publicId = s2, r2.systemId = a2;
    else {
      const r3 = { nodeName: "#documentType", name: t2, publicId: s2, systemId: a2, parentNode: null };
      se.appendChild(e3, r3);
    }
  }, setDocumentMode(e3, t2) {
    e3.mode = t2;
  }, getDocumentMode: (e3) => e3.mode, detachNode(e3) {
    if (e3.parentNode) {
      const t2 = e3.parentNode.childNodes.indexOf(e3);
      e3.parentNode.childNodes.splice(t2, 1), e3.parentNode = null;
    }
  }, insertText(e3, t2) {
    if (e3.childNodes.length > 0) {
      const s2 = e3.childNodes[e3.childNodes.length - 1];
      if (se.isTextNode(s2))
        return void (s2.value += t2);
    }
    se.appendChild(e3, te(t2));
  }, insertTextBefore(e3, t2, s2) {
    const a2 = e3.childNodes[e3.childNodes.indexOf(s2) - 1];
    a2 && se.isTextNode(a2) ? a2.value += t2 : se.insertBefore(e3, te(t2), s2);
  }, adoptAttributes(e3, t2) {
    const s2 = new Set(e3.attrs.map((e4) => e4.name));
    for (let a2 = 0; a2 < t2.length; a2++)
      s2.has(t2[a2].name) || e3.attrs.push(t2[a2]);
  }, getFirstChild: (e3) => e3.childNodes[0], getChildNodes: (e3) => e3.childNodes, getParentNode: (e3) => e3.parentNode, getAttrList: (e3) => e3.attrs, getTagName: (e3) => e3.tagName, getNamespaceURI: (e3) => e3.namespaceURI, getTextNodeContent: (e3) => e3.value, getCommentNodeContent: (e3) => e3.data, getDocumentTypeNodeName: (e3) => e3.name, getDocumentTypeNodePublicId: (e3) => e3.publicId, getDocumentTypeNodeSystemId: (e3) => e3.systemId, isTextNode: (e3) => "#text" === e3.nodeName, isCommentNode: (e3) => "#comment" === e3.nodeName, isDocumentTypeNode: (e3) => "#documentType" === e3.nodeName, isElementNode: (e3) => Object.prototype.hasOwnProperty.call(e3, "tagName"), setNodeSourceCodeLocation(e3, t2) {
    e3.sourceCodeLocation = t2;
  }, getNodeSourceCodeLocation: (e3) => e3.sourceCodeLocation, updateNodeSourceCodeLocation(e3, t2) {
    e3.sourceCodeLocation = { ...e3.sourceCodeLocation, ...t2 };
  } }, ae = "html", re = ["+//silmaril//dtd html pro v0r11 19970101//", "-//as//dtd html 3.0 aswedit + extensions//", "-//advasoft ltd//dtd html 3.0 aswedit + extensions//", "-//ietf//dtd html 2.0 level 1//", "-//ietf//dtd html 2.0 level 2//", "-//ietf//dtd html 2.0 strict level 1//", "-//ietf//dtd html 2.0 strict level 2//", "-//ietf//dtd html 2.0 strict//", "-//ietf//dtd html 2.0//", "-//ietf//dtd html 2.1e//", "-//ietf//dtd html 3.0//", "-//ietf//dtd html 3.2 final//", "-//ietf//dtd html 3.2//", "-//ietf//dtd html 3//", "-//ietf//dtd html level 0//", "-//ietf//dtd html level 1//", "-//ietf//dtd html level 2//", "-//ietf//dtd html level 3//", "-//ietf//dtd html strict level 0//", "-//ietf//dtd html strict level 1//", "-//ietf//dtd html strict level 2//", "-//ietf//dtd html strict level 3//", "-//ietf//dtd html strict//", "-//ietf//dtd html//", "-//metrius//dtd metrius presentational//", "-//microsoft//dtd internet explorer 2.0 html strict//", "-//microsoft//dtd internet explorer 2.0 html//", "-//microsoft//dtd internet explorer 2.0 tables//", "-//microsoft//dtd internet explorer 3.0 html strict//", "-//microsoft//dtd internet explorer 3.0 html//", "-//microsoft//dtd internet explorer 3.0 tables//", "-//netscape comm. corp.//dtd html//", "-//netscape comm. corp.//dtd strict html//", "-//o'reilly and associates//dtd html 2.0//", "-//o'reilly and associates//dtd html extended 1.0//", "-//o'reilly and associates//dtd html extended relaxed 1.0//", "-//sq//dtd html 2.0 hotmetal + extensions//", "-//softquad software//dtd hotmetal pro 6.0::19990601::extensions to html 4.0//", "-//softquad//dtd hotmetal pro 4.0::19971010::extensions to html 4.0//", "-//spyglass//dtd html 2.0 extended//", "-//sun microsystems corp.//dtd hotjava html//", "-//sun microsystems corp.//dtd hotjava strict html//", "-//w3c//dtd html 3 1995-03-24//", "-//w3c//dtd html 3.2 draft//", "-//w3c//dtd html 3.2 final//", "-//w3c//dtd html 3.2//", "-//w3c//dtd html 3.2s draft//", "-//w3c//dtd html 4.0 frameset//", "-//w3c//dtd html 4.0 transitional//", "-//w3c//dtd html experimental 19960712//", "-//w3c//dtd html experimental 970421//", "-//w3c//dtd w3 html//", "-//w3o//dtd w3 html 3.0//", "-//webtechs//dtd mozilla html 2.0//", "-//webtechs//dtd mozilla html//"], ne = [...re, "-//w3c//dtd html 4.01 frameset//", "-//w3c//dtd html 4.01 transitional//"], ie = /* @__PURE__ */ new Set(["-//w3o//dtd w3 html strict 3.0//en//", "-/w3c/dtd html 4.0 transitional/en", "html"]), oe = ["-//w3c//dtd xhtml 1.0 frameset//", "-//w3c//dtd xhtml 1.0 transitional//"], ce = [...oe, "-//w3c//dtd html 4.01 frameset//", "-//w3c//dtd html 4.01 transitional//"];
  function Ee(e3, t2) {
    return t2.some((t3) => e3.startsWith(t3));
  }
  const Te = "text/html", he = "application/xhtml+xml", _e = "definitionurl", Ae = "definitionURL", le = new Map(["attributeName", "attributeType", "baseFrequency", "baseProfile", "calcMode", "clipPathUnits", "diffuseConstant", "edgeMode", "filterUnits", "glyphRef", "gradientTransform", "gradientUnits", "kernelMatrix", "kernelUnitLength", "keyPoints", "keySplines", "keyTimes", "lengthAdjust", "limitingConeAngle", "markerHeight", "markerUnits", "markerWidth", "maskContentUnits", "maskUnits", "numOctaves", "pathLength", "patternContentUnits", "patternTransform", "patternUnits", "pointsAtX", "pointsAtY", "pointsAtZ", "preserveAlpha", "preserveAspectRatio", "primitiveUnits", "refX", "refY", "repeatCount", "repeatDur", "requiredExtensions", "requiredFeatures", "specularConstant", "specularExponent", "spreadMethod", "startOffset", "stdDeviation", "stitchTiles", "surfaceScale", "systemLanguage", "tableValues", "targetX", "targetY", "textLength", "viewBox", "viewTarget", "xChannelSelector", "yChannelSelector", "zoomAndPan"].map((e3) => [e3.toLowerCase(), e3])), me = /* @__PURE__ */ new Map([["xlink:actuate", { prefix: "xlink", name: "actuate", namespace: p.XLINK }], ["xlink:arcrole", { prefix: "xlink", name: "arcrole", namespace: p.XLINK }], ["xlink:href", { prefix: "xlink", name: "href", namespace: p.XLINK }], ["xlink:role", { prefix: "xlink", name: "role", namespace: p.XLINK }], ["xlink:show", { prefix: "xlink", name: "show", namespace: p.XLINK }], ["xlink:title", { prefix: "xlink", name: "title", namespace: p.XLINK }], ["xlink:type", { prefix: "xlink", name: "type", namespace: p.XLINK }], ["xml:base", { prefix: "xml", name: "base", namespace: p.XML }], ["xml:lang", { prefix: "xml", name: "lang", namespace: p.XML }], ["xml:space", { prefix: "xml", name: "space", namespace: p.XML }], ["xmlns", { prefix: "", name: "xmlns", namespace: p.XMLNS }], ["xmlns:xlink", { prefix: "xmlns", name: "xlink", namespace: p.XMLNS }]]), pe = new Map(["altGlyph", "altGlyphDef", "altGlyphItem", "animateColor", "animateMotion", "animateTransform", "clipPath", "feBlend", "feColorMatrix", "feComponentTransfer", "feComposite", "feConvolveMatrix", "feDiffuseLighting", "feDisplacementMap", "feDistantLight", "feFlood", "feFuncA", "feFuncB", "feFuncG", "feFuncR", "feGaussianBlur", "feImage", "feMerge", "feMergeNode", "feMorphology", "feOffset", "fePointLight", "feSpecularLighting", "feSpotLight", "feTile", "feTurbulence", "foreignObject", "glyphRef", "linearGradient", "radialGradient", "textPath"].map((e3) => [e3.toLowerCase(), e3])), de = /* @__PURE__ */ new Set([u.B, u.BIG, u.BLOCKQUOTE, u.BODY, u.BR, u.CENTER, u.CODE, u.DD, u.DIV, u.DL, u.DT, u.EM, u.EMBED, u.H1, u.H2, u.H3, u.H4, u.H5, u.H6, u.HEAD, u.HR, u.I, u.IMG, u.LI, u.LISTING, u.MENU, u.META, u.NOBR, u.OL, u.P, u.PRE, u.RUBY, u.S, u.SMALL, u.SPAN, u.STRONG, u.STRIKE, u.SUB, u.SUP, u.TABLE, u.TT, u.U, u.UL, u.VAR]);
  function Ie(e3) {
    for (let t2 = 0; t2 < e3.attrs.length; t2++)
      if (e3.attrs[t2].name === _e) {
        e3.attrs[t2].name = Ae;
        break;
      }
  }
  function Ne(e3) {
    for (let t2 = 0; t2 < e3.attrs.length; t2++) {
      const s2 = le.get(e3.attrs[t2].name);
      null != s2 && (e3.attrs[t2].name = s2);
    }
  }
  function ue(e3) {
    for (let t2 = 0; t2 < e3.attrs.length; t2++) {
      const s2 = me.get(e3.attrs[t2].name);
      s2 && (e3.attrs[t2].prefix = s2.prefix, e3.attrs[t2].name = s2.name, e3.attrs[t2].namespace = s2.namespace);
    }
  }
  const Ce = "hidden", De = 8, Se = 3;
  var Re;
  !function(e3) {
    e3[e3.INITIAL = 0] = "INITIAL", e3[e3.BEFORE_HTML = 1] = "BEFORE_HTML", e3[e3.BEFORE_HEAD = 2] = "BEFORE_HEAD", e3[e3.IN_HEAD = 3] = "IN_HEAD", e3[e3.IN_HEAD_NO_SCRIPT = 4] = "IN_HEAD_NO_SCRIPT", e3[e3.AFTER_HEAD = 5] = "AFTER_HEAD", e3[e3.IN_BODY = 6] = "IN_BODY", e3[e3.TEXT = 7] = "TEXT", e3[e3.IN_TABLE = 8] = "IN_TABLE", e3[e3.IN_TABLE_TEXT = 9] = "IN_TABLE_TEXT", e3[e3.IN_CAPTION = 10] = "IN_CAPTION", e3[e3.IN_COLUMN_GROUP = 11] = "IN_COLUMN_GROUP", e3[e3.IN_TABLE_BODY = 12] = "IN_TABLE_BODY", e3[e3.IN_ROW = 13] = "IN_ROW", e3[e3.IN_CELL = 14] = "IN_CELL", e3[e3.IN_SELECT = 15] = "IN_SELECT", e3[e3.IN_SELECT_IN_TABLE = 16] = "IN_SELECT_IN_TABLE", e3[e3.IN_TEMPLATE = 17] = "IN_TEMPLATE", e3[e3.AFTER_BODY = 18] = "AFTER_BODY", e3[e3.IN_FRAMESET = 19] = "IN_FRAMESET", e3[e3.AFTER_FRAMESET = 20] = "AFTER_FRAMESET", e3[e3.AFTER_AFTER_BODY = 21] = "AFTER_AFTER_BODY", e3[e3.AFTER_AFTER_FRAMESET = 22] = "AFTER_AFTER_FRAMESET";
  }(Re || (Re = {}));
  const Oe = { startLine: -1, startCol: -1, startOffset: -1, endLine: -1, endCol: -1, endOffset: -1 }, fe = /* @__PURE__ */ new Set([u.TABLE, u.TBODY, u.TFOOT, u.THEAD, u.TR]), Le = { scriptingEnabled: true, sourceCodeLocationInfo: false, treeAdapter: se, onParseError: null };
  class Me {
    constructor(e3, t2, s2 = null, a2 = null) {
      this.fragmentContext = s2, this.scriptHandler = a2, this.currentToken = null, this.stopped = false, this.insertionMode = Re.INITIAL, this.originalInsertionMode = Re.INITIAL, this.headElement = null, this.formElement = null, this.currentNotInHTML = false, this.tmplInsertionModeStack = [], this.pendingCharacterTokens = [], this.hasNonWhitespacePendingCharacterToken = false, this.framesetOk = true, this.skipNextNewLine = false, this.fosterParentingEnabled = false, this.options = { ...Le, ...e3 }, this.treeAdapter = this.options.treeAdapter, this.onParseError = this.options.onParseError, this.onParseError && (this.options.sourceCodeLocationInfo = true), this.document = null != t2 ? t2 : this.treeAdapter.createDocument(), this.tokenizer = new v(this.options, this), this.activeFormattingElements = new ee(this.treeAdapter), this.fragmentContextID = s2 ? f(this.treeAdapter.getTagName(s2)) : u.UNKNOWN, this._setContextModes(null != s2 ? s2 : this.document, this.fragmentContextID), this.openElements = new J(this.document, this.treeAdapter, this);
    }
    static parse(e3, t2) {
      const s2 = new this(t2);
      return s2.tokenizer.write(e3, true), s2.document;
    }
    static getFragmentParser(e3, t2) {
      const s2 = { ...Le, ...t2 };
      null != e3 || (e3 = s2.treeAdapter.createElement(N.TEMPLATE, p.HTML, []));
      const a2 = s2.treeAdapter.createElement("documentmock", p.HTML, []), r2 = new this(s2, a2, e3);
      return r2.fragmentContextID === u.TEMPLATE && r2.tmplInsertionModeStack.unshift(Re.IN_TEMPLATE), r2._initTokenizerForFragmentParsing(), r2._insertFakeRootElement(), r2._resetInsertionMode(), r2._findFormInFragmentContext(), r2;
    }
    getFragment() {
      const e3 = this.treeAdapter.getFirstChild(this.document), t2 = this.treeAdapter.createDocumentFragment();
      return this._adoptNodes(e3, t2), t2;
    }
    _err(e3, t2, s2) {
      var a2;
      if (!this.onParseError)
        return;
      const r2 = null !== (a2 = e3.location) && void 0 !== a2 ? a2 : Oe, n2 = { code: t2, startLine: r2.startLine, startCol: r2.startCol, startOffset: r2.startOffset, endLine: s2 ? r2.startLine : r2.endLine, endCol: s2 ? r2.startCol : r2.endCol, endOffset: s2 ? r2.startOffset : r2.endOffset };
      this.onParseError(n2);
    }
    onItemPush(e3, t2, s2) {
      var a2, r2;
      null === (r2 = (a2 = this.treeAdapter).onItemPush) || void 0 === r2 || r2.call(a2, e3), s2 && this.openElements.stackTop > 0 && this._setContextModes(e3, t2);
    }
    onItemPop(e3, t2) {
      var s2, a2;
      if (this.options.sourceCodeLocationInfo && this._setEndLocation(e3, this.currentToken), null === (a2 = (s2 = this.treeAdapter).onItemPop) || void 0 === a2 || a2.call(s2, e3, this.openElements.current), t2) {
        let e4, t3;
        0 === this.openElements.stackTop && this.fragmentContext ? (e4 = this.fragmentContext, t3 = this.fragmentContextID) : { current: e4, currentTagId: t3 } = this.openElements, this._setContextModes(e4, t3);
      }
    }
    _setContextModes(e3, t2) {
      const s2 = e3 === this.document || this.treeAdapter.getNamespaceURI(e3) === p.HTML;
      this.currentNotInHTML = !s2, this.tokenizer.inForeignNode = !s2 && !this._isIntegrationPoint(t2, e3);
    }
    _switchToTextParsing(e3, t2) {
      this._insertElement(e3, p.HTML), this.tokenizer.state = t2, this.originalInsertionMode = this.insertionMode, this.insertionMode = Re.TEXT;
    }
    switchToPlaintextParsing() {
      this.insertionMode = Re.TEXT, this.originalInsertionMode = Re.IN_BODY, this.tokenizer.state = b.PLAINTEXT;
    }
    _getAdjustedCurrentElement() {
      return 0 === this.openElements.stackTop && this.fragmentContext ? this.fragmentContext : this.openElements.current;
    }
    _findFormInFragmentContext() {
      let e3 = this.fragmentContext;
      for (; e3; ) {
        if (this.treeAdapter.getTagName(e3) === N.FORM) {
          this.formElement = e3;
          break;
        }
        e3 = this.treeAdapter.getParentNode(e3);
      }
    }
    _initTokenizerForFragmentParsing() {
      if (this.fragmentContext && this.treeAdapter.getNamespaceURI(this.fragmentContext) === p.HTML)
        switch (this.fragmentContextID) {
          case u.TITLE:
          case u.TEXTAREA:
            this.tokenizer.state = b.RCDATA;
            break;
          case u.STYLE:
          case u.XMP:
          case u.IFRAME:
          case u.NOEMBED:
          case u.NOFRAMES:
          case u.NOSCRIPT:
            this.tokenizer.state = b.RAWTEXT;
            break;
          case u.SCRIPT:
            this.tokenizer.state = b.SCRIPT_DATA;
            break;
          case u.PLAINTEXT:
            this.tokenizer.state = b.PLAINTEXT;
        }
    }
    _setDocumentType(e3) {
      const t2 = e3.name || "", s2 = e3.publicId || "", a2 = e3.systemId || "";
      if (this.treeAdapter.setDocumentType(this.document, t2, s2, a2), e3.location) {
        const t3 = this.treeAdapter.getChildNodes(this.document).find((e4) => this.treeAdapter.isDocumentTypeNode(e4));
        t3 && this.treeAdapter.setNodeSourceCodeLocation(t3, e3.location);
      }
    }
    _attachElementToTree(e3, t2) {
      if (this.options.sourceCodeLocationInfo) {
        const s2 = t2 && { ...t2, startTag: t2 };
        this.treeAdapter.setNodeSourceCodeLocation(e3, s2);
      }
      if (this._shouldFosterParentOnInsertion())
        this._fosterParentElement(e3);
      else {
        const t3 = this.openElements.currentTmplContentOrNode;
        this.treeAdapter.appendChild(t3, e3);
      }
    }
    _appendElement(e3, t2) {
      const s2 = this.treeAdapter.createElement(e3.tagName, t2, e3.attrs);
      this._attachElementToTree(s2, e3.location);
    }
    _insertElement(e3, t2) {
      const s2 = this.treeAdapter.createElement(e3.tagName, t2, e3.attrs);
      this._attachElementToTree(s2, e3.location), this.openElements.push(s2, e3.tagID);
    }
    _insertFakeElement(e3, t2) {
      const s2 = this.treeAdapter.createElement(e3, p.HTML, []);
      this._attachElementToTree(s2, null), this.openElements.push(s2, t2);
    }
    _insertTemplate(e3) {
      const t2 = this.treeAdapter.createElement(e3.tagName, p.HTML, e3.attrs), s2 = this.treeAdapter.createDocumentFragment();
      this.treeAdapter.setTemplateContent(t2, s2), this._attachElementToTree(t2, e3.location), this.openElements.push(t2, e3.tagID), this.options.sourceCodeLocationInfo && this.treeAdapter.setNodeSourceCodeLocation(s2, null);
    }
    _insertFakeRootElement() {
      const e3 = this.treeAdapter.createElement(N.HTML, p.HTML, []);
      this.options.sourceCodeLocationInfo && this.treeAdapter.setNodeSourceCodeLocation(e3, null), this.treeAdapter.appendChild(this.openElements.current, e3), this.openElements.push(e3, u.HTML);
    }
    _appendCommentNode(e3, t2) {
      const s2 = this.treeAdapter.createCommentNode(e3.data);
      this.treeAdapter.appendChild(t2, s2), this.options.sourceCodeLocationInfo && this.treeAdapter.setNodeSourceCodeLocation(s2, e3.location);
    }
    _insertCharacters(e3) {
      let t2, s2;
      if (this._shouldFosterParentOnInsertion() ? ({ parent: t2, beforeElement: s2 } = this._findFosterParentingLocation(), s2 ? this.treeAdapter.insertTextBefore(t2, e3.chars, s2) : this.treeAdapter.insertText(t2, e3.chars)) : (t2 = this.openElements.currentTmplContentOrNode, this.treeAdapter.insertText(t2, e3.chars)), !e3.location)
        return;
      const a2 = this.treeAdapter.getChildNodes(t2), r2 = s2 ? a2.lastIndexOf(s2) : a2.length, n2 = a2[r2 - 1];
      if (this.treeAdapter.getNodeSourceCodeLocation(n2)) {
        const { endLine: t3, endCol: s3, endOffset: a3 } = e3.location;
        this.treeAdapter.updateNodeSourceCodeLocation(n2, { endLine: t3, endCol: s3, endOffset: a3 });
      } else
        this.options.sourceCodeLocationInfo && this.treeAdapter.setNodeSourceCodeLocation(n2, e3.location);
    }
    _adoptNodes(e3, t2) {
      for (let s2 = this.treeAdapter.getFirstChild(e3); s2; s2 = this.treeAdapter.getFirstChild(e3))
        this.treeAdapter.detachNode(s2), this.treeAdapter.appendChild(t2, s2);
    }
    _setEndLocation(e3, t2) {
      if (this.treeAdapter.getNodeSourceCodeLocation(e3) && t2.location) {
        const s2 = t2.location, a2 = this.treeAdapter.getTagName(e3), r2 = t2.type === h.END_TAG && a2 === t2.tagName ? { endTag: { ...s2 }, endLine: s2.endLine, endCol: s2.endCol, endOffset: s2.endOffset } : { endLine: s2.startLine, endCol: s2.startCol, endOffset: s2.startOffset };
        this.treeAdapter.updateNodeSourceCodeLocation(e3, r2);
      }
    }
    shouldProcessStartTagTokenInForeignContent(e3) {
      if (!this.currentNotInHTML)
        return false;
      let t2, s2;
      return 0 === this.openElements.stackTop && this.fragmentContext ? (t2 = this.fragmentContext, s2 = this.fragmentContextID) : { current: t2, currentTagId: s2 } = this.openElements, (e3.tagID !== u.SVG || this.treeAdapter.getTagName(t2) !== N.ANNOTATION_XML || this.treeAdapter.getNamespaceURI(t2) !== p.MATHML) && (this.tokenizer.inForeignNode || (e3.tagID === u.MGLYPH || e3.tagID === u.MALIGNMARK) && !this._isIntegrationPoint(s2, t2, p.HTML));
    }
    _processToken(e3) {
      switch (e3.type) {
        case h.CHARACTER:
          this.onCharacter(e3);
          break;
        case h.NULL_CHARACTER:
          this.onNullCharacter(e3);
          break;
        case h.COMMENT:
          this.onComment(e3);
          break;
        case h.DOCTYPE:
          this.onDoctype(e3);
          break;
        case h.START_TAG:
          this._processStartTag(e3);
          break;
        case h.END_TAG:
          this.onEndTag(e3);
          break;
        case h.EOF:
          this.onEof(e3);
          break;
        case h.WHITESPACE_CHARACTER:
          this.onWhitespaceCharacter(e3);
      }
    }
    _isIntegrationPoint(e3, t2, s2) {
      return function(e4, t3, s3, a2) {
        return (!a2 || a2 === p.HTML) && function(e5, t4, s4) {
          if (t4 === p.MATHML && e5 === u.ANNOTATION_XML) {
            for (let e6 = 0; e6 < s4.length; e6++)
              if (s4[e6].name === d.ENCODING) {
                const t5 = s4[e6].value.toLowerCase();
                return t5 === Te || t5 === he;
              }
          }
          return t4 === p.SVG && (e5 === u.FOREIGN_OBJECT || e5 === u.DESC || e5 === u.TITLE);
        }(e4, t3, s3) || (!a2 || a2 === p.MATHML) && function(e5, t4) {
          return t4 === p.MATHML && (e5 === u.MI || e5 === u.MO || e5 === u.MN || e5 === u.MS || e5 === u.MTEXT);
        }(e4, t3);
      }(e3, this.treeAdapter.getNamespaceURI(t2), this.treeAdapter.getAttrList(t2), s2);
    }
    _reconstructActiveFormattingElements() {
      const e3 = this.activeFormattingElements.entries.length;
      if (e3) {
        const t2 = this.activeFormattingElements.entries.findIndex((e4) => e4.type === Z.Marker || this.openElements.contains(e4.element));
        for (let s2 = t2 < 0 ? e3 - 1 : t2 - 1; s2 >= 0; s2--) {
          const e4 = this.activeFormattingElements.entries[s2];
          this._insertElement(e4.token, this.treeAdapter.getNamespaceURI(e4.element)), e4.element = this.openElements.current;
        }
      }
    }
    _closeTableCell() {
      this.openElements.generateImpliedEndTags(), this.openElements.popUntilTableCellPopped(), this.activeFormattingElements.clearToLastMarker(), this.insertionMode = Re.IN_ROW;
    }
    _closePElement() {
      this.openElements.generateImpliedEndTagsWithExclusion(u.P), this.openElements.popUntilTagNamePopped(u.P);
    }
    _resetInsertionMode() {
      for (let e3 = this.openElements.stackTop; e3 >= 0; e3--)
        switch (0 === e3 && this.fragmentContext ? this.fragmentContextID : this.openElements.tagIDs[e3]) {
          case u.TR:
            return void (this.insertionMode = Re.IN_ROW);
          case u.TBODY:
          case u.THEAD:
          case u.TFOOT:
            return void (this.insertionMode = Re.IN_TABLE_BODY);
          case u.CAPTION:
            return void (this.insertionMode = Re.IN_CAPTION);
          case u.COLGROUP:
            return void (this.insertionMode = Re.IN_COLUMN_GROUP);
          case u.TABLE:
            return void (this.insertionMode = Re.IN_TABLE);
          case u.BODY:
            return void (this.insertionMode = Re.IN_BODY);
          case u.FRAMESET:
            return void (this.insertionMode = Re.IN_FRAMESET);
          case u.SELECT:
            return void this._resetInsertionModeForSelect(e3);
          case u.TEMPLATE:
            return void (this.insertionMode = this.tmplInsertionModeStack[0]);
          case u.HTML:
            return void (this.insertionMode = this.headElement ? Re.AFTER_HEAD : Re.BEFORE_HEAD);
          case u.TD:
          case u.TH:
            if (e3 > 0)
              return void (this.insertionMode = Re.IN_CELL);
            break;
          case u.HEAD:
            if (e3 > 0)
              return void (this.insertionMode = Re.IN_HEAD);
        }
      this.insertionMode = Re.IN_BODY;
    }
    _resetInsertionModeForSelect(e3) {
      if (e3 > 0)
        for (let t2 = e3 - 1; t2 > 0; t2--) {
          const e4 = this.openElements.tagIDs[t2];
          if (e4 === u.TEMPLATE)
            break;
          if (e4 === u.TABLE)
            return void (this.insertionMode = Re.IN_SELECT_IN_TABLE);
        }
      this.insertionMode = Re.IN_SELECT;
    }
    _isElementCausesFosterParenting(e3) {
      return fe.has(e3);
    }
    _shouldFosterParentOnInsertion() {
      return this.fosterParentingEnabled && this._isElementCausesFosterParenting(this.openElements.currentTagId);
    }
    _findFosterParentingLocation() {
      for (let e3 = this.openElements.stackTop; e3 >= 0; e3--) {
        const t2 = this.openElements.items[e3];
        switch (this.openElements.tagIDs[e3]) {
          case u.TEMPLATE:
            if (this.treeAdapter.getNamespaceURI(t2) === p.HTML)
              return { parent: this.treeAdapter.getTemplateContent(t2), beforeElement: null };
            break;
          case u.TABLE: {
            const s2 = this.treeAdapter.getParentNode(t2);
            return s2 ? { parent: s2, beforeElement: t2 } : { parent: this.openElements.items[e3 - 1], beforeElement: null };
          }
        }
      }
      return { parent: this.openElements.items[0], beforeElement: null };
    }
    _fosterParentElement(e3) {
      const t2 = this._findFosterParentingLocation();
      t2.beforeElement ? this.treeAdapter.insertBefore(t2.parent, e3, t2.beforeElement) : this.treeAdapter.appendChild(t2.parent, e3);
    }
    _isSpecialElement(e3, t2) {
      const s2 = this.treeAdapter.getNamespaceURI(e3);
      return M[s2].has(t2);
    }
    onCharacter(e3) {
      if (this.skipNextNewLine = false, this.tokenizer.inForeignNode)
        !function(e4, t2) {
          e4._insertCharacters(t2), e4.framesetOk = false;
        }(this, e3);
      else
        switch (this.insertionMode) {
          case Re.INITIAL:
            ye(this, e3);
            break;
          case Re.BEFORE_HTML:
            we(this, e3);
            break;
          case Re.BEFORE_HEAD:
            Ye(this, e3);
            break;
          case Re.IN_HEAD:
            Qe(this, e3);
            break;
          case Re.IN_HEAD_NO_SCRIPT:
            qe(this, e3);
            break;
          case Re.AFTER_HEAD:
            We(this, e3);
            break;
          case Re.IN_BODY:
          case Re.IN_CAPTION:
          case Re.IN_CELL:
          case Re.IN_TEMPLATE:
            Ve(this, e3);
            break;
          case Re.TEXT:
          case Re.IN_SELECT:
          case Re.IN_SELECT_IN_TABLE:
            this._insertCharacters(e3);
            break;
          case Re.IN_TABLE:
          case Re.IN_TABLE_BODY:
          case Re.IN_ROW:
            at(this, e3);
            break;
          case Re.IN_TABLE_TEXT:
            ct(this, e3);
            break;
          case Re.IN_COLUMN_GROUP:
            _t(this, e3);
            break;
          case Re.AFTER_BODY:
            Ct(this, e3);
            break;
          case Re.AFTER_AFTER_BODY:
            Dt(this, e3);
        }
    }
    onNullCharacter(e3) {
      if (this.skipNextNewLine = false, this.tokenizer.inForeignNode)
        !function(e4, t2) {
          t2.chars = s, e4._insertCharacters(t2);
        }(this, e3);
      else
        switch (this.insertionMode) {
          case Re.INITIAL:
            ye(this, e3);
            break;
          case Re.BEFORE_HTML:
            we(this, e3);
            break;
          case Re.BEFORE_HEAD:
            Ye(this, e3);
            break;
          case Re.IN_HEAD:
            Qe(this, e3);
            break;
          case Re.IN_HEAD_NO_SCRIPT:
            qe(this, e3);
            break;
          case Re.AFTER_HEAD:
            We(this, e3);
            break;
          case Re.TEXT:
            this._insertCharacters(e3);
            break;
          case Re.IN_TABLE:
          case Re.IN_TABLE_BODY:
          case Re.IN_ROW:
            at(this, e3);
            break;
          case Re.IN_COLUMN_GROUP:
            _t(this, e3);
            break;
          case Re.AFTER_BODY:
            Ct(this, e3);
            break;
          case Re.AFTER_AFTER_BODY:
            Dt(this, e3);
        }
    }
    onComment(e3) {
      if (this.skipNextNewLine = false, this.currentNotInHTML)
        Ue(this, e3);
      else
        switch (this.insertionMode) {
          case Re.INITIAL:
          case Re.BEFORE_HTML:
          case Re.BEFORE_HEAD:
          case Re.IN_HEAD:
          case Re.IN_HEAD_NO_SCRIPT:
          case Re.AFTER_HEAD:
          case Re.IN_BODY:
          case Re.IN_TABLE:
          case Re.IN_CAPTION:
          case Re.IN_COLUMN_GROUP:
          case Re.IN_TABLE_BODY:
          case Re.IN_ROW:
          case Re.IN_CELL:
          case Re.IN_SELECT:
          case Re.IN_SELECT_IN_TABLE:
          case Re.IN_TEMPLATE:
          case Re.IN_FRAMESET:
          case Re.AFTER_FRAMESET:
            Ue(this, e3);
            break;
          case Re.IN_TABLE_TEXT:
            Et(this, e3);
            break;
          case Re.AFTER_BODY:
            !function(e4, t2) {
              e4._appendCommentNode(t2, e4.openElements.items[0]);
            }(this, e3);
            break;
          case Re.AFTER_AFTER_BODY:
          case Re.AFTER_AFTER_FRAMESET:
            !function(e4, t2) {
              e4._appendCommentNode(t2, e4.document);
            }(this, e3);
        }
    }
    onDoctype(e3) {
      switch (this.skipNextNewLine = false, this.insertionMode) {
        case Re.INITIAL:
          !function(e4, t2) {
            e4._setDocumentType(t2);
            const s2 = t2.forceQuirks ? I.QUIRKS : function(e5) {
              if (e5.name !== ae)
                return I.QUIRKS;
              const { systemId: t3 } = e5;
              if (t3 && "http://www.ibm.com/data/dtd/v11/ibmxhtml1-transitional.dtd" === t3.toLowerCase())
                return I.QUIRKS;
              let { publicId: s3 } = e5;
              if (null !== s3) {
                if (s3 = s3.toLowerCase(), ie.has(s3))
                  return I.QUIRKS;
                let e6 = null === t3 ? ne : re;
                if (Ee(s3, e6))
                  return I.QUIRKS;
                if (e6 = null === t3 ? oe : ce, Ee(s3, e6))
                  return I.LIMITED_QUIRKS;
              }
              return I.NO_QUIRKS;
            }(t2);
            (function(e5) {
              return e5.name === ae && null === e5.publicId && (null === e5.systemId || "about:legacy-compat" === e5.systemId);
            })(t2) || e4._err(t2, T.nonConformingDoctype), e4.treeAdapter.setDocumentMode(e4.document, s2), e4.insertionMode = Re.BEFORE_HTML;
          }(this, e3);
          break;
        case Re.BEFORE_HEAD:
        case Re.IN_HEAD:
        case Re.IN_HEAD_NO_SCRIPT:
        case Re.AFTER_HEAD:
          this._err(e3, T.misplacedDoctype);
          break;
        case Re.IN_TABLE_TEXT:
          Et(this, e3);
      }
    }
    onStartTag(e3) {
      this.skipNextNewLine = false, this.currentToken = e3, this._processStartTag(e3), e3.selfClosing && !e3.ackSelfClosing && this._err(e3, T.nonVoidHtmlElementStartTagWithTrailingSolidus);
    }
    _processStartTag(e3) {
      this.shouldProcessStartTagTokenInForeignContent(e3) ? function(e4, t2) {
        if (function(e5) {
          const t3 = e5.tagID;
          return t3 === u.FONT && e5.attrs.some(({ name: e6 }) => e6 === d.COLOR || e6 === d.SIZE || e6 === d.FACE) || de.has(t3);
        }(t2))
          St(e4), e4._startTagOutsideForeignContent(t2);
        else {
          const s2 = e4._getAdjustedCurrentElement(), a2 = e4.treeAdapter.getNamespaceURI(s2);
          a2 === p.MATHML ? Ie(t2) : a2 === p.SVG && (function(e5) {
            const t3 = pe.get(e5.tagName);
            null != t3 && (e5.tagName = t3, e5.tagID = f(e5.tagName));
          }(t2), Ne(t2)), ue(t2), t2.selfClosing ? e4._appendElement(t2, a2) : e4._insertElement(t2, a2), t2.ackSelfClosing = true;
        }
      }(this, e3) : this._startTagOutsideForeignContent(e3);
    }
    _startTagOutsideForeignContent(e3) {
      switch (this.insertionMode) {
        case Re.INITIAL:
          ye(this, e3);
          break;
        case Re.BEFORE_HTML:
          !function(e4, t2) {
            t2.tagID === u.HTML ? (e4._insertElement(t2, p.HTML), e4.insertionMode = Re.BEFORE_HEAD) : we(e4, t2);
          }(this, e3);
          break;
        case Re.BEFORE_HEAD:
          !function(e4, t2) {
            switch (t2.tagID) {
              case u.HTML:
                $e(e4, t2);
                break;
              case u.HEAD:
                e4._insertElement(t2, p.HTML), e4.headElement = e4.openElements.current, e4.insertionMode = Re.IN_HEAD;
                break;
              default:
                Ye(e4, t2);
            }
          }(this, e3);
          break;
        case Re.IN_HEAD:
          xe(this, e3);
          break;
        case Re.IN_HEAD_NO_SCRIPT:
          !function(e4, t2) {
            switch (t2.tagID) {
              case u.HTML:
                $e(e4, t2);
                break;
              case u.BASEFONT:
              case u.BGSOUND:
              case u.HEAD:
              case u.LINK:
              case u.META:
              case u.NOFRAMES:
              case u.STYLE:
                xe(e4, t2);
                break;
              case u.NOSCRIPT:
                e4._err(t2, T.nestedNoscriptInHead);
                break;
              default:
                qe(e4, t2);
            }
          }(this, e3);
          break;
        case Re.AFTER_HEAD:
          !function(e4, t2) {
            switch (t2.tagID) {
              case u.HTML:
                $e(e4, t2);
                break;
              case u.BODY:
                e4._insertElement(t2, p.HTML), e4.framesetOk = false, e4.insertionMode = Re.IN_BODY;
                break;
              case u.FRAMESET:
                e4._insertElement(t2, p.HTML), e4.insertionMode = Re.IN_FRAMESET;
                break;
              case u.BASE:
              case u.BASEFONT:
              case u.BGSOUND:
              case u.LINK:
              case u.META:
              case u.NOFRAMES:
              case u.SCRIPT:
              case u.STYLE:
              case u.TEMPLATE:
              case u.TITLE:
                e4._err(t2, T.abandonedHeadElementChild), e4.openElements.push(e4.headElement, u.HEAD), xe(e4, t2), e4.openElements.remove(e4.headElement);
                break;
              case u.HEAD:
                e4._err(t2, T.misplacedStartTagForHeadElement);
                break;
              default:
                We(e4, t2);
            }
          }(this, e3);
          break;
        case Re.IN_BODY:
          $e(this, e3);
          break;
        case Re.IN_TABLE:
          rt(this, e3);
          break;
        case Re.IN_TABLE_TEXT:
          Et(this, e3);
          break;
        case Re.IN_CAPTION:
          !function(e4, t2) {
            const s2 = t2.tagID;
            Tt.has(s2) ? e4.openElements.hasInTableScope(u.CAPTION) && (e4.openElements.generateImpliedEndTags(), e4.openElements.popUntilTagNamePopped(u.CAPTION), e4.activeFormattingElements.clearToLastMarker(), e4.insertionMode = Re.IN_TABLE, rt(e4, t2)) : $e(e4, t2);
          }(this, e3);
          break;
        case Re.IN_COLUMN_GROUP:
          ht(this, e3);
          break;
        case Re.IN_TABLE_BODY:
          At(this, e3);
          break;
        case Re.IN_ROW:
          mt(this, e3);
          break;
        case Re.IN_CELL:
          !function(e4, t2) {
            const s2 = t2.tagID;
            Tt.has(s2) ? (e4.openElements.hasInTableScope(u.TD) || e4.openElements.hasInTableScope(u.TH)) && (e4._closeTableCell(), mt(e4, t2)) : $e(e4, t2);
          }(this, e3);
          break;
        case Re.IN_SELECT:
          dt(this, e3);
          break;
        case Re.IN_SELECT_IN_TABLE:
          !function(e4, t2) {
            const s2 = t2.tagID;
            s2 === u.CAPTION || s2 === u.TABLE || s2 === u.TBODY || s2 === u.TFOOT || s2 === u.THEAD || s2 === u.TR || s2 === u.TD || s2 === u.TH ? (e4.openElements.popUntilTagNamePopped(u.SELECT), e4._resetInsertionMode(), e4._processStartTag(t2)) : dt(e4, t2);
          }(this, e3);
          break;
        case Re.IN_TEMPLATE:
          !function(e4, t2) {
            switch (t2.tagID) {
              case u.BASE:
              case u.BASEFONT:
              case u.BGSOUND:
              case u.LINK:
              case u.META:
              case u.NOFRAMES:
              case u.SCRIPT:
              case u.STYLE:
              case u.TEMPLATE:
              case u.TITLE:
                xe(e4, t2);
                break;
              case u.CAPTION:
              case u.COLGROUP:
              case u.TBODY:
              case u.TFOOT:
              case u.THEAD:
                e4.tmplInsertionModeStack[0] = Re.IN_TABLE, e4.insertionMode = Re.IN_TABLE, rt(e4, t2);
                break;
              case u.COL:
                e4.tmplInsertionModeStack[0] = Re.IN_COLUMN_GROUP, e4.insertionMode = Re.IN_COLUMN_GROUP, ht(e4, t2);
                break;
              case u.TR:
                e4.tmplInsertionModeStack[0] = Re.IN_TABLE_BODY, e4.insertionMode = Re.IN_TABLE_BODY, At(e4, t2);
                break;
              case u.TD:
              case u.TH:
                e4.tmplInsertionModeStack[0] = Re.IN_ROW, e4.insertionMode = Re.IN_ROW, mt(e4, t2);
                break;
              default:
                e4.tmplInsertionModeStack[0] = Re.IN_BODY, e4.insertionMode = Re.IN_BODY, $e(e4, t2);
            }
          }(this, e3);
          break;
        case Re.AFTER_BODY:
          !function(e4, t2) {
            t2.tagID === u.HTML ? $e(e4, t2) : Ct(e4, t2);
          }(this, e3);
          break;
        case Re.IN_FRAMESET:
          !function(e4, t2) {
            switch (t2.tagID) {
              case u.HTML:
                $e(e4, t2);
                break;
              case u.FRAMESET:
                e4._insertElement(t2, p.HTML);
                break;
              case u.FRAME:
                e4._appendElement(t2, p.HTML), t2.ackSelfClosing = true;
                break;
              case u.NOFRAMES:
                xe(e4, t2);
            }
          }(this, e3);
          break;
        case Re.AFTER_FRAMESET:
          !function(e4, t2) {
            switch (t2.tagID) {
              case u.HTML:
                $e(e4, t2);
                break;
              case u.NOFRAMES:
                xe(e4, t2);
            }
          }(this, e3);
          break;
        case Re.AFTER_AFTER_BODY:
          !function(e4, t2) {
            t2.tagID === u.HTML ? $e(e4, t2) : Dt(e4, t2);
          }(this, e3);
          break;
        case Re.AFTER_AFTER_FRAMESET:
          !function(e4, t2) {
            switch (t2.tagID) {
              case u.HTML:
                $e(e4, t2);
                break;
              case u.NOFRAMES:
                xe(e4, t2);
            }
          }(this, e3);
      }
    }
    onEndTag(e3) {
      this.skipNextNewLine = false, this.currentToken = e3, this.currentNotInHTML ? function(e4, t2) {
        if (t2.tagID === u.P || t2.tagID === u.BR)
          return St(e4), void e4._endTagOutsideForeignContent(t2);
        for (let s2 = e4.openElements.stackTop; s2 > 0; s2--) {
          const a2 = e4.openElements.items[s2];
          if (e4.treeAdapter.getNamespaceURI(a2) === p.HTML) {
            e4._endTagOutsideForeignContent(t2);
            break;
          }
          const r2 = e4.treeAdapter.getTagName(a2);
          if (r2.toLowerCase() === t2.tagName) {
            t2.tagName = r2, e4.openElements.shortenToLength(s2);
            break;
          }
        }
      }(this, e3) : this._endTagOutsideForeignContent(e3);
    }
    _endTagOutsideForeignContent(e3) {
      switch (this.insertionMode) {
        case Re.INITIAL:
          ye(this, e3);
          break;
        case Re.BEFORE_HTML:
          !function(e4, t2) {
            const s2 = t2.tagID;
            s2 !== u.HTML && s2 !== u.HEAD && s2 !== u.BODY && s2 !== u.BR || we(e4, t2);
          }(this, e3);
          break;
        case Re.BEFORE_HEAD:
          !function(e4, t2) {
            const s2 = t2.tagID;
            s2 === u.HEAD || s2 === u.BODY || s2 === u.HTML || s2 === u.BR ? Ye(e4, t2) : e4._err(t2, T.endTagWithoutMatchingOpenElement);
          }(this, e3);
          break;
        case Re.IN_HEAD:
          !function(e4, t2) {
            switch (t2.tagID) {
              case u.HEAD:
                e4.openElements.pop(), e4.insertionMode = Re.AFTER_HEAD;
                break;
              case u.BODY:
              case u.BR:
              case u.HTML:
                Qe(e4, t2);
                break;
              case u.TEMPLATE:
                ve(e4, t2);
                break;
              default:
                e4._err(t2, T.endTagWithoutMatchingOpenElement);
            }
          }(this, e3);
          break;
        case Re.IN_HEAD_NO_SCRIPT:
          !function(e4, t2) {
            switch (t2.tagID) {
              case u.NOSCRIPT:
                e4.openElements.pop(), e4.insertionMode = Re.IN_HEAD;
                break;
              case u.BR:
                qe(e4, t2);
                break;
              default:
                e4._err(t2, T.endTagWithoutMatchingOpenElement);
            }
          }(this, e3);
          break;
        case Re.AFTER_HEAD:
          !function(e4, t2) {
            switch (t2.tagID) {
              case u.BODY:
              case u.HTML:
              case u.BR:
                We(e4, t2);
                break;
              case u.TEMPLATE:
                ve(e4, t2);
                break;
              default:
                e4._err(t2, T.endTagWithoutMatchingOpenElement);
            }
          }(this, e3);
          break;
        case Re.IN_BODY:
          tt(this, e3);
          break;
        case Re.TEXT:
          !function(e4, t2) {
            var s2;
            t2.tagID === u.SCRIPT && (null === (s2 = e4.scriptHandler) || void 0 === s2 || s2.call(e4, e4.openElements.current)), e4.openElements.pop(), e4.insertionMode = e4.originalInsertionMode;
          }(this, e3);
          break;
        case Re.IN_TABLE:
          nt(this, e3);
          break;
        case Re.IN_TABLE_TEXT:
          Et(this, e3);
          break;
        case Re.IN_CAPTION:
          !function(e4, t2) {
            const s2 = t2.tagID;
            switch (s2) {
              case u.CAPTION:
              case u.TABLE:
                e4.openElements.hasInTableScope(u.CAPTION) && (e4.openElements.generateImpliedEndTags(), e4.openElements.popUntilTagNamePopped(u.CAPTION), e4.activeFormattingElements.clearToLastMarker(), e4.insertionMode = Re.IN_TABLE, s2 === u.TABLE && nt(e4, t2));
                break;
              case u.BODY:
              case u.COL:
              case u.COLGROUP:
              case u.HTML:
              case u.TBODY:
              case u.TD:
              case u.TFOOT:
              case u.TH:
              case u.THEAD:
              case u.TR:
                break;
              default:
                tt(e4, t2);
            }
          }(this, e3);
          break;
        case Re.IN_COLUMN_GROUP:
          !function(e4, t2) {
            switch (t2.tagID) {
              case u.COLGROUP:
                e4.openElements.currentTagId === u.COLGROUP && (e4.openElements.pop(), e4.insertionMode = Re.IN_TABLE);
                break;
              case u.TEMPLATE:
                ve(e4, t2);
                break;
              case u.COL:
                break;
              default:
                _t(e4, t2);
            }
          }(this, e3);
          break;
        case Re.IN_TABLE_BODY:
          lt(this, e3);
          break;
        case Re.IN_ROW:
          pt(this, e3);
          break;
        case Re.IN_CELL:
          !function(e4, t2) {
            const s2 = t2.tagID;
            switch (s2) {
              case u.TD:
              case u.TH:
                e4.openElements.hasInTableScope(s2) && (e4.openElements.generateImpliedEndTags(), e4.openElements.popUntilTagNamePopped(s2), e4.activeFormattingElements.clearToLastMarker(), e4.insertionMode = Re.IN_ROW);
                break;
              case u.TABLE:
              case u.TBODY:
              case u.TFOOT:
              case u.THEAD:
              case u.TR:
                e4.openElements.hasInTableScope(s2) && (e4._closeTableCell(), pt(e4, t2));
                break;
              case u.BODY:
              case u.CAPTION:
              case u.COL:
              case u.COLGROUP:
              case u.HTML:
                break;
              default:
                tt(e4, t2);
            }
          }(this, e3);
          break;
        case Re.IN_SELECT:
          It(this, e3);
          break;
        case Re.IN_SELECT_IN_TABLE:
          !function(e4, t2) {
            const s2 = t2.tagID;
            s2 === u.CAPTION || s2 === u.TABLE || s2 === u.TBODY || s2 === u.TFOOT || s2 === u.THEAD || s2 === u.TR || s2 === u.TD || s2 === u.TH ? e4.openElements.hasInTableScope(s2) && (e4.openElements.popUntilTagNamePopped(u.SELECT), e4._resetInsertionMode(), e4.onEndTag(t2)) : It(e4, t2);
          }(this, e3);
          break;
        case Re.IN_TEMPLATE:
          !function(e4, t2) {
            t2.tagID === u.TEMPLATE && ve(e4, t2);
          }(this, e3);
          break;
        case Re.AFTER_BODY:
          ut(this, e3);
          break;
        case Re.IN_FRAMESET:
          !function(e4, t2) {
            t2.tagID !== u.FRAMESET || e4.openElements.isRootHtmlElementCurrent() || (e4.openElements.pop(), e4.fragmentContext || e4.openElements.currentTagId === u.FRAMESET || (e4.insertionMode = Re.AFTER_FRAMESET));
          }(this, e3);
          break;
        case Re.AFTER_FRAMESET:
          !function(e4, t2) {
            t2.tagID === u.HTML && (e4.insertionMode = Re.AFTER_AFTER_FRAMESET);
          }(this, e3);
          break;
        case Re.AFTER_AFTER_BODY:
          Dt(this, e3);
      }
    }
    onEof(e3) {
      switch (this.insertionMode) {
        case Re.INITIAL:
          ye(this, e3);
          break;
        case Re.BEFORE_HTML:
          we(this, e3);
          break;
        case Re.BEFORE_HEAD:
          Ye(this, e3);
          break;
        case Re.IN_HEAD:
          Qe(this, e3);
          break;
        case Re.IN_HEAD_NO_SCRIPT:
          qe(this, e3);
          break;
        case Re.AFTER_HEAD:
          We(this, e3);
          break;
        case Re.IN_BODY:
        case Re.IN_TABLE:
        case Re.IN_CAPTION:
        case Re.IN_COLUMN_GROUP:
        case Re.IN_TABLE_BODY:
        case Re.IN_ROW:
        case Re.IN_CELL:
        case Re.IN_SELECT:
        case Re.IN_SELECT_IN_TABLE:
          st(this, e3);
          break;
        case Re.TEXT:
          !function(e4, t2) {
            e4._err(t2, T.eofInElementThatCanContainOnlyText), e4.openElements.pop(), e4.insertionMode = e4.originalInsertionMode, e4.onEof(t2);
          }(this, e3);
          break;
        case Re.IN_TABLE_TEXT:
          Et(this, e3);
          break;
        case Re.IN_TEMPLATE:
          Nt(this, e3);
          break;
        case Re.AFTER_BODY:
        case Re.IN_FRAMESET:
        case Re.AFTER_FRAMESET:
        case Re.AFTER_AFTER_BODY:
        case Re.AFTER_AFTER_FRAMESET:
          Ge(this, e3);
      }
    }
    onWhitespaceCharacter(e3) {
      if (this.skipNextNewLine && (this.skipNextNewLine = false, e3.chars.charCodeAt(0) === a.LINE_FEED)) {
        if (1 === e3.chars.length)
          return;
        e3.chars = e3.chars.substr(1);
      }
      if (this.tokenizer.inForeignNode)
        this._insertCharacters(e3);
      else
        switch (this.insertionMode) {
          case Re.IN_HEAD:
          case Re.IN_HEAD_NO_SCRIPT:
          case Re.AFTER_HEAD:
          case Re.TEXT:
          case Re.IN_COLUMN_GROUP:
          case Re.IN_SELECT:
          case Re.IN_SELECT_IN_TABLE:
          case Re.IN_FRAMESET:
          case Re.AFTER_FRAMESET:
            this._insertCharacters(e3);
            break;
          case Re.IN_BODY:
          case Re.IN_CAPTION:
          case Re.IN_CELL:
          case Re.IN_TEMPLATE:
          case Re.AFTER_BODY:
          case Re.AFTER_AFTER_BODY:
          case Re.AFTER_AFTER_FRAMESET:
            Ke(this, e3);
            break;
          case Re.IN_TABLE:
          case Re.IN_TABLE_BODY:
          case Re.IN_ROW:
            at(this, e3);
            break;
          case Re.IN_TABLE_TEXT:
            ot(this, e3);
        }
    }
  }
  function ge(e3, t2) {
    let s2 = e3.activeFormattingElements.getElementEntryInScopeWithTagName(t2.tagName);
    return s2 ? e3.openElements.contains(s2.element) ? e3.openElements.hasInScope(t2.tagID) || (s2 = null) : (e3.activeFormattingElements.removeEntry(s2), s2 = null) : et(e3, t2), s2;
  }
  function ke(e3, t2) {
    let s2 = null, a2 = e3.openElements.stackTop;
    for (; a2 >= 0; a2--) {
      const r2 = e3.openElements.items[a2];
      if (r2 === t2.element)
        break;
      e3._isSpecialElement(r2, e3.openElements.tagIDs[a2]) && (s2 = r2);
    }
    return s2 || (e3.openElements.shortenToLength(a2 < 0 ? 0 : a2), e3.activeFormattingElements.removeEntry(t2)), s2;
  }
  function Pe(e3, t2, s2) {
    let a2 = t2, r2 = e3.openElements.getCommonAncestor(t2);
    for (let n2 = 0, i2 = r2; i2 !== s2; n2++, i2 = r2) {
      r2 = e3.openElements.getCommonAncestor(i2);
      const s3 = e3.activeFormattingElements.getElementEntry(i2), o2 = s3 && n2 >= Se;
      !s3 || o2 ? (o2 && e3.activeFormattingElements.removeEntry(s3), e3.openElements.remove(i2)) : (i2 = be(e3, s3), a2 === t2 && (e3.activeFormattingElements.bookmark = s3), e3.treeAdapter.detachNode(a2), e3.treeAdapter.appendChild(i2, a2), a2 = i2);
    }
    return a2;
  }
  function be(e3, t2) {
    const s2 = e3.treeAdapter.getNamespaceURI(t2.element), a2 = e3.treeAdapter.createElement(t2.token.tagName, s2, t2.token.attrs);
    return e3.openElements.replace(t2.element, a2), t2.element = a2, a2;
  }
  function Be(e3, t2, s2) {
    const a2 = f(e3.treeAdapter.getTagName(t2));
    if (e3._isElementCausesFosterParenting(a2))
      e3._fosterParentElement(s2);
    else {
      const r2 = e3.treeAdapter.getNamespaceURI(t2);
      a2 === u.TEMPLATE && r2 === p.HTML && (t2 = e3.treeAdapter.getTemplateContent(t2)), e3.treeAdapter.appendChild(t2, s2);
    }
  }
  function He(e3, t2, s2) {
    const a2 = e3.treeAdapter.getNamespaceURI(s2.element), { token: r2 } = s2, n2 = e3.treeAdapter.createElement(r2.tagName, a2, r2.attrs);
    e3._adoptNodes(t2, n2), e3.treeAdapter.appendChild(t2, n2), e3.activeFormattingElements.insertElementAfterBookmark(n2, r2), e3.activeFormattingElements.removeEntry(s2), e3.openElements.remove(s2.element), e3.openElements.insertAfter(t2, n2, r2.tagID);
  }
  function Fe(e3, t2) {
    for (let s2 = 0; s2 < De; s2++) {
      const s3 = ge(e3, t2);
      if (!s3)
        break;
      const a2 = ke(e3, s3);
      if (!a2)
        break;
      e3.activeFormattingElements.bookmark = s3;
      const r2 = Pe(e3, a2, s3.element), n2 = e3.openElements.getCommonAncestor(s3.element);
      e3.treeAdapter.detachNode(r2), n2 && Be(e3, n2, r2), He(e3, a2, s3);
    }
  }
  function Ue(e3, t2) {
    e3._appendCommentNode(t2, e3.openElements.currentTmplContentOrNode);
  }
  function Ge(e3, t2) {
    if (e3.stopped = true, t2.location) {
      const s2 = e3.fragmentContext ? 0 : 2;
      for (let a2 = e3.openElements.stackTop; a2 >= s2; a2--)
        e3._setEndLocation(e3.openElements.items[a2], t2);
      if (!e3.fragmentContext && e3.openElements.stackTop >= 0) {
        const s3 = e3.openElements.items[0], a2 = e3.treeAdapter.getNodeSourceCodeLocation(s3);
        if (a2 && !a2.endTag && (e3._setEndLocation(s3, t2), e3.openElements.stackTop >= 1)) {
          const s4 = e3.openElements.items[1], a3 = e3.treeAdapter.getNodeSourceCodeLocation(s4);
          a3 && !a3.endTag && e3._setEndLocation(s4, t2);
        }
      }
    }
  }
  function ye(e3, t2) {
    e3._err(t2, T.missingDoctype, true), e3.treeAdapter.setDocumentMode(e3.document, I.QUIRKS), e3.insertionMode = Re.BEFORE_HTML, e3._processToken(t2);
  }
  function we(e3, t2) {
    e3._insertFakeRootElement(), e3.insertionMode = Re.BEFORE_HEAD, e3._processToken(t2);
  }
  function Ye(e3, t2) {
    e3._insertFakeElement(N.HEAD, u.HEAD), e3.headElement = e3.openElements.current, e3.insertionMode = Re.IN_HEAD, e3._processToken(t2);
  }
  function xe(e3, t2) {
    switch (t2.tagID) {
      case u.HTML:
        $e(e3, t2);
        break;
      case u.BASE:
      case u.BASEFONT:
      case u.BGSOUND:
      case u.LINK:
      case u.META:
        e3._appendElement(t2, p.HTML), t2.ackSelfClosing = true;
        break;
      case u.TITLE:
        e3._switchToTextParsing(t2, b.RCDATA);
        break;
      case u.NOSCRIPT:
        e3.options.scriptingEnabled ? e3._switchToTextParsing(t2, b.RAWTEXT) : (e3._insertElement(t2, p.HTML), e3.insertionMode = Re.IN_HEAD_NO_SCRIPT);
        break;
      case u.NOFRAMES:
      case u.STYLE:
        e3._switchToTextParsing(t2, b.RAWTEXT);
        break;
      case u.SCRIPT:
        e3._switchToTextParsing(t2, b.SCRIPT_DATA);
        break;
      case u.TEMPLATE:
        e3._insertTemplate(t2), e3.activeFormattingElements.insertMarker(), e3.framesetOk = false, e3.insertionMode = Re.IN_TEMPLATE, e3.tmplInsertionModeStack.unshift(Re.IN_TEMPLATE);
        break;
      case u.HEAD:
        e3._err(t2, T.misplacedStartTagForHeadElement);
        break;
      default:
        Qe(e3, t2);
    }
  }
  function ve(e3, t2) {
    e3.openElements.tmplCount > 0 ? (e3.openElements.generateImpliedEndTagsThoroughly(), e3.openElements.currentTagId !== u.TEMPLATE && e3._err(t2, T.closingOfElementWithOpenChildElements), e3.openElements.popUntilTagNamePopped(u.TEMPLATE), e3.activeFormattingElements.clearToLastMarker(), e3.tmplInsertionModeStack.shift(), e3._resetInsertionMode()) : e3._err(t2, T.endTagWithoutMatchingOpenElement);
  }
  function Qe(e3, t2) {
    e3.openElements.pop(), e3.insertionMode = Re.AFTER_HEAD, e3._processToken(t2);
  }
  function qe(e3, t2) {
    const s2 = t2.type === h.EOF ? T.openElementsLeftAfterEof : T.disallowedContentInNoscriptInHead;
    e3._err(t2, s2), e3.openElements.pop(), e3.insertionMode = Re.IN_HEAD, e3._processToken(t2);
  }
  function We(e3, t2) {
    e3._insertFakeElement(N.BODY, u.BODY), e3.insertionMode = Re.IN_BODY, Xe(e3, t2);
  }
  function Xe(e3, t2) {
    switch (t2.type) {
      case h.CHARACTER:
        Ve(e3, t2);
        break;
      case h.WHITESPACE_CHARACTER:
        Ke(e3, t2);
        break;
      case h.COMMENT:
        Ue(e3, t2);
        break;
      case h.START_TAG:
        $e(e3, t2);
        break;
      case h.END_TAG:
        tt(e3, t2);
        break;
      case h.EOF:
        st(e3, t2);
    }
  }
  function Ke(e3, t2) {
    e3._reconstructActiveFormattingElements(), e3._insertCharacters(t2);
  }
  function Ve(e3, t2) {
    e3._reconstructActiveFormattingElements(), e3._insertCharacters(t2), e3.framesetOk = false;
  }
  function ze(e3, t2) {
    e3._reconstructActiveFormattingElements(), e3._appendElement(t2, p.HTML), e3.framesetOk = false, t2.ackSelfClosing = true;
  }
  function je(e3) {
    const t2 = A(e3, d.TYPE);
    return null != t2 && t2.toLowerCase() === Ce;
  }
  function Je(e3, t2) {
    e3._switchToTextParsing(t2, b.RAWTEXT);
  }
  function Ze(e3, t2) {
    e3._reconstructActiveFormattingElements(), e3._insertElement(t2, p.HTML);
  }
  function $e(e3, t2) {
    switch (t2.tagID) {
      case u.I:
      case u.S:
      case u.B:
      case u.U:
      case u.EM:
      case u.TT:
      case u.BIG:
      case u.CODE:
      case u.FONT:
      case u.SMALL:
      case u.STRIKE:
      case u.STRONG:
        !function(e4, t3) {
          e4._reconstructActiveFormattingElements(), e4._insertElement(t3, p.HTML), e4.activeFormattingElements.pushElement(e4.openElements.current, t3);
        }(e3, t2);
        break;
      case u.A:
        !function(e4, t3) {
          const s2 = e4.activeFormattingElements.getElementEntryInScopeWithTagName(N.A);
          s2 && (Fe(e4, t3), e4.openElements.remove(s2.element), e4.activeFormattingElements.removeEntry(s2)), e4._reconstructActiveFormattingElements(), e4._insertElement(t3, p.HTML), e4.activeFormattingElements.pushElement(e4.openElements.current, t3);
        }(e3, t2);
        break;
      case u.H1:
      case u.H2:
      case u.H3:
      case u.H4:
      case u.H5:
      case u.H6:
        !function(e4, t3) {
          e4.openElements.hasInButtonScope(u.P) && e4._closePElement(), g(e4.openElements.currentTagId) && e4.openElements.pop(), e4._insertElement(t3, p.HTML);
        }(e3, t2);
        break;
      case u.P:
      case u.DL:
      case u.OL:
      case u.UL:
      case u.DIV:
      case u.DIR:
      case u.NAV:
      case u.MAIN:
      case u.MENU:
      case u.ASIDE:
      case u.CENTER:
      case u.FIGURE:
      case u.FOOTER:
      case u.HEADER:
      case u.HGROUP:
      case u.DIALOG:
      case u.DETAILS:
      case u.ADDRESS:
      case u.ARTICLE:
      case u.SECTION:
      case u.SUMMARY:
      case u.FIELDSET:
      case u.BLOCKQUOTE:
      case u.FIGCAPTION:
        !function(e4, t3) {
          e4.openElements.hasInButtonScope(u.P) && e4._closePElement(), e4._insertElement(t3, p.HTML);
        }(e3, t2);
        break;
      case u.LI:
      case u.DD:
      case u.DT:
        !function(e4, t3) {
          e4.framesetOk = false;
          const s2 = t3.tagID;
          for (let t4 = e4.openElements.stackTop; t4 >= 0; t4--) {
            const a2 = e4.openElements.tagIDs[t4];
            if (s2 === u.LI && a2 === u.LI || (s2 === u.DD || s2 === u.DT) && (a2 === u.DD || a2 === u.DT)) {
              e4.openElements.generateImpliedEndTagsWithExclusion(a2), e4.openElements.popUntilTagNamePopped(a2);
              break;
            }
            if (a2 !== u.ADDRESS && a2 !== u.DIV && a2 !== u.P && e4._isSpecialElement(e4.openElements.items[t4], a2))
              break;
          }
          e4.openElements.hasInButtonScope(u.P) && e4._closePElement(), e4._insertElement(t3, p.HTML);
        }(e3, t2);
        break;
      case u.BR:
      case u.IMG:
      case u.WBR:
      case u.AREA:
      case u.EMBED:
      case u.KEYGEN:
        ze(e3, t2);
        break;
      case u.HR:
        !function(e4, t3) {
          e4.openElements.hasInButtonScope(u.P) && e4._closePElement(), e4._appendElement(t3, p.HTML), e4.framesetOk = false, t3.ackSelfClosing = true;
        }(e3, t2);
        break;
      case u.RB:
      case u.RTC:
        !function(e4, t3) {
          e4.openElements.hasInScope(u.RUBY) && e4.openElements.generateImpliedEndTags(), e4._insertElement(t3, p.HTML);
        }(e3, t2);
        break;
      case u.RT:
      case u.RP:
        !function(e4, t3) {
          e4.openElements.hasInScope(u.RUBY) && e4.openElements.generateImpliedEndTagsWithExclusion(u.RTC), e4._insertElement(t3, p.HTML);
        }(e3, t2);
        break;
      case u.PRE:
      case u.LISTING:
        !function(e4, t3) {
          e4.openElements.hasInButtonScope(u.P) && e4._closePElement(), e4._insertElement(t3, p.HTML), e4.skipNextNewLine = true, e4.framesetOk = false;
        }(e3, t2);
        break;
      case u.XMP:
        !function(e4, t3) {
          e4.openElements.hasInButtonScope(u.P) && e4._closePElement(), e4._reconstructActiveFormattingElements(), e4.framesetOk = false, e4._switchToTextParsing(t3, b.RAWTEXT);
        }(e3, t2);
        break;
      case u.SVG:
        !function(e4, t3) {
          e4._reconstructActiveFormattingElements(), Ne(t3), ue(t3), t3.selfClosing ? e4._appendElement(t3, p.SVG) : e4._insertElement(t3, p.SVG), t3.ackSelfClosing = true;
        }(e3, t2);
        break;
      case u.HTML:
        !function(e4, t3) {
          0 === e4.openElements.tmplCount && e4.treeAdapter.adoptAttributes(e4.openElements.items[0], t3.attrs);
        }(e3, t2);
        break;
      case u.BASE:
      case u.LINK:
      case u.META:
      case u.STYLE:
      case u.TITLE:
      case u.SCRIPT:
      case u.BGSOUND:
      case u.BASEFONT:
      case u.TEMPLATE:
        xe(e3, t2);
        break;
      case u.BODY:
        !function(e4, t3) {
          const s2 = e4.openElements.tryPeekProperlyNestedBodyElement();
          s2 && 0 === e4.openElements.tmplCount && (e4.framesetOk = false, e4.treeAdapter.adoptAttributes(s2, t3.attrs));
        }(e3, t2);
        break;
      case u.FORM:
        !function(e4, t3) {
          const s2 = e4.openElements.tmplCount > 0;
          e4.formElement && !s2 || (e4.openElements.hasInButtonScope(u.P) && e4._closePElement(), e4._insertElement(t3, p.HTML), s2 || (e4.formElement = e4.openElements.current));
        }(e3, t2);
        break;
      case u.NOBR:
        !function(e4, t3) {
          e4._reconstructActiveFormattingElements(), e4.openElements.hasInScope(u.NOBR) && (Fe(e4, t3), e4._reconstructActiveFormattingElements()), e4._insertElement(t3, p.HTML), e4.activeFormattingElements.pushElement(e4.openElements.current, t3);
        }(e3, t2);
        break;
      case u.MATH:
        !function(e4, t3) {
          e4._reconstructActiveFormattingElements(), Ie(t3), ue(t3), t3.selfClosing ? e4._appendElement(t3, p.MATHML) : e4._insertElement(t3, p.MATHML), t3.ackSelfClosing = true;
        }(e3, t2);
        break;
      case u.TABLE:
        !function(e4, t3) {
          e4.treeAdapter.getDocumentMode(e4.document) !== I.QUIRKS && e4.openElements.hasInButtonScope(u.P) && e4._closePElement(), e4._insertElement(t3, p.HTML), e4.framesetOk = false, e4.insertionMode = Re.IN_TABLE;
        }(e3, t2);
        break;
      case u.INPUT:
        !function(e4, t3) {
          e4._reconstructActiveFormattingElements(), e4._appendElement(t3, p.HTML), je(t3) || (e4.framesetOk = false), t3.ackSelfClosing = true;
        }(e3, t2);
        break;
      case u.PARAM:
      case u.TRACK:
      case u.SOURCE:
        !function(e4, t3) {
          e4._appendElement(t3, p.HTML), t3.ackSelfClosing = true;
        }(e3, t2);
        break;
      case u.IMAGE:
        !function(e4, t3) {
          t3.tagName = N.IMG, t3.tagID = u.IMG, ze(e4, t3);
        }(e3, t2);
        break;
      case u.BUTTON:
        !function(e4, t3) {
          e4.openElements.hasInScope(u.BUTTON) && (e4.openElements.generateImpliedEndTags(), e4.openElements.popUntilTagNamePopped(u.BUTTON)), e4._reconstructActiveFormattingElements(), e4._insertElement(t3, p.HTML), e4.framesetOk = false;
        }(e3, t2);
        break;
      case u.APPLET:
      case u.OBJECT:
      case u.MARQUEE:
        !function(e4, t3) {
          e4._reconstructActiveFormattingElements(), e4._insertElement(t3, p.HTML), e4.activeFormattingElements.insertMarker(), e4.framesetOk = false;
        }(e3, t2);
        break;
      case u.IFRAME:
        !function(e4, t3) {
          e4.framesetOk = false, e4._switchToTextParsing(t3, b.RAWTEXT);
        }(e3, t2);
        break;
      case u.SELECT:
        !function(e4, t3) {
          e4._reconstructActiveFormattingElements(), e4._insertElement(t3, p.HTML), e4.framesetOk = false, e4.insertionMode = e4.insertionMode === Re.IN_TABLE || e4.insertionMode === Re.IN_CAPTION || e4.insertionMode === Re.IN_TABLE_BODY || e4.insertionMode === Re.IN_ROW || e4.insertionMode === Re.IN_CELL ? Re.IN_SELECT_IN_TABLE : Re.IN_SELECT;
        }(e3, t2);
        break;
      case u.OPTION:
      case u.OPTGROUP:
        !function(e4, t3) {
          e4.openElements.currentTagId === u.OPTION && e4.openElements.pop(), e4._reconstructActiveFormattingElements(), e4._insertElement(t3, p.HTML);
        }(e3, t2);
        break;
      case u.NOEMBED:
        Je(e3, t2);
        break;
      case u.FRAMESET:
        !function(e4, t3) {
          const s2 = e4.openElements.tryPeekProperlyNestedBodyElement();
          e4.framesetOk && s2 && (e4.treeAdapter.detachNode(s2), e4.openElements.popAllUpToHtmlElement(), e4._insertElement(t3, p.HTML), e4.insertionMode = Re.IN_FRAMESET);
        }(e3, t2);
        break;
      case u.TEXTAREA:
        !function(e4, t3) {
          e4._insertElement(t3, p.HTML), e4.skipNextNewLine = true, e4.tokenizer.state = b.RCDATA, e4.originalInsertionMode = e4.insertionMode, e4.framesetOk = false, e4.insertionMode = Re.TEXT;
        }(e3, t2);
        break;
      case u.NOSCRIPT:
        e3.options.scriptingEnabled ? Je(e3, t2) : Ze(e3, t2);
        break;
      case u.PLAINTEXT:
        !function(e4, t3) {
          e4.openElements.hasInButtonScope(u.P) && e4._closePElement(), e4._insertElement(t3, p.HTML), e4.tokenizer.state = b.PLAINTEXT;
        }(e3, t2);
        break;
      case u.COL:
      case u.TH:
      case u.TD:
      case u.TR:
      case u.HEAD:
      case u.FRAME:
      case u.TBODY:
      case u.TFOOT:
      case u.THEAD:
      case u.CAPTION:
      case u.COLGROUP:
        break;
      default:
        Ze(e3, t2);
    }
  }
  function et(e3, t2) {
    const s2 = t2.tagName, a2 = t2.tagID;
    for (let t3 = e3.openElements.stackTop; t3 > 0; t3--) {
      const r2 = e3.openElements.items[t3], n2 = e3.openElements.tagIDs[t3];
      if (a2 === n2 && (a2 !== u.UNKNOWN || e3.treeAdapter.getTagName(r2) === s2)) {
        e3.openElements.generateImpliedEndTagsWithExclusion(a2), e3.openElements.stackTop >= t3 && e3.openElements.shortenToLength(t3);
        break;
      }
      if (e3._isSpecialElement(r2, n2))
        break;
    }
  }
  function tt(e3, t2) {
    switch (t2.tagID) {
      case u.A:
      case u.B:
      case u.I:
      case u.S:
      case u.U:
      case u.EM:
      case u.TT:
      case u.BIG:
      case u.CODE:
      case u.FONT:
      case u.NOBR:
      case u.SMALL:
      case u.STRIKE:
      case u.STRONG:
        Fe(e3, t2);
        break;
      case u.P:
        !function(e4) {
          e4.openElements.hasInButtonScope(u.P) || e4._insertFakeElement(N.P, u.P), e4._closePElement();
        }(e3);
        break;
      case u.DL:
      case u.UL:
      case u.OL:
      case u.DIR:
      case u.DIV:
      case u.NAV:
      case u.PRE:
      case u.MAIN:
      case u.MENU:
      case u.ASIDE:
      case u.BUTTON:
      case u.CENTER:
      case u.FIGURE:
      case u.FOOTER:
      case u.HEADER:
      case u.HGROUP:
      case u.DIALOG:
      case u.ADDRESS:
      case u.ARTICLE:
      case u.DETAILS:
      case u.SECTION:
      case u.SUMMARY:
      case u.LISTING:
      case u.FIELDSET:
      case u.BLOCKQUOTE:
      case u.FIGCAPTION:
        !function(e4, t3) {
          const s2 = t3.tagID;
          e4.openElements.hasInScope(s2) && (e4.openElements.generateImpliedEndTags(), e4.openElements.popUntilTagNamePopped(s2));
        }(e3, t2);
        break;
      case u.LI:
        !function(e4) {
          e4.openElements.hasInListItemScope(u.LI) && (e4.openElements.generateImpliedEndTagsWithExclusion(u.LI), e4.openElements.popUntilTagNamePopped(u.LI));
        }(e3);
        break;
      case u.DD:
      case u.DT:
        !function(e4, t3) {
          const s2 = t3.tagID;
          e4.openElements.hasInScope(s2) && (e4.openElements.generateImpliedEndTagsWithExclusion(s2), e4.openElements.popUntilTagNamePopped(s2));
        }(e3, t2);
        break;
      case u.H1:
      case u.H2:
      case u.H3:
      case u.H4:
      case u.H5:
      case u.H6:
        !function(e4) {
          e4.openElements.hasNumberedHeaderInScope() && (e4.openElements.generateImpliedEndTags(), e4.openElements.popUntilNumberedHeaderPopped());
        }(e3);
        break;
      case u.BR:
        !function(e4) {
          e4._reconstructActiveFormattingElements(), e4._insertFakeElement(N.BR, u.BR), e4.openElements.pop(), e4.framesetOk = false;
        }(e3);
        break;
      case u.BODY:
        !function(e4, t3) {
          if (e4.openElements.hasInScope(u.BODY) && (e4.insertionMode = Re.AFTER_BODY, e4.options.sourceCodeLocationInfo)) {
            const s2 = e4.openElements.tryPeekProperlyNestedBodyElement();
            s2 && e4._setEndLocation(s2, t3);
          }
        }(e3, t2);
        break;
      case u.HTML:
        !function(e4, t3) {
          e4.openElements.hasInScope(u.BODY) && (e4.insertionMode = Re.AFTER_BODY, ut(e4, t3));
        }(e3, t2);
        break;
      case u.FORM:
        !function(e4) {
          const t3 = e4.openElements.tmplCount > 0, { formElement: s2 } = e4;
          t3 || (e4.formElement = null), (s2 || t3) && e4.openElements.hasInScope(u.FORM) && (e4.openElements.generateImpliedEndTags(), t3 ? e4.openElements.popUntilTagNamePopped(u.FORM) : s2 && e4.openElements.remove(s2));
        }(e3);
        break;
      case u.APPLET:
      case u.OBJECT:
      case u.MARQUEE:
        !function(e4, t3) {
          const s2 = t3.tagID;
          e4.openElements.hasInScope(s2) && (e4.openElements.generateImpliedEndTags(), e4.openElements.popUntilTagNamePopped(s2), e4.activeFormattingElements.clearToLastMarker());
        }(e3, t2);
        break;
      case u.TEMPLATE:
        ve(e3, t2);
        break;
      default:
        et(e3, t2);
    }
  }
  function st(e3, t2) {
    e3.tmplInsertionModeStack.length > 0 ? Nt(e3, t2) : Ge(e3, t2);
  }
  function at(e3, t2) {
    if (fe.has(e3.openElements.currentTagId))
      switch (e3.pendingCharacterTokens.length = 0, e3.hasNonWhitespacePendingCharacterToken = false, e3.originalInsertionMode = e3.insertionMode, e3.insertionMode = Re.IN_TABLE_TEXT, t2.type) {
        case h.CHARACTER:
          ct(e3, t2);
          break;
        case h.WHITESPACE_CHARACTER:
          ot(e3, t2);
      }
    else
      it(e3, t2);
  }
  function rt(e3, t2) {
    switch (t2.tagID) {
      case u.TD:
      case u.TH:
      case u.TR:
        !function(e4, t3) {
          e4.openElements.clearBackToTableContext(), e4._insertFakeElement(N.TBODY, u.TBODY), e4.insertionMode = Re.IN_TABLE_BODY, At(e4, t3);
        }(e3, t2);
        break;
      case u.STYLE:
      case u.SCRIPT:
      case u.TEMPLATE:
        xe(e3, t2);
        break;
      case u.COL:
        !function(e4, t3) {
          e4.openElements.clearBackToTableContext(), e4._insertFakeElement(N.COLGROUP, u.COLGROUP), e4.insertionMode = Re.IN_COLUMN_GROUP, ht(e4, t3);
        }(e3, t2);
        break;
      case u.FORM:
        !function(e4, t3) {
          e4.formElement || 0 !== e4.openElements.tmplCount || (e4._insertElement(t3, p.HTML), e4.formElement = e4.openElements.current, e4.openElements.pop());
        }(e3, t2);
        break;
      case u.TABLE:
        !function(e4, t3) {
          e4.openElements.hasInTableScope(u.TABLE) && (e4.openElements.popUntilTagNamePopped(u.TABLE), e4._resetInsertionMode(), e4._processStartTag(t3));
        }(e3, t2);
        break;
      case u.TBODY:
      case u.TFOOT:
      case u.THEAD:
        !function(e4, t3) {
          e4.openElements.clearBackToTableContext(), e4._insertElement(t3, p.HTML), e4.insertionMode = Re.IN_TABLE_BODY;
        }(e3, t2);
        break;
      case u.INPUT:
        !function(e4, t3) {
          je(t3) ? e4._appendElement(t3, p.HTML) : it(e4, t3), t3.ackSelfClosing = true;
        }(e3, t2);
        break;
      case u.CAPTION:
        !function(e4, t3) {
          e4.openElements.clearBackToTableContext(), e4.activeFormattingElements.insertMarker(), e4._insertElement(t3, p.HTML), e4.insertionMode = Re.IN_CAPTION;
        }(e3, t2);
        break;
      case u.COLGROUP:
        !function(e4, t3) {
          e4.openElements.clearBackToTableContext(), e4._insertElement(t3, p.HTML), e4.insertionMode = Re.IN_COLUMN_GROUP;
        }(e3, t2);
        break;
      default:
        it(e3, t2);
    }
  }
  function nt(e3, t2) {
    switch (t2.tagID) {
      case u.TABLE:
        e3.openElements.hasInTableScope(u.TABLE) && (e3.openElements.popUntilTagNamePopped(u.TABLE), e3._resetInsertionMode());
        break;
      case u.TEMPLATE:
        ve(e3, t2);
        break;
      case u.BODY:
      case u.CAPTION:
      case u.COL:
      case u.COLGROUP:
      case u.HTML:
      case u.TBODY:
      case u.TD:
      case u.TFOOT:
      case u.TH:
      case u.THEAD:
      case u.TR:
        break;
      default:
        it(e3, t2);
    }
  }
  function it(e3, t2) {
    const s2 = e3.fosterParentingEnabled;
    e3.fosterParentingEnabled = true, Xe(e3, t2), e3.fosterParentingEnabled = s2;
  }
  function ot(e3, t2) {
    e3.pendingCharacterTokens.push(t2);
  }
  function ct(e3, t2) {
    e3.pendingCharacterTokens.push(t2), e3.hasNonWhitespacePendingCharacterToken = true;
  }
  function Et(e3, t2) {
    let s2 = 0;
    if (e3.hasNonWhitespacePendingCharacterToken)
      for (; s2 < e3.pendingCharacterTokens.length; s2++)
        it(e3, e3.pendingCharacterTokens[s2]);
    else
      for (; s2 < e3.pendingCharacterTokens.length; s2++)
        e3._insertCharacters(e3.pendingCharacterTokens[s2]);
    e3.insertionMode = e3.originalInsertionMode, e3._processToken(t2);
  }
  const Tt = /* @__PURE__ */ new Set([u.CAPTION, u.COL, u.COLGROUP, u.TBODY, u.TD, u.TFOOT, u.TH, u.THEAD, u.TR]);
  function ht(e3, t2) {
    switch (t2.tagID) {
      case u.HTML:
        $e(e3, t2);
        break;
      case u.COL:
        e3._appendElement(t2, p.HTML), t2.ackSelfClosing = true;
        break;
      case u.TEMPLATE:
        xe(e3, t2);
        break;
      default:
        _t(e3, t2);
    }
  }
  function _t(e3, t2) {
    e3.openElements.currentTagId === u.COLGROUP && (e3.openElements.pop(), e3.insertionMode = Re.IN_TABLE, e3._processToken(t2));
  }
  function At(e3, t2) {
    switch (t2.tagID) {
      case u.TR:
        e3.openElements.clearBackToTableBodyContext(), e3._insertElement(t2, p.HTML), e3.insertionMode = Re.IN_ROW;
        break;
      case u.TH:
      case u.TD:
        e3.openElements.clearBackToTableBodyContext(), e3._insertFakeElement(N.TR, u.TR), e3.insertionMode = Re.IN_ROW, mt(e3, t2);
        break;
      case u.CAPTION:
      case u.COL:
      case u.COLGROUP:
      case u.TBODY:
      case u.TFOOT:
      case u.THEAD:
        e3.openElements.hasTableBodyContextInTableScope() && (e3.openElements.clearBackToTableBodyContext(), e3.openElements.pop(), e3.insertionMode = Re.IN_TABLE, rt(e3, t2));
        break;
      default:
        rt(e3, t2);
    }
  }
  function lt(e3, t2) {
    const s2 = t2.tagID;
    switch (t2.tagID) {
      case u.TBODY:
      case u.TFOOT:
      case u.THEAD:
        e3.openElements.hasInTableScope(s2) && (e3.openElements.clearBackToTableBodyContext(), e3.openElements.pop(), e3.insertionMode = Re.IN_TABLE);
        break;
      case u.TABLE:
        e3.openElements.hasTableBodyContextInTableScope() && (e3.openElements.clearBackToTableBodyContext(), e3.openElements.pop(), e3.insertionMode = Re.IN_TABLE, nt(e3, t2));
        break;
      case u.BODY:
      case u.CAPTION:
      case u.COL:
      case u.COLGROUP:
      case u.HTML:
      case u.TD:
      case u.TH:
      case u.TR:
        break;
      default:
        nt(e3, t2);
    }
  }
  function mt(e3, t2) {
    switch (t2.tagID) {
      case u.TH:
      case u.TD:
        e3.openElements.clearBackToTableRowContext(), e3._insertElement(t2, p.HTML), e3.insertionMode = Re.IN_CELL, e3.activeFormattingElements.insertMarker();
        break;
      case u.CAPTION:
      case u.COL:
      case u.COLGROUP:
      case u.TBODY:
      case u.TFOOT:
      case u.THEAD:
      case u.TR:
        e3.openElements.hasInTableScope(u.TR) && (e3.openElements.clearBackToTableRowContext(), e3.openElements.pop(), e3.insertionMode = Re.IN_TABLE_BODY, At(e3, t2));
        break;
      default:
        rt(e3, t2);
    }
  }
  function pt(e3, t2) {
    switch (t2.tagID) {
      case u.TR:
        e3.openElements.hasInTableScope(u.TR) && (e3.openElements.clearBackToTableRowContext(), e3.openElements.pop(), e3.insertionMode = Re.IN_TABLE_BODY);
        break;
      case u.TABLE:
        e3.openElements.hasInTableScope(u.TR) && (e3.openElements.clearBackToTableRowContext(), e3.openElements.pop(), e3.insertionMode = Re.IN_TABLE_BODY, lt(e3, t2));
        break;
      case u.TBODY:
      case u.TFOOT:
      case u.THEAD:
        (e3.openElements.hasInTableScope(t2.tagID) || e3.openElements.hasInTableScope(u.TR)) && (e3.openElements.clearBackToTableRowContext(), e3.openElements.pop(), e3.insertionMode = Re.IN_TABLE_BODY, lt(e3, t2));
        break;
      case u.BODY:
      case u.CAPTION:
      case u.COL:
      case u.COLGROUP:
      case u.HTML:
      case u.TD:
      case u.TH:
        break;
      default:
        nt(e3, t2);
    }
  }
  function dt(e3, t2) {
    switch (t2.tagID) {
      case u.HTML:
        $e(e3, t2);
        break;
      case u.OPTION:
        e3.openElements.currentTagId === u.OPTION && e3.openElements.pop(), e3._insertElement(t2, p.HTML);
        break;
      case u.OPTGROUP:
        e3.openElements.currentTagId === u.OPTION && e3.openElements.pop(), e3.openElements.currentTagId === u.OPTGROUP && e3.openElements.pop(), e3._insertElement(t2, p.HTML);
        break;
      case u.INPUT:
      case u.KEYGEN:
      case u.TEXTAREA:
      case u.SELECT:
        e3.openElements.hasInSelectScope(u.SELECT) && (e3.openElements.popUntilTagNamePopped(u.SELECT), e3._resetInsertionMode(), t2.tagID !== u.SELECT && e3._processStartTag(t2));
        break;
      case u.SCRIPT:
      case u.TEMPLATE:
        xe(e3, t2);
    }
  }
  function It(e3, t2) {
    switch (t2.tagID) {
      case u.OPTGROUP:
        e3.openElements.stackTop > 0 && e3.openElements.currentTagId === u.OPTION && e3.openElements.tagIDs[e3.openElements.stackTop - 1] === u.OPTGROUP && e3.openElements.pop(), e3.openElements.currentTagId === u.OPTGROUP && e3.openElements.pop();
        break;
      case u.OPTION:
        e3.openElements.currentTagId === u.OPTION && e3.openElements.pop();
        break;
      case u.SELECT:
        e3.openElements.hasInSelectScope(u.SELECT) && (e3.openElements.popUntilTagNamePopped(u.SELECT), e3._resetInsertionMode());
        break;
      case u.TEMPLATE:
        ve(e3, t2);
    }
  }
  function Nt(e3, t2) {
    e3.openElements.tmplCount > 0 ? (e3.openElements.popUntilTagNamePopped(u.TEMPLATE), e3.activeFormattingElements.clearToLastMarker(), e3.tmplInsertionModeStack.shift(), e3._resetInsertionMode(), e3.onEof(t2)) : Ge(e3, t2);
  }
  function ut(e3, t2) {
    var s2;
    if (t2.tagID === u.HTML) {
      if (e3.fragmentContext || (e3.insertionMode = Re.AFTER_AFTER_BODY), e3.options.sourceCodeLocationInfo && e3.openElements.tagIDs[0] === u.HTML) {
        e3._setEndLocation(e3.openElements.items[0], t2);
        const a2 = e3.openElements.items[1];
        a2 && !(null === (s2 = e3.treeAdapter.getNodeSourceCodeLocation(a2)) || void 0 === s2 ? void 0 : s2.endTag) && e3._setEndLocation(a2, t2);
      }
    } else
      Ct(e3, t2);
  }
  function Ct(e3, t2) {
    e3.insertionMode = Re.IN_BODY, Xe(e3, t2);
  }
  function Dt(e3, t2) {
    e3.insertionMode = Re.IN_BODY, Xe(e3, t2);
  }
  function St(e3) {
    for (; e3.treeAdapter.getNamespaceURI(e3.openElements.current) !== p.HTML && !e3._isIntegrationPoint(e3.openElements.currentTagId, e3.openElements.current); )
      e3.openElements.pop();
  }
  return /* @__PURE__ */ new Set([N.AREA, N.BASE, N.BASEFONT, N.BGSOUND, N.BR, N.COL, N.EMBED, N.FRAME, N.HR, N.IMG, N.INPUT, N.KEYGEN, N.LINK, N.META, N.PARAM, N.SOURCE, N.TRACK, N.WBR]), e2.parse = function(e3, t2) {
    return Me.parse(e3, t2);
  }, e2.parseFragment = function(e3, t2, s2) {
    "string" == typeof e3 && (s2 = t2, t2 = e3, e3 = null);
    const a2 = Me.getFragmentParser(e3, s2);
    return a2.tokenizer.write(t2, true), a2.getFragment();
  }, Object.defineProperty(e2, "__esModule", { value: true }), e2;
}({});
const parse = e.parse;
const parseFragment = e.parseFragment;
const docParser = /* @__PURE__ */ new WeakMap();
function parseDocumentUtil(ownerDocument, html) {
  const doc = parse(html.trim(), getParser(ownerDocument));
  doc.documentElement = doc.firstElementChild;
  doc.head = doc.documentElement.firstElementChild;
  doc.body = doc.head.nextElementSibling;
  return doc;
}
function parseFragmentUtil(ownerDocument, html) {
  if (typeof html === "string") {
    html = html.trim();
  } else {
    html = "";
  }
  const frag = parseFragment(html, getParser(ownerDocument));
  return frag;
}
function getParser(ownerDocument) {
  let parseOptions = docParser.get(ownerDocument);
  if (parseOptions != null) {
    return parseOptions;
  }
  const treeAdapter = {
    createDocument() {
      const doc = ownerDocument.createElement(
        "#document"
        /* NODE_NAMES.DOCUMENT_NODE */
      );
      doc["x-mode"] = "no-quirks";
      return doc;
    },
    setNodeSourceCodeLocation(node, location2) {
      node.sourceCodeLocation = location2;
    },
    getNodeSourceCodeLocation(node) {
      return node.sourceCodeLocation;
    },
    createDocumentFragment() {
      return ownerDocument.createDocumentFragment();
    },
    createElement(tagName, namespaceURI, attrs) {
      const elm = ownerDocument.createElementNS(namespaceURI, tagName);
      for (let i = 0; i < attrs.length; i++) {
        const attr = attrs[i];
        if (attr.namespace == null || attr.namespace === "http://www.w3.org/1999/xhtml") {
          elm.setAttribute(attr.name, attr.value);
        } else {
          elm.setAttributeNS(attr.namespace, attr.name, attr.value);
        }
      }
      return elm;
    },
    createCommentNode(data) {
      return ownerDocument.createComment(data);
    },
    appendChild(parentNode, newNode) {
      parentNode.appendChild(newNode);
    },
    insertBefore(parentNode, newNode, referenceNode) {
      parentNode.insertBefore(newNode, referenceNode);
    },
    setTemplateContent(templateElement, contentElement) {
      templateElement.content = contentElement;
    },
    getTemplateContent(templateElement) {
      return templateElement.content;
    },
    setDocumentType(doc, name, publicId, systemId) {
      let doctypeNode = doc.childNodes.find(
        (n) => n.nodeType === 10
        /* NODE_TYPES.DOCUMENT_TYPE_NODE */
      );
      if (doctypeNode == null) {
        doctypeNode = ownerDocument.createDocumentTypeNode();
        doc.insertBefore(doctypeNode, doc.firstChild);
      }
      doctypeNode.nodeValue = "!DOCTYPE";
      doctypeNode["x-name"] = name;
      doctypeNode["x-publicId"] = publicId;
      doctypeNode["x-systemId"] = systemId;
    },
    setDocumentMode(doc, mode) {
      doc["x-mode"] = mode;
    },
    getDocumentMode(doc) {
      return doc["x-mode"];
    },
    detachNode(node) {
      node.remove();
    },
    insertText(parentNode, text) {
      const lastChild = parentNode.lastChild;
      if (lastChild != null && lastChild.nodeType === 3) {
        lastChild.nodeValue += text;
      } else {
        parentNode.appendChild(ownerDocument.createTextNode(text));
      }
    },
    insertTextBefore(parentNode, text, referenceNode) {
      const prevNode = parentNode.childNodes[parentNode.childNodes.indexOf(referenceNode) - 1];
      if (prevNode != null && prevNode.nodeType === 3) {
        prevNode.nodeValue += text;
      } else {
        parentNode.insertBefore(ownerDocument.createTextNode(text), referenceNode);
      }
    },
    adoptAttributes(recipient, attrs) {
      for (let i = 0; i < attrs.length; i++) {
        const attr = attrs[i];
        if (recipient.hasAttributeNS(attr.namespace, attr.name) === false) {
          recipient.setAttributeNS(attr.namespace, attr.name, attr.value);
        }
      }
    },
    getFirstChild(node) {
      return node.childNodes[0];
    },
    getChildNodes(node) {
      return node.childNodes;
    },
    getParentNode(node) {
      return node.parentNode;
    },
    getAttrList(element) {
      const attrs = element.attributes.__items.map((attr) => {
        return {
          name: attr.name,
          value: attr.value,
          namespace: attr.namespaceURI,
          prefix: null
        };
      });
      return attrs;
    },
    getTagName(element) {
      if (element.namespaceURI === "http://www.w3.org/1999/xhtml") {
        return element.nodeName.toLowerCase();
      } else {
        return element.nodeName;
      }
    },
    getNamespaceURI(element) {
      return element.namespaceURI;
    },
    getTextNodeContent(textNode) {
      return textNode.nodeValue;
    },
    getCommentNodeContent(commentNode) {
      return commentNode.nodeValue;
    },
    getDocumentTypeNodeName(doctypeNode) {
      return doctypeNode["x-name"];
    },
    getDocumentTypeNodePublicId(doctypeNode) {
      return doctypeNode["x-publicId"];
    },
    getDocumentTypeNodeSystemId(doctypeNode) {
      return doctypeNode["x-systemId"];
    },
    // @ts-ignore - a `MockNode` will never be assignable to a `TreeAdapterTypeMap['text']`. As a result, we cannot
    // complete this function signature
    isTextNode(node) {
      return node.nodeType === 3;
    },
    // @ts-ignore - a `MockNode` will never be assignable to a `TreeAdapterTypeMap['comment']`. As a result, we cannot
    // complete this function signature (which requires its return type to be a type predicate)
    isCommentNode(node) {
      return node.nodeType === 8;
    },
    // @ts-ignore - a `MockNode` will never be assignable to a `TreeAdapterTypeMap['document']`. As a result, we cannot
    // complete this function signature (which requires its return type to be a type predicate)
    isDocumentTypeNode(node) {
      return node.nodeType === 10;
    },
    // @ts-ignore - a `MockNode` will never be assignable to a `TreeAdapterTypeMap['element']`. As a result, we cannot
    // complete this function signature (which requires its return type to be a type predicate)
    isElementNode(node) {
      return node.nodeType === 1;
    }
  };
  parseOptions = {
    treeAdapter
  };
  docParser.set(ownerDocument, parseOptions);
  return parseOptions;
}
const Sizzle = function() {
  const window2 = {
    document: {
      createElement() {
        return {};
      },
      nodeType: 9,
      documentElement: {
        nodeType: 1,
        nodeName: "HTML"
      }
    }
  };
  const module2 = { exports: {} };
  /*! Sizzle v2.3.10 | (c) JS Foundation and other contributors | js.foundation */
  !function(e2) {
    var t, n, r, i, o, u, l, a, c, s, f, d, p, h, g, m, y, v, w, b = "sizzle" + 1 * /* @__PURE__ */ new Date(), N = e2.document, C = 0, x = 0, E = ae(), A = ae(), S = ae(), D = ae(), T = function(e3, t2) {
      return e3 === t2 && (f = true), 0;
    }, L = {}.hasOwnProperty, q = [], I = q.pop, B = q.push, R = q.push, $ = q.slice, k = function(e3, t2) {
      for (var n2 = 0, r2 = e3.length; n2 < r2; n2++)
        if (e3[n2] === t2)
          return n2;
      return -1;
    }, H = "checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped", M = "[\\x20\\t\\r\\n\\f]", P = "(?:\\\\[\\da-fA-F]{1,6}" + M + "?|\\\\[^\\r\\n\\f]|[\\w-]|[^\0-\\x7f])+", z = "\\[" + M + "*(" + P + ")(?:" + M + "*([*^$|!~]?=)" + M + `*(?:'((?:\\\\.|[^\\\\'])*)'|"((?:\\\\.|[^\\\\"])*)"|(` + P + "))|)" + M + "*\\]", F = ":(" + P + `)(?:\\((('((?:\\\\.|[^\\\\'])*)'|"((?:\\\\.|[^\\\\"])*)")|((?:\\\\.|[^\\\\()[\\]]|` + z + ")*)|.*)\\)|)", O = new RegExp(M + "+", "g"), j = new RegExp("^" + M + "+|((?:^|[^\\\\])(?:\\\\.)*)" + M + "+$", "g"), G = new RegExp("^" + M + "*," + M + "*"), U = new RegExp("^" + M + "*([>+~]|" + M + ")" + M + "*"), V = new RegExp(M + "|>"), X = new RegExp(F), J = new RegExp("^" + P + "$"), K = { ID: new RegExp("^#(" + P + ")"), CLASS: new RegExp("^\\.(" + P + ")"), TAG: new RegExp("^(" + P + "|[*])"), ATTR: new RegExp("^" + z), PSEUDO: new RegExp("^" + F), CHILD: new RegExp("^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\(" + M + "*(even|odd|(([+-]|)(\\d*)n|)" + M + "*(?:([+-]|)" + M + "*(\\d+)|))" + M + "*\\)|)", "i"), bool: new RegExp("^(?:" + H + ")$", "i"), needsContext: new RegExp("^" + M + "*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\(" + M + "*((?:-\\d)?\\d*)" + M + "*\\)|)(?=[^-]|$)", "i") }, Q = /HTML$/i, W = /^(?:input|select|textarea|button)$/i, Y = /^h\d$/i, Z = /^[^{]+\{\s*\[native \w/, _ = /^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/, ee = /[+~]/, te = new RegExp("\\\\[\\da-fA-F]{1,6}" + M + "?|\\\\([^\\r\\n\\f])", "g"), ne = function(e3, t2) {
      var n2 = "0x" + e3.slice(1) - 65536;
      return t2 || (n2 < 0 ? String.fromCharCode(n2 + 65536) : String.fromCharCode(n2 >> 10 | 55296, 1023 & n2 | 56320));
    }, re = /([\0-\x1f\x7f]|^-?\d)|^-$|[^\0-\x1f\x7f-\uFFFF\w-]/g, ie = function(e3, t2) {
      return t2 ? "\0" === e3 ? "\uFFFD" : e3.slice(0, -1) + "\\" + e3.charCodeAt(e3.length - 1).toString(16) + " " : "\\" + e3;
    }, oe = function() {
      d();
    }, ue = ve(function(e3) {
      return true === e3.disabled && "fieldset" === e3.nodeName.toLowerCase();
    }, { dir: "parentNode", next: "legend" });
    try {
      R.apply(q = $.call(N.childNodes), N.childNodes), q[N.childNodes.length].nodeType;
    } catch (e3) {
      R = { apply: q.length ? function(e4, t2) {
        B.apply(e4, $.call(t2));
      } : function(e4, t2) {
        var n2 = e4.length, r2 = 0;
        while (e4[n2++] = t2[r2++])
          ;
        e4.length = n2 - 1;
      } };
    }
    function le(e3, t2, r2, i2) {
      var o2, l2, c2, s2, f2, h2, y2, v2 = t2 && t2.ownerDocument, N2 = t2 ? t2.nodeType : 9;
      if (r2 = r2 || [], "string" != typeof e3 || !e3 || 1 !== N2 && 9 !== N2 && 11 !== N2)
        return r2;
      if (!i2 && (d(t2), t2 = t2 || p, g)) {
        if (11 !== N2 && (f2 = _.exec(e3)))
          if (o2 = f2[1]) {
            if (9 === N2) {
              if (!(c2 = t2.getElementById(o2)))
                return r2;
              if (c2.id === o2)
                return r2.push(c2), r2;
            } else if (v2 && (c2 = v2.getElementById(o2)) && w(t2, c2) && c2.id === o2)
              return r2.push(c2), r2;
          } else {
            if (f2[2])
              return R.apply(r2, t2.getElementsByTagName(e3)), r2;
            if ((o2 = f2[3]) && n.getElementsByClassName && t2.getElementsByClassName)
              return R.apply(r2, t2.getElementsByClassName(o2)), r2;
          }
        if (n.qsa && !D[e3 + " "] && (!m || !m.test(e3)) && (1 !== N2 || "object" !== t2.nodeName.toLowerCase())) {
          if (y2 = e3, v2 = t2, 1 === N2 && (V.test(e3) || U.test(e3))) {
            (v2 = ee.test(e3) && ge(t2.parentNode) || t2) === t2 && n.scope || ((s2 = t2.getAttribute("id")) ? s2 = s2.replace(re, ie) : t2.setAttribute("id", s2 = b)), l2 = (h2 = u(e3)).length;
            while (l2--)
              h2[l2] = (s2 ? "#" + s2 : ":scope") + " " + ye(h2[l2]);
            y2 = h2.join(",");
          }
          try {
            return R.apply(r2, v2.querySelectorAll(y2)), r2;
          } catch (t3) {
            D(e3, true);
          } finally {
            s2 === b && t2.removeAttribute("id");
          }
        }
      }
      return a(e3.replace(j, "$1"), t2, r2, i2);
    }
    function ae() {
      var e3 = [];
      function t2(n2, i2) {
        return e3.push(n2 + " ") > r.cacheLength && delete t2[e3.shift()], t2[n2 + " "] = i2;
      }
      return t2;
    }
    function ce(e3) {
      return e3[b] = true, e3;
    }
    function se(e3) {
      var t2 = p.createElement("fieldset");
      try {
        return !!e3(t2);
      } catch (e4) {
        return false;
      } finally {
        t2.parentNode && t2.parentNode.removeChild(t2), t2 = null;
      }
    }
    function fe(e3, t2) {
      var n2 = e3.split("|"), i2 = n2.length;
      while (i2--)
        r.attrHandle[n2[i2]] = t2;
    }
    function de(e3, t2) {
      var n2 = t2 && e3, r2 = n2 && 1 === e3.nodeType && 1 === t2.nodeType && e3.sourceIndex - t2.sourceIndex;
      if (r2)
        return r2;
      if (n2) {
        while (n2 = n2.nextSibling)
          if (n2 === t2)
            return -1;
      }
      return e3 ? 1 : -1;
    }
    function pe(e3) {
      return function(t2) {
        return "form" in t2 ? t2.parentNode && false === t2.disabled ? "label" in t2 ? "label" in t2.parentNode ? t2.parentNode.disabled === e3 : t2.disabled === e3 : t2.isDisabled === e3 || t2.isDisabled !== !e3 && ue(t2) === e3 : t2.disabled === e3 : "label" in t2 && t2.disabled === e3;
      };
    }
    function he(e3) {
      return ce(function(t2) {
        return t2 = +t2, ce(function(n2, r2) {
          var i2, o2 = e3([], n2.length, t2), u2 = o2.length;
          while (u2--)
            n2[i2 = o2[u2]] && (n2[i2] = !(r2[i2] = n2[i2]));
        });
      });
    }
    function ge(e3) {
      return e3 && void 0 !== e3.getElementsByTagName && e3;
    }
    n = le.support = {}, o = le.isXML = function(e3) {
      var t2 = e3 && e3.namespaceURI, n2 = e3 && (e3.ownerDocument || e3).documentElement;
      return !Q.test(t2 || n2 && n2.nodeName || "HTML");
    }, d = le.setDocument = function(e3) {
      var t2, i2, u2 = e3 ? e3.ownerDocument || e3 : N;
      return u2 != p && 9 === u2.nodeType && u2.documentElement ? (p = u2, h = p.documentElement, g = !o(p), N != p && (i2 = p.defaultView) && i2.top !== i2 && (i2.addEventListener ? i2.addEventListener("unload", oe, false) : i2.attachEvent && i2.attachEvent("onunload", oe)), n.scope = se(function(e4) {
        return h.appendChild(e4).appendChild(p.createElement("div")), void 0 !== e4.querySelectorAll && !e4.querySelectorAll(":scope fieldset div").length;
      }), n.cssHas = se(function() {
        try {
          return p.querySelector(":has(*,:jqfake)"), false;
        } catch (e4) {
          return true;
        }
      }), n.attributes = se(function(e4) {
        return e4.className = "i", !e4.getAttribute("className");
      }), n.getElementsByTagName = se(function(e4) {
        return e4.appendChild(p.createComment("")), !e4.getElementsByTagName("*").length;
      }), n.getElementsByClassName = Z.test(p.getElementsByClassName), n.getById = se(function(e4) {
        return h.appendChild(e4).id = b, !p.getElementsByName || !p.getElementsByName(b).length;
      }), n.getById ? (r.filter.ID = function(e4) {
        var t3 = e4.replace(te, ne);
        return function(e5) {
          return e5.getAttribute("id") === t3;
        };
      }, r.find.ID = function(e4, t3) {
        if (void 0 !== t3.getElementById && g) {
          var n2 = t3.getElementById(e4);
          return n2 ? [n2] : [];
        }
      }) : (r.filter.ID = function(e4) {
        var t3 = e4.replace(te, ne);
        return function(e5) {
          var n2 = void 0 !== e5.getAttributeNode && e5.getAttributeNode("id");
          return n2 && n2.value === t3;
        };
      }, r.find.ID = function(e4, t3) {
        if (void 0 !== t3.getElementById && g) {
          var n2, r2, i3, o2 = t3.getElementById(e4);
          if (o2) {
            if ((n2 = o2.getAttributeNode("id")) && n2.value === e4)
              return [o2];
            i3 = t3.getElementsByName(e4), r2 = 0;
            while (o2 = i3[r2++])
              if ((n2 = o2.getAttributeNode("id")) && n2.value === e4)
                return [o2];
          }
          return [];
        }
      }), r.find.TAG = n.getElementsByTagName ? function(e4, t3) {
        return void 0 !== t3.getElementsByTagName ? t3.getElementsByTagName(e4) : n.qsa ? t3.querySelectorAll(e4) : void 0;
      } : function(e4, t3) {
        var n2, r2 = [], i3 = 0, o2 = t3.getElementsByTagName(e4);
        if ("*" === e4) {
          while (n2 = o2[i3++])
            1 === n2.nodeType && r2.push(n2);
          return r2;
        }
        return o2;
      }, r.find.CLASS = n.getElementsByClassName && function(e4, t3) {
        if (void 0 !== t3.getElementsByClassName && g)
          return t3.getElementsByClassName(e4);
      }, y = [], m = [], (n.qsa = Z.test(p.querySelectorAll)) && (se(function(e4) {
        var t3;
        h.appendChild(e4).innerHTML = "<a id='" + b + "'></a><select id='" + b + "-\r\\' msallowcapture=''><option selected=''></option></select>", e4.querySelectorAll("[msallowcapture^='']").length && m.push("[*^$]=" + M + `*(?:''|"")`), e4.querySelectorAll("[selected]").length || m.push("\\[" + M + "*(?:value|" + H + ")"), e4.querySelectorAll("[id~=" + b + "-]").length || m.push("~="), (t3 = p.createElement("input")).setAttribute("name", ""), e4.appendChild(t3), e4.querySelectorAll("[name='']").length || m.push("\\[" + M + "*name" + M + "*=" + M + `*(?:''|"")`), e4.querySelectorAll(":checked").length || m.push(":checked"), e4.querySelectorAll("a#" + b + "+*").length || m.push(".#.+[+~]"), e4.querySelectorAll("\\\f"), m.push("[\\r\\n\\f]");
      }), se(function(e4) {
        e4.innerHTML = "<a href='' disabled='disabled'></a><select disabled='disabled'><option/></select>";
        var t3 = p.createElement("input");
        t3.setAttribute("type", "hidden"), e4.appendChild(t3).setAttribute("name", "D"), e4.querySelectorAll("[name=d]").length && m.push("name" + M + "*[*^$|!~]?="), 2 !== e4.querySelectorAll(":enabled").length && m.push(":enabled", ":disabled"), h.appendChild(e4).disabled = true, 2 !== e4.querySelectorAll(":disabled").length && m.push(":enabled", ":disabled"), e4.querySelectorAll("*,:x"), m.push(",.*:");
      })), (n.matchesSelector = Z.test(v = h.matches || h.webkitMatchesSelector || h.mozMatchesSelector || h.oMatchesSelector || h.msMatchesSelector)) && se(function(e4) {
        n.disconnectedMatch = v.call(e4, "*"), v.call(e4, "[s!='']:x"), y.push("!=", F);
      }), n.cssHas || m.push(":has"), m = m.length && new RegExp(m.join("|")), y = y.length && new RegExp(y.join("|")), t2 = Z.test(h.compareDocumentPosition), w = t2 || Z.test(h.contains) ? function(e4, t3) {
        var n2 = 9 === e4.nodeType && e4.documentElement || e4, r2 = t3 && t3.parentNode;
        return e4 === r2 || !(!r2 || 1 !== r2.nodeType || !(n2.contains ? n2.contains(r2) : e4.compareDocumentPosition && 16 & e4.compareDocumentPosition(r2)));
      } : function(e4, t3) {
        if (t3) {
          while (t3 = t3.parentNode)
            if (t3 === e4)
              return true;
        }
        return false;
      }, T = t2 ? function(e4, t3) {
        if (e4 === t3)
          return f = true, 0;
        var r2 = !e4.compareDocumentPosition - !t3.compareDocumentPosition;
        return r2 || (1 & (r2 = (e4.ownerDocument || e4) == (t3.ownerDocument || t3) ? e4.compareDocumentPosition(t3) : 1) || !n.sortDetached && t3.compareDocumentPosition(e4) === r2 ? e4 == p || e4.ownerDocument == N && w(N, e4) ? -1 : t3 == p || t3.ownerDocument == N && w(N, t3) ? 1 : s ? k(s, e4) - k(s, t3) : 0 : 4 & r2 ? -1 : 1);
      } : function(e4, t3) {
        if (e4 === t3)
          return f = true, 0;
        var n2, r2 = 0, i3 = e4.parentNode, o2 = t3.parentNode, u3 = [e4], l2 = [t3];
        if (!i3 || !o2)
          return e4 == p ? -1 : t3 == p ? 1 : i3 ? -1 : o2 ? 1 : s ? k(s, e4) - k(s, t3) : 0;
        if (i3 === o2)
          return de(e4, t3);
        n2 = e4;
        while (n2 = n2.parentNode)
          u3.unshift(n2);
        n2 = t3;
        while (n2 = n2.parentNode)
          l2.unshift(n2);
        while (u3[r2] === l2[r2])
          r2++;
        return r2 ? de(u3[r2], l2[r2]) : u3[r2] == N ? -1 : l2[r2] == N ? 1 : 0;
      }, p) : p;
    }, le.matches = function(e3, t2) {
      return le(e3, null, null, t2);
    }, le.matchesSelector = function(e3, t2) {
      if (d(e3), n.matchesSelector && g && !D[t2 + " "] && (!y || !y.test(t2)) && (!m || !m.test(t2)))
        try {
          var r2 = v.call(e3, t2);
          if (r2 || n.disconnectedMatch || e3.document && 11 !== e3.document.nodeType)
            return r2;
        } catch (e4) {
          D(t2, true);
        }
      return le(t2, p, null, [e3]).length > 0;
    }, le.contains = function(e3, t2) {
      return (e3.ownerDocument || e3) != p && d(e3), w(e3, t2);
    }, le.attr = function(e3, t2) {
      (e3.ownerDocument || e3) != p && d(e3);
      var i2 = r.attrHandle[t2.toLowerCase()], o2 = i2 && L.call(r.attrHandle, t2.toLowerCase()) ? i2(e3, t2, !g) : void 0;
      return void 0 !== o2 ? o2 : n.attributes || !g ? e3.getAttribute(t2) : (o2 = e3.getAttributeNode(t2)) && o2.specified ? o2.value : null;
    }, le.escape = function(e3) {
      return (e3 + "").replace(re, ie);
    }, le.error = function(e3) {
      throw new Error("Syntax error, unrecognized expression: " + e3);
    }, le.uniqueSort = function(e3) {
      var t2, r2 = [], i2 = 0, o2 = 0;
      if (f = !n.detectDuplicates, s = !n.sortStable && e3.slice(0), e3.sort(T), f) {
        while (t2 = e3[o2++])
          t2 === e3[o2] && (i2 = r2.push(o2));
        while (i2--)
          e3.splice(r2[i2], 1);
      }
      return s = null, e3;
    }, i = le.getText = function(e3) {
      var t2, n2 = "", r2 = 0, o2 = e3.nodeType;
      if (o2) {
        if (1 === o2 || 9 === o2 || 11 === o2) {
          if ("string" == typeof e3.textContent)
            return e3.textContent;
          for (e3 = e3.firstChild; e3; e3 = e3.nextSibling)
            n2 += i(e3);
        } else if (3 === o2 || 4 === o2)
          return e3.nodeValue;
      } else
        while (t2 = e3[r2++])
          n2 += i(t2);
      return n2;
    }, (r = le.selectors = { cacheLength: 50, createPseudo: ce, match: K, attrHandle: {}, find: {}, relative: { ">": { dir: "parentNode", first: true }, " ": { dir: "parentNode" }, "+": { dir: "previousSibling", first: true }, "~": { dir: "previousSibling" } }, preFilter: { ATTR: function(e3) {
      return e3[1] = e3[1].replace(te, ne), e3[3] = (e3[3] || e3[4] || e3[5] || "").replace(te, ne), "~=" === e3[2] && (e3[3] = " " + e3[3] + " "), e3.slice(0, 4);
    }, CHILD: function(e3) {
      return e3[1] = e3[1].toLowerCase(), "nth" === e3[1].slice(0, 3) ? (e3[3] || le.error(e3[0]), e3[4] = +(e3[4] ? e3[5] + (e3[6] || 1) : 2 * ("even" === e3[3] || "odd" === e3[3])), e3[5] = +(e3[7] + e3[8] || "odd" === e3[3])) : e3[3] && le.error(e3[0]), e3;
    }, PSEUDO: function(e3) {
      var t2, n2 = !e3[6] && e3[2];
      return K.CHILD.test(e3[0]) ? null : (e3[3] ? e3[2] = e3[4] || e3[5] || "" : n2 && X.test(n2) && (t2 = u(n2, true)) && (t2 = n2.indexOf(")", n2.length - t2) - n2.length) && (e3[0] = e3[0].slice(0, t2), e3[2] = n2.slice(0, t2)), e3.slice(0, 3));
    } }, filter: { TAG: function(e3) {
      var t2 = e3.replace(te, ne).toLowerCase();
      return "*" === e3 ? function() {
        return true;
      } : function(e4) {
        return e4.nodeName && e4.nodeName.toLowerCase() === t2;
      };
    }, CLASS: function(e3) {
      var t2 = E[e3 + " "];
      return t2 || (t2 = new RegExp("(^|" + M + ")" + e3 + "(" + M + "|$)")) && E(e3, function(e4) {
        return t2.test("string" == typeof e4.className && e4.className || void 0 !== e4.getAttribute && e4.getAttribute("class") || "");
      });
    }, ATTR: function(e3, t2, n2) {
      return function(r2) {
        var i2 = le.attr(r2, e3);
        return null == i2 ? "!=" === t2 : !t2 || (i2 += "", "=" === t2 ? i2 === n2 : "!=" === t2 ? i2 !== n2 : "^=" === t2 ? n2 && 0 === i2.indexOf(n2) : "*=" === t2 ? n2 && i2.indexOf(n2) > -1 : "$=" === t2 ? n2 && i2.slice(-n2.length) === n2 : "~=" === t2 ? (" " + i2.replace(O, " ") + " ").indexOf(n2) > -1 : "|=" === t2 && (i2 === n2 || i2.slice(0, n2.length + 1) === n2 + "-"));
      };
    }, CHILD: function(e3, t2, n2, r2, i2) {
      var o2 = "nth" !== e3.slice(0, 3), u2 = "last" !== e3.slice(-4), l2 = "of-type" === t2;
      return 1 === r2 && 0 === i2 ? function(e4) {
        return !!e4.parentNode;
      } : function(t3, n3, a2) {
        var c2, s2, f2, d2, p2, h2, g2 = o2 !== u2 ? "nextSibling" : "previousSibling", m2 = t3.parentNode, y2 = l2 && t3.nodeName.toLowerCase(), v2 = !a2 && !l2, w2 = false;
        if (m2) {
          if (o2) {
            while (g2) {
              d2 = t3;
              while (d2 = d2[g2])
                if (l2 ? d2.nodeName.toLowerCase() === y2 : 1 === d2.nodeType)
                  return false;
              h2 = g2 = "only" === e3 && !h2 && "nextSibling";
            }
            return true;
          }
          if (h2 = [u2 ? m2.firstChild : m2.lastChild], u2 && v2) {
            w2 = (p2 = (c2 = (s2 = (f2 = (d2 = m2)[b] || (d2[b] = {}))[d2.uniqueID] || (f2[d2.uniqueID] = {}))[e3] || [])[0] === C && c2[1]) && c2[2], d2 = p2 && m2.childNodes[p2];
            while (d2 = ++p2 && d2 && d2[g2] || (w2 = p2 = 0) || h2.pop())
              if (1 === d2.nodeType && ++w2 && d2 === t3) {
                s2[e3] = [C, p2, w2];
                break;
              }
          } else if (v2 && (w2 = p2 = (c2 = (s2 = (f2 = (d2 = t3)[b] || (d2[b] = {}))[d2.uniqueID] || (f2[d2.uniqueID] = {}))[e3] || [])[0] === C && c2[1]), false === w2) {
            while (d2 = ++p2 && d2 && d2[g2] || (w2 = p2 = 0) || h2.pop())
              if ((l2 ? d2.nodeName.toLowerCase() === y2 : 1 === d2.nodeType) && ++w2 && (v2 && ((s2 = (f2 = d2[b] || (d2[b] = {}))[d2.uniqueID] || (f2[d2.uniqueID] = {}))[e3] = [C, w2]), d2 === t3))
                break;
          }
          return (w2 -= i2) === r2 || w2 % r2 == 0 && w2 / r2 >= 0;
        }
      };
    }, PSEUDO: function(e3, t2) {
      var n2, i2 = r.pseudos[e3] || r.setFilters[e3.toLowerCase()] || le.error("unsupported pseudo: " + e3);
      return i2[b] ? i2(t2) : i2.length > 1 ? (n2 = [e3, e3, "", t2], r.setFilters.hasOwnProperty(e3.toLowerCase()) ? ce(function(e4, n3) {
        var r2, o2 = i2(e4, t2), u2 = o2.length;
        while (u2--)
          e4[r2 = k(e4, o2[u2])] = !(n3[r2] = o2[u2]);
      }) : function(e4) {
        return i2(e4, 0, n2);
      }) : i2;
    } }, pseudos: { not: ce(function(e3) {
      var t2 = [], n2 = [], r2 = l(e3.replace(j, "$1"));
      return r2[b] ? ce(function(e4, t3, n3, i2) {
        var o2, u2 = r2(e4, null, i2, []), l2 = e4.length;
        while (l2--)
          (o2 = u2[l2]) && (e4[l2] = !(t3[l2] = o2));
      }) : function(e4, i2, o2) {
        return t2[0] = e4, r2(t2, null, o2, n2), t2[0] = null, !n2.pop();
      };
    }), has: ce(function(e3) {
      return function(t2) {
        return le(e3, t2).length > 0;
      };
    }), contains: ce(function(e3) {
      return e3 = e3.replace(te, ne), function(t2) {
        return (t2.textContent || i(t2)).indexOf(e3) > -1;
      };
    }), lang: ce(function(e3) {
      return J.test(e3 || "") || le.error("unsupported lang: " + e3), e3 = e3.replace(te, ne).toLowerCase(), function(t2) {
        var n2;
        do {
          if (n2 = g ? t2.lang : t2.getAttribute("xml:lang") || t2.getAttribute("lang"))
            return (n2 = n2.toLowerCase()) === e3 || 0 === n2.indexOf(e3 + "-");
        } while ((t2 = t2.parentNode) && 1 === t2.nodeType);
        return false;
      };
    }), target: function(t2) {
      var n2 = e2.location && e2.location.hash;
      return n2 && n2.slice(1) === t2.id;
    }, root: function(e3) {
      return e3 === h;
    }, focus: function(e3) {
      return e3 === p.activeElement && (!p.hasFocus || p.hasFocus()) && !!(e3.type || e3.href || ~e3.tabIndex);
    }, enabled: pe(false), disabled: pe(true), checked: function(e3) {
      var t2 = e3.nodeName.toLowerCase();
      return "input" === t2 && !!e3.checked || "option" === t2 && !!e3.selected;
    }, selected: function(e3) {
      return e3.parentNode && e3.parentNode.selectedIndex, true === e3.selected;
    }, empty: function(e3) {
      for (e3 = e3.firstChild; e3; e3 = e3.nextSibling)
        if (e3.nodeType < 6)
          return false;
      return true;
    }, parent: function(e3) {
      return !r.pseudos.empty(e3);
    }, header: function(e3) {
      return Y.test(e3.nodeName);
    }, input: function(e3) {
      return W.test(e3.nodeName);
    }, button: function(e3) {
      var t2 = e3.nodeName.toLowerCase();
      return "input" === t2 && "button" === e3.type || "button" === t2;
    }, text: function(e3) {
      var t2;
      return "input" === e3.nodeName.toLowerCase() && "text" === e3.type && (null == (t2 = e3.getAttribute("type")) || "text" === t2.toLowerCase());
    }, first: he(function() {
      return [0];
    }), last: he(function(e3, t2) {
      return [t2 - 1];
    }), eq: he(function(e3, t2, n2) {
      return [n2 < 0 ? n2 + t2 : n2];
    }), even: he(function(e3, t2) {
      for (var n2 = 0; n2 < t2; n2 += 2)
        e3.push(n2);
      return e3;
    }), odd: he(function(e3, t2) {
      for (var n2 = 1; n2 < t2; n2 += 2)
        e3.push(n2);
      return e3;
    }), lt: he(function(e3, t2, n2) {
      for (var r2 = n2 < 0 ? n2 + t2 : n2 > t2 ? t2 : n2; --r2 >= 0; )
        e3.push(r2);
      return e3;
    }), gt: he(function(e3, t2, n2) {
      for (var r2 = n2 < 0 ? n2 + t2 : n2; ++r2 < t2; )
        e3.push(r2);
      return e3;
    }) } }).pseudos.nth = r.pseudos.eq;
    for (t in { radio: true, checkbox: true, file: true, password: true, image: true })
      r.pseudos[t] = /* @__PURE__ */ function(e3) {
        return function(t2) {
          return "input" === t2.nodeName.toLowerCase() && t2.type === e3;
        };
      }(t);
    for (t in { submit: true, reset: true })
      r.pseudos[t] = /* @__PURE__ */ function(e3) {
        return function(t2) {
          var n2 = t2.nodeName.toLowerCase();
          return ("input" === n2 || "button" === n2) && t2.type === e3;
        };
      }(t);
    function me() {
    }
    me.prototype = r.filters = r.pseudos, r.setFilters = new me(), u = le.tokenize = function(e3, t2) {
      var n2, i2, o2, u2, l2, a2, c2, s2 = A[e3 + " "];
      if (s2)
        return t2 ? 0 : s2.slice(0);
      l2 = e3, a2 = [], c2 = r.preFilter;
      while (l2) {
        n2 && !(i2 = G.exec(l2)) || (i2 && (l2 = l2.slice(i2[0].length) || l2), a2.push(o2 = [])), n2 = false, (i2 = U.exec(l2)) && (n2 = i2.shift(), o2.push({ value: n2, type: i2[0].replace(j, " ") }), l2 = l2.slice(n2.length));
        for (u2 in r.filter)
          !(i2 = K[u2].exec(l2)) || c2[u2] && !(i2 = c2[u2](i2)) || (n2 = i2.shift(), o2.push({ value: n2, type: u2, matches: i2 }), l2 = l2.slice(n2.length));
        if (!n2)
          break;
      }
      return t2 ? l2.length : l2 ? le.error(e3) : A(e3, a2).slice(0);
    };
    function ye(e3) {
      for (var t2 = 0, n2 = e3.length, r2 = ""; t2 < n2; t2++)
        r2 += e3[t2].value;
      return r2;
    }
    function ve(e3, t2, n2) {
      var r2 = t2.dir, i2 = t2.next, o2 = i2 || r2, u2 = n2 && "parentNode" === o2, l2 = x++;
      return t2.first ? function(t3, n3, i3) {
        while (t3 = t3[r2])
          if (1 === t3.nodeType || u2)
            return e3(t3, n3, i3);
        return false;
      } : function(t3, n3, a2) {
        var c2, s2, f2, d2 = [C, l2];
        if (a2) {
          while (t3 = t3[r2])
            if ((1 === t3.nodeType || u2) && e3(t3, n3, a2))
              return true;
        } else
          while (t3 = t3[r2])
            if (1 === t3.nodeType || u2)
              if (f2 = t3[b] || (t3[b] = {}), s2 = f2[t3.uniqueID] || (f2[t3.uniqueID] = {}), i2 && i2 === t3.nodeName.toLowerCase())
                t3 = t3[r2] || t3;
              else {
                if ((c2 = s2[o2]) && c2[0] === C && c2[1] === l2)
                  return d2[2] = c2[2];
                if (s2[o2] = d2, d2[2] = e3(t3, n3, a2))
                  return true;
              }
        return false;
      };
    }
    function we(e3) {
      return e3.length > 1 ? function(t2, n2, r2) {
        var i2 = e3.length;
        while (i2--)
          if (!e3[i2](t2, n2, r2))
            return false;
        return true;
      } : e3[0];
    }
    function be(e3, t2, n2) {
      for (var r2 = 0, i2 = t2.length; r2 < i2; r2++)
        le(e3, t2[r2], n2);
      return n2;
    }
    function Ne(e3, t2, n2, r2, i2) {
      for (var o2, u2 = [], l2 = 0, a2 = e3.length, c2 = null != t2; l2 < a2; l2++)
        (o2 = e3[l2]) && (n2 && !n2(o2, r2, i2) || (u2.push(o2), c2 && t2.push(l2)));
      return u2;
    }
    function Ce(e3, t2, n2, r2, i2, o2) {
      return r2 && !r2[b] && (r2 = Ce(r2)), i2 && !i2[b] && (i2 = Ce(i2, o2)), ce(function(o3, u2, l2, a2) {
        var c2, s2, f2, d2 = [], p2 = [], h2 = u2.length, g2 = o3 || be(t2 || "*", l2.nodeType ? [l2] : l2, []), m2 = !e3 || !o3 && t2 ? g2 : Ne(g2, d2, e3, l2, a2), y2 = n2 ? i2 || (o3 ? e3 : h2 || r2) ? [] : u2 : m2;
        if (n2 && n2(m2, y2, l2, a2), r2) {
          c2 = Ne(y2, p2), r2(c2, [], l2, a2), s2 = c2.length;
          while (s2--)
            (f2 = c2[s2]) && (y2[p2[s2]] = !(m2[p2[s2]] = f2));
        }
        if (o3) {
          if (i2 || e3) {
            if (i2) {
              c2 = [], s2 = y2.length;
              while (s2--)
                (f2 = y2[s2]) && c2.push(m2[s2] = f2);
              i2(null, y2 = [], c2, a2);
            }
            s2 = y2.length;
            while (s2--)
              (f2 = y2[s2]) && (c2 = i2 ? k(o3, f2) : d2[s2]) > -1 && (o3[c2] = !(u2[c2] = f2));
          }
        } else
          y2 = Ne(y2 === u2 ? y2.splice(h2, y2.length) : y2), i2 ? i2(null, u2, y2, a2) : R.apply(u2, y2);
      });
    }
    function xe(e3) {
      for (var t2, n2, i2, o2 = e3.length, u2 = r.relative[e3[0].type], l2 = u2 || r.relative[" "], a2 = u2 ? 1 : 0, s2 = ve(function(e4) {
        return e4 === t2;
      }, l2, true), f2 = ve(function(e4) {
        return k(t2, e4) > -1;
      }, l2, true), d2 = [function(e4, n3, r2) {
        var i3 = !u2 && (r2 || n3 !== c) || ((t2 = n3).nodeType ? s2(e4, n3, r2) : f2(e4, n3, r2));
        return t2 = null, i3;
      }]; a2 < o2; a2++)
        if (n2 = r.relative[e3[a2].type])
          d2 = [ve(we(d2), n2)];
        else {
          if ((n2 = r.filter[e3[a2].type].apply(null, e3[a2].matches))[b]) {
            for (i2 = ++a2; i2 < o2; i2++)
              if (r.relative[e3[i2].type])
                break;
            return Ce(a2 > 1 && we(d2), a2 > 1 && ye(e3.slice(0, a2 - 1).concat({ value: " " === e3[a2 - 2].type ? "*" : "" })).replace(j, "$1"), n2, a2 < i2 && xe(e3.slice(a2, i2)), i2 < o2 && xe(e3 = e3.slice(i2)), i2 < o2 && ye(e3));
          }
          d2.push(n2);
        }
      return we(d2);
    }
    function Ee(e3, t2) {
      var n2 = t2.length > 0, i2 = e3.length > 0, o2 = function(o3, u2, l2, a2, s2) {
        var f2, h2, m2, y2 = 0, v2 = "0", w2 = o3 && [], b2 = [], N2 = c, x2 = o3 || i2 && r.find.TAG("*", s2), E2 = C += null == N2 ? 1 : Math.random() || 0.1, A2 = x2.length;
        for (s2 && (c = u2 == p || u2 || s2); v2 !== A2 && null != (f2 = x2[v2]); v2++) {
          if (i2 && f2) {
            h2 = 0, u2 || f2.ownerDocument == p || (d(f2), l2 = !g);
            while (m2 = e3[h2++])
              if (m2(f2, u2 || p, l2)) {
                a2.push(f2);
                break;
              }
            s2 && (C = E2);
          }
          n2 && ((f2 = !m2 && f2) && y2--, o3 && w2.push(f2));
        }
        if (y2 += v2, n2 && v2 !== y2) {
          h2 = 0;
          while (m2 = t2[h2++])
            m2(w2, b2, u2, l2);
          if (o3) {
            if (y2 > 0)
              while (v2--)
                w2[v2] || b2[v2] || (b2[v2] = I.call(a2));
            b2 = Ne(b2);
          }
          R.apply(a2, b2), s2 && !o3 && b2.length > 0 && y2 + t2.length > 1 && le.uniqueSort(a2);
        }
        return s2 && (C = E2, c = N2), w2;
      };
      return n2 ? ce(o2) : o2;
    }
    l = le.compile = function(e3, t2) {
      var n2, r2 = [], i2 = [], o2 = S[e3 + " "];
      if (!o2) {
        t2 || (t2 = u(e3)), n2 = t2.length;
        while (n2--)
          (o2 = xe(t2[n2]))[b] ? r2.push(o2) : i2.push(o2);
        (o2 = S(e3, Ee(i2, r2))).selector = e3;
      }
      return o2;
    }, a = le.select = function(e3, t2, n2, i2) {
      var o2, a2, c2, s2, f2, d2 = "function" == typeof e3 && e3, p2 = !i2 && u(e3 = d2.selector || e3);
      if (n2 = n2 || [], 1 === p2.length) {
        if ((a2 = p2[0] = p2[0].slice(0)).length > 2 && "ID" === (c2 = a2[0]).type && 9 === t2.nodeType && g && r.relative[a2[1].type]) {
          if (!(t2 = (r.find.ID(c2.matches[0].replace(te, ne), t2) || [])[0]))
            return n2;
          d2 && (t2 = t2.parentNode), e3 = e3.slice(a2.shift().value.length);
        }
        o2 = K.needsContext.test(e3) ? 0 : a2.length;
        while (o2--) {
          if (c2 = a2[o2], r.relative[s2 = c2.type])
            break;
          if ((f2 = r.find[s2]) && (i2 = f2(c2.matches[0].replace(te, ne), ee.test(a2[0].type) && ge(t2.parentNode) || t2))) {
            if (a2.splice(o2, 1), !(e3 = i2.length && ye(a2)))
              return R.apply(n2, i2), n2;
            break;
          }
        }
      }
      return (d2 || l(e3, p2))(i2, t2, !g, n2, !t2 || ee.test(e3) && ge(t2.parentNode) || t2), n2;
    }, n.sortStable = b.split("").sort(T).join("") === b, n.detectDuplicates = !!f, d(), n.sortDetached = se(function(e3) {
      return 1 & e3.compareDocumentPosition(p.createElement("fieldset"));
    }), se(function(e3) {
      return e3.innerHTML = "<a href='#'></a>", "#" === e3.firstChild.getAttribute("href");
    }) || fe("type|href|height|width", function(e3, t2, n2) {
      if (!n2)
        return e3.getAttribute(t2, "type" === t2.toLowerCase() ? 1 : 2);
    }), n.attributes && se(function(e3) {
      return e3.innerHTML = "<input/>", e3.firstChild.setAttribute("value", ""), "" === e3.firstChild.getAttribute("value");
    }) || fe("value", function(e3, t2, n2) {
      if (!n2 && "input" === e3.nodeName.toLowerCase())
        return e3.defaultValue;
    }), se(function(e3) {
      return null == e3.getAttribute("disabled");
    }) || fe(H, function(e3, t2, n2) {
      var r2;
      if (!n2)
        return true === e3[t2] ? t2.toLowerCase() : (r2 = e3.getAttributeNode(t2)) && r2.specified ? r2.value : null;
    });
    var Ae = e2.Sizzle;
    le.noConflict = function() {
      return e2.Sizzle === le && (e2.Sizzle = Ae), le;
    }, "function" == typeof define && define.amd ? define(function() {
      return le;
    }) : "undefined" != typeof module2 && module2.exports ? module2.exports = le : e2.Sizzle = le;
  }(window2);
  return module2.exports;
}();
function matches(selector, elm) {
  const r = Sizzle.matches(selector, [elm]);
  return r.length > 0;
}
function selectOne(selector, elm) {
  const r = Sizzle(selector, elm);
  return r[0] || null;
}
function selectAll(selector, elm) {
  return Sizzle(selector, elm);
}
function serializeNodeToHtml(elm, opts = {}) {
  const output = {
    currentLineWidth: 0,
    indent: 0,
    isWithinBody: false,
    text: []
  };
  if (opts.prettyHtml) {
    if (typeof opts.indentSpaces !== "number") {
      opts.indentSpaces = 2;
    }
    if (typeof opts.newLines !== "boolean") {
      opts.newLines = true;
    }
    opts.approximateLineWidth = -1;
  } else {
    opts.prettyHtml = false;
    if (typeof opts.newLines !== "boolean") {
      opts.newLines = false;
    }
    if (typeof opts.indentSpaces !== "number") {
      opts.indentSpaces = 0;
    }
  }
  if (typeof opts.approximateLineWidth !== "number") {
    opts.approximateLineWidth = -1;
  }
  if (typeof opts.removeEmptyAttributes !== "boolean") {
    opts.removeEmptyAttributes = true;
  }
  if (typeof opts.removeAttributeQuotes !== "boolean") {
    opts.removeAttributeQuotes = false;
  }
  if (typeof opts.removeBooleanAttributeQuotes !== "boolean") {
    opts.removeBooleanAttributeQuotes = false;
  }
  if (typeof opts.removeHtmlComments !== "boolean") {
    opts.removeHtmlComments = false;
  }
  if (typeof opts.serializeShadowRoot !== "boolean") {
    opts.serializeShadowRoot = false;
  }
  if (opts.outerHtml) {
    serializeToHtml(elm, opts, output, false);
  } else {
    for (let i = 0, ii = elm.childNodes.length; i < ii; i++) {
      serializeToHtml(elm.childNodes[i], opts, output, false);
    }
  }
  if (output.text[0] === "\n") {
    output.text.shift();
  }
  if (output.text[output.text.length - 1] === "\n") {
    output.text.pop();
  }
  return output.text.join("");
}
function serializeToHtml(node, opts, output, isShadowRoot) {
  if (node.nodeType === 1 || isShadowRoot) {
    const tagName = isShadowRoot ? "mock:shadow-root" : getTagName(node);
    if (tagName === "body") {
      output.isWithinBody = true;
    }
    const ignoreTag = opts.excludeTags != null && opts.excludeTags.includes(tagName);
    if (ignoreTag === false) {
      const isWithinWhitespaceSensitiveNode = opts.newLines || opts.indentSpaces > 0 ? isWithinWhitespaceSensitive(node) : false;
      if (opts.newLines && !isWithinWhitespaceSensitiveNode) {
        output.text.push("\n");
        output.currentLineWidth = 0;
      }
      if (opts.indentSpaces > 0 && !isWithinWhitespaceSensitiveNode) {
        for (let i = 0; i < output.indent; i++) {
          output.text.push(" ");
        }
        output.currentLineWidth += output.indent;
      }
      output.text.push("<" + tagName);
      output.currentLineWidth += tagName.length + 1;
      const attrsLength = node.attributes.length;
      const attributes = opts.prettyHtml && attrsLength > 1 ? cloneAttributes(node.attributes, true) : node.attributes;
      for (let i = 0; i < attrsLength; i++) {
        const attr = attributes.item(i);
        const attrName = attr.name;
        if (attrName === "style") {
          continue;
        }
        let attrValue = attr.value;
        if (opts.removeEmptyAttributes && attrValue === "" && REMOVE_EMPTY_ATTR.has(attrName)) {
          continue;
        }
        const attrNamespaceURI = attr.namespaceURI;
        if (attrNamespaceURI == null) {
          output.currentLineWidth += attrName.length + 1;
          if (opts.approximateLineWidth > 0 && output.currentLineWidth > opts.approximateLineWidth) {
            output.text.push("\n" + attrName);
            output.currentLineWidth = 0;
          } else {
            output.text.push(" " + attrName);
          }
        } else if (attrNamespaceURI === "http://www.w3.org/XML/1998/namespace") {
          output.text.push(" xml:" + attrName);
          output.currentLineWidth += attrName.length + 5;
        } else if (attrNamespaceURI === "http://www.w3.org/2000/xmlns/") {
          if (attrName !== "xmlns") {
            output.text.push(" xmlns:" + attrName);
            output.currentLineWidth += attrName.length + 7;
          } else {
            output.text.push(" " + attrName);
            output.currentLineWidth += attrName.length + 1;
          }
        } else if (attrNamespaceURI === XLINK_NS) {
          output.text.push(" xlink:" + attrName);
          output.currentLineWidth += attrName.length + 7;
        } else {
          output.text.push(" " + attrNamespaceURI + ":" + attrName);
          output.currentLineWidth += attrNamespaceURI.length + attrName.length + 2;
        }
        if (opts.prettyHtml && attrName === "class") {
          attrValue = attr.value = attrValue.split(" ").filter((t) => t !== "").sort().join(" ").trim();
        }
        if (attrValue === "") {
          if (opts.removeBooleanAttributeQuotes && BOOLEAN_ATTR.has(attrName)) {
            continue;
          }
          if (opts.removeEmptyAttributes && attrName.startsWith("data-")) {
            continue;
          }
        }
        if (opts.removeAttributeQuotes && CAN_REMOVE_ATTR_QUOTES.test(attrValue)) {
          output.text.push("=" + escapeString(attrValue, true));
          output.currentLineWidth += attrValue.length + 1;
        } else {
          output.text.push('="' + escapeString(attrValue, true) + '"');
          output.currentLineWidth += attrValue.length + 3;
        }
      }
      if (node.hasAttribute("style")) {
        const cssText = node.style.cssText;
        if (opts.approximateLineWidth > 0 && output.currentLineWidth + cssText.length + 10 > opts.approximateLineWidth) {
          output.text.push(`
style="${cssText}">`);
          output.currentLineWidth = 0;
        } else {
          output.text.push(` style="${cssText}">`);
          output.currentLineWidth += cssText.length + 10;
        }
      } else {
        output.text.push(">");
        output.currentLineWidth += 1;
      }
    }
    if (EMPTY_ELEMENTS.has(tagName) === false) {
      if (opts.serializeShadowRoot && node.shadowRoot != null) {
        output.indent = output.indent + opts.indentSpaces;
        serializeToHtml(node.shadowRoot, opts, output, true);
        output.indent = output.indent - opts.indentSpaces;
        if (opts.newLines && (node.childNodes.length === 0 || node.childNodes.length === 1 && node.childNodes[0].nodeType === 3 && node.childNodes[0].nodeValue.trim() === "")) {
          output.text.push("\n");
          output.currentLineWidth = 0;
          for (let i = 0; i < output.indent; i++) {
            output.text.push(" ");
          }
          output.currentLineWidth += output.indent;
        }
      }
      if (opts.excludeTagContent == null || opts.excludeTagContent.includes(tagName) === false) {
        const childNodes = tagName === "template" ? node.content.childNodes : node.childNodes;
        const childNodeLength = childNodes.length;
        if (childNodeLength > 0) {
          if (childNodeLength === 1 && childNodes[0].nodeType === 3 && (typeof childNodes[0].nodeValue !== "string" || childNodes[0].nodeValue.trim() === ""))
            ;
          else {
            const isWithinWhitespaceSensitiveNode = opts.newLines || opts.indentSpaces > 0 ? isWithinWhitespaceSensitive(node) : false;
            if (!isWithinWhitespaceSensitiveNode && opts.indentSpaces > 0 && ignoreTag === false) {
              output.indent = output.indent + opts.indentSpaces;
            }
            for (let i = 0; i < childNodeLength; i++) {
              serializeToHtml(childNodes[i], opts, output, false);
            }
            if (ignoreTag === false) {
              if (opts.newLines && !isWithinWhitespaceSensitiveNode) {
                output.text.push("\n");
                output.currentLineWidth = 0;
              }
              if (opts.indentSpaces > 0 && !isWithinWhitespaceSensitiveNode) {
                output.indent = output.indent - opts.indentSpaces;
                for (let i = 0; i < output.indent; i++) {
                  output.text.push(" ");
                }
                output.currentLineWidth += output.indent;
              }
            }
          }
        }
        if (ignoreTag === false) {
          output.text.push("</" + tagName + ">");
          output.currentLineWidth += tagName.length + 3;
        }
      }
    }
    if (opts.approximateLineWidth > 0 && STRUCTURE_ELEMENTS.has(tagName)) {
      output.text.push("\n");
      output.currentLineWidth = 0;
    }
    if (tagName === "body") {
      output.isWithinBody = false;
    }
  } else if (node.nodeType === 3) {
    let textContent = node.nodeValue;
    if (typeof textContent === "string") {
      const trimmedTextContent = textContent.trim();
      if (trimmedTextContent === "") {
        if (isWithinWhitespaceSensitive(node)) {
          output.text.push(textContent);
          output.currentLineWidth += textContent.length;
        } else if (opts.approximateLineWidth > 0 && !output.isWithinBody)
          ;
        else if (!opts.prettyHtml) {
          output.currentLineWidth += 1;
          if (opts.approximateLineWidth > 0 && output.currentLineWidth > opts.approximateLineWidth) {
            output.text.push("\n");
            output.currentLineWidth = 0;
          } else {
            output.text.push(" ");
          }
        }
      } else {
        const isWithinWhitespaceSensitiveNode = opts.newLines || opts.indentSpaces > 0 || opts.prettyHtml ? isWithinWhitespaceSensitive(node) : false;
        if (opts.newLines && !isWithinWhitespaceSensitiveNode) {
          output.text.push("\n");
          output.currentLineWidth = 0;
        }
        if (opts.indentSpaces > 0 && !isWithinWhitespaceSensitiveNode) {
          for (let i = 0; i < output.indent; i++) {
            output.text.push(" ");
          }
          output.currentLineWidth += output.indent;
        }
        let textContentLength = textContent.length;
        if (textContentLength > 0) {
          const parentTagName = node.parentNode != null && node.parentNode.nodeType === 1 ? node.parentNode.nodeName : null;
          if (NON_ESCAPABLE_CONTENT.has(parentTagName)) {
            if (isWithinWhitespaceSensitive(node)) {
              output.text.push(textContent);
            } else {
              output.text.push(trimmedTextContent);
              textContentLength = trimmedTextContent.length;
            }
            output.currentLineWidth += textContentLength;
          } else {
            if (opts.prettyHtml && !isWithinWhitespaceSensitiveNode) {
              output.text.push(escapeString(textContent.replace(/\s\s+/g, " ").trim(), false));
              output.currentLineWidth += textContentLength;
            } else {
              if (isWithinWhitespaceSensitive(node)) {
                output.currentLineWidth += textContentLength;
              } else {
                if (/\s/.test(textContent.charAt(0))) {
                  textContent = " " + textContent.trimLeft();
                }
                textContentLength = textContent.length;
                if (textContentLength > 1) {
                  if (/\s/.test(textContent.charAt(textContentLength - 1))) {
                    if (opts.approximateLineWidth > 0 && output.currentLineWidth + textContentLength > opts.approximateLineWidth) {
                      textContent = textContent.trimRight() + "\n";
                      output.currentLineWidth = 0;
                    } else {
                      textContent = textContent.trimRight() + " ";
                    }
                  }
                }
                output.currentLineWidth += textContentLength;
              }
              output.text.push(escapeString(textContent, false));
            }
          }
        }
      }
    }
  } else if (node.nodeType === 8) {
    const nodeValue = node.nodeValue;
    if (opts.removeHtmlComments) {
      const isHydrateAnnotation = nodeValue.startsWith(CONTENT_REF_ID + ".") || nodeValue.startsWith(ORG_LOCATION_ID + ".") || nodeValue.startsWith(SLOT_NODE_ID + ".") || nodeValue.startsWith(TEXT_NODE_ID + ".");
      if (!isHydrateAnnotation) {
        return;
      }
    }
    const isWithinWhitespaceSensitiveNode = opts.newLines || opts.indentSpaces > 0 ? isWithinWhitespaceSensitive(node) : false;
    if (opts.newLines && !isWithinWhitespaceSensitiveNode) {
      output.text.push("\n");
      output.currentLineWidth = 0;
    }
    if (opts.indentSpaces > 0 && !isWithinWhitespaceSensitiveNode) {
      for (let i = 0; i < output.indent; i++) {
        output.text.push(" ");
      }
      output.currentLineWidth += output.indent;
    }
    output.text.push("<!--" + nodeValue + "-->");
    output.currentLineWidth += nodeValue.length + 7;
  } else if (node.nodeType === 10) {
    output.text.push("<!doctype html>");
  }
}
const AMP_REGEX = /&/g;
const NBSP_REGEX = /\u00a0/g;
const DOUBLE_QUOTE_REGEX = /"/g;
const LT_REGEX = /</g;
const GT_REGEX = />/g;
const CAN_REMOVE_ATTR_QUOTES = /^[^ \t\n\f\r"'`=<>\/\\-]+$/;
function getTagName(element) {
  if (element.namespaceURI === "http://www.w3.org/1999/xhtml") {
    return element.nodeName.toLowerCase();
  } else {
    return element.nodeName;
  }
}
function escapeString(str, attrMode) {
  str = str.replace(AMP_REGEX, "&amp;").replace(NBSP_REGEX, "&nbsp;");
  if (attrMode) {
    return str.replace(DOUBLE_QUOTE_REGEX, "&quot;");
  }
  return str.replace(LT_REGEX, "&lt;").replace(GT_REGEX, "&gt;");
}
function isWithinWhitespaceSensitive(node) {
  while (node != null) {
    if (WHITESPACE_SENSITIVE.has(node.nodeName)) {
      return true;
    }
    node = node.parentNode;
  }
  return false;
}
const NON_ESCAPABLE_CONTENT = /* @__PURE__ */ new Set([
  "STYLE",
  "SCRIPT",
  "IFRAME",
  "NOSCRIPT",
  "XMP",
  "NOEMBED",
  "NOFRAMES",
  "PLAINTEXT"
]);
const WHITESPACE_SENSITIVE = /* @__PURE__ */ new Set([
  "CODE",
  "OUTPUT",
  "PLAINTEXT",
  "PRE",
  "SCRIPT",
  "TEMPLATE",
  "TEXTAREA"
]);
const EMPTY_ELEMENTS = /* @__PURE__ */ new Set([
  "area",
  "base",
  "basefont",
  "bgsound",
  "br",
  "col",
  "embed",
  "frame",
  "hr",
  "img",
  "input",
  "keygen",
  "link",
  "meta",
  "param",
  "source",
  "trace",
  "wbr"
]);
const REMOVE_EMPTY_ATTR = /* @__PURE__ */ new Set(["class", "dir", "id", "lang", "name", "title"]);
const BOOLEAN_ATTR = /* @__PURE__ */ new Set([
  "allowfullscreen",
  "async",
  "autofocus",
  "autoplay",
  "checked",
  "compact",
  "controls",
  "declare",
  "default",
  "defaultchecked",
  "defaultmuted",
  "defaultselected",
  "defer",
  "disabled",
  "enabled",
  "formnovalidate",
  "hidden",
  "indeterminate",
  "inert",
  "ismap",
  "itemscope",
  "loop",
  "multiple",
  "muted",
  "nohref",
  "nomodule",
  "noresize",
  "noshade",
  "novalidate",
  "nowrap",
  "open",
  "pauseonexit",
  "readonly",
  "required",
  "reversed",
  "scoped",
  "seamless",
  "selected",
  "sortable",
  "truespeed",
  "typemustmatch",
  "visible"
]);
const STRUCTURE_ELEMENTS = /* @__PURE__ */ new Set([
  "html",
  "body",
  "head",
  "iframe",
  "meta",
  "link",
  "base",
  "title",
  "script",
  "style"
]);
class MockNode {
  constructor(ownerDocument, nodeType, nodeName, nodeValue) {
    this.ownerDocument = ownerDocument;
    this.nodeType = nodeType;
    this.nodeName = nodeName;
    this._nodeValue = nodeValue;
    this.parentNode = null;
    this.childNodes = [];
  }
  appendChild(newNode) {
    if (newNode.nodeType === 11) {
      const nodes = newNode.childNodes.slice();
      for (const child of nodes) {
        this.appendChild(child);
      }
    } else {
      newNode.remove();
      newNode.parentNode = this;
      this.childNodes.push(newNode);
      connectNode(this.ownerDocument, newNode);
    }
    return newNode;
  }
  append(...items) {
    items.forEach((item) => {
      const isNode = typeof item === "object" && item !== null && "nodeType" in item;
      this.appendChild(isNode ? item : this.ownerDocument.createTextNode(String(item)));
    });
  }
  prepend(...items) {
    const firstChild = this.firstChild;
    items.forEach((item) => {
      const isNode = typeof item === "object" && item !== null && "nodeType" in item;
      if (firstChild) {
        this.insertBefore(isNode ? item : this.ownerDocument.createTextNode(String(item)), firstChild);
      }
    });
  }
  cloneNode(deep) {
    throw new Error(`invalid node type to clone: ${this.nodeType}, deep: ${deep}`);
  }
  compareDocumentPosition(_other) {
    return -1;
  }
  get firstChild() {
    return this.childNodes[0] || null;
  }
  insertBefore(newNode, referenceNode) {
    if (newNode.nodeType === 11) {
      for (let i = 0, ii = newNode.childNodes.length; i < ii; i++) {
        insertBefore(this, newNode.childNodes[i], referenceNode);
      }
    } else {
      insertBefore(this, newNode, referenceNode);
    }
    return newNode;
  }
  get isConnected() {
    let node = this;
    while (node != null) {
      if (node.nodeType === 9) {
        return true;
      }
      node = node.parentNode;
      if (node != null && node.nodeType === 11) {
        node = node.host;
      }
    }
    return false;
  }
  isSameNode(node) {
    return this === node;
  }
  get lastChild() {
    return this.childNodes[this.childNodes.length - 1] || null;
  }
  get nextSibling() {
    if (this.parentNode != null) {
      const index = this.parentNode.childNodes.indexOf(this) + 1;
      return this.parentNode.childNodes[index] || null;
    }
    return null;
  }
  get nodeValue() {
    var _a;
    return (_a = this._nodeValue) !== null && _a !== void 0 ? _a : "";
  }
  set nodeValue(value) {
    this._nodeValue = value;
  }
  get parentElement() {
    return this.parentNode || null;
  }
  set parentElement(value) {
    this.parentNode = value;
  }
  get previousSibling() {
    if (this.parentNode != null) {
      const index = this.parentNode.childNodes.indexOf(this) - 1;
      return this.parentNode.childNodes[index] || null;
    }
    return null;
  }
  contains(otherNode) {
    if (otherNode === this) {
      return true;
    }
    const childNodes = Array.from(this.childNodes);
    if (childNodes.includes(otherNode)) {
      return true;
    }
    return childNodes.some((node) => this.contains.bind(node)(otherNode));
  }
  removeChild(childNode) {
    const index = this.childNodes.indexOf(childNode);
    if (index > -1) {
      this.childNodes.splice(index, 1);
      if (this.nodeType === 1) {
        const wasConnected = this.isConnected;
        childNode.parentNode = null;
        if (wasConnected === true) {
          disconnectNode(childNode);
        }
      } else {
        childNode.parentNode = null;
      }
    } else {
      throw new Error(`node not found within childNodes during removeChild`);
    }
    return childNode;
  }
  remove() {
    if (this.parentNode != null) {
      this.parentNode.removeChild(this);
    }
  }
  replaceChild(newChild, oldChild) {
    if (oldChild.parentNode === this) {
      this.insertBefore(newChild, oldChild);
      oldChild.remove();
      return newChild;
    }
    return null;
  }
  get textContent() {
    var _a;
    return (_a = this._nodeValue) !== null && _a !== void 0 ? _a : "";
  }
  set textContent(value) {
    this._nodeValue = String(value);
  }
}
MockNode.ELEMENT_NODE = 1;
MockNode.TEXT_NODE = 3;
MockNode.PROCESSING_INSTRUCTION_NODE = 7;
MockNode.COMMENT_NODE = 8;
MockNode.DOCUMENT_NODE = 9;
MockNode.DOCUMENT_TYPE_NODE = 10;
MockNode.DOCUMENT_FRAGMENT_NODE = 11;
class MockNodeList {
  constructor(ownerDocument, childNodes, length) {
    this.ownerDocument = ownerDocument;
    this.childNodes = childNodes;
    this.length = length;
  }
}
class MockElement extends MockNode {
  attachInternals() {
    return new Proxy({}, {
      get: function(_target, prop, _receiver) {
        console.error(`NOTE: Property ${String(prop)} was accessed on ElementInternals, but this property is not implemented.
Testing components with ElementInternals is fully supported in e2e tests.`);
      }
    });
  }
  constructor(ownerDocument, nodeName, namespaceURI = null) {
    super(ownerDocument, 1, typeof nodeName === "string" ? nodeName : null, null);
    this.__namespaceURI = namespaceURI;
    this.__shadowRoot = null;
    this.__attributeMap = null;
  }
  addEventListener(type, handler) {
    addEventListener(this, type, handler);
  }
  attachShadow(_opts) {
    const shadowRoot = this.ownerDocument.createDocumentFragment();
    this.shadowRoot = shadowRoot;
    return shadowRoot;
  }
  blur() {
    dispatchEvent(this, new MockFocusEvent("blur", { relatedTarget: null, bubbles: true, cancelable: true, composed: true }));
  }
  get namespaceURI() {
    return this.__namespaceURI;
  }
  get shadowRoot() {
    return this.__shadowRoot || null;
  }
  set shadowRoot(shadowRoot) {
    if (shadowRoot != null) {
      shadowRoot.host = this;
      this.__shadowRoot = shadowRoot;
    } else {
      delete this.__shadowRoot;
    }
  }
  get attributes() {
    if (this.__attributeMap == null) {
      const attrMap = createAttributeProxy(false);
      this.__attributeMap = attrMap;
      return attrMap;
    }
    return this.__attributeMap;
  }
  set attributes(attrs) {
    this.__attributeMap = attrs;
  }
  get children() {
    return this.childNodes.filter(
      (n) => n.nodeType === 1
      /* NODE_TYPES.ELEMENT_NODE */
    );
  }
  get childElementCount() {
    return this.childNodes.filter(
      (n) => n.nodeType === 1
      /* NODE_TYPES.ELEMENT_NODE */
    ).length;
  }
  get className() {
    return this.getAttributeNS(null, "class") || "";
  }
  set className(value) {
    this.setAttributeNS(null, "class", value);
  }
  get classList() {
    return new MockClassList(this);
  }
  click() {
    dispatchEvent(this, new MockEvent("click", { bubbles: true, cancelable: true, composed: true }));
  }
  cloneNode(_deep) {
    return null;
  }
  closest(selector) {
    let elm = this;
    while (elm != null) {
      if (elm.matches(selector)) {
        return elm;
      }
      elm = elm.parentNode;
    }
    return null;
  }
  get dataset() {
    return dataset(this);
  }
  get dir() {
    return this.getAttributeNS(null, "dir") || "";
  }
  set dir(value) {
    this.setAttributeNS(null, "dir", value);
  }
  dispatchEvent(ev) {
    return dispatchEvent(this, ev);
  }
  get firstElementChild() {
    return this.children[0] || null;
  }
  focus(_options) {
    dispatchEvent(this, new MockFocusEvent("focus", { relatedTarget: null, bubbles: true, cancelable: true, composed: true }));
  }
  getAttribute(attrName) {
    if (attrName === "style") {
      if (this.__style != null && this.__style.length > 0) {
        return this.style.cssText;
      }
      return null;
    }
    const attr = this.attributes.getNamedItem(attrName);
    if (attr != null) {
      return attr.value;
    }
    return null;
  }
  getAttributeNS(namespaceURI, attrName) {
    const attr = this.attributes.getNamedItemNS(namespaceURI, attrName);
    if (attr != null) {
      return attr.value;
    }
    return null;
  }
  getAttributeNode(attrName) {
    if (!this.hasAttribute(attrName)) {
      return null;
    }
    return new MockAttr(attrName, this.getAttribute(attrName));
  }
  getBoundingClientRect() {
    return { bottom: 0, height: 0, left: 0, right: 0, top: 0, width: 0, x: 0, y: 0 };
  }
  getRootNode(opts) {
    const isComposed = opts != null && opts.composed === true;
    let node = this;
    while (node.parentNode != null) {
      node = node.parentNode;
      if (isComposed === true && node.parentNode == null && node.host != null) {
        node = node.host;
      }
    }
    return node;
  }
  get draggable() {
    return this.getAttributeNS(null, "draggable") === "true";
  }
  set draggable(value) {
    this.setAttributeNS(null, "draggable", value);
  }
  hasChildNodes() {
    return this.childNodes.length > 0;
  }
  get id() {
    return this.getAttributeNS(null, "id") || "";
  }
  set id(value) {
    this.setAttributeNS(null, "id", value);
  }
  get innerHTML() {
    if (this.childNodes.length === 0) {
      return "";
    }
    return serializeNodeToHtml(this, {
      newLines: false,
      indentSpaces: 0
    });
  }
  set innerHTML(html) {
    var _a;
    if (NON_ESCAPABLE_CONTENT.has((_a = this.nodeName) !== null && _a !== void 0 ? _a : "") === true) {
      setTextContent(this, html);
    } else {
      for (let i = this.childNodes.length - 1; i >= 0; i--) {
        this.removeChild(this.childNodes[i]);
      }
      if (typeof html === "string") {
        const frag = parseFragmentUtil(this.ownerDocument, html);
        while (frag.childNodes.length > 0) {
          this.appendChild(frag.childNodes[0]);
        }
      }
    }
  }
  get innerText() {
    const text = [];
    getTextContent(this.childNodes, text);
    return text.join("");
  }
  set innerText(value) {
    setTextContent(this, value);
  }
  insertAdjacentElement(position, elm) {
    if (position === "beforebegin") {
      insertBefore(this.parentNode, elm, this);
    } else if (position === "afterbegin") {
      this.prepend(elm);
    } else if (position === "beforeend") {
      this.appendChild(elm);
    } else if (position === "afterend") {
      insertBefore(this.parentNode, elm, this.nextSibling);
    }
    return elm;
  }
  insertAdjacentHTML(position, html) {
    const frag = parseFragmentUtil(this.ownerDocument, html);
    if (position === "beforebegin") {
      while (frag.childNodes.length > 0) {
        insertBefore(this.parentNode, frag.childNodes[0], this);
      }
    } else if (position === "afterbegin") {
      while (frag.childNodes.length > 0) {
        this.prepend(frag.childNodes[frag.childNodes.length - 1]);
      }
    } else if (position === "beforeend") {
      while (frag.childNodes.length > 0) {
        this.appendChild(frag.childNodes[0]);
      }
    } else if (position === "afterend") {
      while (frag.childNodes.length > 0) {
        insertBefore(this.parentNode, frag.childNodes[frag.childNodes.length - 1], this.nextSibling);
      }
    }
  }
  insertAdjacentText(position, text) {
    const elm = this.ownerDocument.createTextNode(text);
    if (position === "beforebegin") {
      insertBefore(this.parentNode, elm, this);
    } else if (position === "afterbegin") {
      this.prepend(elm);
    } else if (position === "beforeend") {
      this.appendChild(elm);
    } else if (position === "afterend") {
      insertBefore(this.parentNode, elm, this.nextSibling);
    }
  }
  hasAttribute(attrName) {
    if (attrName === "style") {
      return this.__style != null && this.__style.length > 0;
    }
    return this.getAttribute(attrName) !== null;
  }
  hasAttributeNS(namespaceURI, name) {
    return this.getAttributeNS(namespaceURI, name) !== null;
  }
  get hidden() {
    return this.hasAttributeNS(null, "hidden");
  }
  set hidden(isHidden) {
    if (isHidden === true) {
      this.setAttributeNS(null, "hidden", "");
    } else {
      this.removeAttributeNS(null, "hidden");
    }
  }
  get lang() {
    return this.getAttributeNS(null, "lang") || "";
  }
  set lang(value) {
    this.setAttributeNS(null, "lang", value);
  }
  get lastElementChild() {
    const children = this.children;
    return children[children.length - 1] || null;
  }
  matches(selector) {
    return matches(selector, this);
  }
  get nextElementSibling() {
    const parentElement = this.parentElement;
    if (parentElement != null && (parentElement.nodeType === 1 || parentElement.nodeType === 11 || parentElement.nodeType === 9)) {
      const children = parentElement.children;
      const index = children.indexOf(this) + 1;
      return parentElement.children[index] || null;
    }
    return null;
  }
  get outerHTML() {
    return serializeNodeToHtml(this, {
      newLines: false,
      outerHtml: true,
      indentSpaces: 0
    });
  }
  get previousElementSibling() {
    const parentElement = this.parentElement;
    if (parentElement != null && (parentElement.nodeType === 1 || parentElement.nodeType === 11 || parentElement.nodeType === 9)) {
      const children = parentElement.children;
      const index = children.indexOf(this) - 1;
      return parentElement.children[index] || null;
    }
    return null;
  }
  getElementsByClassName(classNames) {
    const classes = classNames.trim().split(" ").filter((c) => c.length > 0);
    const results = [];
    getElementsByClassName(this, classes, results);
    return results;
  }
  getElementsByTagName(tagName) {
    const results = [];
    getElementsByTagName(this, tagName.toLowerCase(), results);
    return results;
  }
  querySelector(selector) {
    return selectOne(selector, this);
  }
  querySelectorAll(selector) {
    return selectAll(selector, this);
  }
  removeAttribute(attrName) {
    if (attrName === "style") {
      delete this.__style;
    } else {
      const attr = this.attributes.getNamedItem(attrName);
      if (attr != null) {
        this.attributes.removeNamedItemNS(attr);
        if (checkAttributeChanged(this) === true) {
          attributeChanged(this, attrName, attr.value, null);
        }
      }
    }
  }
  removeAttributeNS(namespaceURI, attrName) {
    const attr = this.attributes.getNamedItemNS(namespaceURI, attrName);
    if (attr != null) {
      this.attributes.removeNamedItemNS(attr);
      if (checkAttributeChanged(this) === true) {
        attributeChanged(this, attrName, attr.value, null);
      }
    }
  }
  removeEventListener(type, handler) {
    removeEventListener(this, type, handler);
  }
  setAttribute(attrName, value) {
    if (attrName === "style") {
      this.style = value;
    } else {
      const attributes = this.attributes;
      let attr = attributes.getNamedItem(attrName);
      const checkAttrChanged = checkAttributeChanged(this);
      if (attr != null) {
        if (checkAttrChanged === true) {
          const oldValue = attr.value;
          attr.value = value;
          if (oldValue !== attr.value) {
            attributeChanged(this, attr.name, oldValue, attr.value);
          }
        } else {
          attr.value = value;
        }
      } else {
        if (attributes.caseInsensitive) {
          attrName = attrName.toLowerCase();
        }
        attr = new MockAttr(attrName, value);
        attributes.__items.push(attr);
        if (checkAttrChanged === true) {
          attributeChanged(this, attrName, null, attr.value);
        }
      }
    }
  }
  setAttributeNS(namespaceURI, attrName, value) {
    const attributes = this.attributes;
    let attr = attributes.getNamedItemNS(namespaceURI, attrName);
    const checkAttrChanged = checkAttributeChanged(this);
    if (attr != null) {
      if (checkAttrChanged === true) {
        const oldValue = attr.value;
        attr.value = value;
        if (oldValue !== attr.value) {
          attributeChanged(this, attr.name, oldValue, attr.value);
        }
      } else {
        attr.value = value;
      }
    } else {
      attr = new MockAttr(attrName, value, namespaceURI);
      attributes.__items.push(attr);
      if (checkAttrChanged === true) {
        attributeChanged(this, attrName, null, attr.value);
      }
    }
  }
  get style() {
    if (this.__style == null) {
      this.__style = createCSSStyleDeclaration();
    }
    return this.__style;
  }
  set style(val) {
    if (typeof val === "string") {
      if (this.__style == null) {
        this.__style = createCSSStyleDeclaration();
      }
      this.__style.cssText = val;
    } else {
      this.__style = val;
    }
  }
  get tabIndex() {
    return parseInt(this.getAttributeNS(null, "tabindex") || "-1", 10);
  }
  set tabIndex(value) {
    this.setAttributeNS(null, "tabindex", value);
  }
  get tagName() {
    var _a;
    return (_a = this.nodeName) !== null && _a !== void 0 ? _a : "";
  }
  set tagName(value) {
    this.nodeName = value;
  }
  get textContent() {
    const text = [];
    getTextContent(this.childNodes, text);
    return text.join("");
  }
  set textContent(value) {
    setTextContent(this, value);
  }
  get title() {
    return this.getAttributeNS(null, "title") || "";
  }
  set title(value) {
    this.setAttributeNS(null, "title", value);
  }
  animate() {
  }
  onanimationstart() {
  }
  onanimationend() {
  }
  onanimationiteration() {
  }
  onabort() {
  }
  onauxclick() {
  }
  onbeforecopy() {
  }
  onbeforecut() {
  }
  onbeforepaste() {
  }
  onblur() {
  }
  oncancel() {
  }
  oncanplay() {
  }
  oncanplaythrough() {
  }
  onchange() {
  }
  onclick() {
  }
  onclose() {
  }
  oncontextmenu() {
  }
  oncopy() {
  }
  oncuechange() {
  }
  oncut() {
  }
  ondblclick() {
  }
  ondrag() {
  }
  ondragend() {
  }
  ondragenter() {
  }
  ondragleave() {
  }
  ondragover() {
  }
  ondragstart() {
  }
  ondrop() {
  }
  ondurationchange() {
  }
  onemptied() {
  }
  onended() {
  }
  onerror() {
  }
  onfocus() {
  }
  onfocusin() {
  }
  onfocusout() {
  }
  onformdata() {
  }
  onfullscreenchange() {
  }
  onfullscreenerror() {
  }
  ongotpointercapture() {
  }
  oninput() {
  }
  oninvalid() {
  }
  onkeydown() {
  }
  onkeypress() {
  }
  onkeyup() {
  }
  onload() {
  }
  onloadeddata() {
  }
  onloadedmetadata() {
  }
  onloadstart() {
  }
  onlostpointercapture() {
  }
  onmousedown() {
  }
  onmouseenter() {
  }
  onmouseleave() {
  }
  onmousemove() {
  }
  onmouseout() {
  }
  onmouseover() {
  }
  onmouseup() {
  }
  onmousewheel() {
  }
  onpaste() {
  }
  onpause() {
  }
  onplay() {
  }
  onplaying() {
  }
  onpointercancel() {
  }
  onpointerdown() {
  }
  onpointerenter() {
  }
  onpointerleave() {
  }
  onpointermove() {
  }
  onpointerout() {
  }
  onpointerover() {
  }
  onpointerup() {
  }
  onprogress() {
  }
  onratechange() {
  }
  onreset() {
  }
  onresize() {
  }
  onscroll() {
  }
  onsearch() {
  }
  onseeked() {
  }
  onseeking() {
  }
  onselect() {
  }
  onselectstart() {
  }
  onstalled() {
  }
  onsubmit() {
  }
  onsuspend() {
  }
  ontimeupdate() {
  }
  ontoggle() {
  }
  onvolumechange() {
  }
  onwaiting() {
  }
  onwebkitfullscreenchange() {
  }
  onwebkitfullscreenerror() {
  }
  onwheel() {
  }
  requestFullscreen() {
  }
  scrollBy() {
  }
  scrollTo() {
  }
  scrollIntoView() {
  }
  toString(opts) {
    return serializeNodeToHtml(this, opts);
  }
}
function getElementsByClassName(elm, classNames, foundElms) {
  const children = elm.children;
  for (let i = 0, ii = children.length; i < ii; i++) {
    const childElm = children[i];
    for (let j = 0, jj = classNames.length; j < jj; j++) {
      if (childElm.classList.contains(classNames[j])) {
        foundElms.push(childElm);
      }
    }
    getElementsByClassName(childElm, classNames, foundElms);
  }
}
function getElementsByTagName(elm, tagName, foundElms) {
  var _a;
  const children = elm.children;
  for (let i = 0, ii = children.length; i < ii; i++) {
    const childElm = children[i];
    if (tagName === "*" || ((_a = childElm.nodeName) !== null && _a !== void 0 ? _a : "").toLowerCase() === tagName) {
      foundElms.push(childElm);
    }
    getElementsByTagName(childElm, tagName, foundElms);
  }
}
function resetElement(elm) {
  resetEventListeners(elm);
  delete elm.__attributeMap;
  delete elm.__shadowRoot;
  delete elm.__style;
}
function insertBefore(parentNode, newNode, referenceNode) {
  if (newNode !== referenceNode) {
    newNode.remove();
    newNode.parentNode = parentNode;
    newNode.ownerDocument = parentNode.ownerDocument;
    if (referenceNode != null) {
      const index = parentNode.childNodes.indexOf(referenceNode);
      if (index > -1) {
        parentNode.childNodes.splice(index, 0, newNode);
      } else {
        throw new Error(`referenceNode not found in parentNode.childNodes`);
      }
    } else {
      parentNode.childNodes.push(newNode);
    }
    connectNode(parentNode.ownerDocument, newNode);
  }
  return newNode;
}
class MockHTMLElement extends MockElement {
  constructor(ownerDocument, nodeName) {
    super(ownerDocument, typeof nodeName === "string" ? nodeName.toUpperCase() : null);
    this.__namespaceURI = "http://www.w3.org/1999/xhtml";
  }
  get tagName() {
    var _a;
    return (_a = this.nodeName) !== null && _a !== void 0 ? _a : "";
  }
  set tagName(value) {
    this.nodeName = value;
  }
  get attributes() {
    if (this.__attributeMap == null) {
      const attrMap = createAttributeProxy(true);
      this.__attributeMap = attrMap;
      return attrMap;
    }
    return this.__attributeMap;
  }
  set attributes(attrs) {
    this.__attributeMap = attrs;
  }
}
class MockTextNode extends MockNode {
  constructor(ownerDocument, text) {
    super(ownerDocument, 3, "#text", text);
  }
  cloneNode(_deep) {
    return new MockTextNode(null, this.nodeValue);
  }
  get textContent() {
    return this.nodeValue;
  }
  set textContent(text) {
    this.nodeValue = text;
  }
  get data() {
    return this.nodeValue;
  }
  set data(text) {
    this.nodeValue = text;
  }
  get wholeText() {
    if (this.parentNode != null) {
      const text = [];
      for (let i = 0, ii = this.parentNode.childNodes.length; i < ii; i++) {
        const childNode = this.parentNode.childNodes[i];
        if (childNode.nodeType === 3) {
          text.push(childNode.nodeValue);
        }
      }
      return text.join("");
    }
    return this.nodeValue;
  }
}
function getTextContent(childNodes, text) {
  for (let i = 0, ii = childNodes.length; i < ii; i++) {
    const childNode = childNodes[i];
    if (childNode.nodeType === 3) {
      text.push(childNode.nodeValue);
    } else if (childNode.nodeType === 1) {
      getTextContent(childNode.childNodes, text);
    }
  }
}
function setTextContent(elm, text) {
  for (let i = elm.childNodes.length - 1; i >= 0; i--) {
    elm.removeChild(elm.childNodes[i]);
  }
  const textNode = new MockTextNode(elm.ownerDocument, text);
  elm.appendChild(textNode);
}
class MockComment extends MockNode {
  constructor(ownerDocument, data) {
    super(ownerDocument, 8, "#comment", data);
  }
  cloneNode(_deep) {
    return new MockComment(null, this.nodeValue);
  }
  get textContent() {
    return this.nodeValue;
  }
  set textContent(text) {
    this.nodeValue = text;
  }
}
class MockDocumentFragment extends MockHTMLElement {
  constructor(ownerDocument) {
    super(ownerDocument, null);
    this.nodeName = "#document-fragment";
    this.nodeType = 11;
  }
  getElementById(id) {
    return getElementById(this, id);
  }
  cloneNode(deep) {
    const cloned = new MockDocumentFragment(null);
    if (deep) {
      for (let i = 0, ii = this.childNodes.length; i < ii; i++) {
        const childNode = this.childNodes[i];
        if (childNode.nodeType === 1 || childNode.nodeType === 3 || childNode.nodeType === 8) {
          const clonedChildNode = this.childNodes[i].cloneNode(true);
          cloned.appendChild(clonedChildNode);
        }
      }
    }
    return cloned;
  }
}
class MockDocumentTypeNode extends MockHTMLElement {
  constructor(ownerDocument) {
    super(ownerDocument, "!DOCTYPE");
    this.nodeType = 10;
    this.setAttribute("html", "");
  }
}
class MockCSSRule {
  constructor(parentStyleSheet) {
    this.parentStyleSheet = parentStyleSheet;
    this.cssText = "";
    this.type = 0;
  }
}
class MockCSSStyleSheet {
  constructor(ownerNode) {
    this.type = "text/css";
    this.parentStyleSheet = null;
    this.cssRules = [];
    this.ownerNode = ownerNode;
  }
  get rules() {
    return this.cssRules;
  }
  set rules(rules) {
    this.cssRules = rules;
  }
  deleteRule(index) {
    if (index >= 0 && index < this.cssRules.length) {
      this.cssRules.splice(index, 1);
      updateStyleTextNode(this.ownerNode);
    }
  }
  insertRule(rule, index = 0) {
    if (typeof index !== "number") {
      index = 0;
    }
    if (index < 0) {
      index = 0;
    }
    if (index > this.cssRules.length) {
      index = this.cssRules.length;
    }
    const cssRule = new MockCSSRule(this);
    cssRule.cssText = rule;
    this.cssRules.splice(index, 0, cssRule);
    updateStyleTextNode(this.ownerNode);
    return index;
  }
}
function getStyleElementText(styleElm) {
  const output = [];
  for (let i = 0; i < styleElm.childNodes.length; i++) {
    output.push(styleElm.childNodes[i].nodeValue);
  }
  return output.join("");
}
function setStyleElementText(styleElm, text) {
  const sheet = styleElm.sheet;
  sheet.cssRules.length = 0;
  sheet.insertRule(text);
  updateStyleTextNode(styleElm);
}
function updateStyleTextNode(styleElm) {
  const childNodeLen = styleElm.childNodes.length;
  if (childNodeLen > 1) {
    for (let i = childNodeLen - 1; i >= 1; i--) {
      styleElm.removeChild(styleElm.childNodes[i]);
    }
  } else if (childNodeLen < 1) {
    styleElm.appendChild(styleElm.ownerDocument.createTextNode(""));
  }
  const textNode = styleElm.childNodes[0];
  textNode.nodeValue = styleElm.sheet.cssRules.map((r) => r.cssText).join("\n");
}
function createElement(ownerDocument, tagName) {
  if (typeof tagName !== "string" || tagName === "" || !/^[a-z0-9-_:]+$/i.test(tagName)) {
    throw new Error(`The tag name provided (${tagName}) is not a valid name.`);
  }
  tagName = tagName.toLowerCase();
  switch (tagName) {
    case "a":
      return new MockAnchorElement(ownerDocument);
    case "base":
      return new MockBaseElement(ownerDocument);
    case "button":
      return new MockButtonElement(ownerDocument);
    case "canvas":
      return new MockCanvasElement(ownerDocument);
    case "form":
      return new MockFormElement(ownerDocument);
    case "img":
      return new MockImageElement(ownerDocument);
    case "input":
      return new MockInputElement(ownerDocument);
    case "link":
      return new MockLinkElement(ownerDocument);
    case "meta":
      return new MockMetaElement(ownerDocument);
    case "script":
      return new MockScriptElement(ownerDocument);
    case "style":
      return new MockStyleElement(ownerDocument);
    case "template":
      return new MockTemplateElement(ownerDocument);
    case "title":
      return new MockTitleElement(ownerDocument);
  }
  if (ownerDocument != null && tagName.includes("-")) {
    const win = ownerDocument.defaultView;
    if (win != null && win.customElements != null) {
      return createCustomElement(win.customElements, ownerDocument, tagName);
    }
  }
  return new MockHTMLElement(ownerDocument, tagName);
}
function createElementNS(ownerDocument, namespaceURI, tagName) {
  if (namespaceURI === "http://www.w3.org/1999/xhtml") {
    return createElement(ownerDocument, tagName);
  } else if (namespaceURI === "http://www.w3.org/2000/svg") {
    switch (tagName.toLowerCase()) {
      case "text":
      case "tspan":
      case "tref":
      case "altglyph":
      case "textpath":
        return new MockSVGTextContentElement(ownerDocument, tagName);
      case "circle":
      case "ellipse":
      case "image":
      case "line":
      case "path":
      case "polygon":
      case "polyline":
      case "rect":
      case "use":
        return new MockSVGGraphicsElement(ownerDocument, tagName);
      case "svg":
        return new MockSVGSVGElement(ownerDocument, tagName);
      default:
        return new MockSVGElement(ownerDocument, tagName);
    }
  } else {
    return new MockElement(ownerDocument, tagName, namespaceURI);
  }
}
class MockAnchorElement extends MockHTMLElement {
  constructor(ownerDocument) {
    super(ownerDocument, "a");
  }
  get href() {
    return fullUrl(this, "href");
  }
  set href(value) {
    this.setAttribute("href", value);
  }
  get pathname() {
    return new URL(this.href).pathname;
  }
}
class MockButtonElement extends MockHTMLElement {
  constructor(ownerDocument) {
    super(ownerDocument, "button");
  }
}
patchPropAttributes(MockButtonElement.prototype, {
  type: String
}, {
  type: "submit"
});
class MockImageElement extends MockHTMLElement {
  constructor(ownerDocument) {
    super(ownerDocument, "img");
  }
  get draggable() {
    return this.getAttributeNS(null, "draggable") !== "false";
  }
  set draggable(value) {
    this.setAttributeNS(null, "draggable", value);
  }
  get src() {
    return fullUrl(this, "src");
  }
  set src(value) {
    this.setAttribute("src", value);
  }
}
patchPropAttributes(MockImageElement.prototype, {
  height: Number,
  width: Number
});
class MockInputElement extends MockHTMLElement {
  constructor(ownerDocument) {
    super(ownerDocument, "input");
  }
  get list() {
    const listId = this.getAttribute("list");
    if (listId) {
      return this.ownerDocument.getElementById(listId);
    }
    return null;
  }
}
patchPropAttributes(MockInputElement.prototype, {
  accept: String,
  autocomplete: String,
  autofocus: Boolean,
  capture: String,
  checked: Boolean,
  disabled: Boolean,
  form: String,
  formaction: String,
  formenctype: String,
  formmethod: String,
  formnovalidate: String,
  formtarget: String,
  height: Number,
  inputmode: String,
  max: String,
  maxLength: Number,
  min: String,
  minLength: Number,
  multiple: Boolean,
  name: String,
  pattern: String,
  placeholder: String,
  required: Boolean,
  readOnly: Boolean,
  size: Number,
  spellCheck: Boolean,
  src: String,
  step: String,
  type: String,
  value: String,
  width: Number
}, {
  type: "text"
});
class MockFormElement extends MockHTMLElement {
  constructor(ownerDocument) {
    super(ownerDocument, "form");
  }
}
patchPropAttributes(MockFormElement.prototype, {
  name: String
});
class MockLinkElement extends MockHTMLElement {
  constructor(ownerDocument) {
    super(ownerDocument, "link");
  }
  get href() {
    return fullUrl(this, "href");
  }
  set href(value) {
    this.setAttribute("href", value);
  }
}
patchPropAttributes(MockLinkElement.prototype, {
  crossorigin: String,
  media: String,
  rel: String,
  type: String
});
class MockMetaElement extends MockHTMLElement {
  constructor(ownerDocument) {
    super(ownerDocument, "meta");
  }
}
patchPropAttributes(MockMetaElement.prototype, {
  charset: String,
  content: String,
  name: String
});
class MockScriptElement extends MockHTMLElement {
  constructor(ownerDocument) {
    super(ownerDocument, "script");
  }
  get src() {
    return fullUrl(this, "src");
  }
  set src(value) {
    this.setAttribute("src", value);
  }
}
patchPropAttributes(MockScriptElement.prototype, {
  type: String
});
class MockDOMMatrix {
  constructor() {
    this.a = 1;
    this.b = 0;
    this.c = 0;
    this.d = 1;
    this.e = 0;
    this.f = 0;
    this.m11 = 1;
    this.m12 = 0;
    this.m13 = 0;
    this.m14 = 0;
    this.m21 = 0;
    this.m22 = 1;
    this.m23 = 0;
    this.m24 = 0;
    this.m31 = 0;
    this.m32 = 0;
    this.m33 = 1;
    this.m34 = 0;
    this.m41 = 0;
    this.m42 = 0;
    this.m43 = 0;
    this.m44 = 1;
    this.is2D = true;
    this.isIdentity = true;
  }
  static fromMatrix() {
    return new MockDOMMatrix();
  }
  inverse() {
    return new MockDOMMatrix();
  }
  flipX() {
    return new MockDOMMatrix();
  }
  flipY() {
    return new MockDOMMatrix();
  }
  multiply() {
    return new MockDOMMatrix();
  }
  rotate() {
    return new MockDOMMatrix();
  }
  rotateAxisAngle() {
    return new MockDOMMatrix();
  }
  rotateFromVector() {
    return new MockDOMMatrix();
  }
  scale() {
    return new MockDOMMatrix();
  }
  scaleNonUniform() {
    return new MockDOMMatrix();
  }
  skewX() {
    return new MockDOMMatrix();
  }
  skewY() {
    return new MockDOMMatrix();
  }
  toJSON() {
  }
  toString() {
  }
  transformPoint() {
    return new MockDOMPoint();
  }
  translate() {
    return new MockDOMMatrix();
  }
}
class MockDOMPoint {
  constructor() {
    this.w = 1;
    this.x = 0;
    this.y = 0;
    this.z = 0;
  }
  toJSON() {
  }
  matrixTransform() {
    return new MockDOMMatrix();
  }
}
class MockSVGRect {
  constructor() {
    this.height = 10;
    this.width = 10;
    this.x = 0;
    this.y = 0;
  }
}
class MockStyleElement extends MockHTMLElement {
  constructor(ownerDocument) {
    super(ownerDocument, "style");
    this.sheet = new MockCSSStyleSheet(this);
  }
  get innerHTML() {
    return getStyleElementText(this);
  }
  set innerHTML(value) {
    setStyleElementText(this, value);
  }
  get innerText() {
    return getStyleElementText(this);
  }
  set innerText(value) {
    setStyleElementText(this, value);
  }
  get textContent() {
    return getStyleElementText(this);
  }
  set textContent(value) {
    setStyleElementText(this, value);
  }
}
class MockSVGElement extends MockElement {
  constructor() {
    super(...arguments);
    this.__namespaceURI = "http://www.w3.org/2000/svg";
  }
  // SVGElement properties and methods
  get ownerSVGElement() {
    return null;
  }
  get viewportElement() {
    return null;
  }
  onunload() {
  }
  // SVGGeometryElement properties and methods
  get pathLength() {
    return 0;
  }
  isPointInFill(_pt) {
    return false;
  }
  isPointInStroke(_pt) {
    return false;
  }
  getTotalLength() {
    return 0;
  }
}
class MockSVGGraphicsElement extends MockSVGElement {
  getBBox(_options) {
    return new MockSVGRect();
  }
  getCTM() {
    return new MockDOMMatrix();
  }
  getScreenCTM() {
    return new MockDOMMatrix();
  }
}
class MockSVGSVGElement extends MockSVGGraphicsElement {
  createSVGPoint() {
    return new MockDOMPoint();
  }
}
class MockSVGTextContentElement extends MockSVGGraphicsElement {
  getComputedTextLength() {
    return 0;
  }
}
class MockBaseElement extends MockHTMLElement {
  constructor(ownerDocument) {
    super(ownerDocument, "base");
  }
  get href() {
    return fullUrl(this, "href");
  }
  set href(value) {
    this.setAttribute("href", value);
  }
}
class MockTemplateElement extends MockHTMLElement {
  constructor(ownerDocument) {
    super(ownerDocument, "template");
    this.content = new MockDocumentFragment(ownerDocument);
  }
  get innerHTML() {
    return this.content.innerHTML;
  }
  set innerHTML(html) {
    this.content.innerHTML = html;
  }
  cloneNode(deep) {
    const cloned = new MockTemplateElement(null);
    cloned.attributes = cloneAttributes(this.attributes);
    const styleCssText = this.getAttribute("style");
    if (styleCssText != null && styleCssText.length > 0) {
      cloned.setAttribute("style", styleCssText);
    }
    cloned.content = this.content.cloneNode(deep);
    if (deep) {
      for (let i = 0, ii = this.childNodes.length; i < ii; i++) {
        const clonedChildNode = this.childNodes[i].cloneNode(true);
        cloned.appendChild(clonedChildNode);
      }
    }
    return cloned;
  }
}
class MockTitleElement extends MockHTMLElement {
  constructor(ownerDocument) {
    super(ownerDocument, "title");
  }
  get text() {
    return this.textContent;
  }
  set text(value) {
    this.textContent = value;
  }
}
class MockCanvasElement extends MockHTMLElement {
  constructor(ownerDocument) {
    super(ownerDocument, "canvas");
  }
  getContext() {
    return {
      fillRect() {
        return;
      },
      clearRect() {
      },
      getImageData: function(_, __, w, h) {
        return {
          data: new Array(w * h * 4)
        };
      },
      putImageData() {
      },
      createImageData: function() {
        return [];
      },
      setTransform() {
      },
      drawImage() {
      },
      save() {
      },
      fillText() {
      },
      restore() {
      },
      beginPath() {
      },
      moveTo() {
      },
      lineTo() {
      },
      closePath() {
      },
      stroke() {
      },
      translate() {
      },
      scale() {
      },
      rotate() {
      },
      arc() {
      },
      fill() {
      },
      measureText() {
        return { width: 0 };
      },
      transform() {
      },
      rect() {
      },
      clip() {
      }
    };
  }
}
function fullUrl(elm, attrName) {
  const val = elm.getAttribute(attrName) || "";
  if (elm.ownerDocument != null) {
    const win = elm.ownerDocument.defaultView;
    if (win != null) {
      const loc = win.location;
      if (loc != null) {
        try {
          const url = new URL(val, loc.href);
          return url.href;
        } catch (e2) {
        }
      }
    }
  }
  return val.replace(/\'|\"/g, "").trim();
}
function patchPropAttributes(prototype, attrs, defaults = {}) {
  Object.keys(attrs).forEach((propName) => {
    const attr = attrs[propName];
    const defaultValue = defaults[propName];
    if (attr === Boolean) {
      Object.defineProperty(prototype, propName, {
        get() {
          return this.hasAttribute(propName);
        },
        set(value) {
          if (value) {
            this.setAttribute(propName, "");
          } else {
            this.removeAttribute(propName);
          }
        }
      });
    } else if (attr === Number) {
      Object.defineProperty(prototype, propName, {
        get() {
          const value = this.getAttribute(propName);
          return value ? parseInt(value, 10) : defaultValue === void 0 ? 0 : defaultValue;
        },
        set(value) {
          this.setAttribute(propName, value);
        }
      });
    } else {
      Object.defineProperty(prototype, propName, {
        get() {
          return this.hasAttribute(propName) ? this.getAttribute(propName) : defaultValue || "";
        },
        set(value) {
          this.setAttribute(propName, value);
        }
      });
    }
  });
}
MockElement.prototype.cloneNode = function(deep) {
  const cloned = createElement(this.ownerDocument, this.nodeName);
  cloned.attributes = cloneAttributes(this.attributes);
  const styleCssText = this.getAttribute("style");
  if (styleCssText != null && styleCssText.length > 0) {
    cloned.setAttribute("style", styleCssText);
  }
  if (deep) {
    for (let i = 0, ii = this.childNodes.length; i < ii; i++) {
      const clonedChildNode = this.childNodes[i].cloneNode(true);
      cloned.appendChild(clonedChildNode);
    }
  }
  return cloned;
};
let sharedDocument;
function parseHtmlToDocument(html, ownerDocument = null) {
  if (ownerDocument == null) {
    if (sharedDocument == null) {
      sharedDocument = new MockDocument();
    }
    ownerDocument = sharedDocument;
  }
  return parseDocumentUtil(ownerDocument, html);
}
function parseHtmlToFragment(html, ownerDocument = null) {
  if (ownerDocument == null) {
    if (sharedDocument == null) {
      sharedDocument = new MockDocument();
    }
    ownerDocument = sharedDocument;
  }
  return parseFragmentUtil(ownerDocument, html);
}
const consoleNoop = () => {
};
function createConsole() {
  return {
    debug: consoleNoop,
    error: consoleNoop,
    info: consoleNoop,
    log: consoleNoop,
    warn: consoleNoop,
    dir: consoleNoop,
    dirxml: consoleNoop,
    table: consoleNoop,
    trace: consoleNoop,
    group: consoleNoop,
    groupCollapsed: consoleNoop,
    groupEnd: consoleNoop,
    clear: consoleNoop,
    count: consoleNoop,
    countReset: consoleNoop,
    assert: consoleNoop,
    profile: consoleNoop,
    profileEnd: consoleNoop,
    time: consoleNoop,
    timeLog: consoleNoop,
    timeEnd: consoleNoop,
    timeStamp: consoleNoop,
    context: consoleNoop,
    memory: consoleNoop
  };
}
class MockHeaders {
  constructor(init) {
    this._values = [];
    if (typeof init === "object") {
      if (typeof init[Symbol.iterator] === "function") {
        const kvs = [];
        for (const kv of init) {
          if (typeof kv[Symbol.iterator] === "function") {
            kvs.push([...kv]);
          }
        }
        for (const kv of kvs) {
          this.append(kv[0], kv[1]);
        }
      } else {
        for (const key in init) {
          this.append(key, init[key]);
        }
      }
    }
  }
  append(key, value) {
    this._values.push([key, value + ""]);
  }
  delete(key) {
    key = key.toLowerCase();
    for (let i = this._values.length - 1; i >= 0; i--) {
      if (this._values[i][0].toLowerCase() === key) {
        this._values.splice(i, 1);
      }
    }
  }
  entries() {
    const entries = [];
    for (const kv of this.keys()) {
      entries.push([kv, this.get(kv)]);
    }
    let index = -1;
    return {
      next() {
        index++;
        return {
          value: entries[index],
          done: !entries[index]
        };
      },
      [Symbol.iterator]() {
        return this;
      }
    };
  }
  forEach(cb) {
    for (const kv of this.entries()) {
      cb(kv[1], kv[0]);
    }
  }
  get(key) {
    const rtn = [];
    key = key.toLowerCase();
    for (const kv of this._values) {
      if (kv[0].toLowerCase() === key) {
        rtn.push(kv[1]);
      }
    }
    return rtn.length > 0 ? rtn.join(", ") : null;
  }
  has(key) {
    key = key.toLowerCase();
    for (const kv of this._values) {
      if (kv[0].toLowerCase() === key) {
        return true;
      }
    }
    return false;
  }
  keys() {
    const keys = [];
    for (const kv of this._values) {
      const key = kv[0].toLowerCase();
      if (!keys.includes(key)) {
        keys.push(key);
      }
    }
    let index = -1;
    return {
      next() {
        index++;
        return {
          value: keys[index],
          done: !keys[index]
        };
      },
      [Symbol.iterator]() {
        return this;
      }
    };
  }
  set(key, value) {
    for (const kv of this._values) {
      if (kv[0].toLowerCase() === key.toLowerCase()) {
        kv[1] = value + "";
        return;
      }
    }
    this.append(key, value);
  }
  values() {
    const values = this._values;
    let index = -1;
    return {
      next() {
        index++;
        const done = !values[index];
        return {
          value: done ? void 0 : values[index][1],
          done
        };
      },
      [Symbol.iterator]() {
        return this;
      }
    };
  }
  [Symbol.iterator]() {
    return this.entries();
  }
}
class MockDOMParser {
  parseFromString(htmlToParse, mimeType) {
    if (mimeType !== "text/html") {
      console.error("XML parsing not implemented yet, continuing as html");
    }
    return parseHtmlToDocument(htmlToParse);
  }
}
class MockRequest {
  constructor(input, init = {}) {
    this._method = "GET";
    this._url = "/";
    this.bodyUsed = false;
    this.cache = "default";
    this.credentials = "same-origin";
    this.integrity = "";
    this.keepalive = false;
    this.mode = "cors";
    this.redirect = "follow";
    this.referrer = "about:client";
    this.referrerPolicy = "";
    if (typeof input === "string") {
      this.url = input;
    } else if (input) {
      Object.assign(this, input);
      this.headers = new MockHeaders(input.headers);
    }
    Object.assign(this, init);
    if (init.headers) {
      this.headers = new MockHeaders(init.headers);
    }
    if (!this.headers) {
      this.headers = new MockHeaders();
    }
  }
  get url() {
    if (typeof this._url === "string") {
      return new URL(this._url, location.href).href;
    }
    return new URL("/", location.href).href;
  }
  set url(value) {
    this._url = value;
  }
  get method() {
    if (typeof this._method === "string") {
      return this._method.toUpperCase();
    }
    return "GET";
  }
  set method(value) {
    this._method = value;
  }
  clone() {
    const clone = { ...this };
    clone.headers = new MockHeaders(this.headers);
    return new MockRequest(clone);
  }
}
class MockResponse {
  constructor(body, init = {}) {
    this.ok = true;
    this.status = 200;
    this.statusText = "";
    this.type = "default";
    this.url = "";
    this._body = body;
    if (init) {
      Object.assign(this, init);
    }
    this.headers = new MockHeaders(init.headers);
  }
  async json() {
    return JSON.parse(this._body);
  }
  async text() {
    return this._body;
  }
  clone() {
    const initClone = { ...this };
    initClone.headers = new MockHeaders(this.headers);
    return new MockResponse(this._body, initClone);
  }
}
function setupGlobal(gbl) {
  if (gbl.window == null) {
    const win = gbl.window = new MockWindow();
    WINDOW_FUNCTIONS.forEach((fnName) => {
      if (!(fnName in gbl)) {
        gbl[fnName] = win[fnName].bind(win);
      }
    });
    WINDOW_PROPS.forEach((propName) => {
      if (!(propName in gbl)) {
        Object.defineProperty(gbl, propName, {
          get() {
            return win[propName];
          },
          set(val) {
            win[propName] = val;
          },
          configurable: true,
          enumerable: true
        });
      }
    });
    GLOBAL_CONSTRUCTORS.forEach(([cstrName]) => {
      gbl[cstrName] = win[cstrName];
    });
  }
  return gbl.window;
}
function teardownGlobal(gbl) {
  const win = gbl.window;
  if (win && typeof win.close === "function") {
    win.close();
  }
}
function patchWindow(winToBePatched) {
  const mockWin = new MockWindow(false);
  WINDOW_FUNCTIONS.forEach((fnName) => {
    if (typeof winToBePatched[fnName] !== "function") {
      winToBePatched[fnName] = mockWin[fnName].bind(mockWin);
    }
  });
  WINDOW_PROPS.forEach((propName) => {
    if (winToBePatched === void 0) {
      Object.defineProperty(winToBePatched, propName, {
        get() {
          return mockWin[propName];
        },
        set(val) {
          mockWin[propName] = val;
        },
        configurable: true,
        enumerable: true
      });
    }
  });
}
function addGlobalsToWindowPrototype(mockWinPrototype) {
  GLOBAL_CONSTRUCTORS.forEach(([cstrName, Cstr]) => {
    Object.defineProperty(mockWinPrototype, cstrName, {
      get() {
        return this["__" + cstrName] || Cstr;
      },
      set(cstr) {
        this["__" + cstrName] = cstr;
      },
      configurable: true,
      enumerable: true
    });
  });
}
const WINDOW_FUNCTIONS = [
  "addEventListener",
  "alert",
  "blur",
  "cancelAnimationFrame",
  "cancelIdleCallback",
  "clearInterval",
  "clearTimeout",
  "close",
  "confirm",
  "dispatchEvent",
  "focus",
  "getComputedStyle",
  "matchMedia",
  "open",
  "prompt",
  "removeEventListener",
  "requestAnimationFrame",
  "requestIdleCallback",
  "URL"
];
const WINDOW_PROPS = [
  "customElements",
  "devicePixelRatio",
  "document",
  "history",
  "innerHeight",
  "innerWidth",
  "localStorage",
  "location",
  "navigator",
  "pageXOffset",
  "pageYOffset",
  "performance",
  "screenLeft",
  "screenTop",
  "screenX",
  "screenY",
  "scrollX",
  "scrollY",
  "sessionStorage",
  "CSS",
  "CustomEvent",
  "Event",
  "Element",
  "HTMLElement",
  "Node",
  "NodeList",
  "FocusEvent",
  "KeyboardEvent",
  "MouseEvent"
];
const GLOBAL_CONSTRUCTORS = [
  ["CustomEvent", MockCustomEvent],
  ["Event", MockEvent],
  ["Headers", MockHeaders],
  ["FocusEvent", MockFocusEvent],
  ["KeyboardEvent", MockKeyboardEvent],
  ["MouseEvent", MockMouseEvent],
  ["Request", MockRequest],
  ["Response", MockResponse],
  ["DOMParser", MockDOMParser],
  ["HTMLAnchorElement", MockAnchorElement],
  ["HTMLBaseElement", MockBaseElement],
  ["HTMLButtonElement", MockButtonElement],
  ["HTMLCanvasElement", MockCanvasElement],
  ["HTMLFormElement", MockFormElement],
  ["HTMLImageElement", MockImageElement],
  ["HTMLInputElement", MockInputElement],
  ["HTMLLinkElement", MockLinkElement],
  ["HTMLMetaElement", MockMetaElement],
  ["HTMLScriptElement", MockScriptElement],
  ["HTMLStyleElement", MockStyleElement],
  ["HTMLTemplateElement", MockTemplateElement],
  ["HTMLTitleElement", MockTitleElement]
];
class MockHistory {
  constructor() {
    this.items = [];
  }
  get length() {
    return this.items.length;
  }
  back() {
    this.go(-1);
  }
  forward() {
    this.go(1);
  }
  go(_value) {
  }
  pushState(_state, _title, _url) {
  }
  replaceState(_state, _title, _url) {
  }
}
class MockIntersectionObserver {
  constructor() {
  }
  disconnect() {
  }
  observe() {
  }
  takeRecords() {
    return [];
  }
  unobserve() {
  }
}
class MockLocation {
  constructor() {
    this.ancestorOrigins = null;
    this.protocol = "";
    this.host = "";
    this.hostname = "";
    this.port = "";
    this.pathname = "";
    this.search = "";
    this.hash = "";
    this.username = "";
    this.password = "";
    this.origin = "";
    this._href = "";
  }
  get href() {
    return this._href;
  }
  set href(value) {
    const url = new URL(value, "http://mockdoc.stenciljs.com");
    this._href = url.href;
    this.protocol = url.protocol;
    this.host = url.host;
    this.hostname = url.hostname;
    this.port = url.port;
    this.pathname = url.pathname;
    this.search = url.search;
    this.hash = url.hash;
    this.username = url.username;
    this.password = url.password;
    this.origin = url.origin;
  }
  assign(_url) {
  }
  reload(_forcedReload) {
  }
  replace(_url) {
  }
  toString() {
    return this.href;
  }
}
class MockNavigator {
  constructor() {
    this.appCodeName = "MockNavigator";
    this.appName = "MockNavigator";
    this.appVersion = "MockNavigator";
    this.platform = "MockNavigator";
    this.userAgent = "MockNavigator";
  }
}
class MockPerformance {
  constructor() {
    this.timeOrigin = Date.now();
    this.eventCounts = /* @__PURE__ */ new Map();
  }
  addEventListener() {
  }
  clearMarks() {
  }
  clearMeasures() {
  }
  clearResourceTimings() {
  }
  dispatchEvent() {
    return true;
  }
  getEntries() {
    return [];
  }
  getEntriesByName() {
    return [];
  }
  getEntriesByType() {
    return [];
  }
  // Stencil's implementation of `mark` is non-compliant with the `Performance` interface. Because Stencil will
  // instantiate an instance of this class and may attempt to assign it to a variable of type `Performance`, the return
  // type must match the `Performance` interface (rather than typing this function as returning `void` and ignoring the
  // associated errors returned by the type checker)
  // @ts-ignore
  mark() {
  }
  // Stencil's implementation of `measure` is non-compliant with the `Performance` interface. Because Stencil will
  // instantiate an instance of this class and may attempt to assign it to a variable of type `Performance`, the return
  // type must match the `Performance` interface (rather than typing this function as returning `void` and ignoring the
  // associated errors returned by the type checker)
  // @ts-ignore
  measure() {
  }
  get navigation() {
    return {};
  }
  now() {
    return Date.now() - this.timeOrigin;
  }
  get onresourcetimingbufferfull() {
    return null;
  }
  removeEventListener() {
  }
  setResourceTimingBufferSize() {
  }
  get timing() {
    return {};
  }
  toJSON() {
  }
}
function resetPerformance(perf) {
  if (perf != null) {
    try {
      perf.timeOrigin = Date.now();
    } catch (e2) {
    }
  }
}
class MockStorage {
  constructor() {
    this.items = /* @__PURE__ */ new Map();
  }
  key(_value) {
  }
  getItem(key) {
    key = String(key);
    if (this.items.has(key)) {
      return this.items.get(key);
    }
    return null;
  }
  setItem(key, value) {
    if (value == null) {
      value = "null";
    }
    this.items.set(String(key), String(value));
  }
  removeItem(key) {
    this.items.delete(String(key));
  }
  clear() {
    this.items.clear();
  }
}
const nativeClearInterval = clearInterval;
const nativeClearTimeout = clearTimeout;
const nativeSetInterval = setInterval;
const nativeSetTimeout = setTimeout;
const nativeURL = URL;
class MockWindow {
  constructor(html = null) {
    if (html !== false) {
      this.document = new MockDocument(html, this);
    } else {
      this.document = null;
    }
    this.performance = new MockPerformance();
    this.customElements = new MockCustomElementRegistry(this);
    this.console = createConsole();
    resetWindowDefaults(this);
    resetWindowDimensions(this);
  }
  addEventListener(type, handler) {
    addEventListener(this, type, handler);
  }
  alert(msg) {
    if (this.console) {
      this.console.debug(msg);
    } else {
      console.debug(msg);
    }
  }
  blur() {
  }
  cancelAnimationFrame(id) {
    this.__clearTimeout(id);
  }
  cancelIdleCallback(id) {
    this.__clearTimeout(id);
  }
  get CharacterData() {
    if (this.__charDataCstr == null) {
      const ownerDocument = this.document;
      this.__charDataCstr = class extends MockNode {
        constructor() {
          super(ownerDocument, 0, "test", "");
          throw new Error("Illegal constructor: cannot construct CharacterData");
        }
      };
    }
    return this.__charDataCstr;
  }
  set CharacterData(charDataCstr) {
    this.__charDataCstr = charDataCstr;
  }
  clearInterval(id) {
    this.__clearInterval(id);
  }
  clearTimeout(id) {
    this.__clearTimeout(id);
  }
  close() {
    resetWindow(this);
  }
  confirm() {
    return false;
  }
  get CSS() {
    return {
      supports: () => true
    };
  }
  get Document() {
    if (this.__docCstr == null) {
      const win = this;
      this.__docCstr = class extends MockDocument {
        constructor() {
          super(false, win);
          throw new Error("Illegal constructor: cannot construct Document");
        }
      };
    }
    return this.__docCstr;
  }
  set Document(docCstr) {
    this.__docCstr = docCstr;
  }
  get DocumentFragment() {
    if (this.__docFragCstr == null) {
      const ownerDocument = this.document;
      this.__docFragCstr = class extends MockDocumentFragment {
        constructor() {
          super(ownerDocument);
          throw new Error("Illegal constructor: cannot construct DocumentFragment");
        }
      };
    }
    return this.__docFragCstr;
  }
  set DocumentFragment(docFragCstr) {
    this.__docFragCstr = docFragCstr;
  }
  get DocumentType() {
    if (this.__docTypeCstr == null) {
      const ownerDocument = this.document;
      this.__docTypeCstr = class extends MockNode {
        constructor() {
          super(ownerDocument, 0, "test", "");
          throw new Error("Illegal constructor: cannot construct DocumentType");
        }
      };
    }
    return this.__docTypeCstr;
  }
  set DocumentType(docTypeCstr) {
    this.__docTypeCstr = docTypeCstr;
  }
  get DOMTokenList() {
    if (this.__domTokenListCstr == null) {
      this.__domTokenListCstr = class MockDOMTokenList {
      };
    }
    return this.__domTokenListCstr;
  }
  set DOMTokenList(domTokenListCstr) {
    this.__domTokenListCstr = domTokenListCstr;
  }
  dispatchEvent(ev) {
    return dispatchEvent(this, ev);
  }
  get Element() {
    if (this.__elementCstr == null) {
      const ownerDocument = this.document;
      this.__elementCstr = class extends MockElement {
        constructor() {
          super(ownerDocument, "");
          throw new Error("Illegal constructor: cannot construct Element");
        }
      };
    }
    return this.__elementCstr;
  }
  fetch(input, init) {
    if (typeof fetch === "function") {
      return fetch(input, init);
    }
    throw new Error(`fetch() not implemented`);
  }
  focus() {
  }
  getComputedStyle(_) {
    return {
      cssText: "",
      length: 0,
      parentRule: null,
      getPropertyPriority() {
        return null;
      },
      getPropertyValue() {
        return "";
      },
      item() {
        return null;
      },
      removeProperty() {
        return null;
      },
      setProperty() {
        return null;
      }
    };
  }
  get globalThis() {
    return this;
  }
  get history() {
    if (this.__history == null) {
      this.__history = new MockHistory();
    }
    return this.__history;
  }
  set history(hsty) {
    this.__history = hsty;
  }
  get JSON() {
    return JSON;
  }
  get HTMLElement() {
    if (this.__htmlElementCstr == null) {
      const ownerDocument = this.document;
      this.__htmlElementCstr = class extends MockHTMLElement {
        constructor() {
          super(ownerDocument, "");
          const observedAttributes = this.constructor.observedAttributes;
          if (Array.isArray(observedAttributes) && typeof this.attributeChangedCallback === "function") {
            observedAttributes.forEach((attrName) => {
              const attrValue = this.getAttribute(attrName);
              if (attrValue != null) {
                this.attributeChangedCallback(attrName, null, attrValue);
              }
            });
          }
        }
      };
    }
    return this.__htmlElementCstr;
  }
  set HTMLElement(htmlElementCstr) {
    this.__htmlElementCstr = htmlElementCstr;
  }
  get IntersectionObserver() {
    return MockIntersectionObserver;
  }
  get localStorage() {
    if (this.__localStorage == null) {
      this.__localStorage = new MockStorage();
    }
    return this.__localStorage;
  }
  set localStorage(locStorage) {
    this.__localStorage = locStorage;
  }
  get location() {
    if (this.__location == null) {
      this.__location = new MockLocation();
    }
    return this.__location;
  }
  set location(val) {
    if (typeof val === "string") {
      if (this.__location == null) {
        this.__location = new MockLocation();
      }
      this.__location.href = val;
    } else {
      this.__location = val;
    }
  }
  matchMedia(media) {
    return {
      media,
      matches: false,
      addListener: (_handler) => {
      },
      removeListener: (_handler) => {
      },
      addEventListener: (_type, _handler) => {
      },
      removeEventListener: (_type, _handler) => {
      },
      dispatchEvent: (_ev) => {
      },
      onchange: null
    };
  }
  get Node() {
    if (this.__nodeCstr == null) {
      const ownerDocument = this.document;
      this.__nodeCstr = class extends MockNode {
        constructor() {
          super(ownerDocument, 0, "test", "");
          throw new Error("Illegal constructor: cannot construct Node");
        }
      };
    }
    return this.__nodeCstr;
  }
  get NodeList() {
    if (this.__nodeListCstr == null) {
      const ownerDocument = this.document;
      this.__nodeListCstr = class extends MockNodeList {
        constructor() {
          super(ownerDocument, [], 0);
          throw new Error("Illegal constructor: cannot construct NodeList");
        }
      };
    }
    return this.__nodeListCstr;
  }
  get navigator() {
    if (this.__navigator == null) {
      this.__navigator = new MockNavigator();
    }
    return this.__navigator;
  }
  set navigator(nav) {
    this.__navigator = nav;
  }
  get parent() {
    return null;
  }
  prompt() {
    return "";
  }
  open() {
    return null;
  }
  get origin() {
    return this.location.origin;
  }
  removeEventListener(type, handler) {
    removeEventListener(this, type, handler);
  }
  requestAnimationFrame(callback) {
    return this.setTimeout(() => {
      callback(Date.now());
    }, 0);
  }
  requestIdleCallback(callback) {
    return this.setTimeout(() => {
      callback({
        didTimeout: false,
        timeRemaining: () => 0
      });
    }, 0);
  }
  scroll(_x, _y) {
  }
  scrollBy(_x, _y) {
  }
  scrollTo(_x, _y) {
  }
  get self() {
    return this;
  }
  get sessionStorage() {
    if (this.__sessionStorage == null) {
      this.__sessionStorage = new MockStorage();
    }
    return this.__sessionStorage;
  }
  set sessionStorage(locStorage) {
    this.__sessionStorage = locStorage;
  }
  setInterval(callback, ms, ...args) {
    if (this.__timeouts == null) {
      this.__timeouts = /* @__PURE__ */ new Set();
    }
    ms = Math.min(ms, this.__maxTimeout);
    if (this.__allowInterval) {
      const intervalId = this.__setInterval(() => {
        if (this.__timeouts) {
          this.__timeouts.delete(intervalId);
          try {
            callback(...args);
          } catch (e2) {
            if (this.console) {
              this.console.error(e2);
            } else {
              console.error(e2);
            }
          }
        }
      }, ms);
      if (this.__timeouts) {
        this.__timeouts.add(intervalId);
      }
      return intervalId;
    }
    const timeoutId = this.__setTimeout(() => {
      if (this.__timeouts) {
        this.__timeouts.delete(timeoutId);
        try {
          callback(...args);
        } catch (e2) {
          if (this.console) {
            this.console.error(e2);
          } else {
            console.error(e2);
          }
        }
      }
    }, ms);
    if (this.__timeouts) {
      this.__timeouts.add(timeoutId);
    }
    return timeoutId;
  }
  setTimeout(callback, ms, ...args) {
    if (this.__timeouts == null) {
      this.__timeouts = /* @__PURE__ */ new Set();
    }
    ms = Math.min(ms, this.__maxTimeout);
    const timeoutId = this.__setTimeout(() => {
      if (this.__timeouts) {
        this.__timeouts.delete(timeoutId);
        try {
          callback(...args);
        } catch (e2) {
          if (this.console) {
            this.console.error(e2);
          } else {
            console.error(e2);
          }
        }
      }
    }, ms);
    if (this.__timeouts) {
      this.__timeouts.add(timeoutId);
    }
    return timeoutId;
  }
  get top() {
    return this;
  }
  get window() {
    return this;
  }
  onanimationstart() {
  }
  onanimationend() {
  }
  onanimationiteration() {
  }
  onabort() {
  }
  onauxclick() {
  }
  onbeforecopy() {
  }
  onbeforecut() {
  }
  onbeforepaste() {
  }
  onblur() {
  }
  oncancel() {
  }
  oncanplay() {
  }
  oncanplaythrough() {
  }
  onchange() {
  }
  onclick() {
  }
  onclose() {
  }
  oncontextmenu() {
  }
  oncopy() {
  }
  oncuechange() {
  }
  oncut() {
  }
  ondblclick() {
  }
  ondrag() {
  }
  ondragend() {
  }
  ondragenter() {
  }
  ondragleave() {
  }
  ondragover() {
  }
  ondragstart() {
  }
  ondrop() {
  }
  ondurationchange() {
  }
  onemptied() {
  }
  onended() {
  }
  onerror() {
  }
  onfocus() {
  }
  onfocusin() {
  }
  onfocusout() {
  }
  onformdata() {
  }
  onfullscreenchange() {
  }
  onfullscreenerror() {
  }
  ongotpointercapture() {
  }
  oninput() {
  }
  oninvalid() {
  }
  onkeydown() {
  }
  onkeypress() {
  }
  onkeyup() {
  }
  onload() {
  }
  onloadeddata() {
  }
  onloadedmetadata() {
  }
  onloadstart() {
  }
  onlostpointercapture() {
  }
  onmousedown() {
  }
  onmouseenter() {
  }
  onmouseleave() {
  }
  onmousemove() {
  }
  onmouseout() {
  }
  onmouseover() {
  }
  onmouseup() {
  }
  onmousewheel() {
  }
  onpaste() {
  }
  onpause() {
  }
  onplay() {
  }
  onplaying() {
  }
  onpointercancel() {
  }
  onpointerdown() {
  }
  onpointerenter() {
  }
  onpointerleave() {
  }
  onpointermove() {
  }
  onpointerout() {
  }
  onpointerover() {
  }
  onpointerup() {
  }
  onprogress() {
  }
  onratechange() {
  }
  onreset() {
  }
  onresize() {
  }
  onscroll() {
  }
  onsearch() {
  }
  onseeked() {
  }
  onseeking() {
  }
  onselect() {
  }
  onselectstart() {
  }
  onstalled() {
  }
  onsubmit() {
  }
  onsuspend() {
  }
  ontimeupdate() {
  }
  ontoggle() {
  }
  onvolumechange() {
  }
  onwaiting() {
  }
  onwebkitfullscreenchange() {
  }
  onwebkitfullscreenerror() {
  }
  onwheel() {
  }
}
addGlobalsToWindowPrototype(MockWindow.prototype);
function resetWindowDefaults(win) {
  win.__clearInterval = nativeClearInterval;
  win.__clearTimeout = nativeClearTimeout;
  win.__setInterval = nativeSetInterval;
  win.__setTimeout = nativeSetTimeout;
  win.__maxTimeout = 3e4;
  win.__allowInterval = true;
  win.URL = nativeURL;
}
function cloneWindow(srcWin, opts = {}) {
  if (srcWin == null) {
    return null;
  }
  const clonedWin = new MockWindow(false);
  if (!opts.customElementProxy) {
    srcWin.customElements = null;
  }
  if (srcWin.document != null) {
    const clonedDoc = new MockDocument(false, clonedWin);
    clonedWin.document = clonedDoc;
    clonedDoc.documentElement = srcWin.document.documentElement.cloneNode(true);
  } else {
    clonedWin.document = new MockDocument(null, clonedWin);
  }
  return clonedWin;
}
function cloneDocument(srcDoc) {
  if (srcDoc == null) {
    return null;
  }
  const dstWin = cloneWindow(srcDoc.defaultView);
  return dstWin.document;
}
function constrainTimeouts(win) {
  win.__allowInterval = false;
  win.__maxTimeout = 0;
}
function resetWindow(win) {
  if (win != null) {
    if (win.__timeouts) {
      win.__timeouts.forEach((timeoutId) => {
        nativeClearInterval(timeoutId);
        nativeClearTimeout(timeoutId);
      });
      win.__timeouts.clear();
    }
    if (win.customElements && win.customElements.clear) {
      win.customElements.clear();
    }
    resetDocument(win.document);
    resetPerformance(win.performance);
    for (const key in win) {
      if (win.hasOwnProperty(key) && key !== "document" && key !== "performance" && key !== "customElements") {
        delete win[key];
      }
    }
    resetWindowDefaults(win);
    resetWindowDimensions(win);
    resetEventListeners(win);
    if (win.document != null) {
      try {
        win.document.defaultView = win;
      } catch (e2) {
      }
    }
    win.fetch = null;
    win.Headers = null;
    win.Request = null;
    win.Response = null;
    win.FetchError = null;
  }
}
function resetWindowDimensions(win) {
  try {
    win.devicePixelRatio = 1;
    win.innerHeight = 768;
    win.innerWidth = 1366;
    win.pageXOffset = 0;
    win.pageYOffset = 0;
    win.screenLeft = 0;
    win.screenTop = 0;
    win.screenX = 0;
    win.screenY = 0;
    win.scrollX = 0;
    win.scrollY = 0;
    win.screen = {
      availHeight: win.innerHeight,
      availLeft: 0,
      availTop: 0,
      availWidth: win.innerWidth,
      colorDepth: 24,
      height: win.innerHeight,
      keepAwake: false,
      orientation: {
        angle: 0,
        type: "portrait-primary"
      },
      pixelDepth: 24,
      width: win.innerWidth
    };
  } catch (e2) {
  }
}
class MockDocument extends MockHTMLElement {
  constructor(html = null, win = null) {
    super(null, null);
    this.nodeName = "#document";
    this.nodeType = 9;
    this.defaultView = win;
    this.cookie = "";
    this.referrer = "";
    this.appendChild(this.createDocumentTypeNode());
    if (typeof html === "string") {
      const parsedDoc = parseDocumentUtil(this, html);
      const documentElement = parsedDoc.children.find((elm) => elm.nodeName === "HTML");
      if (documentElement != null) {
        this.appendChild(documentElement);
        setOwnerDocument(documentElement, this);
      }
    } else if (html !== false) {
      const documentElement = new MockHTMLElement(this, "html");
      this.appendChild(documentElement);
      documentElement.appendChild(new MockHTMLElement(this, "head"));
      documentElement.appendChild(new MockHTMLElement(this, "body"));
    }
  }
  get dir() {
    return this.documentElement.dir;
  }
  set dir(value) {
    this.documentElement.dir = value;
  }
  get location() {
    if (this.defaultView != null) {
      return this.defaultView.location;
    }
    return null;
  }
  set location(val) {
    if (this.defaultView != null) {
      this.defaultView.location = val;
    }
  }
  get baseURI() {
    const baseNode = this.head.childNodes.find((node) => node.nodeName === "BASE");
    if (baseNode) {
      return baseNode.href;
    }
    return this.URL;
  }
  get URL() {
    return this.location.href;
  }
  get styleSheets() {
    return this.querySelectorAll("style");
  }
  get scripts() {
    return this.querySelectorAll("script");
  }
  get forms() {
    return this.querySelectorAll("form");
  }
  get images() {
    return this.querySelectorAll("img");
  }
  get scrollingElement() {
    return this.documentElement;
  }
  get documentElement() {
    for (let i = this.childNodes.length - 1; i >= 0; i--) {
      if (this.childNodes[i].nodeName === "HTML") {
        return this.childNodes[i];
      }
    }
    const documentElement = new MockHTMLElement(this, "html");
    this.appendChild(documentElement);
    return documentElement;
  }
  set documentElement(documentElement) {
    for (let i = this.childNodes.length - 1; i >= 0; i--) {
      if (this.childNodes[i].nodeType !== 10) {
        this.childNodes[i].remove();
      }
    }
    if (documentElement != null) {
      this.appendChild(documentElement);
      setOwnerDocument(documentElement, this);
    }
  }
  get head() {
    const documentElement = this.documentElement;
    for (let i = 0; i < documentElement.childNodes.length; i++) {
      if (documentElement.childNodes[i].nodeName === "HEAD") {
        return documentElement.childNodes[i];
      }
    }
    const head = new MockHTMLElement(this, "head");
    documentElement.insertBefore(head, documentElement.firstChild);
    return head;
  }
  set head(head) {
    const documentElement = this.documentElement;
    for (let i = documentElement.childNodes.length - 1; i >= 0; i--) {
      if (documentElement.childNodes[i].nodeName === "HEAD") {
        documentElement.childNodes[i].remove();
      }
    }
    if (head != null) {
      documentElement.insertBefore(head, documentElement.firstChild);
      setOwnerDocument(head, this);
    }
  }
  get body() {
    const documentElement = this.documentElement;
    for (let i = documentElement.childNodes.length - 1; i >= 0; i--) {
      if (documentElement.childNodes[i].nodeName === "BODY") {
        return documentElement.childNodes[i];
      }
    }
    const body = new MockHTMLElement(this, "body");
    documentElement.appendChild(body);
    return body;
  }
  set body(body) {
    const documentElement = this.documentElement;
    for (let i = documentElement.childNodes.length - 1; i >= 0; i--) {
      if (documentElement.childNodes[i].nodeName === "BODY") {
        documentElement.childNodes[i].remove();
      }
    }
    if (body != null) {
      documentElement.appendChild(body);
      setOwnerDocument(body, this);
    }
  }
  appendChild(newNode) {
    newNode.remove();
    newNode.parentNode = this;
    this.childNodes.push(newNode);
    return newNode;
  }
  createComment(data) {
    return new MockComment(this, data);
  }
  createAttribute(attrName) {
    return new MockAttr(attrName.toLowerCase(), "");
  }
  createAttributeNS(namespaceURI, attrName) {
    return new MockAttr(attrName, "", namespaceURI);
  }
  createElement(tagName) {
    if (tagName === "#document") {
      const doc = new MockDocument(false);
      doc.nodeName = tagName;
      doc.parentNode = null;
      return doc;
    }
    return createElement(this, tagName);
  }
  createElementNS(namespaceURI, tagName) {
    const elmNs = createElementNS(this, namespaceURI, tagName);
    return elmNs;
  }
  createTextNode(text) {
    return new MockTextNode(this, text);
  }
  createDocumentFragment() {
    return new MockDocumentFragment(this);
  }
  createDocumentTypeNode() {
    return new MockDocumentTypeNode(this);
  }
  getElementById(id) {
    return getElementById(this, id);
  }
  getElementsByName(elmName) {
    return getElementsByName(this, elmName.toLowerCase());
  }
  get title() {
    const title = this.head.childNodes.find((elm) => elm.nodeName === "TITLE");
    if (title != null && typeof title.textContent === "string") {
      return title.textContent.trim();
    }
    return "";
  }
  set title(value) {
    const head = this.head;
    let title = head.childNodes.find((elm) => elm.nodeName === "TITLE");
    if (title == null) {
      title = this.createElement("title");
      head.appendChild(title);
    }
    title.textContent = value;
  }
}
function createDocument(html = null) {
  return new MockWindow(html).document;
}
function createFragment(html) {
  return parseHtmlToFragment(html, null);
}
function resetDocument(doc) {
  if (doc != null) {
    resetEventListeners(doc);
    const documentElement = doc.documentElement;
    if (documentElement != null) {
      resetElement(documentElement);
      for (let i = 0, ii = documentElement.childNodes.length; i < ii; i++) {
        const childNode = documentElement.childNodes[i];
        resetElement(childNode);
        childNode.childNodes.length = 0;
      }
    }
    for (const key in doc) {
      if (doc.hasOwnProperty(key) && !DOC_KEY_KEEPERS.has(key)) {
        delete doc[key];
      }
    }
    try {
      doc.nodeName = "#document";
    } catch (e2) {
    }
    try {
      doc.nodeType = 9;
    } catch (e2) {
    }
    try {
      doc.cookie = "";
    } catch (e2) {
    }
    try {
      doc.referrer = "";
    } catch (e2) {
    }
  }
}
const DOC_KEY_KEEPERS = /* @__PURE__ */ new Set([
  "nodeName",
  "nodeType",
  "nodeValue",
  "ownerDocument",
  "parentNode",
  "childNodes",
  "_shadowRoot"
]);
function getElementById(elm, id) {
  const children = elm.children;
  for (let i = 0, ii = children.length; i < ii; i++) {
    const childElm = children[i];
    if (childElm.id === id) {
      return childElm;
    }
    const childElmFound = getElementById(childElm, id);
    if (childElmFound != null) {
      return childElmFound;
    }
  }
  return null;
}
function getElementsByName(elm, elmName, foundElms = []) {
  const children = elm.children;
  for (let i = 0, ii = children.length; i < ii; i++) {
    const childElm = children[i];
    if (childElm.name && childElm.name.toLowerCase() === elmName) {
      foundElms.push(childElm);
    }
    getElementsByName(childElm, elmName, foundElms);
  }
  return foundElms;
}
function setOwnerDocument(elm, ownerDocument) {
  for (let i = 0, ii = elm.childNodes.length; i < ii; i++) {
    elm.childNodes[i].ownerDocument = ownerDocument;
    if (elm.childNodes[i].nodeType === 1) {
      setOwnerDocument(elm.childNodes[i], ownerDocument);
    }
  }
}
function hydrateFactory($stencilWindow, $stencilHydrateOpts, $stencilHydrateResults, $stencilAfterHydrate, $stencilHydrateResolve) {
  var globalThis2 = $stencilWindow;
  var self2 = $stencilWindow;
  var top = $stencilWindow;
  var parent = $stencilWindow;
  var addEventListener2 = $stencilWindow.addEventListener.bind($stencilWindow);
  var alert = $stencilWindow.alert.bind($stencilWindow);
  var blur = $stencilWindow.blur.bind($stencilWindow);
  var cancelAnimationFrame = $stencilWindow.cancelAnimationFrame.bind($stencilWindow);
  var cancelIdleCallback = $stencilWindow.cancelIdleCallback.bind($stencilWindow);
  var clearInterval2 = $stencilWindow.clearInterval.bind($stencilWindow);
  var clearTimeout2 = $stencilWindow.clearTimeout.bind($stencilWindow);
  var close = () => {
  };
  var confirm = $stencilWindow.confirm.bind($stencilWindow);
  var dispatchEvent2 = $stencilWindow.dispatchEvent.bind($stencilWindow);
  var focus = $stencilWindow.focus.bind($stencilWindow);
  var getComputedStyle = $stencilWindow.getComputedStyle.bind($stencilWindow);
  var matchMedia = $stencilWindow.matchMedia.bind($stencilWindow);
  var open = $stencilWindow.open.bind($stencilWindow);
  var prompt = $stencilWindow.prompt.bind($stencilWindow);
  var removeEventListener2 = $stencilWindow.removeEventListener.bind($stencilWindow);
  var requestAnimationFrame = $stencilWindow.requestAnimationFrame.bind($stencilWindow);
  var requestIdleCallback = $stencilWindow.requestIdleCallback.bind($stencilWindow);
  var setInterval2 = $stencilWindow.setInterval.bind($stencilWindow);
  var setTimeout2 = $stencilWindow.setTimeout.bind($stencilWindow);
  var CharacterData = $stencilWindow.CharacterData;
  var CSS = $stencilWindow.CSS;
  var CustomEvent = $stencilWindow.CustomEvent;
  var Document = $stencilWindow.Document;
  var DocumentFragment = $stencilWindow.DocumentFragment;
  var DocumentType = $stencilWindow.DocumentType;
  var DOMTokenList = $stencilWindow.DOMTokenList;
  var Element = $stencilWindow.Element;
  var Event = $stencilWindow.Event;
  var HTMLAnchorElement = $stencilWindow.HTMLAnchorElement;
  var HTMLBaseElement = $stencilWindow.HTMLBaseElement;
  var HTMLButtonElement = $stencilWindow.HTMLButtonElement;
  var HTMLCanvasElement = $stencilWindow.HTMLCanvasElement;
  var HTMLElement = $stencilWindow.HTMLElement;
  var HTMLFormElement = $stencilWindow.HTMLFormElement;
  var HTMLImageElement = $stencilWindow.HTMLImageElement;
  var HTMLInputElement = $stencilWindow.HTMLInputElement;
  var HTMLLinkElement = $stencilWindow.HTMLLinkElement;
  var HTMLMetaElement = $stencilWindow.HTMLMetaElement;
  var HTMLScriptElement = $stencilWindow.HTMLScriptElement;
  var HTMLStyleElement = $stencilWindow.HTMLStyleElement;
  var HTMLTemplateElement = $stencilWindow.HTMLTemplateElement;
  var HTMLTitleElement = $stencilWindow.HTMLTitleElement;
  var IntersectionObserver = $stencilWindow.IntersectionObserver;
  var KeyboardEvent = $stencilWindow.KeyboardEvent;
  var MouseEvent = $stencilWindow.MouseEvent;
  var Node = $stencilWindow.Node;
  var NodeList = $stencilWindow.NodeList;
  var URL2 = $stencilWindow.URL;
  var console2 = $stencilWindow.console;
  var customElements = $stencilWindow.customElements;
  var history = $stencilWindow.history;
  var localStorage = $stencilWindow.localStorage;
  var location2 = $stencilWindow.location;
  var navigator = $stencilWindow.navigator;
  var performance = $stencilWindow.performance;
  var sessionStorage = $stencilWindow.sessionStorage;
  var devicePixelRatio = $stencilWindow.devicePixelRatio;
  var innerHeight = $stencilWindow.innerHeight;
  var innerWidth = $stencilWindow.innerWidth;
  var origin = $stencilWindow.origin;
  var pageXOffset = $stencilWindow.pageXOffset;
  var pageYOffset = $stencilWindow.pageYOffset;
  var screen = $stencilWindow.screen;
  var screenLeft = $stencilWindow.screenLeft;
  var screenTop = $stencilWindow.screenTop;
  var screenX = $stencilWindow.screenX;
  var screenY = $stencilWindow.screenY;
  var scrollX = $stencilWindow.scrollX;
  var scrollY = $stencilWindow.scrollY;
  var exports2 = {};
  var fetch2, FetchError, Headers, Request, Response;
  if (typeof $stencilWindow.fetch === "function") {
    fetch2 = $stencilWindow.fetch;
  } else {
    fetch2 = $stencilWindow.fetch = function() {
      throw new Error("fetch() is not implemented");
    };
  }
  if (typeof $stencilWindow.FetchError === "function") {
    FetchError = $stencilWindow.FetchError;
  } else {
    FetchError = $stencilWindow.FetchError = class FetchError {
      constructor() {
        throw new Error("FetchError is not implemented");
      }
    };
  }
  if (typeof $stencilWindow.Headers === "function") {
    Headers = $stencilWindow.Headers;
  } else {
    Headers = $stencilWindow.Headers = class Headers {
      constructor() {
        throw new Error("Headers is not implemented");
      }
    };
  }
  if (typeof $stencilWindow.Request === "function") {
    Request = $stencilWindow.Request;
  } else {
    Request = $stencilWindow.Request = class Request {
      constructor() {
        throw new Error("Request is not implemented");
      }
    };
  }
  if (typeof $stencilWindow.Response === "function") {
    Response = $stencilWindow.Response;
  } else {
    Response = $stencilWindow.Response = class Response {
      constructor() {
        throw new Error("Response is not implemented");
      }
    };
  }
  function hydrateAppClosure($stencilWindow2) {
    const window2 = $stencilWindow2;
    const document = $stencilWindow2.document;
    const NAMESPACE = "abc-web-components";
    const BUILD = (
      /* abc-web-components */
      { allRenderFn: true, appendChildSlotFix: false, asyncLoading: true, attachStyles: true, cloneNodeFix: false, cmpDidLoad: true, cmpDidRender: false, cmpDidUnload: false, cmpDidUpdate: false, cmpShouldUpdate: false, cmpWillLoad: false, cmpWillRender: true, cmpWillUpdate: true, connectedCallback: false, constructableCSS: false, cssAnnotations: true, devTools: false, disconnectedCallback: false, element: false, event: true, experimentalSlotFixes: false, formAssociated: false, hasRenderFn: true, hostListener: true, hostListenerTarget: true, hostListenerTargetBody: false, hostListenerTargetDocument: false, hostListenerTargetParent: false, hostListenerTargetWindow: true, hotModuleReplacement: false, hydrateClientSide: true, hydrateServerSide: true, hydratedAttribute: false, hydratedClass: true, isDebug: false, isDev: false, isTesting: false, lazyLoad: true, lifecycle: true, lifecycleDOMEvents: false, member: true, method: true, mode: false, observeAttribute: true, profile: false, prop: true, propBoolean: true, propMutable: false, propNumber: false, propString: true, reflect: true, scoped: false, scriptDataOpts: false, shadowDelegatesFocus: false, shadowDom: true, shadowDomShim: true, slot: true, slotChildNodesFix: false, slotRelocation: true, state: true, style: true, svg: true, taskQueue: true, updatable: true, vdomAttribute: true, vdomClass: true, vdomFunctional: false, vdomKey: false, vdomListener: true, vdomPropOrAttr: true, vdomRef: true, vdomRender: true, vdomStyle: false, vdomText: true, vdomXlink: false, watchCallback: true }
    );
    function queryNonceMetaTagContent(e2) {
      var t, o, n;
      return null !== (n = null === (o = null === (t = e2.head) || void 0 === t ? void 0 : t.querySelector('meta[name="csp-nonce"]')) || void 0 === o ? void 0 : o.getAttribute("content")) && void 0 !== n ? n : void 0;
    }
    function componentOnReady() {
      return getHostRef(this).$onReadyPromise$;
    }
    function forceUpdate() {
    }
    function hydrateApp(e2, t, o, n, s) {
      function l() {
        if (global.clearTimeout(p), i.clear(), r.clear(), !h2) {
          h2 = true;
          try {
            t.clientHydrateAnnotations && insertVdomAnnotations(e2.document, t.staticComponents), e2.dispatchEvent(new e2.Event("DOMContentLoaded")), e2.document.createElement = c, e2.document.createElementNS = $;
          } catch (e3) {
            renderCatchError2(t, o, e3);
          }
        }
        n(e2, t, o, s);
      }
      function a(e3) {
        renderCatchError2(t, o, e3), l();
      }
      const r = /* @__PURE__ */ new Set(), i = /* @__PURE__ */ new Set(), d = /* @__PURE__ */ new Set(), c = e2.document.createElement, $ = e2.document.createElementNS, m = Promise.resolve();
      let p, h2 = false;
      try {
        let u = function() {
          return L(this);
        }, f = function(e3) {
          if (isValidComponent(e3, t) && !getHostRef(e3)) {
            const t2 = loadModule({
              $tagName$: e3.nodeName.toLowerCase(),
              $flags$: null
            });
            null != t2 && null != t2.cmpMeta && (i.add(e3), e3.connectedCallback = u, registerHost(e3, t2.cmpMeta), function o2(e4, t3) {
              if ("function" != typeof e4.componentOnReady && (e4.componentOnReady = componentOnReady), "function" != typeof e4.forceUpdate && (e4.forceUpdate = forceUpdate), 1 & t3.$flags$ && (e4.shadowRoot = e4), null != t3.$members$) {
                const o3 = getHostRef(e4);
                Object.entries(t3.$members$).forEach(([n2, s2]) => {
                  const l2 = s2[0];
                  if (31 & l2) {
                    const a2 = s2[1] || n2, r2 = e4.getAttribute(a2);
                    if (null != r2) {
                      const e5 = parsePropertyValue(r2, l2);
                      o3.$instanceValues$.set(n2, e5);
                    }
                    const i2 = e4[n2];
                    void 0 !== i2 && (o3.$instanceValues$.set(n2, i2), delete e4[n2]), Object.defineProperty(e4, n2, {
                      get() {
                        return getValue(this, n2);
                      },
                      set(e5) {
                        setValue(this, n2, e5, t3);
                      },
                      configurable: true,
                      enumerable: true
                    });
                  } else
                    64 & l2 && Object.defineProperty(e4, n2, {
                      value(...e5) {
                        const t4 = getHostRef(this);
                        return t4.$onInstancePromise$.then(() => t4.$lazyInstance$[n2](...e5)).catch(consoleError);
                      }
                    });
                });
              }
            }(e3, t2.cmpMeta));
          }
        }, g = function(e3) {
          if (null != e3 && 1 === e3.nodeType) {
            f(e3);
            const t2 = e3.children;
            for (let e4 = 0, o2 = t2.length; e4 < o2; e4++)
              g(t2[e4]);
          }
        }, L = function(n2) {
          return i.delete(n2), isValidComponent(n2, t) && o.hydratedCount < t.maxHydrateCount && !r.has(n2) && shouldHydrate(n2) ? (r.add(n2), async function s2(e3, t2, o2, n3, l2) {
            o2 = o2.toLowerCase();
            const a2 = loadModule({
              $tagName$: o2,
              $flags$: null
            });
            if (null != a2 && null != a2.cmpMeta) {
              l2.add(n3);
              try {
                connectedCallback(n3), await n3.componentOnReady(), t2.hydratedCount++;
                const e4 = getHostRef(n3), s3 = e4.$modeName$ ? e4.$modeName$ : "$";
                t2.components.some((e5) => e5.tag === o2 && e5.mode === s3) || t2.components.push({
                  tag: o2,
                  mode: s3,
                  count: 0,
                  depth: -1
                });
              } catch (t3) {
                e3.console.error(t3);
              }
              l2.delete(n3);
            }
          }(e2, o, n2.nodeName, n2, d)) : m;
        }, y = function() {
          const e3 = Array.from(i).filter((e4) => e4.parentElement);
          return e3.length > 0 ? Promise.all(e3.map(L)).then(y) : m;
        };
        e2.document.createElement = function t2(o2) {
          const n2 = c.call(e2.document, o2);
          return f(n2), n2;
        }, e2.document.createElementNS = function t2(o2, n2) {
          const s2 = $.call(e2.document, o2, n2);
          return f(s2), s2;
        }, p = global.setTimeout(function I() {
          a(`Hydrate exceeded timeout${function e3(t2) {
            return Array.from(t2).map(waitingOnElementMsg);
          }(d)}`);
        }, t.timeout), plt.$resourcesUrl$ = new URL2(t.resourcesUrl || "./", doc.baseURI).href, g(e2.document.body), y().then(l).catch(a);
      } catch (D) {
        a(D);
      }
    }
    function isValidComponent(e2, t) {
      if (null != e2 && 1 === e2.nodeType) {
        const o = e2.nodeName;
        if ("string" == typeof o && o.includes("-"))
          return !t.excludeComponents.includes(o.toLowerCase());
      }
      return false;
    }
    function shouldHydrate(e2) {
      if (9 === e2.nodeType)
        return true;
      if (NO_HYDRATE_TAGS.has(e2.nodeName))
        return false;
      if (e2.hasAttribute("no-prerender"))
        return false;
      const t = e2.parentNode;
      return null == t || shouldHydrate(t);
    }
    function renderCatchError2(e2, t, o) {
      const n = {
        level: "error",
        type: "build",
        header: "Hydrate Error",
        messageText: "",
        relFilePath: void 0,
        absFilePath: void 0,
        lines: []
      };
      if (e2.url)
        try {
          const t2 = new URL2(e2.url);
          "/" !== t2.pathname && (n.header += ": " + t2.pathname);
        } catch (e3) {
        }
      null != o && (null != o.stack ? n.messageText = o.stack.toString() : null != o.message ? n.messageText = o.message.toString() : n.messageText = o.toString()), t.diagnostics.push(n);
    }
    function printTag(e2) {
      let t = `<${e2.nodeName.toLowerCase()}`;
      if (Array.isArray(e2.attributes))
        for (let o = 0; o < e2.attributes.length; o++) {
          const n = e2.attributes[o];
          t += ` ${n.name}`, "" !== n.value && (t += `="${n.value}"`);
        }
      return t += ">", t;
    }
    function waitingOnElementMsg(e2) {
      let t = "";
      if (e2) {
        const o = [];
        t = " - waiting on:";
        let n = e2;
        for (; n && 9 !== n.nodeType && "BODY" !== n.nodeName; )
          o.unshift(printTag(n)), n = n.parentElement;
        let s = "";
        for (const e3 of o)
          s += "  ", t += `
${s}${e3}`;
      }
      return t;
    }
    const createTime = (e2, t = "") => {
      return () => {
      };
    }, SLOT_FB_CSS = "slot-fb{display:contents}slot-fb[hidden]{display:none}", EMPTY_OBJ = {}, isComplexType = (e2) => "object" == (e2 = typeof e2) || "function" === e2, isPromise2 = (e2) => !!e2 && ("object" == typeof e2 || "function" == typeof e2) && "function" == typeof e2.then, h = (e2, t, ...o) => {
      let n = null, l = null, a = false, r = false;
      const i = [], d = (t2) => {
        for (let o2 = 0; o2 < t2.length; o2++)
          n = t2[o2], Array.isArray(n) ? d(n) : null != n && "boolean" != typeof n && ((a = "function" != typeof e2 && !isComplexType(n)) ? n = String(n) : BUILD.isDev, a && r ? i[i.length - 1].$text$ += n : i.push(a ? newVNode(null, n) : n), r = a);
      };
      if (d(o), t && (t.name && (l = t.name), BUILD.vdomClass)) {
        const e3 = t.className || t.class;
        e3 && (t.class = "object" != typeof e3 ? e3 : Object.keys(e3).filter((t2) => e3[t2]).join(" "));
      }
      const c = newVNode(e2, null);
      return c.$attrs$ = t, i.length > 0 && (c.$children$ = i), c.$name$ = l, c;
    }, newVNode = (e2, t) => {
      const o = {
        $flags$: 0,
        $tag$: e2,
        $text$: t,
        $elm$: null,
        $children$: null
      };
      return o.$attrs$ = null, o.$name$ = null, o;
    }, Host = {}, isHost = (e2) => e2 && e2.$tag$ === Host, clientHydrate = (e2, t, o, n, s, l, a) => {
      let r, i, d, c;
      if (1 === l.nodeType) {
        for (r = l.getAttribute("c-id"), r && (i = r.split("."), i[0] !== a && "0" !== i[0] || (d = {
          $flags$: 0,
          $hostId$: i[0],
          $nodeId$: i[1],
          $depth$: i[2],
          $index$: i[3],
          $tag$: l.tagName.toLowerCase(),
          $elm$: l,
          $attrs$: null,
          $children$: null,
          $key$: null,
          $name$: null,
          $text$: null
        }, t.push(d), l.removeAttribute("c-id"), e2.$children$ || (e2.$children$ = []), e2.$children$[d.$index$] = d, e2 = d, n && "0" === d.$depth$ && (n[d.$index$] = d.$elm$))), c = l.childNodes.length - 1; c >= 0; c--)
          clientHydrate(e2, t, o, n, s, l.childNodes[c], a);
        if (l.shadowRoot)
          for (c = l.shadowRoot.childNodes.length - 1; c >= 0; c--)
            clientHydrate(e2, t, o, n, s, l.shadowRoot.childNodes[c], a);
      } else if (8 === l.nodeType)
        i = l.nodeValue.split("."), i[1] !== a && "0" !== i[1] || (r = i[0], d = {
          $flags$: 0,
          $hostId$: i[1],
          $nodeId$: i[2],
          $depth$: i[3],
          $index$: i[4],
          $elm$: l,
          $attrs$: null,
          $children$: null,
          $key$: null,
          $name$: null,
          $tag$: null,
          $text$: null
        }, "t" === r ? (d.$elm$ = l.nextSibling, d.$elm$ && 3 === d.$elm$.nodeType && (d.$text$ = d.$elm$.textContent, t.push(d), l.remove(), e2.$children$ || (e2.$children$ = []), e2.$children$[d.$index$] = d, n && "0" === d.$depth$ && (n[d.$index$] = d.$elm$))) : d.$hostId$ === a && ("s" === r ? (d.$tag$ = "slot", i[5] ? l["s-sn"] = d.$name$ = i[5] : l["s-sn"] = "", l["s-sr"] = true, n && (d.$elm$ = doc.createElement(d.$tag$), d.$name$ && d.$elm$.setAttribute("name", d.$name$), l.parentNode.insertBefore(d.$elm$, l), l.remove(), "0" === d.$depth$ && (n[d.$index$] = d.$elm$)), o.push(d), e2.$children$ || (e2.$children$ = []), e2.$children$[d.$index$] = d) : "r" === r && (n ? l.remove() : (s["s-cr"] = l, l["s-cn"] = true))));
      else if (e2 && "style" === e2.$tag$) {
        const t2 = newVNode(null, l.textContent);
        t2.$elm$ = l, t2.$index$ = "0", e2.$children$ = [t2];
      }
    }, initializeDocumentHydrate = (e2, t) => {
      if (1 === e2.nodeType) {
        let o = 0;
        for (; o < e2.childNodes.length; o++)
          initializeDocumentHydrate(e2.childNodes[o], t);
        if (e2.shadowRoot)
          for (o = 0; o < e2.shadowRoot.childNodes.length; o++)
            initializeDocumentHydrate(e2.shadowRoot.childNodes[o], t);
      } else if (8 === e2.nodeType) {
        const o = e2.nodeValue.split(".");
        "o" === o[0] && (t.set(o[1] + "." + o[2], e2), e2.nodeValue = "", e2["s-en"] = o[3]);
      }
    }, parsePropertyValue = (e2, t) => null == e2 || isComplexType(e2) ? e2 : 4 & t ? "false" !== e2 && ("" === e2 || !!e2) : 1 & t ? String(e2) : e2, getElement = (e2) => getHostRef(e2).$hostElement$, createEvent = (e2, t, o) => {
      const n = getElement(e2);
      return {
        emit: (e3) => emitEvent(n, t, {
          bubbles: !!(4 & o),
          composed: !!(2 & o),
          cancelable: !!(1 & o),
          detail: e3
        })
      };
    }, emitEvent = (e2, t, o) => {
      const n = plt.ce(t, o);
      return e2.dispatchEvent(n), n;
    }, rootAppliedStyles = /* @__PURE__ */ new WeakMap(), registerStyle = (e2, t, o) => {
      let n = styles.get(e2);
      n = t, styles.set(e2, n);
    }, addStyle = (e2, t, o) => {
      var n;
      const s = getScopeId(t), l = styles.get(s);
      if (e2 = 11 === e2.nodeType ? e2 : doc, l) {
        if ("string" == typeof l) {
          e2 = e2.head || e2;
          let o2, a = rootAppliedStyles.get(e2);
          if (a || rootAppliedStyles.set(e2, a = /* @__PURE__ */ new Set()), !a.has(s)) {
            if (e2.host && (o2 = e2.querySelector(`[sty-id="${s}"]`)))
              o2.innerHTML = l;
            else {
              o2 = doc.createElement("style"), o2.innerHTML = l;
              const t2 = null !== (n = plt.$nonce$) && void 0 !== n ? n : queryNonceMetaTagContent(doc);
              null != t2 && o2.setAttribute("nonce", t2), o2.setAttribute("sty-id", s), e2.insertBefore(o2, e2.querySelector("link"));
            }
            4 & t.$flags$ && (o2.innerHTML += SLOT_FB_CSS), a && a.add(s);
          }
        }
      }
      return s;
    }, attachStyles = (e2) => {
      const t = e2.$cmpMeta$, o = e2.$hostElement$, n = t.$flags$, s = createTime("attachStyles", t.$tagName$), l = addStyle(o.getRootNode(), t);
      10 & n && (o["s-sc"] = l, o.classList.add(l + "-h"), BUILD.scoped), s();
    }, getScopeId = (e2, t) => "sc-" + e2.$tagName$, setAccessor = (e2, t, o, n, s, l) => {
      if (o !== n) {
        let a = isMemberInElement(e2, t), r = t.toLowerCase();
        if ("class" === t) {
          const t2 = e2.classList, s2 = parseClassList(o), l2 = parseClassList(n);
          t2.remove(...s2.filter((e3) => e3 && !l2.includes(e3))), t2.add(...l2.filter((e3) => e3 && !s2.includes(e3)));
        } else if ("ref" === t)
          n && n(e2);
        else if (a || "o" !== t[0] || "n" !== t[1]) {
          {
            const i = isComplexType(n);
            if ((a || i && null !== n) && !s)
              try {
                if (e2.tagName.includes("-"))
                  e2[t] = n;
                else {
                  const s2 = null == n ? "" : n;
                  "list" === t ? a = false : null != o && e2[t] == s2 || (e2[t] = s2);
                }
              } catch (e3) {
              }
            null == n || false === n ? false === n && "" !== e2.getAttribute(t) || e2.removeAttribute(t) : (!a || 4 & l || s) && !i && (n = true === n ? "" : n, e2.setAttribute(t, n));
          }
        } else if (t = "-" === t[2] ? t.slice(3) : isMemberInElement(win, r) ? r.slice(2) : r[2] + t.slice(3), o || n) {
          const s2 = t.endsWith(CAPTURE_EVENT_SUFFIX);
          t = t.replace(CAPTURE_EVENT_REGEX, ""), o && plt.rel(e2, t, o, s2), n && plt.ael(e2, t, n, s2);
        }
      }
    }, parseClassListRegex = /\s/, parseClassList = (e2) => e2 ? e2.split(parseClassListRegex) : [], CAPTURE_EVENT_SUFFIX = "Capture", CAPTURE_EVENT_REGEX = new RegExp(CAPTURE_EVENT_SUFFIX + "$"), updateElement = (e2, t, o, n) => {
      const s = 11 === t.$elm$.nodeType && t.$elm$.host ? t.$elm$.host : t.$elm$, l = e2 && e2.$attrs$ || EMPTY_OBJ, a = t.$attrs$ || EMPTY_OBJ;
      for (n in l)
        n in a || setAccessor(s, n, l[n], void 0, o, t.$flags$);
      for (n in a)
        setAccessor(s, n, l[n], a[n], o, t.$flags$);
    };
    let scopeId, contentRef, hostTagName, useNativeShadowDom = false, checkSlotFallbackVisibility = false, checkSlotRelocate = false, isSvgMode = false;
    const createElm = (e2, t, o, n) => {
      var s;
      const l = t.$children$[o];
      let a, r, i, d = 0;
      if (!useNativeShadowDom && (checkSlotRelocate = true, "slot" === l.$tag$ && (scopeId && n.classList.add(scopeId + "-s"), l.$flags$ |= l.$children$ ? 2 : 1)), null !== l.$text$)
        a = l.$elm$ = doc.createTextNode(l.$text$);
      else if (1 & l.$flags$)
        a = l.$elm$ = slotReferenceDebugNode(l);
      else {
        if (!isSvgMode && (isSvgMode = "svg" === l.$tag$), a = l.$elm$ = doc.createElementNS(isSvgMode ? "http://www.w3.org/2000/svg" : "http://www.w3.org/1999/xhtml", 2 & l.$flags$ ? "slot-fb" : l.$tag$), isSvgMode && "foreignObject" === l.$tag$ && (isSvgMode = false), updateElement(null, l, isSvgMode), null != scopeId && a["s-si"] !== scopeId && a.classList.add(a["s-si"] = scopeId), l.$children$)
          for (d = 0; d < l.$children$.length; ++d)
            r = createElm(e2, l, d, a), r && a.appendChild(r);
        "svg" === l.$tag$ ? isSvgMode = false : "foreignObject" === a.tagName && (isSvgMode = true);
      }
      return a["s-hn"] = hostTagName, 3 & l.$flags$ && (a["s-sr"] = true, a["s-fs"] = null === (s = l.$attrs$) || void 0 === s ? void 0 : s.slot, a["s-cr"] = contentRef, a["s-sn"] = l.$name$ || "", i = e2 && e2.$children$ && e2.$children$[o], i && i.$tag$ === l.$tag$ && e2.$elm$ && putBackInOriginalLocation(e2.$elm$, false)), a;
    }, putBackInOriginalLocation = (e2, t) => {
      var o;
      plt.$flags$ |= 1;
      const n = e2.childNodes;
      for (let e3 = n.length - 1; e3 >= 0; e3--) {
        const s = n[e3];
        s["s-hn"] !== hostTagName && s["s-ol"] && (parentReferenceNode(s).insertBefore(s, referenceNode(s)), s["s-ol"].remove(), s["s-ol"] = void 0, s["s-sh"] = void 0, 1 === s.nodeType && s.setAttribute("slot", null !== (o = s["s-sn"]) && void 0 !== o ? o : ""), checkSlotRelocate = true), t && putBackInOriginalLocation(s, t);
      }
      plt.$flags$ &= -2;
    }, addVnodes = (e2, t, o, n, s, l) => {
      let a, r = e2["s-cr"] && e2["s-cr"].parentNode || e2;
      for (r.shadowRoot && r.tagName === hostTagName && (r = r.shadowRoot); s <= l; ++s)
        n[s] && (a = createElm(null, o, s, e2), a && (n[s].$elm$ = a, r.insertBefore(a, referenceNode(t))));
    }, removeVnodes = (e2, t, o) => {
      for (let n = t; n <= o; ++n) {
        const t2 = e2[n];
        if (t2) {
          const e3 = t2.$elm$;
          nullifyVNodeRefs(t2), e3 && (checkSlotFallbackVisibility = true, e3["s-ol"] ? e3["s-ol"].remove() : putBackInOriginalLocation(e3, true), e3.remove());
        }
      }
    }, isSameVnode = (e2, t) => e2.$tag$ === t.$tag$ && ("slot" === e2.$tag$ ? e2.$name$ === t.$name$ : !BUILD.vdomKey), referenceNode = (e2) => e2 && e2["s-ol"] || e2, parentReferenceNode = (e2) => (e2["s-ol"] ? e2["s-ol"] : e2).parentNode, patch = (e2, t) => {
      const o = t.$elm$ = e2.$elm$, n = e2.$children$, s = t.$children$, l = t.$tag$, a = t.$text$;
      let r;
      null !== a ? (r = o["s-cr"]) ? r.parentNode.textContent = a : e2.$text$ !== a && (o.data = a) : (isSvgMode = "svg" === l || "foreignObject" !== l && isSvgMode, "slot" === l || updateElement(e2, t, isSvgMode), null !== n && null !== s ? ((e3, t2, o2, n2) => {
        let s2, a2 = 0, r2 = 0, c = t2.length - 1, $ = t2[0], m = t2[c], p = n2.length - 1, h2 = n2[0], u = n2[p];
        for (; a2 <= c && r2 <= p; )
          if (null == $)
            $ = t2[++a2];
          else if (null == m)
            m = t2[--c];
          else if (null == h2)
            h2 = n2[++r2];
          else if (null == u)
            u = n2[--p];
          else if (isSameVnode($, h2))
            patch($, h2), $ = t2[++a2], h2 = n2[++r2];
          else if (isSameVnode(m, u))
            patch(m, u), m = t2[--c], u = n2[--p];
          else if (isSameVnode($, u))
            "slot" !== $.$tag$ && "slot" !== u.$tag$ || putBackInOriginalLocation($.$elm$.parentNode, false), patch($, u), e3.insertBefore($.$elm$, m.$elm$.nextSibling), $ = t2[++a2], u = n2[--p];
          else if (isSameVnode(m, h2))
            "slot" !== $.$tag$ && "slot" !== u.$tag$ || putBackInOriginalLocation(m.$elm$.parentNode, false), patch(m, h2), e3.insertBefore(m.$elm$, $.$elm$), m = t2[--c], h2 = n2[++r2];
          else {
            s2 = createElm(t2 && t2[r2], o2, r2, e3), h2 = n2[++r2], s2 && parentReferenceNode($.$elm$).insertBefore(s2, referenceNode($.$elm$));
          }
        a2 > c ? addVnodes(e3, null == n2[p + 1] ? null : n2[p + 1].$elm$, o2, n2, r2, p) : r2 > p && removeVnodes(t2, a2, c);
      })(o, n, t, s) : null !== s ? (null !== e2.$text$ && (o.textContent = ""), addVnodes(o, null, t, s, 0, s.length - 1)) : null !== n && removeVnodes(n, 0, n.length - 1), isSvgMode && "svg" === l && (isSvgMode = false));
    }, updateFallbackSlotVisibility = (e2) => {
      const t = e2.childNodes;
      for (const e3 of t)
        if (1 === e3.nodeType) {
          if (e3["s-sr"]) {
            const o = e3["s-sn"];
            e3.hidden = false;
            for (const n of t)
              if (n !== e3) {
                if (n["s-hn"] !== e3["s-hn"] || "" !== o) {
                  if (1 === n.nodeType && (o === n.getAttribute("slot") || o === n["s-sn"])) {
                    e3.hidden = true;
                    break;
                  }
                } else if (1 === n.nodeType || 3 === n.nodeType && "" !== n.textContent.trim()) {
                  e3.hidden = true;
                  break;
                }
              }
          }
          updateFallbackSlotVisibility(e3);
        }
    }, relocateNodes = [], markSlotContentForRelocation = (e2) => {
      let t, o, n;
      for (const s of e2.childNodes) {
        if (s["s-sr"] && (t = s["s-cr"]) && t.parentNode) {
          o = t.parentNode.childNodes;
          const e3 = s["s-sn"];
          for (n = o.length - 1; n >= 0; n--)
            if (t = o[n], !(t["s-cn"] || t["s-nr"] || t["s-hn"] === s["s-hn"] || BUILD.experimentalSlotFixes))
              if (isNodeLocatedInSlot(t, e3)) {
                let o2 = relocateNodes.find((e4) => e4.$nodeToRelocate$ === t);
                checkSlotFallbackVisibility = true, t["s-sn"] = t["s-sn"] || e3, o2 ? (o2.$nodeToRelocate$["s-sh"] = s["s-hn"], o2.$slotRefNode$ = s) : (t["s-sh"] = s["s-hn"], relocateNodes.push({
                  $slotRefNode$: s,
                  $nodeToRelocate$: t
                })), t["s-sr"] && relocateNodes.map((e4) => {
                  isNodeLocatedInSlot(e4.$nodeToRelocate$, t["s-sn"]) && (o2 = relocateNodes.find((e5) => e5.$nodeToRelocate$ === t), o2 && !e4.$slotRefNode$ && (e4.$slotRefNode$ = o2.$slotRefNode$));
                });
              } else
                relocateNodes.some((e4) => e4.$nodeToRelocate$ === t) || relocateNodes.push({
                  $nodeToRelocate$: t
                });
        }
        1 === s.nodeType && markSlotContentForRelocation(s);
      }
    }, isNodeLocatedInSlot = (e2, t) => 1 === e2.nodeType ? null === e2.getAttribute("slot") && "" === t || e2.getAttribute("slot") === t : e2["s-sn"] === t || "" === t, nullifyVNodeRefs = (e2) => {
      e2.$attrs$ && e2.$attrs$.ref && e2.$attrs$.ref(null), e2.$children$ && e2.$children$.map(nullifyVNodeRefs);
    }, renderVdom = (e2, t, o = false) => {
      var n, s;
      const l = e2.$hostElement$, a = e2.$cmpMeta$, r = e2.$vnode$ || newVNode(null, null), i = isHost(t) ? t : h(null, null, t);
      if (hostTagName = l.tagName, BUILD.isDev)
        ;
      if (a.$attrsToReflect$ && (i.$attrs$ = i.$attrs$ || {}, a.$attrsToReflect$.map(([e3, t2]) => i.$attrs$[t2] = l[e3])), o && i.$attrs$)
        for (const e3 of Object.keys(i.$attrs$))
          l.hasAttribute(e3) && !["key", "ref", "style", "class"].includes(e3) && (i.$attrs$[e3] = l[e3]);
      if (i.$tag$ = null, i.$flags$ |= 4, e2.$vnode$ = i, i.$elm$ = r.$elm$ = l.shadowRoot || l, scopeId = l["s-sc"], contentRef = l["s-cr"], useNativeShadowDom = supportsShadow, checkSlotFallbackVisibility = false, patch(r, i), BUILD.slotRelocation) {
        if (plt.$flags$ |= 1, checkSlotRelocate) {
          markSlotContentForRelocation(i.$elm$);
          for (const e3 of relocateNodes) {
            const t2 = e3.$nodeToRelocate$;
            if (!t2["s-ol"]) {
              const e4 = originalLocationDebugNode(t2);
              e4["s-nr"] = t2, t2.parentNode.insertBefore(t2["s-ol"] = e4, t2);
            }
          }
          for (const e3 of relocateNodes) {
            const t2 = e3.$nodeToRelocate$, o2 = e3.$slotRefNode$;
            if (o2) {
              const e4 = o2.parentNode;
              let l2 = o2.nextSibling;
              {
                let o3 = null === (n = t2["s-ol"]) || void 0 === n ? void 0 : n.previousSibling;
                for (; o3; ) {
                  let n2 = null !== (s = o3["s-nr"]) && void 0 !== s ? s : null;
                  if (n2 && n2["s-sn"] === t2["s-sn"] && e4 === n2.parentNode && (n2 = n2.nextSibling, !n2 || !n2["s-nr"])) {
                    l2 = n2;
                    break;
                  }
                  o3 = o3.previousSibling;
                }
              }
              (!l2 && e4 !== t2.parentNode || t2.nextSibling !== l2) && t2 !== l2 && (!t2["s-hn"] && t2["s-ol"] && (t2["s-hn"] = t2["s-ol"].parentNode.nodeName), e4.insertBefore(t2, l2));
            } else
              1 === t2.nodeType && (t2.hidden = true);
          }
        }
        checkSlotFallbackVisibility && updateFallbackSlotVisibility(i.$elm$), plt.$flags$ &= -2, relocateNodes.length = 0;
      }
    }, slotReferenceDebugNode = (e2) => doc.createComment(`<slot${e2.$name$ ? ' name="' + e2.$name$ + '"' : ""}> (host=${hostTagName.toLowerCase()})`), originalLocationDebugNode = (e2) => doc.createComment("org-location for " + (e2.localName ? `<${e2.localName}> (host=${e2["s-hn"]})` : `[${e2.textContent}]`)), attachToAncestor = (e2, t) => {
      t && !e2.$onRenderResolve$ && t["s-p"] && t["s-p"].push(new Promise((t2) => e2.$onRenderResolve$ = t2));
    }, scheduleUpdate = (e2, t) => {
      if (e2.$flags$ |= 16, 4 & e2.$flags$)
        return void (e2.$flags$ |= 512);
      attachToAncestor(e2, e2.$ancestorComponent$);
      const o = () => dispatchHooks(e2, t);
      return writeTask(o);
    }, dispatchHooks = (e2, t) => {
      const n = createTime("scheduleUpdate", e2.$cmpMeta$.$tagName$), s = e2.$lazyInstance$;
      let l;
      return t ? (e2.$flags$ |= 256, e2.$queuedListeners$ && (e2.$queuedListeners$.map(([e3, t2]) => safeCall(s, e3, t2)), e2.$queuedListeners$ = void 0), BUILD.cmpWillLoad) : l = safeCall(s, "componentWillUpdate"), l = enqueue(l, () => safeCall(s, "componentWillRender")), n(), enqueue(l, () => updateComponent(e2, s, t));
    }, enqueue = (e2, t) => isPromisey(e2) ? e2.then(t) : t(), isPromisey = (e2) => e2 instanceof Promise || e2 && e2.then && "function" == typeof e2.then, updateComponent = async (e2, t, o) => {
      var n;
      const s = e2.$hostElement$, l = createTime("update", e2.$cmpMeta$.$tagName$), a = s["s-rc"];
      o && attachStyles(e2);
      const r = createTime("render", e2.$cmpMeta$.$tagName$);
      if (await callRender(e2, t, s, o), BUILD.hydrateServerSide)
        try {
          serverSideConnected(s), o && (1 & e2.$cmpMeta$.$flags$ ? s["s-en"] = "" : 2 & e2.$cmpMeta$.$flags$ && (s["s-en"] = "c"));
        } catch (e3) {
          consoleError(e3, s);
        }
      if (a && (a.map((e3) => e3()), s["s-rc"] = void 0), r(), l(), BUILD.asyncLoading) {
        const t2 = null !== (n = s["s-p"]) && void 0 !== n ? n : [], o2 = () => postUpdateComponent(e2);
        0 === t2.length ? o2() : (Promise.all(t2).then(o2), e2.$flags$ |= 4, t2.length = 0);
      }
    };
    const callRender = (e2, t, o, n) => {
      try {
        if (t = t.render(), e2.$flags$ &= -17, e2.$flags$ |= 2, BUILD.hasRenderFn) {
          return Promise.resolve(t).then((t2) => renderVdom(e2, t2, n));
        }
      } catch (t2) {
        consoleError(t2, e2.$hostElement$);
      }
      return null;
    }, postUpdateComponent = (e2) => {
      const t = e2.$cmpMeta$.$tagName$, o = e2.$hostElement$, n = createTime("postUpdate", t), s = e2.$lazyInstance$, l = e2.$ancestorComponent$;
      64 & e2.$flags$ ? n() : (e2.$flags$ |= 64, addHydratedFlag(o), safeCall(s, "componentDidLoad"), BUILD.isDev, n(), e2.$onReadyResolve$(o), l || appDidLoad()), e2.$onInstanceResolve$(o), e2.$onRenderResolve$ && (e2.$onRenderResolve$(), e2.$onRenderResolve$ = void 0), 512 & e2.$flags$ && nextTick(() => scheduleUpdate(e2, false)), e2.$flags$ &= -517;
    }, appDidLoad = (e2) => {
      addHydratedFlag(doc.documentElement), nextTick(() => emitEvent(win, "appload", {
        detail: {
          namespace: NAMESPACE
        }
      })), BUILD.profile;
    }, safeCall = (e2, t, o) => {
      if (e2 && e2[t])
        try {
          return e2[t](o);
        } catch (e3) {
          consoleError(e3);
        }
    }, addHydratedFlag = (e2) => e2.classList.add("hydrated"), serverSideConnected = (e2) => {
      const t = e2.children;
      if (null != t)
        for (let e3 = 0, o = t.length; e3 < o; e3++) {
          const o2 = t[e3];
          "function" == typeof o2.connectedCallback && o2.connectedCallback(), serverSideConnected(o2);
        }
    }, getValue = (e2, t) => getHostRef(e2).$instanceValues$.get(t), setValue = (e2, t, o, n) => {
      const s = getHostRef(e2), l = s.$hostElement$, a = s.$instanceValues$.get(t), r = s.$flags$, i = s.$lazyInstance$;
      o = parsePropertyValue(o, n.$members$[t][0]);
      const d = Number.isNaN(a) && Number.isNaN(o), c = o !== a && !d;
      if ((!(8 & r) || void 0 === a) && c && (s.$instanceValues$.set(t, o), i)) {
        if (n.$watchers$ && 128 & r) {
          const e3 = n.$watchers$[t];
          e3 && e3.map((e4) => {
            try {
              i[e4](o, a, t);
            } catch (e5) {
              consoleError(e5, l);
            }
          });
        }
        if (2 == (18 & r)) {
          scheduleUpdate(s, false);
        }
      }
    }, proxyComponent = (e2, t, o) => {
      var n;
      const s = e2.prototype;
      if (t.$members$) {
        e2.watchers && (t.$watchers$ = e2.watchers);
        const l = Object.entries(t.$members$);
        if (l.map(([e3, [n2]]) => {
          31 & n2 || 2 & o && 32 & n2 ? Object.defineProperty(s, e3, {
            get() {
              return getValue(this, e3);
            },
            set(s2) {
              setValue(this, e3, s2, t);
            },
            configurable: true,
            enumerable: true
          }) : 1 & o && 64 & n2 && Object.defineProperty(s, e3, {
            value(...t2) {
              var o2;
              const n3 = getHostRef(this);
              return null === (o2 = null == n3 ? void 0 : n3.$onInstancePromise$) || void 0 === o2 ? void 0 : o2.then(() => {
                var o3;
                return null === (o3 = n3.$lazyInstance$) || void 0 === o3 ? void 0 : o3[e3](...t2);
              });
            }
          });
        }), 1 & o) {
          const o2 = /* @__PURE__ */ new Map();
          s.attributeChangedCallback = function(e3, n2, l2) {
            plt.jmp(() => {
              var a;
              const r = o2.get(e3);
              if (this.hasOwnProperty(r))
                l2 = this[r], delete this[r];
              else {
                if (s.hasOwnProperty(r) && "number" == typeof this[r] && this[r] == l2)
                  return;
                if (null == r) {
                  const o3 = getHostRef(this), s2 = null == o3 ? void 0 : o3.$flags$;
                  if (s2 && !(8 & s2) && 128 & s2 && l2 !== n2) {
                    const r2 = o3.$lazyInstance$, i = null === (a = t.$watchers$) || void 0 === a ? void 0 : a[e3];
                    null == i || i.forEach((t2) => {
                      null != r2[t2] && r2[t2].call(r2, l2, n2, e3);
                    });
                  }
                  return;
                }
              }
              this[r] = (null !== l2 || "boolean" != typeof this[r]) && l2;
            });
          }, e2.observedAttributes = Array.from(/* @__PURE__ */ new Set([...Object.keys(null !== (n = t.$watchers$) && void 0 !== n ? n : {}), ...l.filter(([e3, t2]) => 15 & t2[0]).map(([e3, n2]) => {
            var s2;
            const l2 = n2[1] || e3;
            return o2.set(l2, e3), 512 & n2[0] && (null === (s2 = t.$attrsToReflect$) || void 0 === s2 || s2.push([e3, l2])), l2;
          })]));
        }
      }
      return e2;
    }, initializeComponent = async (e2, t, o, n) => {
      let s;
      if (0 == (32 & t.$flags$)) {
        if (t.$flags$ |= 32, BUILD.lazyLoad) {
          if (s = loadModule(o), s.then) {
            const e4 = () => {
            };
            s = await s, e4();
          }
          !s.isProxied && (o.$watchers$ = s.watchers, proxyComponent(s, o, 2), s.isProxied = true);
          const e3 = createTime("createInstance", o.$tagName$);
          t.$flags$ |= 8;
          try {
            new s(t);
          } catch (e4) {
            consoleError(e4);
          }
          t.$flags$ &= -9, t.$flags$ |= 128, e3(), fireConnectedCallback2();
        }
        if (s.style) {
          let n2 = s.style;
          const l = getScopeId(o);
          if (!styles.has(l)) {
            const e3 = createTime("registerStyles", o.$tagName$);
            registerStyle(l, n2), e3();
          }
        }
      }
      const r = t.$ancestorComponent$, i = () => scheduleUpdate(t, true);
      r && r["s-rc"] ? r["s-rc"].push(i) : i();
    }, fireConnectedCallback2 = (e2) => {
    }, connectedCallback = (e2) => {
      if (0 == (1 & plt.$flags$)) {
        const t = getHostRef(e2), o = t.$cmpMeta$, n = createTime("connectedCallback", o.$tagName$);
        if (1 & t.$flags$)
          addHostEventListeners(e2, t, o.$listeners$), (null == t ? void 0 : t.$lazyInstance$) ? fireConnectedCallback2() : (null == t ? void 0 : t.$onReadyPromise$) && t.$onReadyPromise$.then(() => fireConnectedCallback2());
        else {
          let n2;
          if (t.$flags$ |= 1, n2 = e2.getAttribute("s-id"), n2) {
            ((e3, t2, o2, n3) => {
              const s = createTime("hydrateClient", t2), l = e3.shadowRoot, a = [], r = l ? [] : null, i = n3.$vnode$ = newVNode(t2, null);
              plt.$orgLocNodes$ || initializeDocumentHydrate(doc.body, plt.$orgLocNodes$ = /* @__PURE__ */ new Map()), e3["s-id"] = o2, e3.removeAttribute("s-id"), clientHydrate(i, a, [], r, e3, e3, o2), a.map((e4) => {
                const o3 = e4.$hostId$ + "." + e4.$nodeId$, n4 = plt.$orgLocNodes$.get(o3), s2 = e4.$elm$;
                n4 && supportsShadow && "" === n4["s-en"] && n4.parentNode.insertBefore(s2, n4.nextSibling), l || (s2["s-hn"] = t2, n4 && (s2["s-ol"] = n4, s2["s-ol"]["s-nr"] = s2)), plt.$orgLocNodes$.delete(o3);
              }), l && r.map((e4) => {
                e4 && l.appendChild(e4);
              }), s();
            })(e2, o.$tagName$, n2, t);
          }
          if (!n2 && BUILD.hydrateServerSide && setContentReference(e2), BUILD.asyncLoading) {
            let o2 = e2;
            for (; o2 = o2.parentNode || o2.host; )
              if (1 === o2.nodeType && o2.hasAttribute("s-id") && o2["s-p"] || o2["s-p"]) {
                attachToAncestor(t, t.$ancestorComponent$ = o2);
                break;
              }
          }
          initializeComponent(e2, t, o);
        }
        n();
      }
    }, setContentReference = (e2) => {
      const t = e2["s-cr"] = doc.createComment("");
      t["s-cn"] = true, e2.insertBefore(t, e2.firstChild);
    }, addHostEventListeners = (e2, t, o, n) => {
      o && o.map(([o2, n2, s]) => {
        const l = getHostListenerTarget(e2, o2), a = hostListenerProxy(t, s), r = hostListenerOpts(o2);
        plt.ael(l, n2, a, r), (t.$rmListeners$ = t.$rmListeners$ || []).push(() => plt.rel(l, n2, a, r));
      });
    }, hostListenerProxy = (e2, t) => (o) => {
      try {
        256 & e2.$flags$ ? e2.$lazyInstance$[t](o) : (e2.$queuedListeners$ = e2.$queuedListeners$ || []).push([t, o]);
      } catch (e3) {
        consoleError(e3);
      }
    }, getHostListenerTarget = (e2, t) => 8 & t ? win : e2, hostListenerOpts = (e2) => 0 != (2 & e2), insertVdomAnnotations = (e2, t) => {
      if (null != e2) {
        const o = {
          hostIds: 0,
          rootLevelIds: 0,
          staticComponents: new Set(t)
        }, n = [];
        parseVNodeAnnotations(e2, e2.body, o, n), n.forEach((t2) => {
          if (null != t2) {
            const n2 = t2["s-nr"];
            let s = n2["s-host-id"], l = n2["s-node-id"], a = `${s}.${l}`;
            if (null == s) {
              if (s = 0, o.rootLevelIds++, l = o.rootLevelIds, a = `${s}.${l}`, 1 === n2.nodeType)
                n2.setAttribute("c-id", a);
              else if (3 === n2.nodeType) {
                if (0 === s && "" === n2.nodeValue.trim())
                  return void t2.remove();
                const o2 = e2.createComment(a);
                o2.nodeValue = `t.${a}`, n2.parentNode.insertBefore(o2, n2);
              }
            }
            let r = `o.${a}`;
            const i = t2.parentElement;
            i && ("" === i["s-en"] ? r += "." : "c" === i["s-en"] && (r += ".c")), t2.nodeValue = r;
          }
        });
      }
    }, parseVNodeAnnotations = (e2, t, o, n) => {
      null != t && (null != t["s-nr"] && n.push(t), 1 === t.nodeType && t.childNodes.forEach((t2) => {
        const s = getHostRef(t2);
        if (null != s && !o.staticComponents.has(t2.nodeName.toLowerCase())) {
          const n2 = {
            nodeIds: 0
          };
          insertVNodeAnnotations(e2, t2, s.$vnode$, o, n2);
        }
        parseVNodeAnnotations(e2, t2, o, n);
      }));
    }, insertVNodeAnnotations = (e2, t, o, n, s) => {
      if (null != o) {
        const l = ++n.hostIds;
        if (t.setAttribute("s-id", l), null != t["s-cr"] && (t["s-cr"].nodeValue = `r.${l}`), null != o.$children$) {
          const t2 = 0;
          o.$children$.forEach((o2, n2) => {
            insertChildVNodeAnnotations(e2, o2, s, l, t2, n2);
          });
        }
        if (t && o && o.$elm$ && !t.hasAttribute("c-id")) {
          const e3 = t.parentElement;
          if (e3 && e3.childNodes) {
            const n2 = Array.from(e3.childNodes), s2 = n2.find((e4) => 8 === e4.nodeType && e4["s-sr"]);
            if (s2) {
              const e4 = n2.indexOf(t) - 1;
              o.$elm$.setAttribute("c-id", `${s2["s-host-id"]}.${s2["s-node-id"]}.0.${e4}`);
            }
          }
        }
      }
    }, insertChildVNodeAnnotations = (e2, t, o, n, s, l) => {
      const a = t.$elm$;
      if (null == a)
        return;
      const r = o.nodeIds++, i = `${n}.${r}.${s}.${l}`;
      if (a["s-host-id"] = n, a["s-node-id"] = r, 1 === a.nodeType)
        a.setAttribute("c-id", i);
      else if (3 === a.nodeType) {
        const t2 = a.parentNode, o2 = t2.nodeName;
        if ("STYLE" !== o2 && "SCRIPT" !== o2) {
          const o3 = `t.${i}`, n2 = e2.createComment(o3);
          t2.insertBefore(n2, a);
        }
      } else if (8 === a.nodeType && a["s-sr"]) {
        const e3 = `s.${i}.${a["s-sn"] || ""}`;
        a.nodeValue = e3;
      }
      if (null != t.$children$) {
        const l2 = s + 1;
        t.$children$.forEach((t2, s2) => {
          insertChildVNodeAnnotations(e2, t2, o, n, l2, s2);
        });
      }
    }, hAsync = (e2, t, ...o) => {
      if (Array.isArray(o) && o.length > 0) {
        const n = o.flat(1 / 0);
        return n.some(isPromise2) ? Promise.all(n).then((o2) => h(e2, t, ...o2)).catch((o2) => h(e2, t)) : h(e2, t, ...o);
      }
      return h(e2, t);
    }, NO_HYDRATE_TAGS = /* @__PURE__ */ new Set(["CODE", "HEAD", "IFRAME", "INPUT", "OBJECT", "OUTPUT", "NOSCRIPT", "PRE", "SCRIPT", "SELECT", "STYLE", "TEMPLATE", "TEXTAREA"]);
    const cmpModules = /* @__PURE__ */ new Map(), getModule = (e2) => {
      if ("string" == typeof e2) {
        e2 = e2.toLowerCase();
        const t = cmpModules.get(e2);
        if (null != t)
          return t[e2];
      }
      return null;
    }, loadModule = (e2, t, o) => getModule(e2.$tagName$), isMemberInElement = (e2, t) => {
      if (null != e2) {
        if (t in e2)
          return true;
        const o = getModule(e2.nodeName);
        if (null != o) {
          const e3 = o;
          if (null != e3 && null != e3.cmpMeta && null != e3.cmpMeta.$members$)
            return t in e3.cmpMeta.$members$;
        }
      }
      return false;
    }, registerComponents = (e2) => {
      for (const t of e2) {
        const e3 = t.cmpMeta.$tagName$;
        cmpModules.set(e3, {
          [e3]: t
        });
      }
    }, win = window2, doc = win.document, writeTask = (e2) => {
      process.nextTick(() => {
        try {
          e2();
        } catch (e3) {
          consoleError(e3);
        }
      });
    }, resolved = Promise.resolve(), nextTick = (e2) => resolved.then(e2), defaultConsoleError = (e2) => {
      null != e2 && console2.error(e2.stack || e2.message || e2);
    }, consoleError = (e2, t) => defaultConsoleError(e2, t), plt = {
      $flags$: 0,
      $resourcesUrl$: "",
      jmp: (e2) => e2(),
      raf: (e2) => requestAnimationFrame(e2),
      ael: (e2, t, o, n) => e2.addEventListener(t, o, n),
      rel: (e2, t, o, n) => e2.removeEventListener(t, o, n),
      ce: (e2, t) => new win.CustomEvent(e2, t)
    }, supportsShadow = false, hostRefs = /* @__PURE__ */ new WeakMap(), getHostRef = (e2) => hostRefs.get(e2), registerInstance = (e2, t) => hostRefs.set(t.$lazyInstance$ = e2, t), registerHost = (e2, t) => {
      const o = {
        $flags$: 0,
        $cmpMeta$: t,
        $hostElement$: e2,
        $instanceValues$: /* @__PURE__ */ new Map(),
        $renderCount$: 0
      };
      return o.$onInstancePromise$ = new Promise((e3) => o.$onInstanceResolve$ = e3), o.$onReadyPromise$ = new Promise((e3) => o.$onReadyResolve$ = e3), e2["s-p"] = [], e2["s-rc"] = [], addHostEventListeners(e2, o, t.$listeners$), hostRefs.set(e2, o);
    }, styles = /* @__PURE__ */ new Map();
    var ICON_SIZES;
    (function(ICON_SIZES2) {
      ICON_SIZES2["XS"] = "xs";
      ICON_SIZES2["SM"] = "sm";
      ICON_SIZES2["MD"] = "md";
      ICON_SIZES2["LG"] = "lg";
      ICON_SIZES2["XL"] = "xl";
      ICON_SIZES2["XXL"] = "xxl";
    })(ICON_SIZES || (ICON_SIZES = {}));
    const iconsCss = "/*!@:host*/.sc-abc-icon-chevron-down-h{box-sizing:border-box;display:flex;align-items:center;justify-content:center}/*!@:host([size=xs]) svg*/[size=xs].sc-abc-icon-chevron-down-h svg.sc-abc-icon-chevron-down{height:16px;width:16px}/*!@:host([size=sm]) svg*/[size=sm].sc-abc-icon-chevron-down-h svg.sc-abc-icon-chevron-down{height:24px;width:24px}/*!@:host([size=md]) svg*/[size=md].sc-abc-icon-chevron-down-h svg.sc-abc-icon-chevron-down{height:32px;width:32px}/*!@:host([size=lg]) svg*/[size=lg].sc-abc-icon-chevron-down-h svg.sc-abc-icon-chevron-down{height:40px;width:40px}/*!@:host([size=xl]) svg*/[size=xl].sc-abc-icon-chevron-down-h svg.sc-abc-icon-chevron-down{height:48px;width:48px}/*!@:host([size=xxl]) svg*/[size=xxl].sc-abc-icon-chevron-down-h svg.sc-abc-icon-chevron-down{height:56px;width:56px}";
    class AbcIconChevronDown {
      constructor(hostRef) {
        registerInstance(this, hostRef);
        this.size = ICON_SIZES.MD;
      }
      render() {
        switch (this.size) {
          case ICON_SIZES.XS:
            return hAsync("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 16 16", "stroke-linejoin": "round", "stroke-linecap": "round", stroke: "currentColor", fill: "none" }, hAsync("path", { "stroke-width": "1.5", d: "m4 6 4 4 4-4" }));
          case ICON_SIZES.SM:
            return hAsync("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 24 24", "stroke-linejoin": "round", "stroke-linecap": "round", stroke: "currentColor", fill: "none" }, hAsync("path", { "stroke-width": "2", d: "m6 9 6 6 6-6" }));
          case ICON_SIZES.MD:
            return hAsync("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 32 32", "stroke-linejoin": "round", "stroke-linecap": "round", stroke: "currentColor", fill: "none" }, hAsync("path", { "stroke-width": "2.3", d: "m8 12 8 8 8-8" }));
          case ICON_SIZES.LG:
            return hAsync("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 40 40", "stroke-linejoin": "round", "stroke-linecap": "round", stroke: "currentColor", fill: "none" }, hAsync("path", { "stroke-width": "2.5", d: "m10 15 10 10 10-10" }));
          case ICON_SIZES.XL:
            return hAsync("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 48 48", "stroke-linejoin": "round", "stroke-linecap": "round", stroke: "currentColor", fill: "none" }, hAsync("path", { "stroke-width": "3", d: "m12 18 12 12 12-12" }));
          case ICON_SIZES.XXL:
            return hAsync("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 56 56", "stroke-linejoin": "round", "stroke-linecap": "round", stroke: "currentColor", fill: "none" }, hAsync("path", { "stroke-width": "3.5", d: "m14 21 14 14 14-14" }));
        }
      }
      static get style() {
        return iconsCss;
      }
      static get cmpMeta() {
        return {
          "$flags$": 9,
          "$tagName$": "abc-icon-chevron-down",
          "$members$": {
            "size": [513]
          },
          "$listeners$": void 0,
          "$lazyBundleId$": "-",
          "$attrsToReflect$": [["size", "size"]]
        };
      }
    }
    var ACCORDION_VARIANTS;
    (function(ACCORDION_VARIANTS2) {
      ACCORDION_VARIANTS2["WHITE"] = "white";
      ACCORDION_VARIANTS2["GREY"] = "grey";
    })(ACCORDION_VARIANTS || (ACCORDION_VARIANTS = {}));
    const accordionCss = "/*!@:host .accordion*/.sc-abc-accordion-h .accordion.sc-abc-accordion{box-sizing:border-box;border-radius:5px;overflow:hidden;border-width:1px}/*!@:host .accordion__summary*/.sc-abc-accordion-h .accordion__summary.sc-abc-accordion{display:flex;align-items:center;justify-content:space-between;padding:10px 15px;font:14px Arial, sans-serif;font-weight:700;word-break:break-all}/*!@:host .accordion__summary:hover*/.sc-abc-accordion-h .accordion__summary.sc-abc-accordion:hover{transition:0.3s}/*!@:host .accordion__paragraph*/.sc-abc-accordion-h .accordion__paragraph.sc-abc-accordion{margin:0;padding:0 15px 10px 15px;word-break:break-all;max-height:0}/*!@:host .accordion__icon*/.sc-abc-accordion-h .accordion__icon.sc-abc-accordion{align-self:flex-start;transition:0.5s}/*!@:host([variant=white]) .accordion*/[variant=white].sc-abc-accordion-h .accordion.sc-abc-accordion{background-color:#ffffff;border-color:#ccc;font:16px Arial, sans-serif}/*!@:host([variant=white]) .accordion__icon*/[variant=white].sc-abc-accordion-h .accordion__icon.sc-abc-accordion{height:24px;width:24px;color:#333}/*!@:host([variant=white]) .accordion__summary*/[variant=white].sc-abc-accordion-h .accordion__summary.sc-abc-accordion{color:#333}/*!@:host([variant=white]) .accordion__summary:hover*/[variant=white].sc-abc-accordion-h .accordion__summary.sc-abc-accordion:hover{color:#555;background-color:#f5f5f5;border-color:#666}/*!@:host([variant=white][open]) .accordion*/[variant=white][open].sc-abc-accordion-h .accordion.sc-abc-accordion{background-color:#ffffff;color:#333;font:16px Arial, sans-serif}/*!@:host([variant=white][open]) .accordion__summary*/[variant=white][open].sc-abc-accordion-h .accordion__summary.sc-abc-accordion{color:#333}/*!@:host([variant=white][open]) .accordion__summary:hover*/[variant=white][open].sc-abc-accordion-h .accordion__summary.sc-abc-accordion:hover{color:#555;background-color:#f5f5f5}/*!@:host([variant=white][open]) .accordion__icon*/[variant=white][open].sc-abc-accordion-h .accordion__icon.sc-abc-accordion{height:24px;width:24px;color:#333;transform:rotate(180deg)}/*!@:host([variant=grey]) .accordion*/[variant=grey].sc-abc-accordion-h .accordion.sc-abc-accordion{background-color:#ccc;border-color:#999;font:16px Arial, sans-serif}/*!@:host([variant=grey]) .accordion__summary*/[variant=grey].sc-abc-accordion-h .accordion__summary.sc-abc-accordion{color:#333}/*!@:host([variant=grey]) .accordion__summary:hover*/[variant=grey].sc-abc-accordion-h .accordion__summary.sc-abc-accordion:hover{color:#555;background-color:#ddd;border-color:#666}/*!@:host([variant=grey]) .accordion__icon*/[variant=grey].sc-abc-accordion-h .accordion__icon.sc-abc-accordion{height:24px;width:24px;color:#333}/*!@:host([variant=grey][open]) .accordion*/[variant=grey][open].sc-abc-accordion-h .accordion.sc-abc-accordion{background-color:#ccc;font:16px Arial, sans-serif}/*!@:host([variant=grey][open]) .accordion__summary*/[variant=grey][open].sc-abc-accordion-h .accordion__summary.sc-abc-accordion{color:#333}/*!@:host([variant=grey][open]) .accordion__summary:hover*/[variant=grey][open].sc-abc-accordion-h .accordion__summary.sc-abc-accordion:hover{color:#555;background-color:#ddd}/*!@:host([variant=grey][open]) .accordion__icon*/[variant=grey][open].sc-abc-accordion-h .accordion__icon.sc-abc-accordion{height:24px;width:24px;color:#333;transform:rotate(180deg)}/*!@details > summary::-webkit-details-marker*/details.sc-abc-accordion>summary.sc-abc-accordion::-webkit-details-marker{display:none}/*!@:host([open]) .accordion__paragraph*/[open].sc-abc-accordion-h .accordion__paragraph.sc-abc-accordion{max-height:100vh;transition:0.5s}";
    class Accordion {
      constructor(hostRef) {
        registerInstance(this, hostRef);
        this.accordionClick = createEvent(this, "accordionClick", 7);
        this.open = false;
        this.variant = ACCORDION_VARIANTS.WHITE;
        this.summary = void 0;
        this.item = void 0;
      }
      componentDidLoad() {
        const { previousSibling, nextSibling, shadowRoot } = this.host;
        const detailsElement = shadowRoot === null || shadowRoot === void 0 ? void 0 : shadowRoot.querySelector("details");
        if (detailsElement) {
          if (previousSibling) {
            detailsElement.style.borderTopLeftRadius = "0";
            detailsElement.style.borderTopRightRadius = "0";
          }
          if (nextSibling) {
            detailsElement.style.borderBottomLeftRadius = "0";
            detailsElement.style.borderBottomRightRadius = "0";
          }
        }
      }
      render() {
        return hAsync("details", { class: "accordion", open: this.open, "aria-expanded": this.open, onToggle: (event) => {
          this.open = event.target.open;
          this.accordionClick.emit({ open: this.open, item: this.item });
        } }, hAsync("summary", { class: "accordion__summary" }, this.summary, hAsync("abc-icon-chevron-down", { class: "accordion__icon" })), hAsync("p", { class: "accordion__paragraph" }, hAsync("slot", { name: "details" })));
      }
      get host() {
        return getElement(this);
      }
      static get style() {
        return accordionCss;
      }
      static get cmpMeta() {
        return {
          "$flags$": 9,
          "$tagName$": "abc-accordion",
          "$members$": {
            "open": [516],
            "variant": [513],
            "summary": [1],
            "item": [513]
          },
          "$listeners$": void 0,
          "$lazyBundleId$": "-",
          "$attrsToReflect$": [["open", "open"], ["variant", "variant"], ["item", "item"]]
        };
      }
    }
    const accordionGroupCss = "/*!@:host*/.sc-abc-accordion-group-h{box-sizing:border-box;display:flex;flex-direction:column;gap:20px;padding:0}";
    const isHTMLAbcAccordionItemElement = (element) => {
      if (typeof element === "object" && typeof element.item === "string") {
        return true;
      }
      return false;
    };
    class AccordionContainer {
      constructor(hostRef) {
        registerInstance(this, hostRef);
        this.accordionChange = createEvent(this, "accordionChange", 7);
        this.selectedAccordion = void 0;
      }
      onAccordionChange() {
        this.accordionChange.emit(this.selectedAccordion);
        if (typeof this.selectedAccordion === "string") {
          const activeAccordion = this.getItems(this.selectedAccordion);
          this.accordions.forEach((accordion) => {
            if ((activeAccordion === null || activeAccordion === void 0 ? void 0 : activeAccordion.item) !== accordion.item) {
              accordion.open = false;
            }
          });
        }
      }
      get accordions() {
        return Array.from(this.host.querySelectorAll("abc-accordion"));
      }
      getItems(accordion) {
        return isHTMLAbcAccordionItemElement(accordion) ? accordion : this.accordions.find((t) => t.item === accordion);
      }
      select(item) {
        if (this.selectedAccordion === item) {
          return false;
        }
        this.selectedAccordion = item;
        return true;
      }
      render() {
        return hAsync(Host, { onAccordionClick: ({ detail: { item, open: open2 } }) => {
          if (open2) {
            this.select(item);
          }
        } }, hAsync("slot", { name: "accordions" }));
      }
      get host() {
        return getElement(this);
      }
      static get watchers() {
        return {
          "selectedAccordion": ["onAccordionChange"]
        };
      }
      static get style() {
        return accordionGroupCss;
      }
      static get cmpMeta() {
        return {
          "$flags$": 9,
          "$tagName$": "abc-accordion-group",
          "$members$": {
            "selectedAccordion": [513, "selected-accordion"]
          },
          "$listeners$": void 0,
          "$lazyBundleId$": "-",
          "$attrsToReflect$": [["selectedAccordion", "selected-accordion"]]
        };
      }
    }
    var BUTTON_VARIANTS;
    (function(BUTTON_VARIANTS2) {
      BUTTON_VARIANTS2["PRIMARY"] = "primary";
      BUTTON_VARIANTS2["SECONDARY"] = "secondary";
      BUTTON_VARIANTS2["TERTIARY"] = "tertiary";
      BUTTON_VARIANTS2["QUATERNARY"] = "quaternary";
    })(BUTTON_VARIANTS || (BUTTON_VARIANTS = {}));
    var BUTTON_SIZES;
    (function(BUTTON_SIZES2) {
      BUTTON_SIZES2["SM"] = "sm";
      BUTTON_SIZES2["MD"] = "md";
      BUTTON_SIZES2["LG"] = "lg";
    })(BUTTON_SIZES || (BUTTON_SIZES = {}));
    var BUTTON_TYPE;
    (function(BUTTON_TYPE2) {
      BUTTON_TYPE2["BUTTON"] = "button";
      BUTTON_TYPE2["LINK"] = "link";
    })(BUTTON_TYPE || (BUTTON_TYPE = {}));
    const isExternalUrl = (href) => {
      if (typeof window2 === "undefined") {
        throw new Error("window is not defined");
      }
      try {
        const base = new URL2(`${window2.location.protocol}//${window2.location.host}`);
        return new URL2(href, base).origin !== location2.origin;
      } catch (e2) {
        return false;
      }
    };
    const buttonCss = "/*!@:host .button*/.sc-abc-button-h .button.sc-abc-button{align-items:center;box-sizing:border-box;cursor:pointer;display:inline-flex;max-width:100%;text-align:center;text-decoration:none;justify-content:center;transition:color linear 0.2s}/*!@:host .button:focus-visible*/.sc-abc-button-h .button.sc-abc-button:focus-visible{border-radius:4px;outline-color:#0078d4;outline-style:solid;outline-width:2px;outline-offset:2px}/*!@:host .button:hover*/.sc-abc-button-h .button.sc-abc-button:hover{transition:0.3s}/*!@:host .button__icon*/.sc-abc-button-h .button__icon.sc-abc-button{display:flex;align-items:center}/*!@:host([variant=primary][size=sm]) .button*/[variant=primary][size=sm].sc-abc-button-h .button.sc-abc-button{font:14px Arial, sans-serif;color:#fff;background-color:#0078d4;border:1px solid #0078d4;border-radius:4px;padding:5px 10px;gap:5px}/*!@:host([variant=primary][size=sm]) .button:hover*/[variant=primary][size=sm].sc-abc-button-h .button.sc-abc-button:hover{color:#fff;background-color:#005a9e;border:1px solid #005a9e;border-radius:4px;padding:5px 10px}/*!@:host([variant=primary][size=sm]) .button:disabled*/[variant=primary][size=sm].sc-abc-button-h .button.sc-abc-button:disabled{color:#ccc;background-color:#f0f0f0;border:1px solid #ccc;border-radius:4px;padding:5px 10px}/*!@:host([variant=secondary][size=sm]) .button*/[variant=secondary][size=sm].sc-abc-button-h .button.sc-abc-button{font:14px Arial, sans-serif;color:#333;background-color:#ccc;border:1px solid #ccc;border-radius:4px;padding:5px 10px;gap:5px}/*!@:host([variant=secondary][size=sm]) .button:hover*/[variant=secondary][size=sm].sc-abc-button-h .button.sc-abc-button:hover{color:#333;background-color:#999;border:1px solid #999;border-radius:4px;padding:5px 10px}/*!@:host([variant=secondary][size=sm]) .button:disabled*/[variant=secondary][size=sm].sc-abc-button-h .button.sc-abc-button:disabled{color:#ccc;background-color:#f0f0f0;border:1px solid #ccc;border-radius:4px;padding:5px 10px}/*!@:host([variant=tertiary][size=sm]) .button*/[variant=tertiary][size=sm].sc-abc-button-h .button.sc-abc-button{font:14px Arial, sans-serif;color:#0078d4;background-color:transparent;border:none;padding:0;gap:5px}/*!@:host([variant=tertiary][size=sm]) .button:hover*/[variant=tertiary][size=sm].sc-abc-button-h .button.sc-abc-button:hover{color:#005a9e}/*!@:host([variant=tertiary][size=sm]) .button:disabled*/[variant=tertiary][size=sm].sc-abc-button-h .button.sc-abc-button:disabled{color:#ccc}/*!@:host([variant=quaternary][size=sm]) .button*/[variant=quaternary][size=sm].sc-abc-button-h .button.sc-abc-button{font:14px Arial, sans-serif;color:#333;background-color:transparent;border:none;padding:0;gap:5px}/*!@:host([variant=quaternary][size=sm]) .button:hover*/[variant=quaternary][size=sm].sc-abc-button-h .button.sc-abc-button:hover{color:#999}/*!@:host([variant=quaternary][size=sm]) .button:disabled*/[variant=quaternary][size=sm].sc-abc-button-h .button.sc-abc-button:disabled{color:#ccc}/*!@:host([variant=primary][size=md]) .button*/[variant=primary][size=md].sc-abc-button-h .button.sc-abc-button{font:16px Arial, sans-serif;color:#fff;background-color:#0078d4;border:1px solid #0078d4;border-radius:4px;padding:7px 14px;gap:5px}/*!@:host([variant=primary][size=md]) .button:hover*/[variant=primary][size=md].sc-abc-button-h .button.sc-abc-button:hover{color:#fff;background-color:#005a9e;border:1px solid #005a9e;border-radius:4px;padding:7px 14px}/*!@:host([variant=primary][size=md]) .button:disabled*/[variant=primary][size=md].sc-abc-button-h .button.sc-abc-button:disabled{color:#ccc;background-color:#f0f0f0;border:1px solid #ccc;border-radius:4px;padding:7px 14px}/*!@:host([variant=secondary][size=md]) .button*/[variant=secondary][size=md].sc-abc-button-h .button.sc-abc-button{font:16px Arial, sans-serif;color:#333;background-color:#ccc;border:1px solid #ccc;border-radius:4px;padding:7px 14px;gap:5px}/*!@:host([variant=secondary][size=md]) .button:hover*/[variant=secondary][size=md].sc-abc-button-h .button.sc-abc-button:hover{color:#333;background-color:#999;border:1px solid #999;border-radius:4px;padding:7px 14px}/*!@:host([variant=secondary][size=md]) .button:disabled*/[variant=secondary][size=md].sc-abc-button-h .button.sc-abc-button:disabled{color:#ccc;background-color:#f0f0f0;border:1px solid #ccc;border-radius:4px;padding:7px 14px}/*!@:host([variant=tertiary][size=md]) .button*/[variant=tertiary][size=md].sc-abc-button-h .button.sc-abc-button{font:16px Arial, sans-serif;color:#0078d4;background-color:transparent;border:none;padding:0;gap:5px}/*!@:host([variant=tertiary][size=md]) .button:hover*/[variant=tertiary][size=md].sc-abc-button-h .button.sc-abc-button:hover{color:#005a9e}/*!@:host([variant=tertiary][size=md]) .button:disabled*/[variant=tertiary][size=md].sc-abc-button-h .button.sc-abc-button:disabled{color:#ccc}/*!@:host([variant=quaternary][size=md]) .button*/[variant=quaternary][size=md].sc-abc-button-h .button.sc-abc-button{font:16px Arial, sans-serif;color:#333;background-color:transparent;border:none;padding:0;gap:5px}/*!@:host([variant=quaternary][size=md]) .button:hover*/[variant=quaternary][size=md].sc-abc-button-h .button.sc-abc-button:hover{color:#999}/*!@:host([variant=quaternary][size=md]) .button:disabled*/[variant=quaternary][size=md].sc-abc-button-h .button.sc-abc-button:disabled{color:#ccc}/*!@:host([variant=primary][size=lg]) .button*/[variant=primary][size=lg].sc-abc-button-h .button.sc-abc-button{font:18px Arial, sans-serif;color:#fff;background-color:#0078d4;border:1px solid #0078d4;border-radius:4px;padding:9px 18px;gap:5px}/*!@:host([variant=primary][size=lg]) .button:hover*/[variant=primary][size=lg].sc-abc-button-h .button.sc-abc-button:hover{color:#fff;background-color:#005a9e;border:1px solid #005a9e;border-radius:4px;padding:9px 18px}/*!@:host([variant=primary][size=lg]) .button:disabled*/[variant=primary][size=lg].sc-abc-button-h .button.sc-abc-button:disabled{color:#ccc;background-color:#f0f0f0;border:1px solid #ccc;border-radius:4px;padding:9px 18px}/*!@:host([variant=secondary][size=lg]) .button*/[variant=secondary][size=lg].sc-abc-button-h .button.sc-abc-button{font:18px Arial, sans-serif;color:#333;background-color:#ccc;border:1px solid #ccc;border-radius:4px;padding:9px 18px;gap:5px}/*!@:host([variant=secondary][size=lg]) .button:hover*/[variant=secondary][size=lg].sc-abc-button-h .button.sc-abc-button:hover{color:#333;background-color:#999;border:1px solid #999;border-radius:4px;padding:9px 18px}/*!@:host([variant=secondary][size=lg]) .button:disabled*/[variant=secondary][size=lg].sc-abc-button-h .button.sc-abc-button:disabled{color:#ccc;background-color:#f0f0f0;border:1px solid #ccc;border-radius:4px;padding:9px 18px}/*!@:host([variant=tertiary][size=lg]) .button*/[variant=tertiary][size=lg].sc-abc-button-h .button.sc-abc-button{font:18px Arial, sans-serif;color:#0078d4;background-color:transparent;border:none;padding:0;gap:5px}/*!@:host([variant=tertiary][size=lg]) .button:hover*/[variant=tertiary][size=lg].sc-abc-button-h .button.sc-abc-button:hover{color:#005a9e}/*!@:host([variant=tertiary][size=lg]) .button:disabled*/[variant=tertiary][size=lg].sc-abc-button-h .button.sc-abc-button:disabled{color:#ccc}/*!@:host([variant=quaternary][size=lg]) .button*/[variant=quaternary][size=lg].sc-abc-button-h .button.sc-abc-button{font:18px Arial, sans-serif;color:#333;background-color:transparent;border:none;padding:0;gap:5px}/*!@:host([variant=quaternary][size=lg]) .button:hover*/[variant=quaternary][size=lg].sc-abc-button-h .button.sc-abc-button:hover{color:#999}/*!@:host([variant=quaternary][size=lg]) .button:disabled*/[variant=quaternary][size=lg].sc-abc-button-h .button.sc-abc-button:disabled{color:#ccc}";
    class Button {
      constructor(hostRef) {
        registerInstance(this, hostRef);
        this.disabled = false;
        this.variant = BUTTON_VARIANTS.PRIMARY;
        this.size = BUTTON_SIZES.MD;
        this.type = "submit";
        this.as = BUTTON_TYPE.BUTTON;
        this.href = void 0;
        this.ariaLabel = void 0;
        this.target = "_self";
      }
      isExternalURL() {
        return isExternalUrl(this.href);
      }
      render() {
        if (this.as === BUTTON_TYPE.BUTTON) {
          return hAsync("button", { part: "button", class: "button", type: this.type, disabled: this.disabled }, hAsync("slot", null));
        }
        return hAsync("a", { part: "button", class: "button", href: this.href, "aria-label": this.ariaLabel, target: this.target, rel: this.isExternalURL() ? "noreferrer" : void 0 }, hAsync("slot", null));
      }
      static get style() {
        return buttonCss;
      }
      static get cmpMeta() {
        return {
          "$flags$": 9,
          "$tagName$": "abc-button",
          "$members$": {
            "disabled": [4],
            "variant": [513],
            "size": [513],
            "type": [1],
            "as": [513],
            "href": [1],
            "ariaLabel": [1, "aria-label"],
            "target": [1]
          },
          "$listeners$": void 0,
          "$lazyBundleId$": "-",
          "$attrsToReflect$": [["variant", "variant"], ["size", "size"], ["as", "as"]]
        };
      }
    }
    const dropdownCss = "/*!@:host .dropdown__flyout*/.sc-abc-dropdown-h .dropdown__flyout.sc-abc-dropdown{position:absolute;width:100%;max-height:0;overflow:hidden;transition:0.3s ease-in-out}/*!@:host .dropdown__information-wrapper*/.sc-abc-dropdown-h .dropdown__information-wrapper.sc-abc-dropdown{display:flex;flex-direction:row;justify-content:space-between;font:14px Arial, sans-serif;position:relative}/*!@:host .dropdown__hint*/.sc-abc-dropdown-h .dropdown__hint.sc-abc-dropdown{color:#777}/*!@:host .dropdown.focused*/.sc-abc-dropdown-h .dropdown.focused.sc-abc-dropdown{border-radius:4px;color:#007bff;outline-color:#007bff;outline-style:solid;outline-width:2px;outline-offset:2px}/*!@:host .dropdown:focus-within :host .dropdown__information-wrapper :host .dropdown__hint, :host .dropdown:focus-within :host .dropdown__information-wrapper :host .dropdown__error-message*/.sc-abc-dropdown-h .dropdown.sc-abc-dropdown:focus-within -shadowcsshost .dropdown__information-wrapper.sc-abc-dropdown -shadowcsshost .dropdown__hint.sc-abc-dropdown,.sc-abc-dropdown-h .dropdown.sc-abc-dropdown:focus-within -shadowcsshost .dropdown__information-wrapper.sc-abc-dropdown -shadowcsshost .dropdown__error-message.sc-abc-dropdown{color:#007bff}/*!@:host([open]) .dropdown__flyout*/[open].sc-abc-dropdown-h .dropdown__flyout.sc-abc-dropdown{max-height:100vh;box-shadow:0 2px 4px rgba(0, 0, 0, 0.1);transition:0.3s ease-in-out}";
    const isHTMLAbcFlyoutItemElement$1 = (element) => {
      if (typeof element === "object" && typeof element.item === "string") {
        return true;
      }
      return false;
    };
    class Dropdown {
      constructor(hostRef) {
        registerInstance(this, hostRef);
        this.dropdownChange = createEvent(this, "dropdownChange", 7);
        this.selectedItem = void 0;
        this.disabled = false;
        this.required = false;
        this.label = void 0;
        this.text = void 0;
        this.hint = void 0;
        this.error = void 0;
        this.open = false;
        this.focused = false;
        this.keyboardEvent = false;
      }
      handleClick() {
        this.keyboardEvent = false;
      }
      handleKeyDown() {
        this.keyboardEvent = true;
      }
      onButtonBlur() {
        this.focused = false;
      }
      onButtonFocus() {
        this.keyboardEvent && (this.focused = true);
      }
      onButtonClick() {
        this.open = !this.open;
      }
      onDropdownChange() {
        this.dropdownChange.emit(this.selectedItem);
      }
      select(item) {
        if (this.selectedItem === item) {
          return false;
        }
        this.selectedItem = item;
        return true;
      }
      get items() {
        return Array.from(this.host.querySelectorAll("abc-flyout-item"));
      }
      getItems(item) {
        return isHTMLAbcFlyoutItemElement$1(item) ? item : this.items.find((t) => t.item === item);
      }
      componentWillUpdate() {
        const selectedItem = this.getItems(this.selectedItem);
        if (selectedItem) {
          selectedItem.selected = true;
        }
      }
      render() {
        var _a;
        const itemLabel = (_a = this.getItems(this.selectedItem)) === null || _a === void 0 ? void 0 : _a.label;
        return hAsync(Host, { onItemClick: ({ detail: { item } }) => {
          this.select(item);
        } }, hAsync("abc-dropdown-button", { disabled: this.disabled, required: this.required, label: this.label, placeholder: typeof itemLabel === "string", open: this.open, text: itemLabel || this.text }, hAsync("div", { class: "dropdown__information-wrapper" }, hAsync("div", null, this.hint && (typeof this.error === "undefined" || this.error === "") && hAsync("span", { class: "dropdown__hint" }, this.hint), this.error && hAsync("abc-error-hint", { text: this.error })), hAsync("div", { class: "dropdown__flyout", "aria-haspopup": "true", "aria-expanded": this.open ? "true" : "false" }, hAsync("slot", null)))));
      }
      get host() {
        return getElement(this);
      }
      static get watchers() {
        return {
          "selectedItem": ["onDropdownChange"]
        };
      }
      static get style() {
        return dropdownCss;
      }
      static get cmpMeta() {
        return {
          "$flags$": 9,
          "$tagName$": "abc-dropdown",
          "$members$": {
            "selectedItem": [513, "selected-item"],
            "disabled": [4],
            "required": [4],
            "label": [1],
            "text": [1],
            "hint": [1],
            "error": [1],
            "open": [516],
            "focused": [32],
            "keyboardEvent": [32]
          },
          "$listeners$": [[10, "click", "handleClick"], [10, "keydown", "handleKeyDown"], [2, "dropdownButtonBlur", "onButtonBlur"], [2, "dropdownButtonFocus", "onButtonFocus"], [2, "dropdownButtonClick", "onButtonClick"]],
          "$lazyBundleId$": "-",
          "$attrsToReflect$": [["selectedItem", "selected-item"], ["open", "open"]]
        };
      }
    }
    const dropdownButtonCss = "/*!@:host .dropdown-button*/.sc-abc-dropdown-button-h .dropdown-button.sc-abc-dropdown-button{box-sizing:border-box;color:#333;display:flex;flex-direction:column;font:16px Arial, sans-serif;letter-spacing:1px;line-height:1.5;margin-bottom:10px;text-decoration:none;text-transform:uppercase}/*!@:host .dropdown-button__wrapper*/.sc-abc-dropdown-button-h .dropdown-button__wrapper.sc-abc-dropdown-button{background-color:#f0f0f0;border-color:#ccc;border-radius:4px;border-width:2px;border-style:solid;box-shadow:0 2px 4px rgba(0, 0, 0, 0.1);font:14px Arial, sans-serif;letter-spacing:1px;line-height:1.4;min-height:30px;margin:5px 0;padding:8px 12px;text-decoration:none;text-transform:uppercase;display:flex;flex-direction:row;justify-content:space-between;align-items:center}/*!@:host .dropdown-button__wrapper:focus-within*/.sc-abc-dropdown-button-h .dropdown-button__wrapper.sc-abc-dropdown-button:focus-within{background-color:#e0e0e0;border-color:#007bff;box-shadow:0 2px 4px rgba(0, 0, 0, 0.2);color:#007bff}/*!@:host .dropdown-button__button*/.sc-abc-dropdown-button-h .dropdown-button__button.sc-abc-dropdown-button{font:14px Arial, sans-serif;letter-spacing:1px;line-height:1.4;text-decoration:none;text-transform:uppercase;background-color:#f0f0f0;border:none;flex-grow:1;padding:0;outline:none;display:flex;flex-direction:row;justify-content:space-between}/*!@:host .dropdown-button__icon*/.sc-abc-dropdown-button-h .dropdown-button__icon.sc-abc-dropdown-button{color:#555;transition:0.3s ease-in-out}/*!@:host .dropdown-button__text*/.sc-abc-dropdown-button-h .dropdown-button__text.sc-abc-dropdown-button{color:#999}/*!@:host .dropdown-button.focused*/.sc-abc-dropdown-button-h .dropdown-button.focused.sc-abc-dropdown-button{border-radius:4px;color:#007bff;outline-color:#007bff;outline-style:solid;outline-width:2px;outline-offset:2px}/*!@:host .dropdown-button :host .dropdown-button__wrapper:focus-within :host .dropdown-button__button*/.sc-abc-dropdown-button-h .dropdown-button.sc-abc-dropdown-button -shadowcsshost .dropdown-button__wrapper.sc-abc-dropdown-button:focus-within -shadowcsshost .dropdown-button__button.sc-abc-dropdown-button{color:#007bff}/*!@:host .dropdown-button :host .dropdown-button__wrapper:focus-within :host .dropdown-button__button svg*/.sc-abc-dropdown-button-h .dropdown-button.sc-abc-dropdown-button -shadowcsshost .dropdown-button__wrapper.sc-abc-dropdown-button:focus-within -shadowcsshost .dropdown-button__button.sc-abc-dropdown-button svg.sc-abc-dropdown-button{color:#007bff}/*!@:host([disabled]) .dropdown-button__label*/[disabled].sc-abc-dropdown-button-h .dropdown-button__label.sc-abc-dropdown-button{color:#999}/*!@:host([disabled]) .dropdown-button__button*/[disabled].sc-abc-dropdown-button-h .dropdown-button__button.sc-abc-dropdown-button{color:#999;background-color:#f0f0f0}/*!@:host([disabled]) .dropdown-button__text*/[disabled].sc-abc-dropdown-button-h .dropdown-button__text.sc-abc-dropdown-button{color:#999}/*!@:host([disabled]) .dropdown-button__wrapper*/[disabled].sc-abc-dropdown-button-h .dropdown-button__wrapper.sc-abc-dropdown-button{background-color:#f0f0f0;border-color:#ccc}/*!@:host([disabled]) .dropdown-button__icon*/[disabled].sc-abc-dropdown-button-h .dropdown-button__icon.sc-abc-dropdown-button{color:#999}/*!@:host([required]) .asterisk*/[required].sc-abc-dropdown-button-h .asterisk.sc-abc-dropdown-button{margin-left:5px}/*!@:host([error]) .dropdown-button__label*/[error].sc-abc-dropdown-button-h .dropdown-button__label.sc-abc-dropdown-button{color:#ff0000}/*!@:host([error]) .dropdown-button__wrapper*/[error].sc-abc-dropdown-button-h .dropdown-button__wrapper.sc-abc-dropdown-button{background-color:#ffeeee;border-color:#ff0000;box-shadow:0 0 4px rgba(255, 0, 0, 0.5);color:#ff0000}/*!@:host([error]) .dropdown-button__button*/[error].sc-abc-dropdown-button-h .dropdown-button__button.sc-abc-dropdown-button{color:#ff0000}/*!@:host([error]) .dropdown-button__text*/[error].sc-abc-dropdown-button-h .dropdown-button__text.sc-abc-dropdown-button{color:#ff0000}/*!@:host([open]) .dropdown-button__icon*/[open].sc-abc-dropdown-button-h .dropdown-button__icon.sc-abc-dropdown-button{transform:rotate(180deg)}";
    class DropdownButton {
      constructor(hostRef) {
        registerInstance(this, hostRef);
        this.dropdownButtonFocus = createEvent(this, "dropdownButtonFocus", 7);
        this.dropdownButtonBlur = createEvent(this, "dropdownButtonBlur", 7);
        this.dropdownButtonClick = createEvent(this, "dropdownButtonClick", 7);
        this.disabled = false;
        this.required = false;
        this.placeholder = false;
        this.label = void 0;
        this.text = void 0;
        this.open = false;
        this.focused = false;
      }
      render() {
        return hAsync("label", { class: `dropdown-button ${this.required ? "required" : ""} ${this.disabled ? "disabled" : ""} ${this.focused ? "focused" : ""}` }, this.label && hAsync("div", { class: "dropdown-button__label" }, this.label, " ", this.required && hAsync("span", { class: "asterisk" }, "*")), hAsync("div", { class: "dropdown-button__wrapper" }, hAsync("button", { onFocus: () => this.dropdownButtonFocus.emit(), onBlur: () => this.dropdownButtonBlur.emit(), class: "dropdown-button__button", disabled: this.disabled, onClick: () => this.dropdownButtonClick.emit(), "aria-haspopup": "listbox", "aria-expanded": this.open }, hAsync("div", { class: this.placeholder ? "dropdown-button__text" : "" }, this.text), hAsync("abc-icon-chevron-down", { class: "dropdown-button__icon", size: ICON_SIZES.SM }))), hAsync("slot", null));
      }
      get host() {
        return getElement(this);
      }
      static get style() {
        return dropdownButtonCss;
      }
      static get cmpMeta() {
        return {
          "$flags$": 9,
          "$tagName$": "abc-dropdown-button",
          "$members$": {
            "disabled": [4],
            "required": [4],
            "placeholder": [4],
            "label": [1],
            "text": [1],
            "open": [516],
            "focused": [32]
          },
          "$listeners$": void 0,
          "$lazyBundleId$": "-",
          "$attrsToReflect$": [["open", "open"]]
        };
      }
    }
    const flyoutCss = "/*!@:host .flyout*/.sc-abc-flyout-h .flyout.sc-abc-flyout{box-sizing:border-box;list-style:none;background-color:#f5f5f5;border-color:#ddd;line-height:1.5;letter-spacing:0.5px;text-decoration:none;font:16px Arial, sans-serif;padding-top:10px;padding-bottom:10px;border-radius:4px;border-width:1px;box-shadow:2px 2px 4px rgba(0, 0, 0, 0.2)}";
    const isHTMLAbcFlyoutItemElement = (element) => {
      if (typeof element === "object" && typeof element.item === "string") {
        return true;
      }
      return false;
    };
    class Flyout {
      constructor(hostRef) {
        registerInstance(this, hostRef);
        this.flyoutChange = createEvent(this, "flyoutChange", 7);
        this.selectedItem = void 0;
      }
      onFlyoutChange() {
        this.flyoutChange.emit(this.selectedItem);
      }
      async handleKeyDown(e2) {
        if (!(e2.key === "ArrowDown" || e2.key === "ArrowUp")) {
          return;
        }
        const items = this.items;
        let currentIndex = items.findIndex((item) => item === document.activeElement);
        if (currentIndex === -1) {
          return;
        }
        if (e2.key === "ArrowDown") {
          currentIndex = (currentIndex + 1) % items.length;
        } else if (e2.key === "ArrowUp") {
          currentIndex = (currentIndex - 1 + items.length) % items.length;
        }
        await items[currentIndex].focusItem();
        e2.preventDefault();
      }
      select(item) {
        if (this.selectedItem === item) {
          return false;
        }
        this.selectedItem = item;
        return true;
      }
      get items() {
        return Array.from(this.host.querySelectorAll("abc-flyout-item"));
      }
      getItems(item) {
        return isHTMLAbcFlyoutItemElement(item) ? item : this.items.find((t) => t.item === item);
      }
      componentWillRender() {
        const selectedItem = this.getItems(this.selectedItem);
        this.items.forEach((item) => {
          item.selected = false;
        });
        if (selectedItem) {
          selectedItem.selected = true;
        }
      }
      render() {
        return hAsync(Host, { onItemClick: ({ detail: { item } }) => {
          this.select(item);
        } }, hAsync("div", { class: "flyout" }, hAsync("slot", null)));
      }
      get host() {
        return getElement(this);
      }
      static get watchers() {
        return {
          "selectedItem": ["onFlyoutChange"]
        };
      }
      static get style() {
        return flyoutCss;
      }
      static get cmpMeta() {
        return {
          "$flags$": 9,
          "$tagName$": "abc-flyout",
          "$members$": {
            "selectedItem": [513, "selected-item"]
          },
          "$listeners$": [[10, "keydown", "handleKeyDown"]],
          "$lazyBundleId$": "-",
          "$attrsToReflect$": [["selectedItem", "selected-item"]]
        };
      }
    }
    const flyoutItemCss = "/*!@:host .flyout-item*/.sc-abc-flyout-item-h .flyout-item.sc-abc-flyout-item{box-sizing:border-box;padding-top:10px;padding-bottom:10px;padding-left:20px;padding-right:20px;background-color:#fff;color:#333;border-width:1px;width:100%;height:100%;cursor:pointer;border:none;outline:none;text-align:left;font:16px Arial, sans-serif}/*!@:host .flyout-item:hover, :host .flyout-item:focus-within*/.sc-abc-flyout-item-h .flyout-item.sc-abc-flyout-item:hover,.sc-abc-flyout-item-h .flyout-item.sc-abc-flyout-item:focus-within{background-color:#f0f0f0;color:#555;border-color:#007bff}/*!@:host([selected]) .flyout-item*/[selected].sc-abc-flyout-item-h .flyout-item.sc-abc-flyout-item{border-style:solid;border-width:2px 2px 2px 2px;border-color:#007bff;background-color:#007bff;color:#fff}";
    class FlyoutItem {
      constructor(hostRef) {
        registerInstance(this, hostRef);
        this.itemClick = createEvent(this, "itemClick", 7);
        this.label = void 0;
        this.selected = false;
        this.item = void 0;
      }
      // eslint-disable-next-line @stencil-community/async-methods
      async focusItem() {
        var _a;
        (_a = this.buttonEl) === null || _a === void 0 ? void 0 : _a.focus();
      }
      render() {
        return hAsync("button", { ref: (el) => this.buttonEl = el, "aria-selected": this.selected, class: "flyout-item", onClick: () => {
          this.itemClick.emit({ item: this.item, selected: this.selected });
        } }, this.label);
      }
      static get style() {
        return flyoutItemCss;
      }
      static get cmpMeta() {
        return {
          "$flags$": 9,
          "$tagName$": "abc-flyout-item",
          "$members$": {
            "label": [1],
            "selected": [516],
            "item": [513],
            "focusItem": [64]
          },
          "$listeners$": void 0,
          "$lazyBundleId$": "-",
          "$attrsToReflect$": [["selected", "selected"], ["item", "item"]]
        };
      }
    }
    registerComponents([
      AbcIconChevronDown,
      Accordion,
      AccordionContainer,
      Button,
      Dropdown,
      DropdownButton,
      Flyout,
      FlyoutItem
    ]);
    exports2.hydrateApp = hydrateApp;
    hydrateApp(window2, $stencilHydrateOpts, $stencilHydrateResults, $stencilAfterHydrate, $stencilHydrateResolve);
  }
  hydrateAppClosure($stencilWindow);
}
function createWindowFromHtml(e2, t) {
  let r = templateWindows.get(t);
  return null == r && (r = new MockWindow(e2), templateWindows.set(t, r)), cloneWindow(r);
}
function inspectElement(e2, t, r) {
  const s = t.children;
  for (let t2 = 0, n = s.length; t2 < n; t2++) {
    const n2 = s[t2], o = n2.nodeName.toLowerCase();
    if (o.includes("-")) {
      const t3 = e2.components.find((e3) => e3.tag === o);
      null != t3 && (t3.count++, r > t3.depth && (t3.depth = r));
    } else
      switch (o) {
        case "a":
          const t3 = collectAttributes(n2);
          t3.href = n2.href, "string" == typeof t3.href && (e2.anchors.some((e3) => e3.href === t3.href) || e2.anchors.push(t3));
          break;
        case "img":
          const r2 = collectAttributes(n2);
          r2.src = n2.src, "string" == typeof r2.src && (e2.imgs.some((e3) => e3.src === r2.src) || e2.imgs.push(r2));
          break;
        case "link":
          const s2 = collectAttributes(n2);
          s2.href = n2.href, "string" == typeof s2.rel && "stylesheet" === s2.rel.toLowerCase() && "string" == typeof s2.href && (e2.styles.some((e3) => e3.link === s2.href) || (delete s2.rel, delete s2.type, e2.styles.push(s2)));
          break;
        case "script":
          const o2 = collectAttributes(n2);
          if (n2.hasAttribute("src"))
            o2.src = n2.src, "string" == typeof o2.src && (e2.scripts.some((e3) => e3.src === o2.src) || e2.scripts.push(o2));
          else {
            const t4 = n2.getAttribute("data-stencil-static");
            t4 && e2.staticData.push({
              id: t4,
              type: n2.getAttribute("type"),
              content: n2.textContent
            });
          }
      }
    inspectElement(e2, n2, ++r);
  }
}
function collectAttributes(e2) {
  const t = {}, r = e2.attributes;
  for (let e3 = 0, s = r.length; e3 < s; e3++) {
    const s2 = r.item(e3), n = s2.nodeName.toLowerCase();
    if (SKIP_ATTRS.has(n))
      continue;
    const o = s2.nodeValue;
    "class" === n && "" === o || (t[n] = o);
  }
  return t;
}
function patchDomImplementation(e2, t) {
  let r;
  if (null != e2.defaultView ? (t.destroyWindow = true, patchWindow(e2.defaultView), r = e2.defaultView) : (t.destroyWindow = true, t.destroyDocument = false, r = new MockWindow(false)), r.document !== e2 && (r.document = e2), e2.defaultView !== r && (e2.defaultView = r), "function" != typeof e2.documentElement.constructor.prototype.getRootNode && (e2.createElement("unknown-element").constructor.prototype.getRootNode = getRootNode), "function" == typeof e2.createEvent) {
    const t2 = e2.createEvent("CustomEvent").constructor;
    r.CustomEvent !== t2 && (r.CustomEvent = t2);
  }
  try {
    r.__stencil_baseURI = e2.baseURI;
  } catch (t2) {
    Object.defineProperty(e2, "baseURI", {
      get() {
        const t3 = e2.querySelector("base[href]");
        return t3 ? new URL(t3.getAttribute("href"), r.location.href).href : r.location.href;
      }
    });
  }
  return r;
}
function getRootNode(e2) {
  const t = null != e2 && true === e2.composed;
  let r = this;
  for (; null != r.parentNode; )
    r = r.parentNode, true === t && null == r.parentNode && null != r.host && (r = r.host);
  return r;
}
function normalizeHydrateOptions(e2) {
  const t = Object.assign({
    serializeToHtml: false,
    destroyWindow: false,
    destroyDocument: false
  }, e2 || {});
  return "boolean" != typeof t.clientHydrateAnnotations && (t.clientHydrateAnnotations = true), "boolean" != typeof t.constrainTimeouts && (t.constrainTimeouts = true), "number" != typeof t.maxHydrateCount && (t.maxHydrateCount = 300), "boolean" != typeof t.runtimeLogging && (t.runtimeLogging = false), "number" != typeof t.timeout && (t.timeout = 15e3), Array.isArray(t.excludeComponents) ? t.excludeComponents = t.excludeComponents.filter(filterValidTags).map(mapValidTags) : t.excludeComponents = [], Array.isArray(t.staticComponents) ? t.staticComponents = t.staticComponents.filter(filterValidTags).map(mapValidTags) : t.staticComponents = [], t;
}
function filterValidTags(e2) {
  return "string" == typeof e2 && e2.includes("-");
}
function mapValidTags(e2) {
  return e2.trim().toLowerCase();
}
function generateHydrateResults(e2) {
  "string" != typeof e2.url && (e2.url = "https://hydrate.stenciljs.com/"), "string" != typeof e2.buildId && (e2.buildId = createHydrateBuildId());
  const t = {
    buildId: e2.buildId,
    diagnostics: [],
    url: e2.url,
    host: null,
    hostname: null,
    href: null,
    pathname: null,
    port: null,
    search: null,
    hash: null,
    html: null,
    httpStatus: null,
    hydratedCount: 0,
    anchors: [],
    components: [],
    imgs: [],
    scripts: [],
    staticData: [],
    styles: [],
    title: null
  };
  try {
    const r = new URL(e2.url, "https://hydrate.stenciljs.com/");
    t.url = r.href, t.host = r.host, t.hostname = r.hostname, t.href = r.href, t.port = r.port, t.pathname = r.pathname, t.search = r.search, t.hash = r.hash;
  } catch (e3) {
    renderCatchError(t, e3);
  }
  return t;
}
function renderBuildDiagnostic(e2, t, r, s) {
  const n = {
    level: t,
    type: "build",
    header: r,
    messageText: s,
    relFilePath: void 0,
    absFilePath: void 0,
    lines: []
  };
  return e2.pathname ? "/" !== e2.pathname && (n.header += ": " + e2.pathname) : e2.url && (n.header += ": " + e2.url), e2.diagnostics.push(n), n;
}
function renderBuildError(e2, t) {
  return renderBuildDiagnostic(e2, "error", "Hydrate Error", t);
}
function renderCatchError(e2, t) {
  const r = renderBuildError(e2, null);
  return null != t && (null != t.stack ? r.messageText = t.stack.toString() : null != t.message ? r.messageText = t.message.toString() : r.messageText = t.toString()), r;
}
function runtimeLog(e2, t, r) {
  global.console[t].apply(global.console, [`[ ${e2}  ${t} ] `, ...r]);
}
function renderToString(e2, t) {
  const r = normalizeHydrateOptions(t);
  return r.serializeToHtml = true, new Promise((t2) => {
    let s;
    const n = generateHydrateResults(r);
    if (hasError(n.diagnostics))
      t2(n);
    else if ("string" == typeof e2)
      try {
        r.destroyWindow = true, r.destroyDocument = true, s = new MockWindow(e2), render(s, r, n, t2);
      } catch (e3) {
        s && s.close && s.close(), s = null, renderCatchError(n, e3), t2(n);
      }
    else if (isValidDocument(e2))
      try {
        r.destroyDocument = false, s = patchDomImplementation(e2, r), render(s, r, n, t2);
      } catch (e3) {
        s && s.close && s.close(), s = null, renderCatchError(n, e3), t2(n);
      }
    else
      renderBuildError(n, 'Invalid html or document. Must be either a valid "html" string, or DOM "document".'), t2(n);
  });
}
function hydrateDocument(e2, t) {
  const r = normalizeHydrateOptions(t);
  return r.serializeToHtml = false, new Promise((t2) => {
    let s;
    const n = generateHydrateResults(r);
    if (hasError(n.diagnostics))
      t2(n);
    else if ("string" == typeof e2)
      try {
        r.destroyWindow = true, r.destroyDocument = true, s = new MockWindow(e2), render(s, r, n, t2);
      } catch (e3) {
        s && s.close && s.close(), s = null, renderCatchError(n, e3), t2(n);
      }
    else if (isValidDocument(e2))
      try {
        r.destroyDocument = false, s = patchDomImplementation(e2, r), render(s, r, n, t2);
      } catch (e3) {
        s && s.close && s.close(), s = null, renderCatchError(n, e3), t2(n);
      }
    else
      renderBuildError(n, 'Invalid html or document. Must be either a valid "html" string, or DOM "document".'), t2(n);
  });
}
function render(e2, t, r, s) {
  if (process.__stencilErrors || (process.__stencilErrors = true, process.on("unhandledRejection", (e3) => {
    console.log("unhandledRejection", e3);
  })), function n(e3, t2, r2, s2) {
    try {
      e3.location.href = r2.url;
    } catch (e4) {
      renderCatchError(s2, e4);
    }
    if ("string" == typeof r2.userAgent)
      try {
        e3.navigator.userAgent = r2.userAgent;
      } catch (e4) {
      }
    if ("string" == typeof r2.cookie)
      try {
        t2.cookie = r2.cookie;
      } catch (e4) {
      }
    if ("string" == typeof r2.referrer)
      try {
        t2.referrer = r2.referrer;
      } catch (e4) {
      }
    if ("string" == typeof r2.direction)
      try {
        t2.documentElement.setAttribute("dir", r2.direction);
      } catch (e4) {
      }
    if ("string" == typeof r2.language)
      try {
        t2.documentElement.setAttribute("lang", r2.language);
      } catch (e4) {
      }
    if ("string" == typeof r2.buildId)
      try {
        t2.documentElement.setAttribute("data-stencil-build", r2.buildId);
      } catch (e4) {
      }
    try {
      e3.customElements = null;
    } catch (e4) {
    }
    return r2.constrainTimeouts && constrainTimeouts(e3), function n2(e4, t3, r3) {
      try {
        const s3 = e4.location.pathname;
        e4.console.error = (...e5) => {
          const n3 = e5.reduce((e6, t4) => {
            if (t4) {
              if (null != t4.stack)
                return e6 + " " + String(t4.stack);
              if (null != t4.message)
                return e6 + " " + String(t4.message);
            }
            return String(t4);
          }, "").trim();
          "" !== n3 && (renderCatchError(r3, n3), t3.runtimeLogging && runtimeLog(s3, "error", [n3]));
        }, e4.console.debug = (...e5) => {
          renderBuildDiagnostic(r3, "debug", "Hydrate Debug", [...e5].join(", ")), t3.runtimeLogging && runtimeLog(s3, "debug", e5);
        }, t3.runtimeLogging && ["log", "warn", "assert", "info", "trace"].forEach((t4) => {
          e4.console[t4] = (...e5) => {
            runtimeLog(s3, t4, e5);
          };
        });
      } catch (e5) {
        renderCatchError(r3, e5);
      }
    }(e3, r2, s2), e3;
  }(e2, e2.document, t, r), "function" == typeof t.beforeHydrate)
    try {
      const n = t.beforeHydrate(e2.document);
      isPromise(n) ? n.then(() => {
        hydrateFactory(e2, t, r, afterHydrate, s);
      }) : hydrateFactory(e2, t, r, afterHydrate, s);
    } catch (n) {
      renderCatchError(r, n), finalizeHydrate(e2, e2.document, t, r, s);
    }
  else
    hydrateFactory(e2, t, r, afterHydrate, s);
}
function afterHydrate(e2, t, r, s) {
  if ("function" == typeof t.afterHydrate)
    try {
      const n = t.afterHydrate(e2.document);
      isPromise(n) ? n.then(() => {
        finalizeHydrate(e2, e2.document, t, r, s);
      }) : finalizeHydrate(e2, e2.document, t, r, s);
    } catch (n) {
      renderCatchError(r, n), finalizeHydrate(e2, e2.document, t, r, s);
    }
  else
    finalizeHydrate(e2, e2.document, t, r, s);
}
function finalizeHydrate(e2, t, r, s, n) {
  try {
    if (inspectElement(s, t.documentElement, 0), false !== r.removeUnusedStyles)
      try {
        removeUnusedStyles(t, s.diagnostics);
      } catch (e3) {
        renderCatchError(s, e3);
      }
    if ("string" == typeof r.title)
      try {
        t.title = r.title;
      } catch (e3) {
        renderCatchError(s, e3);
      }
    s.title = t.title, r.removeScripts && removeScripts(t.documentElement);
    try {
      updateCanonicalLink(t, r.canonicalUrl);
    } catch (e3) {
      renderCatchError(s, e3);
    }
    try {
      relocateMetaCharset(t);
    } catch (e3) {
    }
    hasError(s.diagnostics) || (s.httpStatus = 200);
    try {
      const e3 = t.head.querySelector('meta[http-equiv="status"]');
      if (null != e3) {
        const t2 = e3.getAttribute("content");
        t2 && t2.length > 0 && (s.httpStatus = parseInt(t2, 10));
      }
    } catch (e3) {
    }
    r.clientHydrateAnnotations && t.documentElement.classList.add("hydrated"), r.serializeToHtml && (s.html = serializeDocumentToString(t, r));
  } catch (e3) {
    renderCatchError(s, e3);
  }
  if (r.destroyWindow)
    try {
      r.destroyDocument || (e2.document = null, t.defaultView = null), e2.close && e2.close();
    } catch (e3) {
      renderCatchError(s, e3);
    }
  n(s);
}
function serializeDocumentToString(e2, t) {
  return serializeNodeToHtml(e2, {
    approximateLineWidth: t.approximateLineWidth,
    outerHtml: false,
    prettyHtml: t.prettyHtml,
    removeAttributeQuotes: t.removeAttributeQuotes,
    removeBooleanAttributeQuotes: t.removeBooleanAttributeQuotes,
    removeEmptyAttributes: t.removeEmptyAttributes,
    removeHtmlComments: t.removeHtmlComments,
    serializeShadowRoot: false
  });
}
function isValidDocument(e2) {
  return null != e2 && 9 === e2.nodeType && null != e2.documentElement && 1 === e2.documentElement.nodeType && null != e2.body && 1 === e2.body.nodeType;
}
function removeScripts(e2) {
  const t = e2.children;
  for (let e3 = t.length - 1; e3 >= 0; e3--) {
    const r = t[e3];
    removeScripts(r), ("SCRIPT" === r.nodeName || "LINK" === r.nodeName && "modulepreload" === r.getAttribute("rel")) && r.remove();
  }
}
const templateWindows = /* @__PURE__ */ new Map(), isPromise = (e2) => !!e2 && ("object" == typeof e2 || "function" == typeof e2) && "function" == typeof e2.then, hasError = (e2) => null != e2 && 0 !== e2.length && e2.some((e3) => "error" === e3.level && "runtime" !== e3.type), TASK_CANCELED_MSG = "task canceled", updateCanonicalLink = (e2, t) => {
  let r = e2.head.querySelector('link[rel="canonical"]');
  "string" == typeof t ? (null == r && (r = e2.createElement("link"), r.setAttribute("rel", "canonical"), e2.head.appendChild(r)), r.setAttribute("href", t)) : null != r && (r.getAttribute("href") || r.parentNode.removeChild(r));
}, relocateMetaCharset = (e2) => {
  const t = e2.head;
  let r = t.querySelector("meta[charset]");
  null == r ? (r = e2.createElement("meta"), r.setAttribute("charset", "utf-8")) : r.remove(), t.insertBefore(r, t.firstChild);
}, parseCss = (e2, t) => {
  let r = 1, s = 1;
  const n = [], o = (e3) => {
    const t2 = e3.match(/\n/g);
    t2 && (r += t2.length);
    const n2 = e3.lastIndexOf("\n");
    s = ~n2 ? e3.length - n2 : s + e3.length;
  }, i = () => {
    const e3 = {
      line: r,
      column: s
    };
    return (t2) => (t2.position = new A(e3), m(), t2);
  }, a = (o2) => {
    const i2 = e2.split("\n"), a2 = {
      level: "error",
      type: "css",
      language: "css",
      header: "CSS Parse",
      messageText: o2,
      absFilePath: t,
      lines: [{
        lineIndex: r - 1,
        lineNumber: r,
        errorCharStart: s,
        text: e2[r - 1]
      }]
    };
    if (r > 1) {
      const t2 = {
        lineIndex: r - 1,
        lineNumber: r - 1,
        text: e2[r - 2],
        errorCharStart: -1,
        errorLength: -1
      };
      a2.lines.unshift(t2);
    }
    if (r + 2 < i2.length) {
      const e3 = {
        lineIndex: r,
        lineNumber: r + 1,
        text: i2[r],
        errorCharStart: -1,
        errorLength: -1
      };
      a2.lines.push(e3);
    }
    return n.push(a2), null;
  }, l = () => u(/^{\s*/), c = () => u(/^}/), u = (t2) => {
    const r2 = t2.exec(e2);
    if (!r2)
      return;
    const s2 = r2[0];
    return o(s2), e2 = e2.slice(s2.length), r2;
  }, d = () => {
    let t2;
    const r2 = [];
    for (m(), h(r2); e2.length && "}" !== e2.charAt(0) && (t2 = T() || w()); )
      r2.push(t2), h(r2);
    return r2;
  }, m = () => u(/^\s*/), h = (e3) => {
    let t2;
    for (e3 = e3 || []; t2 = p(); )
      e3.push(t2);
    return e3;
  }, p = () => {
    const t2 = i();
    if ("/" !== e2.charAt(0) || "*" !== e2.charAt(1))
      return null;
    let r2 = 2;
    for (; "" !== e2.charAt(r2) && ("*" !== e2.charAt(r2) || "/" !== e2.charAt(r2 + 1)); )
      ++r2;
    if (r2 += 2, "" === e2.charAt(r2 - 1))
      return a("End of comment missing");
    const n2 = e2.slice(2, r2 - 2);
    return s += 2, o(n2), e2 = e2.slice(r2), s += 2, t2({
      type: 1,
      comment: n2
    });
  }, f = () => {
    const e3 = u(/^([^{]+)/);
    return e3 ? trim(e3[0]).replace(/\/\*([^*]|[\r\n]|(\*+([^*/]|[\r\n])))*\*\/+/g, "").replace(/"(?:\\"|[^"])*"|'(?:\\'|[^'])*'/g, function(e4) {
      return e4.replace(/,/g, "\u200C");
    }).split(/\s*(?![^(]*\)),\s*/).map(function(e4) {
      return e4.replace(/\u200C/g, ",");
    }) : null;
  }, g = () => {
    const e3 = i();
    let t2 = u(/^(\*?[-#\/\*\\\w]+(\[[0-9a-z_-]+\])?)\s*/);
    if (!t2)
      return null;
    if (t2 = trim(t2[0]), !u(/^:\s*/))
      return a("property missing ':'");
    const r2 = u(/^((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^\)]*?\)|[^};])+)/), s2 = e3({
      type: 4,
      property: t2.replace(commentre, ""),
      value: r2 ? trim(r2[0]).replace(commentre, "") : ""
    });
    return u(/^[;\s]*/), s2;
  }, y = () => {
    const e3 = [];
    if (!l())
      return a("missing '{'");
    let t2;
    for (h(e3); t2 = g(); )
      e3.push(t2), h(e3);
    return c() ? e3 : a("missing '}'");
  }, C = () => {
    let e3;
    const t2 = [], r2 = i();
    for (; e3 = u(/^((\d+\.\d+|\.\d+|\d+)%?|[a-z]+)\s*/); )
      t2.push(e3[1]), u(/^,\s*/);
    return t2.length ? r2({
      type: 9,
      values: t2,
      declarations: y()
    }) : null;
  }, S = (e3, t2) => {
    const r2 = new RegExp("^@" + e3 + "\\s*([^;]+);");
    return () => {
      const s2 = i(), n2 = u(r2);
      if (!n2)
        return null;
      const o2 = {
        type: t2
      };
      return o2[e3] = n2[1].trim(), s2(o2);
    };
  }, E = S("import", 7), b = S("charset", 0), v = S("namespace", 11), T = () => "@" !== e2[0] ? null : (() => {
    const e3 = i();
    let t2 = u(/^@([-\w]+)?keyframes\s*/);
    if (!t2)
      return null;
    const r2 = t2[1];
    if (t2 = u(/^([-\w]+)\s*/), !t2)
      return a("@keyframes missing name");
    const s2 = t2[1];
    if (!l())
      return a("@keyframes missing '{'");
    let n2, o2 = h();
    for (; n2 = C(); )
      o2.push(n2), o2 = o2.concat(h());
    return c() ? e3({
      type: 8,
      name: s2,
      vendor: r2,
      keyframes: o2
    }) : a("@keyframes missing '}'");
  })() || (() => {
    const e3 = i(), t2 = u(/^@media *([^{]+)/);
    if (!t2)
      return null;
    const r2 = trim(t2[1]);
    if (!l())
      return a("@media missing '{'");
    const s2 = h().concat(d());
    return c() ? e3({
      type: 10,
      media: r2,
      rules: s2
    }) : a("@media missing '}'");
  })() || (() => {
    const e3 = i(), t2 = u(/^@custom-media\s+(--[^\s]+)\s*([^{;]+);/);
    return t2 ? e3({
      type: 2,
      name: trim(t2[1]),
      media: trim(t2[2])
    }) : null;
  })() || (() => {
    const e3 = i(), t2 = u(/^@supports *([^{]+)/);
    if (!t2)
      return null;
    const r2 = trim(t2[1]);
    if (!l())
      return a("@supports missing '{'");
    const s2 = h().concat(d());
    return c() ? e3({
      type: 15,
      supports: r2,
      rules: s2
    }) : a("@supports missing '}'");
  })() || E() || b() || v() || (() => {
    const e3 = i(), t2 = u(/^@([-\w]+)?document *([^{]+)/);
    if (!t2)
      return null;
    const r2 = trim(t2[1]), s2 = trim(t2[2]);
    if (!l())
      return a("@document missing '{'");
    const n2 = h().concat(d());
    return c() ? e3({
      type: 3,
      document: s2,
      vendor: r2,
      rules: n2
    }) : a("@document missing '}'");
  })() || (() => {
    const e3 = i();
    if (!u(/^@page */))
      return null;
    const t2 = f() || [];
    if (!l())
      return a("@page missing '{'");
    let r2, s2 = h();
    for (; r2 = g(); )
      s2.push(r2), s2 = s2.concat(h());
    return c() ? e3({
      type: 12,
      selectors: t2,
      declarations: s2
    }) : a("@page missing '}'");
  })() || (() => {
    const e3 = i();
    if (!u(/^@host\s*/))
      return null;
    if (!l())
      return a("@host missing '{'");
    const t2 = h().concat(d());
    return c() ? e3({
      type: 6,
      rules: t2
    }) : a("@host missing '}'");
  })() || (() => {
    const e3 = i();
    if (!u(/^@font-face\s*/))
      return null;
    if (!l())
      return a("@font-face missing '{'");
    let t2, r2 = h();
    for (; t2 = g(); )
      r2.push(t2), r2 = r2.concat(h());
    return c() ? e3({
      type: 5,
      declarations: r2
    }) : a("@font-face missing '}'");
  })(), w = () => {
    const e3 = i(), t2 = f();
    return t2 ? (h(), e3({
      type: 13,
      selectors: t2,
      declarations: y()
    })) : a("selector missing");
  };
  class A {
    constructor(e3) {
      this.start = e3, this.end = {
        line: r,
        column: s
      }, this.source = t;
    }
  }
  return A.prototype.content = e2, {
    diagnostics: n,
    ...addParent((() => {
      const e3 = d();
      return {
        type: 14,
        stylesheet: {
          source: t,
          rules: e3
        }
      };
    })())
  };
}, trim = (e2) => e2 ? e2.trim() : "", addParent = (e2, t) => {
  const r = e2 && "string" == typeof e2.type, s = r ? e2 : t;
  for (const t2 in e2) {
    const r2 = e2[t2];
    Array.isArray(r2) ? r2.forEach(function(e3) {
      addParent(e3, s);
    }) : r2 && "object" == typeof r2 && addParent(r2, s);
  }
  return r && Object.defineProperty(e2, "parent", {
    configurable: true,
    writable: true,
    enumerable: false,
    value: t || null
  }), e2;
}, commentre = /\/\*[^*]*\*+([^/*][^*]*\*+)*\//g, getCssSelectors = (e2) => {
  SELECTORS.all.length = SELECTORS.tags.length = SELECTORS.classNames.length = SELECTORS.ids.length = SELECTORS.attrs.length = 0;
  const t = (e2 = e2.replace(/\./g, " .").replace(/\#/g, " #").replace(/\[/g, " [").replace(/\>/g, " > ").replace(/\+/g, " + ").replace(/\~/g, " ~ ").replace(/\*/g, " * ").replace(/\:not\((.*?)\)/g, " ")).split(" ");
  for (let e3 = 0, r = t.length; e3 < r; e3++)
    t[e3] = t[e3].split(":")[0], 0 !== t[e3].length && ("." === t[e3].charAt(0) ? SELECTORS.classNames.push(t[e3].slice(1)) : "#" === t[e3].charAt(0) ? SELECTORS.ids.push(t[e3].slice(1)) : "[" === t[e3].charAt(0) ? (t[e3] = t[e3].slice(1).split("=")[0].split("]")[0].trim(), SELECTORS.attrs.push(t[e3].toLowerCase())) : /[a-z]/g.test(t[e3].charAt(0)) && SELECTORS.tags.push(t[e3].toLowerCase()));
  return SELECTORS.classNames = SELECTORS.classNames.sort((e3, t2) => e3.length < t2.length ? -1 : e3.length > t2.length ? 1 : 0), SELECTORS;
}, SELECTORS = {
  all: [],
  tags: [],
  classNames: [],
  ids: [],
  attrs: []
}, serializeCssVisitNode = (e2, t, r, s) => {
  var n;
  const o = t.type;
  return 4 === o ? serializeCssDeclaration(t, r, s) : 13 === o ? serializeCssRule(e2, t) : 1 === o ? "!" === (null === (n = t.comment) || void 0 === n ? void 0 : n[0]) ? `/*${t.comment}*/` : "" : 10 === o ? serializeCssMedia(e2, t) : 8 === o ? serializeCssKeyframes(e2, t) : 9 === o ? serializeCssKeyframe(e2, t) : 5 === o ? serializeCssFontFace(e2, t) : 15 === o ? serializeCssSupports(e2, t) : 7 === o ? "@import " + t.import + ";" : 0 === o ? "@charset " + t.charset + ";" : 12 === o ? serializeCssPage(e2, t) : 6 === o ? "@host{" + serializeCssMapVisit(e2, t.rules) + "}" : 2 === o ? "@custom-media " + t.name + " " + t.media + ";" : 3 === o ? serializeCssDocument(e2, t) : 11 === o ? "@namespace " + t.namespace + ";" : "";
}, serializeCssRule = (e2, t) => {
  var r, s;
  const n = t.declarations, o = e2.usedSelectors, i = null !== (s = null === (r = t.selectors) || void 0 === r ? void 0 : r.slice()) && void 0 !== s ? s : [];
  if (null == n || 0 === n.length)
    return "";
  if (o) {
    let t2, r2, s2 = true;
    for (t2 = i.length - 1; t2 >= 0; t2--) {
      const n2 = getCssSelectors(i[t2]);
      s2 = true;
      let a2 = n2.classNames.length;
      if (a2 > 0 && e2.hasUsedClassNames) {
        for (r2 = 0; r2 < a2; r2++)
          if (!o.classNames.has(n2.classNames[r2])) {
            s2 = false;
            break;
          }
      }
      if (s2 && e2.hasUsedTags && (a2 = n2.tags.length, a2 > 0)) {
        for (r2 = 0; r2 < a2; r2++)
          if (!o.tags.has(n2.tags[r2])) {
            s2 = false;
            break;
          }
      }
      if (s2 && e2.hasUsedAttrs && (a2 = n2.attrs.length, a2 > 0)) {
        for (r2 = 0; r2 < a2; r2++)
          if (!o.attrs.has(n2.attrs[r2])) {
            s2 = false;
            break;
          }
      }
      if (s2 && e2.hasUsedIds && (a2 = n2.ids.length, a2 > 0)) {
        for (r2 = 0; r2 < a2; r2++)
          if (!o.ids.has(n2.ids[r2])) {
            s2 = false;
            break;
          }
      }
      s2 || i.splice(t2, 1);
    }
  }
  if (0 === i.length)
    return "";
  const a = [];
  let l = "";
  if (t.selectors)
    for (const e3 of t.selectors)
      l = removeSelectorWhitespace(e3), a.includes(l) || a.push(l);
  return `${a}{${serializeCssMapVisit(e2, n)}}`;
}, serializeCssDeclaration = (e2, t, r) => "" === e2.value ? "" : r - 1 === t ? e2.property + ":" + e2.value : e2.property + ":" + e2.value + ";", serializeCssMedia = (e2, t) => {
  const r = serializeCssMapVisit(e2, t.rules);
  return "" === r ? "" : "@media " + removeMediaWhitespace(t.media) + "{" + r + "}";
}, serializeCssKeyframes = (e2, t) => {
  const r = serializeCssMapVisit(e2, t.keyframes);
  return "" === r ? "" : "@" + (t.vendor || "") + "keyframes " + t.name + "{" + r + "}";
}, serializeCssKeyframe = (e2, t) => {
  var r, s;
  return (null !== (s = null === (r = t.values) || void 0 === r ? void 0 : r.join(",")) && void 0 !== s ? s : "") + "{" + serializeCssMapVisit(e2, t.declarations) + "}";
}, serializeCssFontFace = (e2, t) => {
  const r = serializeCssMapVisit(e2, t.declarations);
  return "" === r ? "" : "@font-face{" + r + "}";
}, serializeCssSupports = (e2, t) => {
  const r = serializeCssMapVisit(e2, t.rules);
  return "" === r ? "" : "@supports " + t.supports + "{" + r + "}";
}, serializeCssPage = (e2, t) => {
  var r, s;
  return "@page " + (null !== (s = null === (r = t.selectors) || void 0 === r ? void 0 : r.join(", ")) && void 0 !== s ? s : "") + "{" + serializeCssMapVisit(e2, t.declarations) + "}";
}, serializeCssDocument = (e2, t) => {
  const r = serializeCssMapVisit(e2, t.rules), s = "@" + (t.vendor || "") + "document " + t.document;
  return "" === r ? "" : s + "{" + r + "}";
}, serializeCssMapVisit = (e2, t) => {
  let r = "";
  if (t)
    for (let s = 0, n = t.length; s < n; s++)
      r += serializeCssVisitNode(e2, t[s], s, n);
  return r;
}, removeSelectorWhitespace = (e2) => {
  let t = "", r = "", s = false;
  for (let n = 0, o = (e2 = e2.trim()).length; n < o; n++)
    if (r = e2[n], "[" === r && "\\" !== t[t.length - 1] ? s = true : "]" === r && "\\" !== t[t.length - 1] && (s = false), !s && CSS_WS_REG.test(r)) {
      if (CSS_NEXT_CHAR_REG.test(e2[n + 1]))
        continue;
      if (CSS_PREV_CHAR_REG.test(t[t.length - 1]))
        continue;
      t += " ";
    } else
      t += r;
  return t;
}, removeMediaWhitespace = (e2) => {
  var t;
  let r = "", s = "";
  for (let n = 0, o = (e2 = null !== (t = null == e2 ? void 0 : e2.trim()) && void 0 !== t ? t : "").length; n < o; n++)
    if (s = e2[n], CSS_WS_REG.test(s)) {
      if (CSS_WS_REG.test(r[r.length - 1]))
        continue;
      r += " ";
    } else
      r += s;
  return r;
}, CSS_WS_REG = /\s/, CSS_NEXT_CHAR_REG = /[>\(\)\~\,\+\s]/, CSS_PREV_CHAR_REG = /[>\(\~\,\+]/, collectUsedSelectors = (e2, t) => {
  if (null != t && 1 === t.nodeType) {
    const r = t.children, s = t.nodeName.toLowerCase();
    e2.tags.add(s);
    const n = t.attributes;
    for (let r2 = 0, s2 = n.length; r2 < s2; r2++) {
      const s3 = n.item(r2), o = s3.name.toLowerCase();
      if (e2.attrs.add(o), "class" === o) {
        const r3 = t.classList;
        for (let t2 = 0, s4 = r3.length; t2 < s4; t2++)
          e2.classNames.add(r3.item(t2));
      } else
        "id" === o && e2.ids.add(s3.value);
    }
    if (r)
      for (let t2 = 0, s2 = r.length; t2 < s2; t2++)
        collectUsedSelectors(e2, r[t2]);
  }
}, removeUnusedStyles = (e2, t) => {
  try {
    const r = e2.head.querySelectorAll("style[data-styles]"), s = r.length;
    if (s > 0) {
      const n = ((e3) => {
        const t2 = {
          attrs: /* @__PURE__ */ new Set(),
          classNames: /* @__PURE__ */ new Set(),
          ids: /* @__PURE__ */ new Set(),
          tags: /* @__PURE__ */ new Set()
        };
        return collectUsedSelectors(t2, e3), t2;
      })(e2.documentElement);
      for (let e3 = 0; e3 < s; e3++)
        removeUnusedStyleText(n, t, r[e3]);
    }
  } catch (e3) {
    ((e4, t2, r) => {
      const s = {
        level: "error",
        type: "build",
        header: "Build Error",
        messageText: "build error",
        lines: []
      };
      null != t2 && (null != t2.stack ? s.messageText = t2.stack.toString() : null != t2.message ? s.messageText = t2.message.length ? t2.message : "UNKNOWN ERROR" : s.messageText = t2.toString()), null == e4 || /* @__PURE__ */ ((e5) => e5 === TASK_CANCELED_MSG)(s.messageText) || e4.push(s);
    })(t, e3);
  }
}, removeUnusedStyleText = (e2, t, r) => {
  try {
    const s = parseCss(r.innerHTML);
    if (t.push(...s.diagnostics), hasError(t))
      return;
    try {
      r.innerHTML = ((e3, t2) => {
        const r2 = t2.usedSelectors || null, s2 = {
          usedSelectors: r2 || null,
          hasUsedAttrs: !!r2 && r2.attrs.size > 0,
          hasUsedClassNames: !!r2 && r2.classNames.size > 0,
          hasUsedIds: !!r2 && r2.ids.size > 0,
          hasUsedTags: !!r2 && r2.tags.size > 0
        }, n = e3.rules;
        if (!n)
          return "";
        const o = n.length, i = [];
        for (let e4 = 0; e4 < o; e4++)
          i.push(serializeCssVisitNode(s2, n[e4], e4, o));
        return i.join("");
      })(s.stylesheet, {
        usedSelectors: e2
      });
    } catch (e3) {
      t.push({
        level: "warn",
        type: "css",
        header: "CSS Stringify",
        messageText: e3,
        lines: []
      });
    }
  } catch (e3) {
    t.push({
      level: "warn",
      type: "css",
      header: "CSS Parse",
      messageText: e3,
      lines: []
    });
  }
}, SKIP_ATTRS = /* @__PURE__ */ new Set(["s-id", "c-id"]), createHydrateBuildId = () => {
  let e2 = "abcdefghijklmnopqrstuvwxyz", t = "";
  for (; t.length < 8; )
    t += e2[Math.floor(Math.random() * e2.length)], 1 === t.length && (e2 += "0123456789");
  return t;
};
exports.createWindowFromHtml = createWindowFromHtml;
exports.hydrateDocument = hydrateDocument;
exports.renderToString = renderToString;
exports.serializeDocumentToString = serializeDocumentToString;
